<?php
/*
 * Copyright (C) 2006 Tobias Toedter <t.toedter@gmx.net>
 *
 * This file is part of the Drupal Weather module.
 *
 * Weather is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Weather is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Weather; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */



function _weather_get_countries() {
  $icao_codes = _weather_setup_icao_codes();
  $result = array_keys($icao_codes);
  array_unshift($result, t('- None -'));
  return $result;
}



function _weather_get_places($country) {
  $icao_codes = _weather_setup_icao_codes();
  $result = array('- none -' => t('- None -'));
  foreach ($icao_codes[$country] as $icao => $info) {
    $result[$icao] = $info['name'];
  }
  return $result;
}



function _weather_get_country_from_icao($wanted_icao) {
  $icao_codes = _weather_setup_icao_codes();
  $wanted_icao = strtoupper($wanted_icao);
  foreach ($icao_codes as $country => $data) {
    foreach ($data as $icao => $info) {
      if ($icao == $wanted_icao) {
        return $country;
      }
    }
  }
}



function _weather_get_lat_long($wanted_icao) {
  $icao_codes = _weather_setup_icao_codes();
  foreach ($icao_codes as $country => $data) {
    foreach ($data as $icao => $info) {
      if ($icao == $wanted_icao) {
        return $info;
      }
    }
  }
}



function _weather_setup_icao_codes() {
  $icao_codes['Afghanistan'] = array(
    'OAHR' => array('name' => 'Herat', 'lat' => 34.216667, 'long' => 62.216667),
    'OAKB' => array('name' => 'Kabul Airport', 'lat' => 34.633333, 'long' => 69.200000),
  );

  $icao_codes['Albania'] = array(
    'LATI' => array('name' => 'Tirana', 'lat' => 41.333333, 'long' => 19.783333),
  );

  $icao_codes['Algeria'] = array(
    'DAUA' => array('name' => 'Adrar', 'lat' => 27.883333, 'long' => -0.283333),
    'DABB' => array('name' => 'Annaba', 'lat' => 36.833333, 'long' => 7.816667),
    'DABT' => array('name' => 'Batna', 'lat' => 35.550000, 'long' => 6.183333),
    'DAOR' => array('name' => 'Bechar', 'lat' => 31.616667, 'long' => -2.233333),
    'DAAE' => array('name' => 'Bejaia', 'lat' => 36.716667, 'long' => 5.066667),
    'DAUB' => array('name' => 'Biskra', 'lat' => 34.800000, 'long' => 5.733333),
    'DAAD' => array('name' => 'Bou-Saada', 'lat' => 35.333333, 'long' => 4.200000),
    'DABC' => array('name' => 'Constantine', 'lat' => 36.283333, 'long' => 6.616667),
    'DAAG' => array('name' => 'Dar-El-Beida', 'lat' => 36.716667, 'long' => 3.250000),
    'DAAJ' => array('name' => 'Djanet', 'lat' => 24.550000, 'long' => 9.466667),
    'DAUE' => array('name' => 'El Golea', 'lat' => 30.566667, 'long' => 2.866667),
    'DAUO' => array('name' => 'El Oued', 'lat' => 33.500000, 'long' => 6.116667),
    'DAUG' => array('name' => 'Ghardaia', 'lat' => 32.383333, 'long' => 3.816667),
    'DAUH' => array('name' => 'Hassi-Messaoud', 'lat' => 31.666667, 'long' => 6.150000),
    'DAAP' => array('name' => 'Illizi', 'lat' => 26.500000, 'long' => 8.416667),
    'DAUZ' => array('name' => 'In Amenas', 'lat' => 28.050000, 'long' => 9.633333),
    'DAUI' => array('name' => 'In Salah North', 'lat' => 27.250000, 'long' => 2.516667),
    'DAAV' => array('name' => 'Jijel Achouat', 'lat' => 36.883333, 'long' => 5.816667),
    'DAUL' => array('name' => 'Laghouat', 'lat' => 33.766667, 'long' => 2.933333),
    'DAOV' => array('name' => 'Mascara-Ghriss', 'lat' => 35.200000, 'long' => 0.133333),
    'DAAY' => array('name' => 'Mecheria', 'lat' => 34.933333, 'long' => -0.433333),
    'DAOO' => array('name' => 'Oran / Es Senia', 'lat' => 35.633333, 'long' => -0.600000),
    'DAOL' => array('name' => 'Oran/Tafaraoui', 'lat' => 35.542500, 'long' => -0.532222),
    'DAUU' => array('name' => 'Ouargla', 'lat' => 31.916667, 'long' => 5.400000),
    'DAAS' => array('name' => 'Setif', 'lat' => 36.183333, 'long' => 5.416667),
    'DAAT' => array('name' => 'Tamanrasset / Aguenna', 'lat' => 22.816667, 'long' => 5.466667),
    'DABS' => array('name' => 'Tebessa', 'lat' => 35.483333, 'long' => 8.133333),
    'DAOB' => array('name' => 'Tiaret', 'lat' => 35.250000, 'long' => 1.433333),
    'DAFH' => array('name' => 'Tilrempt/Hassi R\'mel', 'lat' => 32.930000, 'long' => 3.312222),
    'DAUT' => array('name' => 'Timimoun', 'lat' => 29.250000, 'long' => 0.283333),
    'DAOF' => array('name' => 'Tindouf', 'lat' => 27.666667, 'long' => -8.133333),
    'DAON' => array('name' => 'Tlemcen Zenata', 'lat' => 35.016667, 'long' => -1.466667),
    'DAUK' => array('name' => 'Touggourt', 'lat' => 33.116667, 'long' => 6.133333),
  );

  $icao_codes['Angola'] = array(
    'FNHU' => array('name' => 'Huambo Nova Lisboa', 'lat' => -12.800000, 'long' => 15.750000),
    'FNLU' => array('name' => 'Luanda', 'lat' => -8.850000, 'long' => 13.233333),
    'FNBG' => array('name' => 'Monbaca Benguela', 'lat' => -12.583333, 'long' => 13.416667),
  );

  $icao_codes['Anguilla'] = array(
    'TQPF' => array('name' => 'Wallblake', 'lat' => 18.204722, 'long' => -63.055000),
  );

  $icao_codes['Antarctica'] = array(
    'NZSP' => array('name' => 'Amundsen-Scott South Pole Station', 'lat' => -90.000000, 'long' => 0.000000),
  );

  $icao_codes['Antigua and Barbuda'] = array(
    'TKPN' => array('name' => 'Charlestown / Newcast', 'lat' => 17.200000, 'long' => -62.583333),
    'TAPA' => array('name' => 'Vc Bird International Airport Antigua', 'lat' => 17.116667, 'long' => -61.783333),
  );

  $icao_codes['Argentina'] = array(
    'SABE' => array('name' => 'Aeroparque Bs. As. Aerodrome', 'lat' => -34.566667, 'long' => -58.416667),
    'SAZS' => array('name' => 'Bariloche Aerodrome', 'lat' => -41.150000, 'long' => -71.166667),
    'SAVC' => array('name' => 'Comodoro Rivadavia Aerodrome', 'lat' => -45.783333, 'long' => -67.500000),
    'SAAC' => array('name' => 'Concordia Aerodrome', 'lat' => -31.300000, 'long' => -58.016667),
    'SACO' => array('name' => 'Cordoba Aerodrome', 'lat' => -31.316667, 'long' => -64.216667),
    'SARC' => array('name' => 'Corrientes Aero.', 'lat' => -27.450000, 'long' => -58.766667),
    'SAEZ' => array('name' => 'Ezeiza Aerodrome', 'lat' => -34.816667, 'long' => -58.533333),
    'SARF' => array('name' => 'Formosa Aerodrome', 'lat' => -26.200000, 'long' => -58.233333),
    'SARI' => array('name' => 'Iguazu Aerodrome', 'lat' => -25.733333, 'long' => -54.466667),
    'SASJ' => array('name' => 'Jujuy Aerodrome', 'lat' => -24.383333, 'long' => -65.083333),
    'SAZM' => array('name' => 'Mar Del Plata Aerodrome', 'lat' => -37.933333, 'long' => -57.583333),
    'SAME' => array('name' => 'Mendoza Aerodrome', 'lat' => -32.833333, 'long' => -68.783333),
    'SARL' => array('name' => 'Paso De Los Libres Aerodrome', 'lat' => -29.683333, 'long' => -57.150000),
    'SARP' => array('name' => 'Posadas Aero.', 'lat' => -27.366667, 'long' => -55.966667),
    'SATR' => array('name' => 'Reconquista, SF', 'lat' => -29.210278, 'long' => -59.690833),
    'SARE' => array('name' => 'Resistencia Aero.', 'lat' => -27.450000, 'long' => -59.050000),
    'SAWG' => array('name' => 'Rio Gallegos Aerodrome', 'lat' => -51.616667, 'long' => -69.283333),
    'SAWE' => array('name' => 'Rio Grande B. A.', 'lat' => -53.800000, 'long' => -67.750000),
    'SAAR' => array('name' => 'Rosario Aerodrome', 'lat' => -32.916667, 'long' => -60.783333),
    'SASA' => array('name' => 'Salta Aerodrome', 'lat' => -24.850000, 'long' => -65.483333),
    'SAST' => array('name' => 'Tartagal Aerodrome', 'lat' => -22.650000, 'long' => -63.816667),
    'SAVT' => array('name' => 'Trelew Aerodrome', 'lat' => -43.200000, 'long' => -65.266667),
    'SANT' => array('name' => 'Tucuman Aerodrome', 'lat' => -26.850000, 'long' => -65.100000),
    'SAWH' => array('name' => 'Ushuaia Aerodrome', 'lat' => -54.800000, 'long' => -68.316667),
  );

  $icao_codes['Aruba'] = array(
    'TNCA' => array('name' => 'Queen Beatrix Airport', 'lat' => 12.500000, 'long' => -70.016667),
  );

  $icao_codes['Australia'] = array(
    'YPAD' => array('name' => 'Adelaide Airport', 'lat' => -34.933333, 'long' => 138.516667),
    'YBAS' => array('name' => 'Alice Springs Aerodrome', 'lat' => -23.800000, 'long' => 133.883333),
    'YMAV' => array('name' => 'Avalon, Avalon Airport', 'lat' => -38.033333, 'long' => 144.483333),
    'YAYE' => array('name' => 'Ayers Rock', 'lat' => -25.183333, 'long' => 130.966667),
    'YPPH' => array('name' => 'Belmont Perth Airport', 'lat' => -31.933333, 'long' => 115.950000),
    'YBBN' => array('name' => 'Brisbane Airport M. O', 'lat' => -27.383333, 'long' => 153.100000),
    'YBRM' => array('name' => 'Broome Airport', 'lat' => -17.950000, 'long' => 122.216667),
    'YPEA' => array('name' => 'Bullsbrook Pearce Amo', 'lat' => -31.666667, 'long' => 116.016667),
    'YBCS' => array('name' => 'Cairns Airport', 'lat' => -16.883333, 'long' => 145.750000),
    'YSCB' => array('name' => 'Canberra', 'lat' => -35.300000, 'long' => 149.183333),
    'YBCG' => array('name' => 'Coolangatta Airport Aws', 'lat' => -28.166667, 'long' => 153.500000),
    'YPDN' => array('name' => 'Darwin Airport', 'lat' => -12.400000, 'long' => 130.866667),
    'YSDU' => array('name' => 'Dubbo', 'lat' => -32.200000, 'long' => 148.566667),
    'YMHB' => array('name' => 'Hobart Airport', 'lat' => -42.833333, 'long' => 147.483333),
    'YPKG' => array('name' => 'Kalgoorlie Boulder Amo', 'lat' => -30.783333, 'long' => 121.450000),
    'YPKU' => array('name' => 'Kununurra Kununurra Aws', 'lat' => -15.766667, 'long' => 128.700000),
    'YMLT' => array('name' => 'Launceston Airport', 'lat' => -41.533333, 'long' => 147.200000),
    'YPLM' => array('name' => 'Learmonth Airport', 'lat' => -22.233333, 'long' => 114.083333),
    'YBMA' => array('name' => 'Mount Isa Amo', 'lat' => -20.666667, 'long' => 139.466667),
    'YSNF' => array('name' => 'Norfolk Island Airport', 'lat' => -29.033333, 'long' => 167.933333),
    'YPPD' => array('name' => 'Port Hedland Pardoo', 'lat' => -20.100000, 'long' => 119.566667),
    'YSRI' => array('name' => 'Richmond Aus-Afb', 'lat' => -33.600000, 'long' => 150.783333),
    'YBRK' => array('name' => 'Rockhampton Airport', 'lat' => -23.383333, 'long' => 150.466667),
    'YSSY' => array('name' => 'Sydney Airport', 'lat' => -33.950000, 'long' => 151.183333),
    'YSTW' => array('name' => 'Tamworth Airport', 'lat' => -31.083333, 'long' => 150.833333),
    'YPTN' => array('name' => 'Tindal / Katherine', 'lat' => -14.433333, 'long' => 132.266667),
    'YBTL' => array('name' => 'Townsville Amo', 'lat' => -19.250000, 'long' => 146.750000),
    'YSWG' => array('name' => 'Wagga Airport', 'lat' => -35.150000, 'long' => 147.450000),
  );

  $icao_codes['Austria'] = array(
    'LOXA' => array('name' => 'Aigen Im Ennstal', 'lat' => 47.533333, 'long' => 14.133333),
    'LOWG' => array('name' => 'Graz-Thalerhof-Flughafen', 'lat' => 47.000000, 'long' => 15.433333),
    'LOIH' => array('name' => 'Hohenems-Dornbirn', 'lat' => 47.384722, 'long' => 9.700556),
    'LOWI' => array('name' => 'Innsbruck-Flughafen', 'lat' => 47.266667, 'long' => 11.350000),
    'LOWK' => array('name' => 'Klagenfurt-Flughafen', 'lat' => 46.650000, 'long' => 14.333333),
    'LOAG' => array('name' => 'Krems-Langenlois', 'lat' => 48.446111, 'long' => 15.633611),
    'LOWL' => array('name' => 'Linz / Hoersching-Flughafen', 'lat' => 48.233333, 'long' => 14.183333),
    'LOAV' => array('name' => 'Niederosterreich / Flugplatz Voslau', 'lat' => 47.964444, 'long' => 16.259444),
    'LOAN' => array('name' => 'Niederosterreich / Wiener Neustadt-Ost Flugplatz', 'lat' => 47.843333, 'long' => 16.258056),
    'LOLF' => array('name' => 'Oberosterreich / Freistadt Flugplatz', 'lat' => 48.514722, 'long' => 14.408889),
    'LOGG' => array('name' => 'Punitz-Gussing', 'lat' => 47.147500, 'long' => 16.317778),
    'LOWS' => array('name' => 'Salzburg-Flughafen', 'lat' => 47.800000, 'long' => 13.000000),
    'LOXT' => array('name' => 'Tulln', 'lat' => 48.316667, 'long' => 16.116667),
    'LOWW' => array('name' => 'Wien / Schwechat-Flughafen', 'lat' => 48.116667, 'long' => 16.566667),
    'LOWZ' => array('name' => 'Zell Am See', 'lat' => 47.292500, 'long' => 12.787500),
    'LOXZ' => array('name' => 'Zeltweg', 'lat' => 47.200000, 'long' => 14.750000),
  );

  $icao_codes['Azerbaijan'] = array(
    'UBBB' => array('name' => 'Baku / Bine Airport', 'lat' => 40.450000, 'long' => 50.066667),
    'UBBG' => array('name' => 'Gyanca Airport', 'lat' => 40.733333, 'long' => 46.400000),
  );

  $icao_codes['Bahamas, The'] = array(
    'MYGF' => array('name' => 'Freeport, Grand Bahama', 'lat' => 26.550000, 'long' => -78.700000),
    'MYEG' => array('name' => 'Georgetown, Exuma', 'lat' => 23.475000, 'long' => -75.766667),
    'MYNN' => array('name' => 'Nassau Airport', 'lat' => 25.050000, 'long' => -77.466667),
  );

  $icao_codes['Bahrain'] = array(
    'OBBI' => array('name' => 'Bahrain International Airport', 'lat' => 26.266667, 'long' => 50.650000),
  );

  $icao_codes['Barbados'] = array(
    'TBPB' => array('name' => 'Grantley Adams', 'lat' => 13.066667, 'long' => -59.483333),
  );

  $icao_codes['Belarus'] = array(
    'UMBB' => array('name' => 'Brest', 'lat' => 52.108333, 'long' => 23.896667),
    'UMGG' => array('name' => 'Gomel\'', 'lat' => 52.526667, 'long' => 31.018333),
    'UMMG' => array('name' => 'Grodno', 'lat' => 53.601667, 'long' => 24.055000),
    'UMMM' => array('name' => 'Loshitsa / Minsk International 1', 'lat' => 53.865000, 'long' => 27.541667),
    'UMMS' => array('name' => 'Minsk', 'lat' => 53.933333, 'long' => 27.633333),
    'UMII' => array('name' => 'Vitebsk', 'lat' => 55.166667, 'long' => 30.216667),
  );

  $icao_codes['Belgium'] = array(
    'EBAW' => array('name' => 'Antwerpen / Deurne', 'lat' => 51.200000, 'long' => 4.466667),
    'EBLG' => array('name' => 'Bierset', 'lat' => 50.650000, 'long' => 5.450000),
    'EBBR' => array('name' => 'Bruxelles National', 'lat' => 50.900000, 'long' => 4.533333),
    'EBCI' => array('name' => 'Charleroi / Gosselies', 'lat' => 50.466667, 'long' => 4.450000),
    'EBLB' => array('name' => 'Elsenborn', 'lat' => 50.466667, 'long' => 6.183333),
    'EBOS' => array('name' => 'Oostende Airport', 'lat' => 51.200000, 'long' => 2.866667),
  );

  $icao_codes['Belize'] = array(
    'MZBZ' => array('name' => 'Belize / Phillip Goldston Intl. Airport', 'lat' => 17.533333, 'long' => -88.300000),
  );

  $icao_codes['Benin'] = array(
    'DBBB' => array('name' => 'Cotonou', 'lat' => 6.350000, 'long' => 2.383333),
  );

  $icao_codes['Bermuda'] = array(
    'TXKF' => array('name' => 'Bermuda', 'lat' => 32.366667, 'long' => -64.683333),
  );

  $icao_codes['Bolivia'] = array(
    'SLAS' => array('name' => 'Ascencion De Guarayos', 'lat' => -15.716667, 'long' => -63.100000),
    'SLCA' => array('name' => 'Camiri', 'lat' => -20.000000, 'long' => -63.533333),
    'SLCO' => array('name' => 'Cobija', 'lat' => -11.033333, 'long' => -68.783333),
    'SLCB' => array('name' => 'Cochabamba', 'lat' => -17.416667, 'long' => -66.183333),
    'SLCP' => array('name' => 'Concepcion', 'lat' => -16.150000, 'long' => -62.016667),
    'SLLP' => array('name' => 'La Paz / Alto', 'lat' => -16.516667, 'long' => -68.183333),
    'SLMG' => array('name' => 'Magdalena', 'lat' => -13.333333, 'long' => -64.116667),
    'SLOR' => array('name' => 'Oruro', 'lat' => -17.966667, 'long' => -67.066667),
    'SLPO' => array('name' => 'Potosi', 'lat' => -19.550000, 'long' => -65.733333),
    'SLPS' => array('name' => 'Puerto Suarez', 'lat' => -18.983333, 'long' => -57.816667),
    'SLRY' => array('name' => 'Reyes', 'lat' => -14.316667, 'long' => -67.383333),
    'SLRI' => array('name' => 'Riberalta', 'lat' => -11.000000, 'long' => -66.116667),
    'SLRB' => array('name' => 'Robore', 'lat' => -18.316667, 'long' => -59.766667),
    'SLRQ' => array('name' => 'Rurrenabaque', 'lat' => -14.466667, 'long' => -67.566667),
    'SLSI' => array('name' => 'San Ignacio De Velasco', 'lat' => -16.383333, 'long' => -60.966667),
    'SLJV' => array('name' => 'San Javier', 'lat' => -16.266667, 'long' => -62.466667),
    'SLJO' => array('name' => 'San Joaquin', 'lat' => -13.066667, 'long' => -64.816667),
    'SLJE' => array('name' => 'San Jose De Chiquitos', 'lat' => -17.800000, 'long' => -60.733333),
    'SLSA' => array('name' => 'Santa Ana', 'lat' => -13.766667, 'long' => -65.433333),
    'SLET' => array('name' => 'Santa Cruz / El Trompillo', 'lat' => -17.800000, 'long' => -63.183333),
    'SLSU' => array('name' => 'Sucre', 'lat' => -19.016667, 'long' => -65.300000),
    'SLTJ' => array('name' => 'Tarija', 'lat' => -21.550000, 'long' => -64.700000),
    'SLTR' => array('name' => 'Trinidad', 'lat' => -14.816667, 'long' => -64.916667),
    'SLVM' => array('name' => 'Villamontes', 'lat' => -21.250000, 'long' => -63.450000),
    'SLVR' => array('name' => 'Viru-Viru', 'lat' => -17.633333, 'long' => -63.133333),
    'SLYA' => array('name' => 'Yacuiba', 'lat' => -21.950000, 'long' => -63.650000),
  );

  $icao_codes['Bosnia and Herzegovina'] = array(
    'LQBK' => array('name' => 'Banja Luka', 'lat' => 44.783333, 'long' => 17.216667),
    'LQMO' => array('name' => 'Mostar', 'lat' => 43.350000, 'long' => 17.800000),
    'LQSA' => array('name' => 'Sarajevo', 'lat' => 43.816667, 'long' => 18.333333),
    'LQTZ' => array('name' => 'Tuzla', 'lat' => 44.550000, 'long' => 18.700000),
  );

  $icao_codes['Botswana'] = array(
    'FBFT' => array('name' => 'Francistown', 'lat' => -21.216667, 'long' => 27.500000),
    'FBGZ' => array('name' => 'Ghanzi', 'lat' => -21.700000, 'long' => 21.650000),
    'FBJW' => array('name' => 'Jwaneng', 'lat' => -24.600000, 'long' => 24.666667),
    'FBKE' => array('name' => 'Kasane', 'lat' => -17.816667, 'long' => 25.150000),
    'FBLT' => array('name' => 'Letlhakane', 'lat' => -21.416667, 'long' => 25.600000),
    'FBMN' => array('name' => 'Maun', 'lat' => -19.983333, 'long' => 23.416667),
    'FBSP' => array('name' => 'Selebi Phikwe', 'lat' => -22.055278, 'long' => 27.820278),
    'FBSK' => array('name' => 'Seretse Khama International Airport', 'lat' => -24.216667, 'long' => 25.916667),
    'FBSW' => array('name' => 'Shakawe', 'lat' => -18.366667, 'long' => 21.850000),
    'FBSN' => array('name' => 'Sua-Pan', 'lat' => -20.466667, 'long' => 25.983333),
    'FBTS' => array('name' => 'Tsabong', 'lat' => -26.050000, 'long' => 22.450000),
    'FBTE' => array('name' => 'Tshane', 'lat' => -24.016667, 'long' => 21.883333),
  );

  $icao_codes['Brazil'] = array(
    'SBBG' => array('name' => 'Bage Aeroporto', 'lat' => -31.350000, 'long' => -54.116667),
    'SBBE' => array('name' => 'Belem Aeroporto', 'lat' => -1.383333, 'long' => -48.483333),
    'SBCF' => array('name' => 'Belo Horizonte', 'lat' => -19.933333, 'long' => -43.933333),
    'SBBV' => array('name' => 'Boa Vista, Boa Vista Intl', 'lat' => 2.833333, 'long' => -60.700000),
    'SBBR' => array('name' => 'Brasilia Aeroporto', 'lat' => -15.866667, 'long' => -47.933333),
    'SBKP' => array('name' => 'Campinas Aeroporto', 'lat' => -23.000000, 'long' => -47.133333),
    'SBCG' => array('name' => 'Campo Grande Aeroporto', 'lat' => -20.466667, 'long' => -54.666667),
    'SBCJ' => array('name' => 'Carajas / Maraba', 'lat' => -6.116667, 'long' => -50.000000),
    'SBCR' => array('name' => 'Corumba', 'lat' => -19.083333, 'long' => -57.500000),
    'SBCZ' => array('name' => 'Cruzeiro Do Sul', 'lat' => -7.633333, 'long' => -72.666667),
    'SBCY' => array('name' => 'Cuiaba Aeroporto', 'lat' => -15.650000, 'long' => -56.100000),
    'SBCT' => array('name' => 'Curitiba Aeroporto', 'lat' => -25.516667, 'long' => -49.166667),
    'SBEG' => array('name' => 'Eduardo Gomes International', 'lat' => -3.033333, 'long' => -60.050000),
    'SBFN' => array('name' => 'Fernando De Noronha', 'lat' => -3.850000, 'long' => -32.416667),
    'SBFL' => array('name' => 'Florianopolis Aeroporto', 'lat' => -27.666667, 'long' => -48.550000),
    'SBFZ' => array('name' => 'Fortaleza / pinto Martins', 'lat' => -3.783333, 'long' => -38.533333),
    'SBFI' => array('name' => 'Foz Do Iguacu Aeroporto', 'lat' => -25.516667, 'long' => -54.583333),
    'SBGL' => array('name' => 'Galeao', 'lat' => -22.816667, 'long' => -43.250000),
    'SBGR' => array('name' => 'Guarulhos Civ / Mil', 'lat' => -23.433333, 'long' => -46.466667),
    'SBJP' => array('name' => 'Joao Pessoa', 'lat' => -7.100000, 'long' => -34.866667),
    'SBRP' => array('name' => 'Leite Lopes / Ribeir', 'lat' => -21.133333, 'long' => -47.783333),
    'SBLO' => array('name' => 'Londrina Aeroporto', 'lat' => -23.333333, 'long' => -51.133333),
    'SBMQ' => array('name' => 'Macapa', 'lat' => 0.033333, 'long' => -50.050000),
    'SBMO' => array('name' => 'Maceio Aeroporto', 'lat' => -9.516667, 'long' => -35.783333),
    'SBMA' => array('name' => 'Maraba', 'lat' => -5.350000, 'long' => -49.150000),
    'SBNT' => array('name' => 'Natal Aeroporto', 'lat' => -5.916667, 'long' => -35.250000),
    'SBPK' => array('name' => 'Pelotas', 'lat' => -31.866667, 'long' => -52.350000),
    'SBPP' => array('name' => 'Ponta Pora Intl', 'lat' => -22.550000, 'long' => -55.700000),
    'SBPA' => array('name' => 'Porto Alegre Aero-Porto', 'lat' => -30.000000, 'long' => -51.183333),
    'SBPV' => array('name' => 'Porto Velho Aeroporto', 'lat' => -8.766667, 'long' => -63.916667),
    'SBRF' => array('name' => 'Recife Aeroporto', 'lat' => -8.066667, 'long' => -34.850000),
    'SBRB' => array('name' => 'Rio Branco', 'lat' => -10.000000, 'long' => -67.800000),
    'SBRJ' => array('name' => 'Rio De Janeiro Aeroporto', 'lat' => -22.900000, 'long' => -43.166667),
    'SBSV' => array('name' => 'Salvador Aeroporto', 'lat' => -12.900000, 'long' => -38.333333),
    'SBSN' => array('name' => 'Santarem-Aeroporto', 'lat' => -2.433333, 'long' => -54.716667),
    'SBSJ' => array('name' => 'Sao Jose Dos Campo', 'lat' => -23.233333, 'long' => -45.866667),
    'SBSL' => array('name' => 'Sao Luiz Aeroporto', 'lat' => -2.600000, 'long' => -44.233333),
    'SBSP' => array('name' => 'Sao Paulo/Congonhas Aeroporto', 'lat' => -23.616667, 'long' => -46.650000),
    'SBTT' => array('name' => 'Tabatinga', 'lat' => -3.666667, 'long' => -69.666667),
    'SBTF' => array('name' => 'Tefe', 'lat' => -3.366667, 'long' => -64.683333),
    'SBTE' => array('name' => 'Teresina Aeroporto', 'lat' => -5.050000, 'long' => -42.816667),
    'SBUG' => array('name' => 'Uruguaiana Aeroporto', 'lat' => -29.783333, 'long' => -57.033333),
  );

  $icao_codes['British Indian Ocean Territory'] = array(
    'FJDG' => array('name' => 'Diego Garcia', 'lat' => -7.300000, 'long' => 72.400000),
  );

  $icao_codes['British Virgin Islands'] = array(
    'TUPJ' => array('name' => 'Beef Island, Tortola', 'lat' => 18.450000, 'long' => -64.533333),
    'TIST' => array('name' => 'Charlotte Amalie St. Thomas, Cyril E. King Airport', 'lat' => 18.333333, 'long' => -64.983333),
    'TISX' => array('name' => 'Christiansted, Henry E. Rohlsen Airport', 'lat' => 17.700000, 'long' => -64.800000),
  );

  $icao_codes['Brunei'] = array(
    'WBSB' => array('name' => 'Brunei Airport', 'lat' => 4.933333, 'long' => 114.933333),
  );

  $icao_codes['Bulgaria'] = array(
    'LBBG' => array('name' => 'Burgas', 'lat' => 42.483333, 'long' => 27.483333),
    'LBGO' => array('name' => 'Gorna Orechovista', 'lat' => 43.150000, 'long' => 25.600000),
    'LBPD' => array('name' => 'Plovdiv', 'lat' => 42.133333, 'long' => 24.750000),
    'LBSF' => array('name' => 'Sofia Observ.', 'lat' => 42.650000, 'long' => 23.383333),
    'LBWN' => array('name' => 'Varna', 'lat' => 43.200000, 'long' => 27.916667),
  );

  $icao_codes['Burkina Faso'] = array(
    'DFOO' => array('name' => 'Bobo-Dioulasso', 'lat' => 11.166667, 'long' => -4.316667),
    'DFFD' => array('name' => 'Ouagadougou', 'lat' => 12.350000, 'long' => -1.516667),
  );

  $icao_codes['Burundi'] = array(
    'HBBA' => array('name' => 'Bujumbura', 'lat' => -3.316667, 'long' => 29.316667),
  );

  $icao_codes['Cambodia'] = array(
    'VDPP' => array('name' => 'Phnom-Penh / Pochentong', 'lat' => 11.550000, 'long' => 104.850000),
    'VDSR' => array('name' => 'Siemreap', 'lat' => 13.366667, 'long' => 103.850000),
  );

  $icao_codes['Cameroon'] = array(
    'FKKD' => array('name' => 'Douala Obs.', 'lat' => 4.000000, 'long' => 9.733333),
    'FKKR' => array('name' => 'Garoua', 'lat' => 9.333333, 'long' => 13.383333),
    'FKKN' => array('name' => 'Ngaoundere', 'lat' => 7.350000, 'long' => 13.566667),
    'FKYS' => array('name' => 'Yaounde', 'lat' => 3.833333, 'long' => 11.516667),
  );

  $icao_codes['Canada'] = array(
    'CYXX' => array('name' => 'Abbotsford, B. C.', 'lat' => 49.033333, 'long' => -122.366667),
    'CYNC' => array('name' => 'Aeroport de Wemindji, Que.', 'lat' => 53.010833, 'long' => -78.830278),
    'CYKD' => array('name' => 'Aklavik Airport', 'lat' => 68.216667, 'long' => -135.000000),
    'CYKO' => array('name' => 'Akulivik Airport', 'lat' => 60.816667, 'long' => -78.150000),
    'CYLT' => array('name' => 'Alert Airport', 'lat' => 82.516667, 'long' => -62.283333),
    'CYEK' => array('name' => 'Arviat Airport', 'lat' => 61.100000, 'long' => -94.066667),
    'CYBG' => array('name' => 'Bagotville, Que.', 'lat' => 48.333333, 'long' => -71.000000),
    'CYBC' => array('name' => 'Baie Comeau, Que.', 'lat' => 49.133333, 'long' => -68.200000),
    'CYBK' => array('name' => 'Baker Lake, N. W. T.', 'lat' => 64.300000, 'long' => -96.083333),
    'CZBF' => array('name' => 'Bathurst Airport Aviation Weather Reporting Station', 'lat' => 47.633333, 'long' => -65.750000),
    'CYXQ' => array('name' => 'Beaver Creek Airport', 'lat' => 62.416667, 'long' => -140.866667),
    'CYBD' => array('name' => 'Bella Coola Airport', 'lat' => 52.383333, 'long' => -126.583333),
    'CYBV' => array('name' => 'Berens River Airport', 'lat' => 52.350000, 'long' => -97.033333),
    'CYTL' => array('name' => 'Big Trout Lake', 'lat' => 53.833333, 'long' => -89.866667),
    'CYBX' => array('name' => 'Blanc Sablon, Que.', 'lat' => 51.450000, 'long' => -57.183333),
    'CYCP' => array('name' => 'Blue River, B. C.', 'lat' => 52.133333, 'long' => -119.300000),
    'CYBN' => array('name' => 'Borden, Ont.', 'lat' => 44.250000, 'long' => -79.916667),
    'CYBR' => array('name' => 'Brandon, Man.', 'lat' => 49.916667, 'long' => -99.950000),
    'CWOB' => array('name' => 'Brevoort Island', 'lat' => 63.333333, 'long' => -64.150000),
    'CWIK' => array('name' => 'Broadview, Sask.', 'lat' => 50.383333, 'long' => -102.683333),
    'CWVD' => array('name' => 'Broughton Island', 'lat' => 67.533333, 'long' => -63.783333),
    'CYVM' => array('name' => 'Broughton Island Airport', 'lat' => 67.550000, 'long' => -64.033333),
    'CYVT' => array('name' => 'Buffalo Narrows Man', 'lat' => 55.833333, 'long' => -108.450000),
    'CYDB' => array('name' => 'Burwash Airport', 'lat' => 61.366667, 'long' => -139.033333),
    'CYBW' => array('name' => 'Calgary / Springbank', 'lat' => 51.100000, 'long' => -114.366667),
    'CYYC' => array('name' => 'Calgary International, Alta.', 'lat' => 51.116667, 'long' => -114.016667),
    'CYCB' => array('name' => 'Cambridge Bay, N. W. T.', 'lat' => 69.100000, 'long' => -105.116667),
    'CYBL' => array('name' => 'Campbell River Airport', 'lat' => 49.950000, 'long' => -125.266667),
    'CYTE' => array('name' => 'Cape Dorset, N. W. T.', 'lat' => 64.216667, 'long' => -76.533333),
    'CWFD' => array('name' => 'Cape Dyer, N. W. T.', 'lat' => 66.583333, 'long' => -61.616667),
    'CWUP' => array('name' => 'Cape Hooper, N. W. T.', 'lat' => 68.466667, 'long' => -66.800000),
    'CWKW' => array('name' => 'Cape Kakkiviak', 'lat' => 59.983333, 'long' => -64.166667),
    'CWYK' => array('name' => 'Cape Kiglapait, Nfld.', 'lat' => 57.133333, 'long' => -61.483333),
    'CWYM' => array('name' => 'Cape Mercy', 'lat' => 64.950000, 'long' => -63.583333),
    'CZCP' => array('name' => 'Cape Parry, N. W. T.', 'lat' => 70.100000, 'long' => -124.716667),
    'CWCA' => array('name' => 'Cartwright, Nfld.', 'lat' => 53.700000, 'long' => -57.033333),
    'CYCG' => array('name' => 'Castlegar Airport', 'lat' => 49.300000, 'long' => -117.633333),
    'CYLD' => array('name' => 'Chapleau, Ont.', 'lat' => 47.816667, 'long' => -83.350000),
    'CYYG' => array('name' => 'Charlottetown, P. E. I.', 'lat' => 46.283333, 'long' => -63.133333),
    'CYCS' => array('name' => 'Chesterfield Inlet', 'lat' => 63.333333, 'long' => -90.716667),
    'CYCQ' => array('name' => 'Chetwynd Airport', 'lat' => 55.700000, 'long' => -121.633333),
    'CYMT' => array('name' => 'Chibougamau-Chapais, Que', 'lat' => 49.766667, 'long' => -74.533333),
    'CZUM' => array('name' => 'Churchill Falls, Nfld.', 'lat' => 53.550000, 'long' => -64.100000),
    'CYYQ' => array('name' => 'Churchill, Man.', 'lat' => 58.733333, 'long' => -94.066667),
    'CWCL' => array('name' => 'Clinton, B. C.', 'lat' => 51.150000, 'long' => -121.500000),
    'CYCY' => array('name' => 'Clyde, N. W. T.', 'lat' => 70.483333, 'long' => -68.516667),
    'CYOD' => array('name' => 'Cold Lake, Alta.', 'lat' => 54.416667, 'long' => -110.283333),
    'CYQQ' => array('name' => 'Comox, B. C.', 'lat' => 49.716667, 'long' => -124.900000),
    'CYCO' => array('name' => 'Coppermine, N. W. T.', 'lat' => 67.816667, 'long' => -115.133333),
    'CYZS' => array('name' => 'Coral Harbour, N. W. T.', 'lat' => 64.200000, 'long' => -83.366667),
    'CYXC' => array('name' => 'Cranbrook, B. C.', 'lat' => 49.616667, 'long' => -115.783333),
    'CWXR' => array('name' => 'Croker River, N. W. T.', 'lat' => 69.266667, 'long' => -119.216667),
    'CYDN' => array('name' => 'Dauphin, Man.', 'lat' => 51.100000, 'long' => -100.050000),
    'CYDQ' => array('name' => 'Dawson Creek Airport', 'lat' => 55.750000, 'long' => -120.183333),
    'CYDA' => array('name' => 'Dawson, Y. T.', 'lat' => 64.050000, 'long' => -139.133333),
    'CWDL' => array('name' => 'Dease Lake B. C.', 'lat' => 58.416667, 'long' => -130.000000),
    'CYDF' => array('name' => 'Deer Lake, Nfld.', 'lat' => 49.216667, 'long' => -57.400000),
    'CWUW' => array('name' => 'Dewar Lakes, N. W. T.', 'lat' => 68.650000, 'long' => -71.166667),
    'CYHD' => array('name' => 'Dryden Airport', 'lat' => 49.833333, 'long' => -92.750000),
    'CYXR' => array('name' => 'Earlton, Ont.', 'lat' => 47.700000, 'long' => -79.850000),
    'CZEM' => array('name' => 'Eastmain River Airport', 'lat' => 52.233333, 'long' => -78.516667),
    'CYEG' => array('name' => 'Edmonton International, Alta.', 'lat' => 53.300000, 'long' => -113.583333),
    'CYXD' => array('name' => 'Edmonton Municipal Alta.', 'lat' => 53.566667, 'long' => -113.516667),
    'CYED' => array('name' => 'Edmonton Namao Alta.', 'lat' => 53.666667, 'long' => -113.466667),
    'CYET' => array('name' => 'Edson, Alta.', 'lat' => 53.583333, 'long' => -116.466667),
    'CYOA' => array('name' => 'Ekati, N. W. T.', 'lat' => 64.700000, 'long' => -110.616667),
    'CYEL' => array('name' => 'Elliot Lake Supplementary Aviation Weather Reporting Station', 'lat' => 46.350000, 'long' => -82.566667),
    'CYEN' => array('name' => 'Estevan, Sask.', 'lat' => 49.216667, 'long' => -102.966667),
    'CWEU' => array('name' => 'Eureka, N. W. T.', 'lat' => 79.983333, 'long' => -85.933333),
    'CZFA' => array('name' => 'Faro Airport', 'lat' => 62.200000, 'long' => -133.366667),
    'CYFO' => array('name' => 'Flin Flon Airport', 'lat' => 54.683333, 'long' => -101.683333),
    'CYPY' => array('name' => 'Fort Chipewyan, Alta.', 'lat' => 58.766667, 'long' => -111.116667),
    'CYWJ' => array('name' => 'Fort Franklin Airport', 'lat' => 65.200000, 'long' => -123.433333),
    'CYGH' => array('name' => 'Fort Good Hope Airport', 'lat' => 66.266667, 'long' => -128.616667),
    'CYJF' => array('name' => 'Fort Liard Airport', 'lat' => 60.233333, 'long' => -123.483333),
    'CYMM' => array('name' => 'Fort Mcmurray, Alta.', 'lat' => 56.650000, 'long' => -111.216667),
    'CZFM' => array('name' => 'Fort Mcpherson Airport', 'lat' => 67.400000, 'long' => -134.850000),
    'CZFN' => array('name' => 'Fort Norman Airport', 'lat' => 64.916667, 'long' => -125.566667),
    'CYFR' => array('name' => 'Fort Resolution', 'lat' => 61.183333, 'long' => -113.683333),
    'CYFS' => array('name' => 'Fort Simpson, N. W. T.', 'lat' => 61.750000, 'long' => -121.233333),
    'CYSM' => array('name' => 'Fort Smith, N. W. T.', 'lat' => 60.016667, 'long' => -111.950000),
    'CYXJ' => array('name' => 'Fort St John, B. C.', 'lat' => 56.233333, 'long' => -120.733333),
    'CYFC' => array('name' => 'Fredericton, N. B.', 'lat' => 45.866667, 'long' => -66.533333),
    'CYCX' => array('name' => 'Gagetown Can-Mil', 'lat' => 45.833333, 'long' => -66.433333),
    'CYQX' => array('name' => 'Gander Int. Airport, Nfld.', 'lat' => 48.950000, 'long' => -54.566667),
    'CYGP' => array('name' => 'Gaspe, Que.', 'lat' => 48.766667, 'long' => -64.483333),
    'CYND' => array('name' => 'Gatineau Airport', 'lat' => 45.516667, 'long' => -75.566667),
    'CYGQ' => array('name' => 'Geraldton, Ont.', 'lat' => 49.783333, 'long' => -86.933333),
    'CYGX' => array('name' => 'Gillam, Man.', 'lat' => 56.350000, 'long' => -94.700000),
    'CYHK' => array('name' => 'Gjoa Haven Airport', 'lat' => 68.633333, 'long' => -95.850000),
    'CYGE' => array('name' => 'Golden Airport', 'lat' => 51.300000, 'long' => -116.983333),
    'CYYR' => array('name' => 'Goose, Nfld.', 'lat' => 53.316667, 'long' => -60.416667),
    'CYZE' => array('name' => 'Gore Bay, Ont.', 'lat' => 45.883333, 'long' => -82.566667),
    'CYQU' => array('name' => 'Grande Prairie, Alta.', 'lat' => 55.183333, 'long' => -118.883333),
    'CYZX' => array('name' => 'Greenwood, N. S.', 'lat' => 44.983333, 'long' => -64.916667),
    'CWGZ' => array('name' => 'Grise Fiord Airport', 'lat' => 76.416667, 'long' => -82.900000),
    'CYHZ' => array('name' => 'Halifax International Airport', 'lat' => 44.883333, 'long' => -63.500000),
    'CYUX' => array('name' => 'Hall Beach, N. W. T.', 'lat' => 68.783333, 'long' => -81.250000),
    'CYHM' => array('name' => 'Hamilton Airport', 'lat' => 43.166667, 'long' => -79.933333),
    'CWIL' => array('name' => 'Hat Island, N. W. T.', 'lat' => 68.316667, 'long' => -100.083333),
    'CYGV' => array('name' => 'Havre St Pierre', 'lat' => 50.283333, 'long' => -63.616667),
    'CYHY' => array('name' => 'Hay River, N. W. T.', 'lat' => 60.833333, 'long' => -115.783333),
    'CYOJ' => array('name' => 'High Level, Alta', 'lat' => 58.616667, 'long' => -117.166667),
    'CYHI' => array('name' => 'Holman Island Airport', 'lat' => 70.766667, 'long' => -117.800000),
    'CYHE' => array('name' => 'Hope, B. C.', 'lat' => 49.366667, 'long' => -121.483333),
    'CYGT' => array('name' => 'Igloolik Airport', 'lat' => 69.366667, 'long' => -81.816667),
    'CYGR' => array('name' => 'Iles De La Madeleineque', 'lat' => 47.416667, 'long' => -61.783333),
    'CWWU' => array('name' => 'Ingenika Point', 'lat' => 56.800000, 'long' => -124.900000),
    'CYPH' => array('name' => 'Inukjuak Airport Supplementary Aviation Weather Reporting Station', 'lat' => 58.466667, 'long' => -78.083333),
    'CYEV' => array('name' => 'Inuvik, N. W. T.', 'lat' => 68.300000, 'long' => -133.483333),
    'CYFB' => array('name' => 'Iqaluit, N. W. T.', 'lat' => 63.750000, 'long' => -68.550000),
    'CYIV' => array('name' => 'Island Lake, Man.', 'lat' => 53.850000, 'long' => -94.650000),
    'CYIK' => array('name' => 'Ivujivik Airport Supplementary Aviation Weather Reporting Station', 'lat' => 62.416667, 'long' => -77.950000),
    'CWHN' => array('name' => 'Jimmy Lake', 'lat' => 54.916667, 'long' => -109.950000),
    'CYKA' => array('name' => 'Kamloops, B. C.', 'lat' => 50.700000, 'long' => -120.450000),
    'CYLU' => array('name' => 'Kangiksualujjuaq A', 'lat' => 58.716667, 'long' => -65.983333),
    'CYKG' => array('name' => 'Kangiqsujuaq Supplementary Aviation Weather Reporting Station', 'lat' => 61.583333, 'long' => -71.933333),
    'CYAS' => array('name' => 'Kangirsuk Supplementary Aviation Weather Reporting Station', 'lat' => 60.016667, 'long' => -70.000000),
    'CYYU' => array('name' => 'Kapuskasing, Ont.', 'lat' => 49.416667, 'long' => -82.466667),
    'CYLW' => array('name' => 'Kelowna Airport', 'lat' => 49.966667, 'long' => -119.383333),
    'CYQK' => array('name' => 'Kenora, Ont.', 'lat' => 49.783333, 'long' => -94.366667),
    'CYKJ' => array('name' => 'Key Lake', 'lat' => 57.250000, 'long' => -105.616667),
    'CYKY' => array('name' => 'Kindersley, Sask.', 'lat' => 51.516667, 'long' => -109.166667),
    'CYGK' => array('name' => 'Kingston, Ont.', 'lat' => 44.216667, 'long' => -76.600000),
    'CWKM' => array('name' => 'Komakuk Beach, Y. T.', 'lat' => 69.616667, 'long' => -140.200000),
    'CYVP' => array('name' => 'Kuujjuaq, Que.', 'lat' => 58.100000, 'long' => -68.416667),
    'CYGW' => array('name' => 'Kuujjuarapik, Que.', 'lat' => 55.283333, 'long' => -77.766667),
    'CYAH' => array('name' => 'La Grande Iv, Que.', 'lat' => 53.750000, 'long' => -73.666667),
    'CYGL' => array('name' => 'La Grande Riviere, Que', 'lat' => 53.633333, 'long' => -77.700000),
    'CYVC' => array('name' => 'La Ronge, Sask', 'lat' => 55.150000, 'long' => -105.266667),
    'CWMT' => array('name' => 'Lac La Martre', 'lat' => 63.150000, 'long' => -117.266667),
    'CYQL' => array('name' => 'Lethbridge, Alta.', 'lat' => 49.633333, 'long' => -112.800000),
    'CWLI' => array('name' => 'Liverpool Bay', 'lat' => 69.600000, 'long' => -130.900000),
    'CYLL' => array('name' => 'Lloydminister, Alta.', 'lat' => 53.316667, 'long' => -110.066667),
    'CYXU' => array('name' => 'London, Ont.', 'lat' => 43.033333, 'long' => -81.150000),
    'CWLX' => array('name' => 'Longstaff Bluff, N. W. T.', 'lat' => 68.883333, 'long' => -75.133333),
    'CYWO' => array('name' => 'Lupin Airport Supplementary Aviation Weather Reporting Station', 'lat' => 65.766667, 'long' => -111.250000),
    'CYLK' => array('name' => 'Lutsel KE, N. W. T.', 'lat' => 62.416667, 'long' => -110.666667),
    'CYYL' => array('name' => 'Lynn Lake, Man.', 'lat' => 56.866667, 'long' => -101.083333),
    'CWLY' => array('name' => 'Lytton, B. C.', 'lat' => 50.233333, 'long' => -121.583333),
    'CYZY' => array('name' => 'Mackenzie, B. C.', 'lat' => 55.300000, 'long' => -123.133333),
    'CYFT' => array('name' => 'Makkovik Airport', 'lat' => 55.083333, 'long' => -59.183333),
    'CYMH' => array('name' => 'Mary\'s Harbour', 'lat' => 52.300000, 'long' => -55.850000),
    'CYNM' => array('name' => 'Matagami, Que.', 'lat' => 49.766667, 'long' => -77.816667),
    'CYMA' => array('name' => 'Mayo Airport', 'lat' => 63.616667, 'long' => -135.866667),
    'CYLJ' => array('name' => 'Meadow Lake, Sask.', 'lat' => 54.133333, 'long' => -108.516667),
    'CYXH' => array('name' => 'Medicine Hat, Alta.', 'lat' => 50.016667, 'long' => -110.716667),
    'CYQM' => array('name' => 'Moncton, N. B.', 'lat' => 46.116667, 'long' => -64.683333),
    'CYYY' => array('name' => 'Mont Joli, Que.', 'lat' => 48.600000, 'long' => -68.216667),
    'CYMX' => array('name' => 'Montreal / Mirabel', 'lat' => 45.683333, 'long' => -74.033333),
    'CYUL' => array('name' => 'Montreal / Pierre Elliot Trudeau International Airport, Que', 'lat' => 45.466667, 'long' => -73.750000),
    'CYMJ' => array('name' => 'Moose Jaw, Sask.', 'lat' => 50.333333, 'long' => -105.550000),
    'CYMO' => array('name' => 'Moosonee, Ont.', 'lat' => 51.266667, 'long' => -80.650000),
    'CYQA' => array('name' => 'Muskoka, Ont.', 'lat' => 44.966667, 'long' => -79.300000),
    'CYDP' => array('name' => 'Nain, Nfld', 'lat' => 56.550000, 'long' => -61.683333),
    'CYCD' => array('name' => 'Nanaimo Airport', 'lat' => 49.050000, 'long' => -123.866667),
    'CYSR' => array('name' => 'Nanisivik Airport', 'lat' => 72.983333, 'long' => -84.633333),
    'CYNA' => array('name' => 'Natashquan, Que.', 'lat' => 50.183333, 'long' => -61.816667),
    'CYHH' => array('name' => 'Nemiscau Airport Supplementary Aviation Weather Reporting Station', 'lat' => 51.700000, 'long' => -76.116667),
    'CYBU' => array('name' => 'Nipawin, Sask.', 'lat' => 53.333333, 'long' => -104.000000),
    'CYVQ' => array('name' => 'Norman Wells, N. W. T.', 'lat' => 65.283333, 'long' => -126.800000),
    'CYQW' => array('name' => 'North Battleford, Sask.', 'lat' => 52.766667, 'long' => -108.250000),
    'CYYB' => array('name' => 'North Bay, Ont.', 'lat' => 46.350000, 'long' => -79.433333),
    'CYNE' => array('name' => 'Norway House, Man.', 'lat' => 53.966667, 'long' => -97.833333),
    'CYOC' => array('name' => 'Old Crow Airport', 'lat' => 67.566667, 'long' => -139.816667),
    'CYOW' => array('name' => 'Ottawa Int\'l. Ont.', 'lat' => 45.316667, 'long' => -75.666667),
    'CYXP' => array('name' => 'Pangnirtung Airport', 'lat' => 66.150000, 'long' => -65.716667),
    'CYPC' => array('name' => 'Paulatuk Airport', 'lat' => 69.350000, 'long' => -124.033333),
    'CYPE' => array('name' => 'Peace River, Alta.', 'lat' => 56.233333, 'long' => -117.433333),
    'CYBB' => array('name' => 'Pelly Bay Airport', 'lat' => 68.533333, 'long' => -89.816667),
    'CYYF' => array('name' => 'Penticton, B. C.', 'lat' => 49.466667, 'long' => -119.600000),
    'CYWA' => array('name' => 'Petawawa, Ont.', 'lat' => 45.950000, 'long' => -77.316667),
    'CYPQ' => array('name' => 'Peterborough Airport', 'lat' => 44.233333, 'long' => -78.366667),
    'CYPL' => array('name' => 'Pickle Lake Man', 'lat' => 51.450000, 'long' => -90.200000),
    'CZPC' => array('name' => 'Pincher Creek Airport', 'lat' => 49.516667, 'long' => -113.983333),
    'CYIO' => array('name' => 'Pond Inlet, N. W. T.', 'lat' => 72.700000, 'long' => -77.966667),
    'CYZT' => array('name' => 'Port Hardy, B. C.', 'lat' => 50.683333, 'long' => -127.366667),
    'CYPG' => array('name' => 'Portage Southport A', 'lat' => 49.900000, 'long' => -98.266667),
    'CYPX' => array('name' => 'Povungnituq', 'lat' => 60.050000, 'long' => -77.283333),
    'CYPW' => array('name' => 'Powell River Airport', 'lat' => 49.833333, 'long' => -124.500000),
    'CYPA' => array('name' => 'Prince Albert, Sask.', 'lat' => 53.216667, 'long' => -105.683333),
    'CYXS' => array('name' => 'Prince George, B. C.', 'lat' => 53.883333, 'long' => -122.683333),
    'CYPR' => array('name' => 'Prince Rupert, B. C.', 'lat' => 54.300000, 'long' => -130.433333),
    'CYDC' => array('name' => 'Princeton Airport', 'lat' => 49.466667, 'long' => -120.516667),
    'CYHA' => array('name' => 'Quaqtaq Airport', 'lat' => 61.050000, 'long' => -69.633333),
    'CYQB' => array('name' => 'Quebec, Que', 'lat' => 46.800000, 'long' => -71.383333),
    'CYQZ' => array('name' => 'Quesnel Airport', 'lat' => 53.033333, 'long' => -122.516667),
    'CYRT' => array('name' => 'Rankin Inlet, N. W. T.', 'lat' => 62.816667, 'long' => -92.116667),
    'CYQF' => array('name' => 'Red Deer, Alta.', 'lat' => 52.183333, 'long' => -113.900000),
    'CYRL' => array('name' => 'Red Lake, Ont.', 'lat' => 51.066667, 'long' => -93.800000),
    'CYQR' => array('name' => 'Regina, Sask.', 'lat' => 50.433333, 'long' => -104.666667),
    'CYUT' => array('name' => 'Repulse Bay Airport', 'lat' => 66.533333, 'long' => -86.250000),
    'CYRB' => array('name' => 'Resolute, N. W. T.', 'lat' => 74.716667, 'long' => -94.983333),
    'CYRV' => array('name' => 'Revelstoke, B. C.', 'lat' => 50.966667, 'long' => -118.183333),
    'CYRJ' => array('name' => 'Roberval, Que.', 'lat' => 48.516667, 'long' => -72.266667),
    'CYUY' => array('name' => 'Rouyn Airport', 'lat' => 48.200000, 'long' => -78.833333),
    'CWRX' => array('name' => 'Rowley Island, N. W. T.', 'lat' => 69.066667, 'long' => -79.066667),
    'CWSA' => array('name' => 'Sable Island, N. S.', 'lat' => 43.933333, 'long' => -60.016667),
    'CYSY' => array('name' => 'Sachs Harbour Airport', 'lat' => 72.000000, 'long' => -125.283333),
    'CWZZ' => array('name' => 'Saglek Bay', 'lat' => 58.333333, 'long' => -62.583333),
    'CYAY' => array('name' => 'Saint Anthony Airport', 'lat' => 51.400000, 'long' => -56.083333),
    'CYSN' => array('name' => 'Saint Catharines Airport', 'lat' => 43.200000, 'long' => -79.166667),
    'CYHU' => array('name' => 'Saint Hubert Airport', 'lat' => 45.516667, 'long' => -73.416667),
    'CYSJ' => array('name' => 'Saint John, N. B.', 'lat' => 45.333333, 'long' => -65.883333),
    'CYSL' => array('name' => 'Saint Leonard Airport', 'lat' => 47.150000, 'long' => -67.833333),
    'CYZG' => array('name' => 'Salliut Airport Supplementary Aviation Weather Reporting Station', 'lat' => 62.183333, 'long' => -75.666667),
    'CYZP' => array('name' => 'Sandspit, B. C.', 'lat' => 53.250000, 'long' => -131.816667),
    'CYSK' => array('name' => 'Sanikiluaq Airport', 'lat' => 56.533333, 'long' => -79.250000),
    'CYZR' => array('name' => 'Sarnia Airport', 'lat' => 43.000000, 'long' => -82.316667),
    'CYXE' => array('name' => 'Saskatoon, Sask.', 'lat' => 52.166667, 'long' => -106.683333),
    'CYAM' => array('name' => 'Sault Ste Marie, Ont.', 'lat' => 46.483333, 'long' => -84.500000),
    'CYKL' => array('name' => 'Schefferville, Que.', 'lat' => 54.800000, 'long' => -66.800000),
    'CYZV' => array('name' => 'Sept-Iles, Que.', 'lat' => 50.216667, 'long' => -66.266667),
    'CYAW' => array('name' => 'Shearwater, N. S.', 'lat' => 44.633333, 'long' => -63.500000),
    'CYUS' => array('name' => 'Shepherd Bay, N. W. T.', 'lat' => 68.816667, 'long' => -93.433333),
    'CYSC' => array('name' => 'Sherbrooke, Que.', 'lat' => 45.400000, 'long' => -71.883333),
    'CYUA' => array('name' => 'Shingle Point, Y. T.', 'lat' => 68.950000, 'long' => -137.216667),
    'CYXL' => array('name' => 'Sioux Lookout, Ont.', 'lat' => 50.116667, 'long' => -91.900000),
    'CYZH' => array('name' => 'Slave Lake, Alta', 'lat' => 55.300000, 'long' => -114.783333),
    'CYYD' => array('name' => 'Smithers, B. C.', 'lat' => 54.816667, 'long' => -127.183333),
    'CWSW' => array('name' => 'Sparwood / Elk Valley', 'lat' => 49.750000, 'long' => -114.883333),
    'CYYH' => array('name' => 'Spence Bay Airport', 'lat' => 69.550000, 'long' => -93.583333),
    'CYYT' => array('name' => 'St. John\'s, Nfld', 'lat' => 47.616667, 'long' => -52.733333),
    'CYJT' => array('name' => 'Stephenville, Nfld.', 'lat' => 48.533333, 'long' => -58.550000),
    'CZST' => array('name' => 'Stewart Airport', 'lat' => 55.933333, 'long' => -129.983333),
    'CYSF' => array('name' => 'Stony Rapids Airport', 'lat' => 59.250000, 'long' => -105.833333),
    'CWVH' => array('name' => 'Storm Hills , N. W. T.', 'lat' => 68.900000, 'long' => -133.933333),
    'CYSB' => array('name' => 'Sudbury, Ont.', 'lat' => 46.616667, 'long' => -80.800000),
    'CYSD' => array('name' => 'Suffield Airport', 'lat' => 50.266667, 'long' => -111.183333),
    'CYYN' => array('name' => 'Swift Current, Sask.', 'lat' => 50.283333, 'long' => -107.683333),
    'CYQY' => array('name' => 'Sydney, N. S.', 'lat' => 46.166667, 'long' => -60.050000),
    'CYTQ' => array('name' => 'Tasiujaq A', 'lat' => 58.666667, 'long' => -69.950000),
    'CYTJ' => array('name' => 'Terrace Bay Supplementary Aviation Weather Reporting Station', 'lat' => 48.816667, 'long' => -87.100000),
    'CYXT' => array('name' => 'Terrace, B. C.', 'lat' => 54.466667, 'long' => -128.583333),
    'CYZW' => array('name' => 'Teslin, Y. T.', 'lat' => 60.166667, 'long' => -132.733333),
    'CYQD' => array('name' => 'The Pas, Man.', 'lat' => 53.966667, 'long' => -101.100000),
    'CYTH' => array('name' => 'Thompson Weather Office, Man', 'lat' => 55.800000, 'long' => -97.850000),
    'CYQT' => array('name' => 'Thunder Bay, Ont.', 'lat' => 48.366667, 'long' => -89.316667),
    'CYTS' => array('name' => 'Timmins, Ont.', 'lat' => 48.566667, 'long' => -81.366667),
    'CYAZ' => array('name' => 'Tofino Airport', 'lat' => 49.083333, 'long' => -125.766667),
    'CYKZ' => array('name' => 'Toronto Buttonville', 'lat' => 43.866667, 'long' => -79.366667),
    'CYTZ' => array('name' => 'Toronto Island Airport Automated Reporting Station', 'lat' => 43.633333, 'long' => -79.400000),
    'CYYZ' => array('name' => 'Toronto Pearson Int\'l. Ont.', 'lat' => 43.666667, 'long' => -79.633333),
    'CYTR' => array('name' => 'Trenton, Ont.', 'lat' => 44.116667, 'long' => -77.533333),
    'CWTU' => array('name' => 'Tukialik Bay, Nfld.', 'lat' => 54.716667, 'long' => -58.350000),
    'CYUB' => array('name' => 'Tuktoyaktuk', 'lat' => 69.450000, 'long' => -133.016667),
    'CYMU' => array('name' => 'Umiujaq', 'lat' => 56.533333, 'long' => -76.516667),
    'CYVO' => array('name' => 'Val D\'Or, Que.', 'lat' => 48.066667, 'long' => -77.783333),
    'CYOY' => array('name' => 'Valcartier Airport', 'lat' => 46.900000, 'long' => -71.500000),
    'CYVR' => array('name' => 'Vancouver International Air-Port, B. C.', 'lat' => 49.183333, 'long' => -123.166667),
    'CYWH' => array('name' => 'Victoria Harbour', 'lat' => 48.416667, 'long' => -123.333333),
    'CYYJ' => array('name' => 'Victoria Int. Airport, B. C.', 'lat' => 48.650000, 'long' => -123.433333),
    'CYWK' => array('name' => 'Wabush Lake, Nfld.', 'lat' => 52.933333, 'long' => -66.866667),
    'CYKQ' => array('name' => 'Waskaganish Airport', 'lat' => 51.483333, 'long' => -78.750000),
    'CYKF' => array('name' => 'Waterloo Well', 'lat' => 43.466667, 'long' => -80.383333),
    'CYQH' => array('name' => 'Watson Lake, Y. T.', 'lat' => 60.116667, 'long' => -128.816667),
    'CYXZ' => array('name' => 'Wawa, Ont.', 'lat' => 47.966667, 'long' => -84.783333),
    'CYXN' => array('name' => 'Whale Cove Airport', 'lat' => 62.233333, 'long' => -92.600000),
    'CWAE' => array('name' => 'Whistler', 'lat' => 50.133333, 'long' => -122.950000),
    'CYZU' => array('name' => 'Whitecourt, Alta.', 'lat' => 54.150000, 'long' => -115.783333),
    'CYXY' => array('name' => 'Whitehorse, Y. T.', 'lat' => 60.716667, 'long' => -135.066667),
    'CYVV' => array('name' => 'Wiarton, Ont.', 'lat' => 44.750000, 'long' => -81.100000),
    'CYWL' => array('name' => 'Williams Lake, B. C.', 'lat' => 52.183333, 'long' => -122.050000),
    'CYQG' => array('name' => 'Windsor, Ont.', 'lat' => 42.266667, 'long' => -82.966667),
    'CYWG' => array('name' => 'Winnipeg Int. Airportman.', 'lat' => 49.900000, 'long' => -97.233333),
    'CYQI' => array('name' => 'Yarmouth, N. S.', 'lat' => 43.833333, 'long' => -66.083333),
    'CYZF' => array('name' => 'Yellowknife, N. W. T.', 'lat' => 62.466667, 'long' => -114.450000),
    'CYQV' => array('name' => 'Yorkton, Sask.', 'lat' => 51.266667, 'long' => -102.466667),
  );

  $icao_codes['Cape Verde'] = array(
    'GVAC' => array('name' => 'Sal', 'lat' => 16.733333, 'long' => -22.950000),
  );

  $icao_codes['Cayman Islands'] = array(
    'MWCB' => array('name' => 'Gerrard Smith Intl. / Cayman Brac', 'lat' => 19.686944, 'long' => -79.882778),
    'MWCR' => array('name' => 'Owen Roberts Airportgrand Cayman', 'lat' => 19.283333, 'long' => -81.350000),
  );

  $icao_codes['Central African Republic'] = array(
    'FEFG' => array('name' => 'Bangassou', 'lat' => 4.733333, 'long' => 22.833333),
    'FEFF' => array('name' => 'Bangui', 'lat' => 4.400000, 'long' => 18.516667),
    'FEFT' => array('name' => 'Berberati', 'lat' => 4.250000, 'long' => 15.800000),
  );

  $icao_codes['Chad'] = array(
    'FTTD' => array('name' => 'Moundou', 'lat' => 8.616667, 'long' => 16.066667),
    'FTTJ' => array('name' => 'Ndjamena', 'lat' => 12.133333, 'long' => 15.033333),
    'FTTA' => array('name' => 'Sarh', 'lat' => 9.150000, 'long' => 18.383333),
  );

  $icao_codes['Chile'] = array(
    'SCFA' => array('name' => 'Antofagasta', 'lat' => -23.433333, 'long' => -70.433333),
    'SCAR' => array('name' => 'Arica', 'lat' => -18.333333, 'long' => -70.333333),
    'SCBA' => array('name' => 'Balmaceda', 'lat' => -45.916667, 'long' => -71.683333),
    'SCCH' => array('name' => 'Chillan', 'lat' => -36.566667, 'long' => -72.033333),
    'SCIE' => array('name' => 'Concepcion', 'lat' => -36.766667, 'long' => -73.050000),
    'SCDA' => array('name' => 'Iquique / Diego Arac', 'lat' => -20.533333, 'long' => -70.183333),
    'SCIP' => array('name' => 'Isla De Pascua', 'lat' => -27.150000, 'long' => -109.416667),
    'SCSE' => array('name' => 'La Serena', 'lat' => -29.900000, 'long' => -71.200000),
    'SCEL' => array('name' => 'Pudahuel', 'lat' => -33.383333, 'long' => -70.783333),
    'SCTE' => array('name' => 'Puerto Montt', 'lat' => -41.416667, 'long' => -73.083333),
    'SCCI' => array('name' => 'Punta Arenas', 'lat' => -53.000000, 'long' => -70.850000),
    'SCTC' => array('name' => 'Temuco', 'lat' => -38.750000, 'long' => -72.633333),
  );

  $icao_codes['China'] = array(
    'ZBAA' => array('name' => 'Beijing', 'lat' => 39.933333, 'long' => 116.283333),
    'ZYCC' => array('name' => 'Changchun', 'lat' => 43.900000, 'long' => 125.216667),
    'ZGHA' => array('name' => 'Changsha', 'lat' => 28.233333, 'long' => 112.866667),
    'ZUUU' => array('name' => 'Chengdu', 'lat' => 30.666667, 'long' => 104.016667),
    'ZUCK' => array('name' => 'Chongqing', 'lat' => 29.516667, 'long' => 106.483333),
    'ZYTL' => array('name' => 'Dalian', 'lat' => 38.900000, 'long' => 121.633333),
    'ZGGG' => array('name' => 'Guangzhou', 'lat' => 23.166667, 'long' => 113.333333),
    'ZGKL' => array('name' => 'Guilin', 'lat' => 25.333333, 'long' => 110.300000),
    'ZSHC' => array('name' => 'Hangzhou', 'lat' => 30.233333, 'long' => 120.166667),
    'ZYHB' => array('name' => 'Harbin', 'lat' => 46.020000, 'long' => 126.580000),
    'ZSOF' => array('name' => 'Hefei', 'lat' => 31.866667, 'long' => 117.233333),
    'ZBHH' => array('name' => 'Hohhot', 'lat' => 40.816667, 'long' => 111.683333),
    'ZWSH' => array('name' => 'Kashi', 'lat' => 39.466667, 'long' => 75.983333),
    'ZPPP' => array('name' => 'Kunming', 'lat' => 25.016667, 'long' => 102.683333),
    'ZLLL' => array('name' => 'Lanzhou / Zhongchuan', 'lat' => 36.020000, 'long' => 103.750000),
    'ZSNJ' => array('name' => 'Nanjing', 'lat' => 32.000000, 'long' => 118.800000),
    'ZGNN' => array('name' => 'Nanning', 'lat' => 22.816667, 'long' => 108.350000),
    'ZSQD' => array('name' => 'Qingdao', 'lat' => 36.066667, 'long' => 120.333333),
    'ZJSY' => array('name' => 'Sanya/Fenghuang', 'lat' => 18.300000, 'long' => 109.400000),
    'ZSSS' => array('name' => 'Shanghai / Hongqiao', 'lat' => 31.166667, 'long' => 121.433333),
    'ZSPD' => array('name' => 'Shanghai / Pudong', 'lat' => 31.116667, 'long' => 121.766667),
    'ZGOW' => array('name' => 'Shantou', 'lat' => 23.400000, 'long' => 116.683333),
    'ZYTX' => array('name' => 'Shenyang / Taokian', 'lat' => 41.800000, 'long' => 123.400000),
    'ZGSZ' => array('name' => 'Shenzhen', 'lat' => 22.550000, 'long' => 114.100000),
    'ZBYN' => array('name' => 'Taiyuan', 'lat' => 37.783333, 'long' => 112.550000),
    'ZBTJ' => array('name' => 'Tianjin / Zhangguizhu', 'lat' => 39.183333, 'long' => 117.350000),
    'ZWWW' => array('name' => 'Urum-Qi / Diwopu', 'lat' => 43.900000, 'long' => 87.466667),
    'ZHHH' => array('name' => 'Wuhan', 'lat' => 30.616667, 'long' => 114.133333),
    'ZSAM' => array('name' => 'Xiamen', 'lat' => 24.483333, 'long' => 118.083333),
    'ZLXY' => array('name' => 'Xian/Xianyang', 'lat' => 34.433333, 'long' => 108.750000),
  );

  $icao_codes['Christmas Island'] = array(
    'YPXM' => array('name' => 'Christmas Island Aerodrome', 'lat' => -10.433333, 'long' => 105.683333),
    'YPCC' => array('name' => 'Cocos Island Airport', 'lat' => -12.183333, 'long' => 96.816667),
  );

  $icao_codes['Colombia'] = array(
    'SKLC' => array('name' => 'Apartado / Los Cedros', 'lat' => 7.816667, 'long' => -76.700000),
    'SKUC' => array('name' => 'Arauca / Santiago Perez', 'lat' => 7.066667, 'long' => -70.733333),
    'SKAR' => array('name' => 'Armenia / El Eden', 'lat' => 4.500000, 'long' => -75.716667),
    'SKEJ' => array('name' => 'Barrancabermeja / Yariguies', 'lat' => 7.016667, 'long' => -73.800000),
    'SKBQ' => array('name' => 'Barranquilla / Ernestocortissoz', 'lat' => 10.883333, 'long' => -74.783333),
    'SKBO' => array('name' => 'Bogota / Eldorado', 'lat' => 4.716667, 'long' => -74.150000),
    'SKBG' => array('name' => 'Bucaramanga / Palonegro', 'lat' => 7.100000, 'long' => -73.200000),
    'SKCL' => array('name' => 'Cali / Alfonso Bonillaaragon', 'lat' => 3.550000, 'long' => -76.383333),
    'SKCG' => array('name' => 'Cartagena / Rafael Nunez', 'lat' => 10.450000, 'long' => -75.516667),
    'SKCC' => array('name' => 'Cucuta / Camilo Daza', 'lat' => 7.933333, 'long' => -72.516667),
    'SKIB' => array('name' => 'Ibague / Perales', 'lat' => 4.433333, 'long' => -75.150000),
    'SKIP' => array('name' => 'Ipiales / San Luis', 'lat' => 0.816667, 'long' => -77.633333),
    'SKLT' => array('name' => 'Leticia / Vasquez Cobo', 'lat' => -4.166667, 'long' => -69.950000),
    'SKMD' => array('name' => 'Medellin / Olaya Herrera', 'lat' => 6.216667, 'long' => -75.600000),
    'SKMR' => array('name' => 'Monteria / Los Garzones', 'lat' => 8.816667, 'long' => -75.850000),
    'SKNV' => array('name' => 'Neiva / Benito Salas', 'lat' => 2.966667, 'long' => -75.300000),
    'SKPE' => array('name' => 'Pereira / Matecana', 'lat' => 4.816667, 'long' => -75.733333),
    'SKPV' => array('name' => 'Providencia Isla / El Embrujo', 'lat' => 13.366667, 'long' => -81.350000),
    'SKPC' => array('name' => 'Puerto Carreno / A. Guauquea', 'lat' => 6.166667, 'long' => -67.500000),
    'SKUI' => array('name' => 'Quibdo / El Carano', 'lat' => 5.716667, 'long' => -76.616667),
    'SKRH' => array('name' => 'Riohacha / Almirante Padilla', 'lat' => 11.533333, 'long' => -72.933333),
    'SKRG' => array('name' => 'Rionegro / J. M. Cordova', 'lat' => 6.133333, 'long' => -75.433333),
    'SKSP' => array('name' => 'San Andres Isla / Sesquicentenario', 'lat' => 12.583333, 'long' => -81.716667),
    'SKSM' => array('name' => 'Santa Marta / Simon Bolivar', 'lat' => 11.133333, 'long' => -74.233333),
    'SKVP' => array('name' => 'Valledupar / Alfonso Lopez', 'lat' => 10.433333, 'long' => -73.250000),
    'SKVV' => array('name' => 'Villavicencio / Vanguardia', 'lat' => 4.166667, 'long' => -73.616667),
  );

  $icao_codes['Comoros'] = array(
    'FMCZ' => array('name' => 'Dzaoudzi / Pamanzi Mayotte', 'lat' => -12.800000, 'long' => 45.283333),
    'FMCH' => array('name' => 'Hahaya International Airport', 'lat' => -11.533333, 'long' => 43.266667),
  );

  $icao_codes['Congo, Democratic Republic of the'] = array(
    'FZOA' => array('name' => 'Kindu', 'lat' => -2.950000, 'long' => 25.916667),
    'FZAA' => array('name' => 'Kinshasa / N\'Djili', 'lat' => -4.383333, 'long' => 15.433333),
    'FZQA' => array('name' => 'Lubumbashi-Luano', 'lat' => -11.666667, 'long' => 27.483333),
  );

  $icao_codes['Congo, Republic of the'] = array(
    'FCBB' => array('name' => 'Brazzaville / Maya-Maya', 'lat' => -4.250000, 'long' => 15.250000),
    'FCPP' => array('name' => 'Pointe-Noire', 'lat' => -4.816667, 'long' => 11.900000),
  );

  $icao_codes['Cook Islands'] = array(
    'NIUE' => array('name' => 'Alofi / Niue', 'lat' => -19.066667, 'long' => -169.916667),
    'NCRG' => array('name' => 'Rarotonga', 'lat' => -21.200000, 'long' => -159.816667),
  );

  $icao_codes['Costa Rica'] = array(
    'MROC' => array('name' => 'Juan Santamaria', 'lat' => 10.000000, 'long' => -84.216667),
    'MRLB' => array('name' => 'Liberia', 'lat' => 10.616667, 'long' => -85.433333),
    'MRLM' => array('name' => 'Puerto Limon', 'lat' => 10.000000, 'long' => -83.050000),
    'MRPV' => array('name' => 'Tobias Bolanos International', 'lat' => 9.950000, 'long' => -84.150000),
  );

  $icao_codes['Cote d\'Ivoire'] = array(
    'DIAP' => array('name' => 'Abidjan', 'lat' => 5.250000, 'long' => -3.933333),
  );

  $icao_codes['Croatia'] = array(
    'LDSB' => array('name' => 'Brac', 'lat' => 43.285833, 'long' => 16.679722),
    'LDDU' => array('name' => 'Dubrovnik / Cilipi', 'lat' => 42.566667, 'long' => 18.266667),
    'LDLO' => array('name' => 'Losinj Island', 'lat' => 44.565833, 'long' => 14.393056),
    'LDOS' => array('name' => 'Osijek / Cepin', 'lat' => 45.450000, 'long' => 18.800000),
    'LDPL' => array('name' => 'Pula Aerodrome', 'lat' => 45.900000, 'long' => 13.916667),
    'LDRI' => array('name' => 'Rijeka / Omisalj', 'lat' => 45.216667, 'long' => 14.583333),
    'LDSP' => array('name' => 'Split / Resnik', 'lat' => 43.533333, 'long' => 16.300000),
    'LDZD' => array('name' => 'Zadar / Zemunik', 'lat' => 44.100000, 'long' => 15.350000),
    'LDZA' => array('name' => 'Zagreb / Pleso', 'lat' => 45.733333, 'long' => 16.066667),
  );

  $icao_codes['Cuba'] = array(
    'MUHA' => array('name' => 'Aeropuerto Jose Marti, Rancho-Boyeros, Habana', 'lat' => 22.983333, 'long' => -82.400000),
    'MUCM' => array('name' => 'Camaguey Aeropuerto', 'lat' => 21.416667, 'long' => -77.850000),
    'MUCC' => array('name' => 'Cayo Coco / Jardines Del Ray', 'lat' => 22.461111, 'long' => -78.328333),
    'MUCL' => array('name' => 'Cayo Largo Del Sur', 'lat' => 21.616667, 'long' => -81.550000),
    'MUCF' => array('name' => 'Cienfuegos, Las Villas', 'lat' => 22.150000, 'long' => -80.400000),
    'MUGM' => array('name' => 'Guantanamo, Leeward Point Field', 'lat' => 19.906389, 'long' => -75.206944),
    'MUHG' => array('name' => 'Holguin Civ / Mil', 'lat' => 20.783333, 'long' => -76.316667),
    'MUMZ' => array('name' => 'Manzanillo, Oriente', 'lat' => 20.333333, 'long' => -77.116667),
    'MUCU' => array('name' => 'Santiago De Cuba, Oriente', 'lat' => 19.966667, 'long' => -75.850000),
    'MUVR' => array('name' => 'Varadero, Matanzas', 'lat' => 23.133333, 'long' => -81.283333),
    'MUCA' => array('name' => 'Venezuela, Ciego De Avila', 'lat' => 21.783333, 'long' => -78.783333),
  );

  $icao_codes['Cyprus'] = array(
    'LCRA' => array('name' => 'Akrotiri', 'lat' => 34.583333, 'long' => 32.983333),
    'LCEN' => array('name' => 'Ercan', 'lat' => 35.150000, 'long' => 33.500000),
    'LCLK' => array('name' => 'Larnaca Airport', 'lat' => 34.883333, 'long' => 33.633333),
    'LCPH' => array('name' => 'Paphos Airport', 'lat' => 34.716667, 'long' => 32.483333),
  );

  $icao_codes['Czech Republic'] = array(
    'LKTB' => array('name' => 'Brno / Turany', 'lat' => 49.150000, 'long' => 16.700000),
    'LKHO' => array('name' => 'Holesov', 'lat' => 49.316667, 'long' => 17.566667),
    'LKKV' => array('name' => 'Karlovy Vary', 'lat' => 50.200000, 'long' => 12.916667),
    'LKKU' => array('name' => 'Kunovice', 'lat' => 49.029444, 'long' => 17.439722),
    'LKLB' => array('name' => 'Liberec', 'lat' => 50.768333, 'long' => 15.025000),
    'LKMT' => array('name' => 'Ostrava / Mosnov', 'lat' => 49.683333, 'long' => 18.116667),
    'LKPR' => array('name' => 'Praha / Ruzyne', 'lat' => 50.100000, 'long' => 14.250000),
  );

  $icao_codes['Denmark'] = array(
    'EKYT' => array('name' => 'Aalborg', 'lat' => 57.100000, 'long' => 9.850000),
    'EKBI' => array('name' => 'Billund Lufthavn', 'lat' => 55.733333, 'long' => 9.166667),
    'EKEB' => array('name' => 'Esbjerg', 'lat' => 55.533333, 'long' => 8.566667),
    'EKKA' => array('name' => 'Karup', 'lat' => 56.300000, 'long' => 9.116667),
    'EKCH' => array('name' => 'Koebenhavn / Kastrup', 'lat' => 55.616667, 'long' => 12.650000),
    'EKRK' => array('name' => 'Koebenhavn / Roskilde', 'lat' => 55.583333, 'long' => 12.133333),
    'EKMB' => array('name' => 'Maribo Lufthavn', 'lat' => 54.700000, 'long' => 11.450000),
    'EKOD' => array('name' => 'Odense / Beldringe', 'lat' => 55.483333, 'long' => 10.333333),
    'EKRN' => array('name' => 'Roenne', 'lat' => 55.066667, 'long' => 14.750000),
    'EKSN' => array('name' => 'Sindal Flyveplads', 'lat' => 57.500000, 'long' => 10.216667),
    'EKSP' => array('name' => 'Skrydstrup', 'lat' => 55.233333, 'long' => 9.266667),
    'EKSB' => array('name' => 'Soenderborg Lufthavn', 'lat' => 54.966667, 'long' => 9.783333),
    'EKVG' => array('name' => 'Soervaag / Vagar', 'lat' => 62.066667, 'long' => -7.283333),
    'EKVJ' => array('name' => 'Stauning Lufthavn', 'lat' => 56.000000, 'long' => 8.350000),
    'EKTS' => array('name' => 'Thisted Lufthavn', 'lat' => 57.066667, 'long' => 8.716667),
    'EKAH' => array('name' => 'Tirstrup', 'lat' => 56.300000, 'long' => 10.616667),
    'EKVD' => array('name' => 'Vamdrup', 'lat' => 55.433333, 'long' => 9.333333),
  );

  $icao_codes['Djibouti'] = array(
    'HDAM' => array('name' => 'Djibouti \ Ambouli', 'lat' => 11.550000, 'long' => 43.166667),
  );

  $icao_codes['Dominica'] = array(
    'TDCF' => array('name' => 'Canefield Airport', 'lat' => 15.533333, 'long' => -61.400000),
    'TDPD' => array('name' => 'Melville Hall Airport', 'lat' => 15.533333, 'long' => -61.300000),
  );

  $icao_codes['Dominican Republic'] = array(
    'MDHE' => array('name' => 'Herrera', 'lat' => 18.466667, 'long' => -69.966667),
    'MDLR' => array('name' => 'La Romana International Airport', 'lat' => 18.416667, 'long' => -68.950000),
    'MDSD' => array('name' => 'Las Americas', 'lat' => 18.433333, 'long' => -69.666667),
    'MDPP' => array('name' => 'Puerto Plata International', 'lat' => 19.750000, 'long' => -70.550000),
    'MDPC' => array('name' => 'Punta Cana', 'lat' => 18.566667, 'long' => -68.366667),
    'MDST' => array('name' => 'Santiago', 'lat' => 19.450000, 'long' => -70.700000),
  );

  $icao_codes['Ecuador'] = array(
    'SEGU' => array('name' => 'Guayaquil / Simon Bolivar', 'lat' => -2.150000, 'long' => -79.883333),
    'SELT' => array('name' => 'Latacunga', 'lat' => -0.916667, 'long' => -78.616667),
    'SEMT' => array('name' => 'Manta', 'lat' => -0.950000, 'long' => -80.683333),
    'SEQU' => array('name' => 'Quito / Mariscal Sucre', 'lat' => -0.150000, 'long' => -78.483333),
  );

  $icao_codes['Egypt'] = array(
    'HEAX' => array('name' => 'Alexandria / Nouzha', 'lat' => 31.200000, 'long' => 29.950000),
    'HEBA' => array('name' => 'Alexandria Borg El Arab', 'lat' => 31.516667, 'long' => 30.166667),
    'HESN' => array('name' => 'Asswan', 'lat' => 23.966667, 'long' => 32.783333),
    'HEAT' => array('name' => 'Asyut', 'lat' => 27.050000, 'long' => 31.016667),
    'HECA' => array('name' => 'Cairo Airport', 'lat' => 30.133333, 'long' => 31.400000),
    'HEAR' => array('name' => 'El Arish', 'lat' => 31.083333, 'long' => 33.816667),
    'HEGN' => array('name' => 'Hurguada', 'lat' => 27.150000, 'long' => 33.716667),
    'HELX' => array('name' => 'Luxor', 'lat' => 25.666667, 'long' => 32.700000),
    'HEMM' => array('name' => 'Mersa Matruh', 'lat' => 31.333333, 'long' => 27.216667),
    'HEPS' => array('name' => 'Port Said', 'lat' => 31.266667, 'long' => 32.300000),
    'HESH' => array('name' => 'Sharm El Sheikhintl', 'lat' => 27.966667, 'long' => 34.383333),
    'HETB' => array('name' => 'Taba', 'lat' => 29.599167, 'long' => 34.776667),
  );

  $icao_codes['El Salvador'] = array(
    'MSAC' => array('name' => 'Acajutla', 'lat' => 13.566667, 'long' => -89.833333),
    'MSLP' => array('name' => 'El Salvador Intl. Airport / Comalapa', 'lat' => 13.433333, 'long' => -89.050000),
    'MSSM' => array('name' => 'San Miguel / El Papalon', 'lat' => 13.450000, 'long' => -88.116667),
    'MSSS' => array('name' => 'San Salvador / Ilopango', 'lat' => 13.700000, 'long' => -89.116667),
    'MSSA' => array('name' => 'Santa Ana / El Palmar', 'lat' => 13.983333, 'long' => -89.566667),
  );

  $icao_codes['Equatorial Guinea'] = array(
    'FGSL' => array('name' => 'Malabo/Fernando Poo', 'lat' => 3.750000, 'long' => 8.766667),
  );

  $icao_codes['Estonia'] = array(
    'EEKA' => array('name' => 'Kardla', 'lat' => 58.983333, 'long' => 22.816667),
    'EEKE' => array('name' => 'Kuressaare', 'lat' => 58.230000, 'long' => 22.509444),
    'EEPU' => array('name' => 'Parnu', 'lat' => 58.419167, 'long' => 24.472778),
    'EETN' => array('name' => 'Tallinn', 'lat' => 59.400000, 'long' => 24.816667),
    'EETU' => array('name' => 'Tartu/Ulenurme', 'lat' => 58.300000, 'long' => 26.733333),
  );

  $icao_codes['Fiji'] = array(
    'NFFN' => array('name' => 'Nandi', 'lat' => -17.750000, 'long' => 177.450000),
    'NFNA' => array('name' => 'Nausori', 'lat' => -18.050000, 'long' => 178.566667),
  );

  $icao_codes['Finland'] = array(
    'EFET' => array('name' => 'Enontekio', 'lat' => 68.364444, 'long' => 23.427500),
    'EFHA' => array('name' => 'Halli', 'lat' => 61.850000, 'long' => 24.800000),
    'EFHF' => array('name' => 'Helsinki-Malmi', 'lat' => 60.250000, 'long' => 25.050000),
    'EFHK' => array('name' => 'Helsinki-Vantaa', 'lat' => 60.316667, 'long' => 24.966667),
    'EFIV' => array('name' => 'Ivalo', 'lat' => 68.616667, 'long' => 27.416667),
    'EFJO' => array('name' => 'Joensuu', 'lat' => 62.666667, 'long' => 29.633333),
    'EFJY' => array('name' => 'Jyvaskyla', 'lat' => 62.400000, 'long' => 25.683333),
    'EFKI' => array('name' => 'Kajaani', 'lat' => 64.283333, 'long' => 27.683333),
    'EFKA' => array('name' => 'Kauhava', 'lat' => 63.100000, 'long' => 23.033333),
    'EFKE' => array('name' => 'Kemi', 'lat' => 65.783333, 'long' => 24.583333),
    'EFKT' => array('name' => 'Kittila', 'lat' => 67.700000, 'long' => 24.850000),
    'EFKK' => array('name' => 'Kruunupyy', 'lat' => 63.716667, 'long' => 23.150000),
    'EFKU' => array('name' => 'Kuopio', 'lat' => 63.016667, 'long' => 27.800000),
    'EFKS' => array('name' => 'Kuusamo', 'lat' => 65.966667, 'long' => 29.183333),
    'EFLP' => array('name' => 'Lappeenranta', 'lat' => 61.045833, 'long' => 28.148611),
    'EFMA' => array('name' => 'Mariehamn / Aland Island', 'lat' => 60.116667, 'long' => 19.900000),
    'EFMI' => array('name' => 'Mikkeli', 'lat' => 61.733333, 'long' => 27.300000),
    'EFOU' => array('name' => 'Oulu', 'lat' => 64.933333, 'long' => 25.366667),
    'EFPO' => array('name' => 'Pori', 'lat' => 61.466667, 'long' => 21.800000),
    'EFRO' => array('name' => 'Rovaniemi', 'lat' => 66.566667, 'long' => 25.833333),
    'EFSA' => array('name' => 'Savonlinna', 'lat' => 61.950000, 'long' => 28.950000),
    'EFSI' => array('name' => 'Seinajoki-Ilmajok', 'lat' => 62.693611, 'long' => 22.831944),
    'EFTP' => array('name' => 'Tampere / Pirkkala', 'lat' => 61.416667, 'long' => 23.583333),
    'EFTU' => array('name' => 'Turku', 'lat' => 60.516667, 'long' => 22.266667),
    'EFUT' => array('name' => 'Utti', 'lat' => 60.900000, 'long' => 26.933333),
    'EFVA' => array('name' => 'Vaasa', 'lat' => 63.050000, 'long' => 21.766667),
    'EFVR' => array('name' => 'Varkaus', 'lat' => 62.166667, 'long' => 27.866667),
  );

  $icao_codes['France'] = array(
    'LFBA' => array('name' => 'Agen', 'lat' => 44.183333, 'long' => 0.600000),
    'LFKJ' => array('name' => 'Ajaccio', 'lat' => 41.916667, 'long' => 8.800000),
    'LFOA' => array('name' => 'Avord', 'lat' => 47.053333, 'long' => 2.632500),
    'LFSB' => array('name' => 'Bale-Mulhouse', 'lat' => 47.600000, 'long' => 7.516667),
    'LFKB' => array('name' => 'Bastia', 'lat' => 42.550000, 'long' => 9.483333),
    'LFOB' => array('name' => 'Beauvais', 'lat' => 49.466667, 'long' => 2.116667),
    'LFBE' => array('name' => 'Bergerac', 'lat' => 44.816667, 'long' => 0.516667),
    'LFMU' => array('name' => 'Beziers / Vias', 'lat' => 43.316667, 'long' => 3.350000),
    'LFBZ' => array('name' => 'Biarritz', 'lat' => 43.466667, 'long' => -1.533333),
    'LFBD' => array('name' => 'Bordeaux / Merignac', 'lat' => 44.833333, 'long' => -0.700000),
    'LFLD' => array('name' => 'Bourges', 'lat' => 47.066667, 'long' => 2.366667),
    'LFRB' => array('name' => 'Brest', 'lat' => 48.450000, 'long' => -4.416667),
    'LFRK' => array('name' => 'Caen', 'lat' => 49.183333, 'long' => -0.450000),
    'LFKC' => array('name' => 'Calvi', 'lat' => 42.533333, 'long' => 8.800000),
    'LFQI' => array('name' => 'Cambrai', 'lat' => 50.216667, 'long' => 3.150000),
    'LFMD' => array('name' => 'Cannes', 'lat' => 43.550000, 'long' => 6.950000),
    'LFMK' => array('name' => 'Carcassonne', 'lat' => 43.216667, 'long' => 2.316667),
    'LFBC' => array('name' => 'Cazaux', 'lat' => 44.533333, 'long' => -1.133333),
    'LFOK' => array('name' => 'Chalons-Vatry', 'lat' => 48.776111, 'long' => 4.184444),
    'LFLB' => array('name' => 'Chambery / Aix-Les-Bains', 'lat' => 45.650000, 'long' => 5.883333),
    'LFLX' => array('name' => 'Chateauroux', 'lat' => 46.850000, 'long' => 1.716667),
    'LFRC' => array('name' => 'Cherbourg / Maupertus', 'lat' => 49.650000, 'long' => -1.466667),
    'LFLC' => array('name' => 'Clermont-Ferrand', 'lat' => 45.783333, 'long' => 3.166667),
    'LFBG' => array('name' => 'Cognac', 'lat' => 45.666667, 'long' => -0.316667),
    'LFSC' => array('name' => 'Colmar', 'lat' => 47.916667, 'long' => 7.400000),
    'LFSD' => array('name' => 'Dijon', 'lat' => 47.266667, 'long' => 5.083333),
    'LFRD' => array('name' => 'Dinard', 'lat' => 48.583333, 'long' => -2.066667),
    'LFGJ' => array('name' => 'Dole Tavaux', 'lat' => 47.042778, 'long' => 5.435000),
    'LFOE' => array('name' => 'Evreux', 'lat' => 49.016667, 'long' => 1.216667),
    'LFKF' => array('name' => 'Figari', 'lat' => 41.500000, 'long' => 9.100000),
    'LFLS' => array('name' => 'Grenoble / St. Geoirs', 'lat' => 45.366667, 'long' => 5.333333),
    'NLWW' => array('name' => 'Hihifo Ile Wallis', 'lat' => -13.233333, 'long' => -176.166667),
    'LFTH' => array('name' => 'Hyeres', 'lat' => 43.100000, 'long' => 6.150000),
    'LFMI' => array('name' => 'Istres', 'lat' => 43.516667, 'long' => 4.933333),
    'LFOH' => array('name' => 'La Heve', 'lat' => 49.516667, 'long' => 0.066667),
    'LFBH' => array('name' => 'La Rochelle', 'lat' => 46.150000, 'long' => -1.150000),
    'LFRH' => array('name' => 'Lann Bihoue', 'lat' => 47.766667, 'long' => -3.450000),
    'LFRO' => array('name' => 'Lannion / Servel', 'lat' => 48.750000, 'long' => -3.466667),
    'LFRM' => array('name' => 'Le Mans', 'lat' => 47.933333, 'long' => 0.200000),
    'LFQQ' => array('name' => 'Lille', 'lat' => 50.566667, 'long' => 3.100000),
    'LFBL' => array('name' => 'Limoges', 'lat' => 45.866667, 'long' => 1.183333),
    'LFSX' => array('name' => 'Luxeuil', 'lat' => 47.783333, 'long' => 6.350000),
    'LFLY' => array('name' => 'Lyon / Bron', 'lat' => 45.716667, 'long' => 4.950000),
    'LFLL' => array('name' => 'Lyon / Satolas', 'lat' => 45.733333, 'long' => 5.083333),
    'LFML' => array('name' => 'Marseille / Marignane', 'lat' => 43.450000, 'long' => 5.233333),
    'LFSF' => array('name' => 'Metz / Frescaty', 'lat' => 49.083333, 'long' => 6.133333),
    'LFJL' => array('name' => 'Metz-Nancy-Lorraine', 'lat' => 48.983333, 'long' => 6.250000),
    'LFMT' => array('name' => 'Montpellier', 'lat' => 43.583333, 'long' => 3.966667),
    'LFSO' => array('name' => 'Nancy / Ochey', 'lat' => 48.583333, 'long' => 5.966667),
    'LFRS' => array('name' => 'Nantes', 'lat' => 47.166667, 'long' => -1.600000),
    'LFMN' => array('name' => 'Nice', 'lat' => 43.650000, 'long' => 7.200000),
    'LFTW' => array('name' => 'Nimes / Garons', 'lat' => 43.750000, 'long' => 4.416667),
    'LFMO' => array('name' => 'Orange', 'lat' => 44.133333, 'long' => 4.833333),
    'LFOJ' => array('name' => 'Orleans', 'lat' => 47.983333, 'long' => 1.750000),
    'LFPB' => array('name' => 'Paris / Le Bourget', 'lat' => 48.966667, 'long' => 2.450000),
    'LFPG' => array('name' => 'Paris-Aeroport Charles De Gaulle', 'lat' => 49.016667, 'long' => 2.533333),
    'LFPO' => array('name' => 'Paris-Orly', 'lat' => 48.733333, 'long' => 2.400000),
    'LFBP' => array('name' => 'Pau', 'lat' => 43.383333, 'long' => -0.416667),
    'LFMP' => array('name' => 'Perpignan', 'lat' => 42.733333, 'long' => 2.866667),
    'LFBI' => array('name' => 'Poitiers', 'lat' => 46.583333, 'long' => 0.316667),
    'LFRQ' => array('name' => 'Quimper', 'lat' => 47.966667, 'long' => -4.166667),
    'LFSR' => array('name' => 'Reims', 'lat' => 49.300000, 'long' => 4.033333),
    'LFRN' => array('name' => 'Rennes', 'lat' => 48.066667, 'long' => -1.733333),
    'LFCR' => array('name' => 'Rodez', 'lat' => 44.400000, 'long' => 2.483333),
    'LFOP' => array('name' => 'Rouen', 'lat' => 49.383333, 'long' => 1.183333),
    'LFRT' => array('name' => 'Saint-Brieuc', 'lat' => 48.533333, 'long' => -2.850000),
    'LFSI' => array('name' => 'St-Dizier', 'lat' => 48.633333, 'long' => 4.900000),
    'LFMH' => array('name' => 'St-Etienne Boutheon', 'lat' => 45.533333, 'long' => 4.300000),
    'LFRZ' => array('name' => 'St-Nazaire', 'lat' => 47.316667, 'long' => -2.166667),
    'LFST' => array('name' => 'Strasbourg', 'lat' => 48.550000, 'long' => 7.633333),
    'LFBT' => array('name' => 'Tarbes Ossun Lourdes', 'lat' => 43.183333, 'long' => -0.000000),
    'LFBO' => array('name' => 'Toulouse / Blagnac', 'lat' => 43.633333, 'long' => 1.366667),
    'LFOT' => array('name' => 'Tours', 'lat' => 47.450000, 'long' => 0.716667),
    'LFPN' => array('name' => 'Toussus Le Noble', 'lat' => 48.766667, 'long' => 1.100000),
    'LFQB' => array('name' => 'Troyes', 'lat' => 48.333333, 'long' => 4.016667),
    'LFLV' => array('name' => 'Vichy', 'lat' => 46.166667, 'long' => 3.400000),
    'LFPV' => array('name' => 'Villacoublay', 'lat' => 48.766667, 'long' => 2.200000),
  );

  $icao_codes['French Guiana'] = array(
    'SOCA' => array('name' => 'Cayenne / Rochambeau', 'lat' => 4.833333, 'long' => -52.366667),
  );

  $icao_codes['French Polynesia'] = array(
    'NTAA' => array('name' => 'Tahiti-Faaa', 'lat' => -17.550000, 'long' => -149.616667),
  );

  $icao_codes['Gabon'] = array(
    'FOOB' => array('name' => 'Bitam', 'lat' => 2.083333, 'long' => 11.483333),
    'FOON' => array('name' => 'Franceville / Mvengue', 'lat' => -1.650000, 'long' => 13.433333),
    'FOGR' => array('name' => 'Lambarene', 'lat' => -0.716667, 'long' => 10.233333),
    'FOOR' => array('name' => 'Lastoursville', 'lat' => -0.833333, 'long' => 12.716667),
    'FOOL' => array('name' => 'Libreville', 'lat' => 0.450000, 'long' => 9.416667),
    'FOOK' => array('name' => 'Makokou', 'lat' => 0.566667, 'long' => 12.866667),
    'FOOG' => array('name' => 'Port-Gentil', 'lat' => -0.700000, 'long' => 8.750000),
    'FOOT' => array('name' => 'Tchibanga', 'lat' => -2.850000, 'long' => 11.016667),
  );

  $icao_codes['Georgia'] = array(
    'UGGG' => array('name' => 'Tbilisi', 'lat' => 41.683333, 'long' => 44.950000),
  );

  $icao_codes['Germany'] = array(
    'EDAC' => array('name' => 'Altenburg Nobitz', 'lat' => 50.966667, 'long' => 12.500000),
    'ETHA' => array('name' => 'Altenstadt', 'lat' => 47.833333, 'long' => 10.866667),
    'EDMA' => array('name' => 'Augsburg', 'lat' => 48.433333, 'long' => 10.933333),
    'EDFM' => array('name' => 'Baden Wurttemberg, Neuostheim', 'lat' => 49.472500, 'long' => 8.515556),
    'EDQD' => array('name' => 'Bayreuth', 'lat' => 49.983333, 'long' => 11.633333),
    'EDDB' => array('name' => 'Berlin-Schoenefeld', 'lat' => 52.383333, 'long' => 13.516667),
    'EDDT' => array('name' => 'Berlin-Tegel', 'lat' => 52.566667, 'long' => 13.316667),
    'EDDI' => array('name' => 'Berlin-Tempelhof', 'lat' => 52.466667, 'long' => 13.400000),
    'EDVE' => array('name' => 'Braunschweig', 'lat' => 52.300000, 'long' => 10.450000),
    'EDDW' => array('name' => 'Bremen', 'lat' => 53.050000, 'long' => 8.800000),
    'ETSB' => array('name' => 'Buechel', 'lat' => 50.166667, 'long' => 7.066667),
    'ETHB' => array('name' => 'Bueckeburg', 'lat' => 52.283333, 'long' => 9.083333),
    'ETHC' => array('name' => 'Celle', 'lat' => 52.600000, 'long' => 10.016667),
    'ETND' => array('name' => 'Diepholz', 'lat' => 52.583333, 'long' => 8.350000),
    'EDTD' => array('name' => 'Donaueschingen / Villingen', 'lat' => 47.966667, 'long' => 8.516667),
    'EDLW' => array('name' => 'Dortmund / Wickede', 'lat' => 51.516667, 'long' => 7.616667),
    'EDDC' => array('name' => 'Dresden-Klotzsche', 'lat' => 51.133333, 'long' => 13.750000),
    'EDDL' => array('name' => 'Duesseldorf', 'lat' => 51.300000, 'long' => 6.766667),
    'ETSE' => array('name' => 'Erding', 'lat' => 48.316667, 'long' => 11.950000),
    'EDDE' => array('name' => 'Erfurt-Bindersleben', 'lat' => 50.983333, 'long' => 10.966667),
    'EDDF' => array('name' => 'Frankfurt / M-Flughafen', 'lat' => 50.050000, 'long' => 8.600000),
    'EDNY' => array('name' => 'Friedrichshafen', 'lat' => 47.666667, 'long' => 9.516667),
    'ETHF' => array('name' => 'Fritzlar', 'lat' => 51.116667, 'long' => 9.283333),
    'ETGG' => array('name' => 'Gluecksburg / Meierwik', 'lat' => 54.833333, 'long' => 9.500000),
    'ETUO' => array('name' => 'Guetersloh', 'lat' => 51.916667, 'long' => 8.300000),
    'EDFH' => array('name' => 'Hahn', 'lat' => 49.950000, 'long' => 7.266667),
    'EDHI' => array('name' => 'Hamburg-Finkenwerder', 'lat' => 53.533333, 'long' => 9.833333),
    'EDDH' => array('name' => 'Hamburg-Fuhlsbuettel', 'lat' => 53.633333, 'long' => 10.000000),
    'EDDV' => array('name' => 'Hannover', 'lat' => 52.466667, 'long' => 9.683333),
    'EDAH' => array('name' => 'Heringsdorf', 'lat' => 53.883333, 'long' => 14.150000),
    'EDGS' => array('name' => 'Hessen', 'lat' => 50.707778, 'long' => 8.083056),
    'EDQM' => array('name' => 'Hof', 'lat' => 50.316667, 'long' => 11.883333),
    'ETNH' => array('name' => 'Hohn', 'lat' => 54.316667, 'long' => 9.533333),
    'ETSH' => array('name' => 'Holzdorf', 'lat' => 51.766667, 'long' => 13.183333),
    'ETSI' => array('name' => 'Ingolstadt', 'lat' => 48.716667, 'long' => 11.533333),
    'ETNJ' => array('name' => 'Jever', 'lat' => 53.533333, 'long' => 7.883333),
    'ETGY' => array('name' => 'Kalkar', 'lat' => 51.733333, 'long' => 6.266667),
    'EDSB' => array('name' => 'Karlsruhe, Baden Wurttemberg', 'lat' => 48.778611, 'long' => 8.079722),
    'EDVK' => array('name' => 'Kassel / Calden', 'lat' => 51.400000, 'long' => 9.383333),
    'EDHK' => array('name' => 'Kiel / Holtenau Civilian', 'lat' => 54.383333, 'long' => 10.166667),
    'EDDK' => array('name' => 'Koeln / Bonn', 'lat' => 50.866667, 'long' => 7.166667),
    'ETNL' => array('name' => 'Laage', 'lat' => 53.916667, 'long' => 12.283333),
    'EDTL' => array('name' => 'Lahr, CAN-AFB', 'lat' => 48.369167, 'long' => 7.827778),
    'ETSA' => array('name' => 'Landsberg', 'lat' => 48.066667, 'long' => 10.900000),
    'ETHL' => array('name' => 'Laupheim', 'lat' => 48.216667, 'long' => 9.916667),
    'ETSL' => array('name' => 'Lechfeld', 'lat' => 48.183333, 'long' => 10.866667),
    'EDDP' => array('name' => 'Leipzig-Schkeuditz', 'lat' => 51.416667, 'long' => 12.233333),
    'EDHL' => array('name' => 'Luebeck-Blankensee', 'lat' => 53.816667, 'long' => 10.700000),
    'EDBM' => array('name' => 'Magdeburg, Sachsen-Anhalt', 'lat' => 52.076389, 'long' => 11.623611),
    'EDOP' => array('name' => 'Mecklenburg-Vorpommern, Parchim', 'lat' => 53.426944, 'long' => 11.783611),
    'ETHM' => array('name' => 'Mendig', 'lat' => 50.366667, 'long' => 7.316667),
    'ETWM' => array('name' => 'Meppen-Mil', 'lat' => 52.723333, 'long' => 7.326389),
    'ETGZ' => array('name' => 'Messstetten', 'lat' => 48.183333, 'long' => 9.000000),
    'EDLN' => array('name' => 'Monchengladbach', 'lat' => 51.230278, 'long' => 6.504444),
    'EDDG' => array('name' => 'Muenster / Osnabrueck', 'lat' => 52.133333, 'long' => 7.700000),
    'EDDM' => array('name' => 'Munchen', 'lat' => 48.350000, 'long' => 11.783333),
    'ETSN' => array('name' => 'Neuburg / Donau', 'lat' => 48.716667, 'long' => 11.216667),
    'EDLV' => array('name' => 'Niederrhein', 'lat' => 51.602500, 'long' => 6.142222),
    'ETHN' => array('name' => 'Niederstetten', 'lat' => 49.400000, 'long' => 9.966667),
    'ETNN' => array('name' => 'Noervenich', 'lat' => 50.833333, 'long' => 6.666667),
    'ETMN' => array('name' => 'Nordholz', 'lat' => 53.766667, 'long' => 8.666667),
    'EDDN' => array('name' => 'Nuernberg', 'lat' => 49.500000, 'long' => 11.050000),
    'EDMO' => array('name' => 'Oberpfaffenhofen', 'lat' => 48.083333, 'long' => 11.283333),
    'EDLP' => array('name' => 'Paderborn / Lippstadt', 'lat' => 51.616667, 'long' => 8.616667),
    'ETAR' => array('name' => 'Ramstein', 'lat' => 49.433333, 'long' => 7.600000),
    'ETHE' => array('name' => 'Rheine-Bentlage', 'lat' => 52.300000, 'long' => 7.383333),
    'ETHR' => array('name' => 'Roth', 'lat' => 49.216667, 'long' => 11.100000),
    'EDDR' => array('name' => 'Saarbruecken / Ensheim', 'lat' => 49.216667, 'long' => 7.116667),
    'ETNS' => array('name' => 'Schleswig-Jagel', 'lat' => 54.466667, 'long' => 9.516667),
    'ETAD' => array('name' => 'Spangdahlem', 'lat' => 49.983333, 'long' => 6.700000),
    'EDDS' => array('name' => 'Stuttgart-Echterdingen', 'lat' => 48.683333, 'long' => 9.216667),
    'ETNU' => array('name' => 'Trollenhagen', 'lat' => 53.600000, 'long' => 13.316667),
    'EDXW' => array('name' => 'Westerland / Sylt', 'lat' => 54.916667, 'long' => 8.350000),
    'ETOU' => array('name' => 'Wiesbaden', 'lat' => 50.050000, 'long' => 8.333333),
    'ETNT' => array('name' => 'Wittmundhaven', 'lat' => 53.550000, 'long' => 7.666667),
    'ETNW' => array('name' => 'Wunstorf', 'lat' => 52.450000, 'long' => 9.433333),
    'EDRZ' => array('name' => 'Zweibrucken, Rheinland-Pfalz', 'lat' => 49.209444, 'long' => 7.401111),
  );

  $icao_codes['Ghana'] = array(
    'DGAA' => array('name' => 'Accra', 'lat' => 5.600000, 'long' => -0.166667),
    'DGSI' => array('name' => 'Kumasi', 'lat' => 6.716667, 'long' => -1.600000),
  );

  $icao_codes['Gibraltar'] = array(
    'LXGB' => array('name' => 'Gibraltar', 'lat' => 36.150000, 'long' => -5.350000),
  );

  $icao_codes['Greece'] = array(
    'LGPZ' => array('name' => 'Aktion Airport', 'lat' => 38.616667, 'long' => 20.766667),
    'LGAL' => array('name' => 'Alexandroupoli Airport', 'lat' => 40.850000, 'long' => 25.916667),
    'LGAD' => array('name' => 'Andravida Airport', 'lat' => 37.916667, 'long' => 21.283333),
    'LGRX' => array('name' => 'Araxos Airport', 'lat' => 38.150000, 'long' => 21.416667),
    'LGAV' => array('name' => 'Athens Eleftherios Venizelos International Airport', 'lat' => 37.933333, 'long' => 23.933333),
    'LGHI' => array('name' => 'Chios Airport', 'lat' => 38.333333, 'long' => 26.133333),
    'LGKV' => array('name' => 'Chrysoupoli Airport', 'lat' => 40.983333, 'long' => 24.600000),
    'LGNX' => array('name' => 'Cyclades Islands, Naxos Airport', 'lat' => 37.079722, 'long' => 25.366944),
    'LGEL' => array('name' => 'Elefsis Airport', 'lat' => 38.066667, 'long' => 23.550000),
    'LGIR' => array('name' => 'Heraklion Airport', 'lat' => 35.333333, 'long' => 25.183333),
    'LGKL' => array('name' => 'Kalamata Airport', 'lat' => 37.066667, 'long' => 22.016667),
    'LGKP' => array('name' => 'Karpathos Airport', 'lat' => 35.414167, 'long' => 27.148333),
    'LGKF' => array('name' => 'Kefalhnia Airport', 'lat' => 38.116667, 'long' => 20.500000),
    'LGKR' => array('name' => 'Kerkyra Airport', 'lat' => 39.616667, 'long' => 19.916667),
    'LGKC' => array('name' => 'Kithira Airport', 'lat' => 36.289167, 'long' => 23.023333),
    'LGKO' => array('name' => 'Kos Airport', 'lat' => 36.783333, 'long' => 27.066667),
    'LGKZ' => array('name' => 'Kozani Airport', 'lat' => 40.300000, 'long' => 21.783333),
    'LGLM' => array('name' => 'Limnos Airport', 'lat' => 39.916667, 'long' => 25.233333),
    'LGMK' => array('name' => 'Mikonos Island, Mikonos Airport', 'lat' => 37.435833, 'long' => 25.345833),
    'LGMT' => array('name' => 'Mytilini Airport', 'lat' => 39.066667, 'long' => 26.600000),
    'LGPA' => array('name' => 'Paros Community Airport', 'lat' => 37.011111, 'long' => 25.125556),
    'LGRP' => array('name' => 'Rhodes Airport', 'lat' => 36.400000, 'long' => 28.083333),
    'LGSM' => array('name' => 'Samos Airport', 'lat' => 37.700000, 'long' => 26.916667),
    'LGSR' => array('name' => 'Santorini Island', 'lat' => 36.400000, 'long' => 25.483333),
    'LGSK' => array('name' => 'Skiathos Island', 'lat' => 39.183333, 'long' => 23.500000),
    'LGSA' => array('name' => 'Souda Airport', 'lat' => 35.483333, 'long' => 24.116667),
    'LGSO' => array('name' => 'Syros Airport', 'lat' => 37.421111, 'long' => 24.948333),
    'LGTS' => array('name' => 'Thessaloniki Airport', 'lat' => 40.516667, 'long' => 22.966667),
    'LGZA' => array('name' => 'Zakinthos Airport', 'lat' => 37.750000, 'long' => 20.883333),
  );

  $icao_codes['Greenland'] = array(
    'BGCO' => array('name' => 'Constable Pynt', 'lat' => 70.750000, 'long' => -22.650000),
    'BGGH' => array('name' => 'Godthaab / Nuuk', 'lat' => 64.166667, 'long' => -51.750000),
    'BGJN' => array('name' => 'Jacobshavn Lufthavn', 'lat' => 69.233333, 'long' => -51.066667),
    'BGKK' => array('name' => 'Kulusuk Lufthavn', 'lat' => 65.583333, 'long' => -37.150000),
    'BGBW' => array('name' => 'Narsarsuaq', 'lat' => 61.166667, 'long' => -45.416667),
    'BGSF' => array('name' => 'Sdr Stroemfjord', 'lat' => 67.016667, 'long' => -50.700000),
    'BGTL' => array('name' => 'Thule A. B.', 'lat' => 76.533333, 'long' => -68.750000),
  );

  $icao_codes['Grenada'] = array(
    'TGPY' => array('name' => 'Point Salines Airport', 'lat' => 12.000000, 'long' => -61.783333),
  );

  $icao_codes['Guadeloupe'] = array(
    'TFFR' => array('name' => 'Le Raizet, Guadeloupe', 'lat' => 16.266667, 'long' => -61.516667),
  );

  $icao_codes['Guatemala'] = array(
    'MGGT' => array('name' => 'Guatemala Aeropuertola Aurora', 'lat' => 14.583333, 'long' => -90.516667),
    'MGHT' => array('name' => 'Huehuetenango', 'lat' => 15.316667, 'long' => -91.466667),
    'MGPB' => array('name' => 'Puerto Barrios', 'lat' => 15.716667, 'long' => -88.600000),
    'MGSJ' => array('name' => 'San Jose', 'lat' => 13.916667, 'long' => -90.816667),
    'MGTK' => array('name' => 'Tikal', 'lat' => 16.900000, 'long' => -89.850000),
  );

  $icao_codes['Guinea'] = array(
    'GUCY' => array('name' => 'Conakry / Gbessia', 'lat' => 9.566667, 'long' => -13.616667),
  );

  $icao_codes['Guyana'] = array(
    'SYCJ' => array('name' => 'Georgetown/Cheddi Jagan International Airport', 'lat' => 6.483333, 'long' => -58.250000),
  );

  $icao_codes['Haiti'] = array(
    'MTPP' => array('name' => 'Port-Au-Prince / Aeroport International', 'lat' => 18.566667, 'long' => -72.300000),
  );

  $icao_codes['Honduras'] = array(
    'MHAM' => array('name' => 'Amapala', 'lat' => 13.266667, 'long' => -87.650000),
    'MHCA' => array('name' => 'Catacamas', 'lat' => 14.900000, 'long' => -85.933333),
    'MHCH' => array('name' => 'Choluteca', 'lat' => 13.300000, 'long' => -87.183333),
    'MHSC' => array('name' => 'Coronel Enrique Soto Cano Air Base', 'lat' => 14.383333, 'long' => -87.616667),
    'MHNO' => array('name' => 'Guanaja', 'lat' => 16.466667, 'long' => -86.066667),
    'MHLC' => array('name' => 'La Ceiba Airport', 'lat' => 15.733333, 'long' => -86.866667),
    'MHLE' => array('name' => 'La Esperanza', 'lat' => 14.316667, 'long' => -88.150000),
    'MHLM' => array('name' => 'La Mesa San Pedro Sula', 'lat' => 15.450000, 'long' => -87.933333),
    'MHPL' => array('name' => 'Puerto Lempira', 'lat' => 15.216667, 'long' => -83.800000),
    'MHRO' => array('name' => 'Roatan', 'lat' => 16.316667, 'long' => -86.516667),
    'MHSR' => array('name' => 'Santa Rosa De Copan', 'lat' => 14.783333, 'long' => -88.783333),
    'MHTG' => array('name' => 'Tegucigalpa', 'lat' => 14.050000, 'long' => -87.216667),
    'MHTE' => array('name' => 'Tela', 'lat' => 15.716667, 'long' => -87.483333),
    'MHYR' => array('name' => 'Yoro', 'lat' => 15.166667, 'long' => -87.116667),
  );

  $icao_codes['Hong Kong'] = array(
    'VHHH' => array('name' => 'Hong Kong Inter-National Airport', 'lat' => 22.333333, 'long' => 114.183333),
  );

  $icao_codes['Hungary'] = array(
    'LHBP' => array('name' => 'Budapest / Ferihegy', 'lat' => 47.433333, 'long' => 19.266667),
    'LHDC' => array('name' => 'Debrecen', 'lat' => 47.483333, 'long' => 21.600000),
    'LHKE' => array('name' => 'Kecskemet', 'lat' => 46.916667, 'long' => 19.750000),
    'LHPP' => array('name' => 'Pecs / Pogany', 'lat' => 46.100000, 'long' => 18.233333),
    'LHUD' => array('name' => 'Szeged', 'lat' => 46.250000, 'long' => 20.100000),
    'LHSN' => array('name' => 'Szolnok', 'lat' => 47.116667, 'long' => 20.233333),
  );

  $icao_codes['Iceland'] = array(
    'BIAR' => array('name' => 'Akureyri', 'lat' => 65.683333, 'long' => -18.083333),
    'BIEG' => array('name' => 'Egilsstadir', 'lat' => 65.283333, 'long' => -14.400000),
    'BIKF' => array('name' => 'Keflavikurflugvollur', 'lat' => 63.966667, 'long' => -22.600000),
    'BIRK' => array('name' => 'Reykjavik', 'lat' => 64.133333, 'long' => -21.900000),
  );

  $icao_codes['India'] = array(
    'VAAH' => array('name' => 'Ahmadabad', 'lat' => 23.066667, 'long' => 72.633333),
    'VIAR' => array('name' => 'Amritsar', 'lat' => 31.633333, 'long' => 74.866667),
    'VOBG' => array('name' => 'Bangalore / Hindustan', 'lat' => 12.950000, 'long' => 77.666667),
    'VABB' => array('name' => 'Bombay / Santacruz', 'lat' => 19.116667, 'long' => 72.850000),
    'VOHY' => array('name' => 'Hyderabad Airport', 'lat' => 17.450000, 'long' => 78.466667),
    'VIJP' => array('name' => 'Jaipur / Sanganer', 'lat' => 26.816667, 'long' => 75.800000),
    'VILK' => array('name' => 'Lucknow / Amausi', 'lat' => 26.750000, 'long' => 80.883333),
    'VOMM' => array('name' => 'Madras / Minambakkam', 'lat' => 13.000000, 'long' => 80.183333),
    'VANP' => array('name' => 'Nagpur Sonegaon', 'lat' => 21.100000, 'long' => 79.050000),
    'VIDP' => array('name' => 'New Delhi / Palam', 'lat' => 28.566667, 'long' => 77.116667),
    'VOTV' => array('name' => 'Thiruvananthapuram', 'lat' => 8.466667, 'long' => 76.950000),
    'VOTR' => array('name' => 'Tiruchchirapalli', 'lat' => 10.766667, 'long' => 78.716667),
    'VIBN' => array('name' => 'Varanasi / Babatpur', 'lat' => 25.450000, 'long' => 82.866667),
  );

  $icao_codes['Indonesia'] = array(
    'WABB' => array('name' => 'Biak / Mokmer', 'lat' => -1.183333, 'long' => 136.116667),
    'WIII' => array('name' => 'Jakarta / Soekarno-Hatta', 'lat' => -6.116667, 'long' => 106.650000),
    'WIMM' => array('name' => 'Medan / Polonia', 'lat' => 3.566667, 'long' => 98.683333),
    'WAAA' => array('name' => 'Ujung Pandang / Hasanuddin', 'lat' => -5.066667, 'long' => 119.550000),
  );

  $icao_codes['Iran'] = array(
    'OIAA' => array('name' => 'Abadan', 'lat' => 30.366667, 'long' => 48.250000),
    'OIAW' => array('name' => 'Ahwaz', 'lat' => 31.333333, 'long' => 48.666667),
    'OITL' => array('name' => 'Ardabil', 'lat' => 38.326389, 'long' => 48.424444),
    'OIKB' => array('name' => 'Bandarabbass', 'lat' => 27.216667, 'long' => 56.366667),
    'OIBB' => array('name' => 'Bushehr Civ / Afb', 'lat' => 28.983333, 'long' => 50.833333),
    'OIFM' => array('name' => 'Esfahan', 'lat' => 32.466667, 'long' => 51.716667),
    'OIHH' => array('name' => 'Hamadan', 'lat' => 34.868056, 'long' => 48.552222),
    'OIIP' => array('name' => 'Karaj / Payam', 'lat' => 35.776111, 'long' => 50.826667),
    'OIKK' => array('name' => 'Kerman', 'lat' => 30.250000, 'long' => 56.966667),
    'OICC' => array('name' => 'Kermanshah', 'lat' => 34.266667, 'long' => 47.116667),
    'OICK' => array('name' => 'Khorram Abad', 'lat' => 33.436389, 'long' => 48.285833),
    'OIBK' => array('name' => 'Kish Island / Kish', 'lat' => 26.526667, 'long' => 53.981667),
    'OIMM' => array('name' => 'Mashhad', 'lat' => 36.266667, 'long' => 59.633333),
    'OINN' => array('name' => 'Noshahr', 'lat' => 36.663333, 'long' => 51.464722),
    'OITR' => array('name' => 'Orumieh', 'lat' => 37.533333, 'long' => 45.083333),
    'OINR' => array('name' => 'Ramsar', 'lat' => 36.900000, 'long' => 50.666667),
    'OIGG' => array('name' => 'Rasht', 'lat' => 37.200000, 'long' => 49.633333),
    'OICS' => array('name' => 'Sanandaj', 'lat' => 35.333333, 'long' => 47.000000),
    'OISS' => array('name' => 'Shiraz', 'lat' => 29.533333, 'long' => 52.583333),
    'OITT' => array('name' => 'Tabriz', 'lat' => 38.083333, 'long' => 46.283333),
    'OIII' => array('name' => 'Tehran-Mehrabad', 'lat' => 35.683333, 'long' => 51.350000),
    'OIYY' => array('name' => 'Yazd', 'lat' => 31.900000, 'long' => 54.400000),
    'OIZH' => array('name' => 'Zahedan', 'lat' => 29.466667, 'long' => 60.883333),
  );

  $icao_codes['Ireland'] = array(
    'EIKN' => array('name' => 'Connaught', 'lat' => 53.910278, 'long' => -8.818056),
    'EICK' => array('name' => 'Cork Airport', 'lat' => 51.850000, 'long' => -8.483333),
    'EIDW' => array('name' => 'Dublin Airport', 'lat' => 53.433333, 'long' => -6.250000),
    'EINN' => array('name' => 'Shannon Airport', 'lat' => 52.700000, 'long' => -8.916667),
  );

  $icao_codes['Israel'] = array(
    'LLBG' => array('name' => 'Ben-Gurion International Airport', 'lat' => 32.000000, 'long' => 34.900000),
    'LLET' => array('name' => 'Eilat', 'lat' => 29.550000, 'long' => 34.950000),
    'LLIB' => array('name' => 'Galilee / Pina', 'lat' => 32.980000, 'long' => 35.570000),
    'LLOV' => array('name' => 'Ovda', 'lat' => 30.000000, 'long' => 34.833333),
    'LLSD' => array('name' => 'Tel Aviv / Sde-Dov Airport', 'lat' => 32.114722, 'long' => 34.782222),
  );

  $icao_codes['Italy'] = array(
    'LIMG' => array('name' => 'Albenga', 'lat' => 44.050000, 'long' => 8.116667),
    'LIEA' => array('name' => 'Alghero', 'lat' => 40.633333, 'long' => 8.283333),
    'LIBA' => array('name' => 'Amendola', 'lat' => 41.533333, 'long' => 15.716667),
    'LIPA' => array('name' => 'Aviano', 'lat' => 46.033333, 'long' => 12.600000),
    'LIYW' => array('name' => 'Aviano Usaf', 'lat' => 46.033333, 'long' => 12.616667),
    'LIBD' => array('name' => 'Bari / Palese Macchie', 'lat' => 41.133333, 'long' => 16.783333),
    'LIME' => array('name' => 'Bergamo / Orio Al Serio', 'lat' => 45.666667, 'long' => 9.700000),
    'LIPE' => array('name' => 'Bologna / Borgo Panigale', 'lat' => 44.533333, 'long' => 11.300000),
    'LIPB' => array('name' => 'Bolzano', 'lat' => 46.466667, 'long' => 11.333333),
    'LIPL' => array('name' => 'Brescia / Ghedi', 'lat' => 45.416667, 'long' => 10.283333),
    'LIPO' => array('name' => 'Brescia / Montichia', 'lat' => 45.400556, 'long' => 10.316389),
    'LIBR' => array('name' => 'Brindisi', 'lat' => 40.650000, 'long' => 17.950000),
    'LIEE' => array('name' => 'Cagliari / Elmas', 'lat' => 39.250000, 'long' => 9.066667),
    'LIMU' => array('name' => 'Capo Mele', 'lat' => 43.950000, 'long' => 8.166667),
    'LICC' => array('name' => 'Catania / Fontanarossa', 'lat' => 37.466667, 'long' => 15.050000),
    'LICZ' => array('name' => 'Catania / Sigonella', 'lat' => 37.400000, 'long' => 14.916667),
    'LIPC' => array('name' => 'Cervia', 'lat' => 44.216667, 'long' => 12.300000),
    'LIBC' => array('name' => 'Crotone', 'lat' => 39.000000, 'long' => 17.066667),
    'LIMZ' => array('name' => 'Cuneo / Levaldigi', 'lat' => 44.546389, 'long' => 7.622222),
    'LIED' => array('name' => 'Decimomannu', 'lat' => 39.350000, 'long' => 8.966667),
    'LIVD' => array('name' => 'Dobbiaco', 'lat' => 46.733333, 'long' => 12.216667),
    'LIPY' => array('name' => 'Falconara', 'lat' => 43.616667, 'long' => 13.366667),
    'LIPF' => array('name' => 'Ferrara', 'lat' => 44.833333, 'long' => 11.616667),
    'LIRQ' => array('name' => 'Firenze / Peretola', 'lat' => 43.800000, 'long' => 11.200000),
    'LIPK' => array('name' => 'Forli', 'lat' => 44.200000, 'long' => 12.066667),
    'LIVF' => array('name' => 'Frontone', 'lat' => 43.516667, 'long' => 12.733333),
    'LIRH' => array('name' => 'Frosinone', 'lat' => 41.633333, 'long' => 13.300000),
    'LIMJ' => array('name' => 'Genova / Sestri', 'lat' => 44.416667, 'long' => 8.850000),
    'LIBV' => array('name' => 'Gioia Del Colle', 'lat' => 40.766667, 'long' => 16.933333),
    'LIRM' => array('name' => 'Grazzanise', 'lat' => 41.050000, 'long' => 14.066667),
    'LIRS' => array('name' => 'Grosseto', 'lat' => 42.750000, 'long' => 11.066667),
    'LIBG' => array('name' => 'Grottaglie', 'lat' => 40.516667, 'long' => 17.400000),
    'LIRG' => array('name' => 'Guidonia', 'lat' => 42.000000, 'long' => 12.733333),
    'LICA' => array('name' => 'Lamezia Terme', 'lat' => 38.900000, 'long' => 16.250000),
    'LICD' => array('name' => 'Lampedusa', 'lat' => 35.500000, 'long' => 12.600000),
    'LIRL' => array('name' => 'Latina', 'lat' => 41.550000, 'long' => 12.900000),
    'LIBN' => array('name' => 'Lecce', 'lat' => 40.233333, 'long' => 18.150000),
    'LIML' => array('name' => 'Milano / Linate', 'lat' => 45.433333, 'long' => 9.283333),
    'LIMC' => array('name' => 'Milano / Malpensa', 'lat' => 45.616667, 'long' => 8.733333),
    'LIQO' => array('name' => 'Monte Argentario', 'lat' => 42.383333, 'long' => 11.166667),
    'LIVC' => array('name' => 'Monte Cimone', 'lat' => 44.200000, 'long' => 10.700000),
    'LIMY' => array('name' => 'Monte Malanotte', 'lat' => 44.250000, 'long' => 7.800000),
    'LIBQ' => array('name' => 'Monte Scuro', 'lat' => 39.333333, 'long' => 16.400000),
    'LIRK' => array('name' => 'Monte Terminillo', 'lat' => 42.466667, 'long' => 12.983333),
    'LIRN' => array('name' => 'Napoli / Capodichino', 'lat' => 40.850000, 'long' => 14.300000),
    'LIMN' => array('name' => 'Novara / Cameri', 'lat' => 45.516667, 'long' => 8.666667),
    'LIEO' => array('name' => 'Olbia / Costa Smeralda', 'lat' => 40.900000, 'long' => 9.516667),
    'LIVP' => array('name' => 'Paganella', 'lat' => 46.150000, 'long' => 11.033333),
    'LICJ' => array('name' => 'Palermo / Punta Raisi', 'lat' => 38.183333, 'long' => 13.100000),
    'LICP' => array('name' => 'Palermo Boccadifalco', 'lat' => 38.100000, 'long' => 13.300000),
    'LICG' => array('name' => 'Pantelleria', 'lat' => 36.816667, 'long' => 11.966667),
    'LIMP' => array('name' => 'Parma', 'lat' => 44.821389, 'long' => 10.294722),
    'LIMV' => array('name' => 'Passo Dei Giovi', 'lat' => 44.633333, 'long' => 8.933333),
    'LIMT' => array('name' => 'Passo Della Cisa', 'lat' => 44.433333, 'long' => 9.933333),
    'LIVR' => array('name' => 'Passo Rolle', 'lat' => 46.300000, 'long' => 11.783333),
    'LIRZ' => array('name' => 'Perugia', 'lat' => 43.083333, 'long' => 12.500000),
    'LIBP' => array('name' => 'Pescara', 'lat' => 42.433333, 'long' => 14.200000),
    'LIMS' => array('name' => 'Piacenza', 'lat' => 44.916667, 'long' => 9.733333),
    'LIMH' => array('name' => 'Pian Rosa', 'lat' => 45.933333, 'long' => 7.700000),
    'LIRP' => array('name' => 'Pisa / S. Giusto', 'lat' => 43.683333, 'long' => 10.383333),
    'LIRE' => array('name' => 'Pratica Di Mare', 'lat' => 41.650000, 'long' => 12.450000),
    'LIVM' => array('name' => 'Punta Marina', 'lat' => 44.450000, 'long' => 12.300000),
    'LICR' => array('name' => 'Reggio Calabria', 'lat' => 38.066667, 'long' => 15.650000),
    'LIVE' => array('name' => 'Resia Pass', 'lat' => 46.833333, 'long' => 10.500000),
    'LIQN' => array('name' => 'Rieti', 'lat' => 42.416667, 'long' => 12.850000),
    'LIPR' => array('name' => 'Rimini', 'lat' => 44.033333, 'long' => 12.616667),
    'LIRA' => array('name' => 'Roma / Ciampino', 'lat' => 41.783333, 'long' => 12.583333),
    'LIRU' => array('name' => 'Roma / Urbe', 'lat' => 41.950000, 'long' => 12.500000),
    'LIRF' => array('name' => 'Roma Fiumicino', 'lat' => 41.800000, 'long' => 12.233333),
    'LIPQ' => array('name' => 'Ronchi Dei Legionari', 'lat' => 45.816667, 'long' => 13.483333),
    'LIQW' => array('name' => 'Sarzana / Luni', 'lat' => 44.083333, 'long' => 9.983333),
    'LIVO' => array('name' => 'Tarvisio', 'lat' => 46.500000, 'long' => 13.583333),
    'LIMK' => array('name' => 'Torino / Bric Della Croce', 'lat' => 45.033333, 'long' => 7.733333),
    'LIMF' => array('name' => 'Torino / Caselle', 'lat' => 45.216667, 'long' => 7.650000),
    'LICT' => array('name' => 'Trapani / Birgi', 'lat' => 37.916667, 'long' => 12.500000),
    'LIRT' => array('name' => 'Trevico', 'lat' => 41.050000, 'long' => 15.233333),
    'LIPS' => array('name' => 'Treviso / Istrana', 'lat' => 45.683333, 'long' => 12.100000),
    'LIPH' => array('name' => 'Treviso / S. Angelo', 'lat' => 45.650000, 'long' => 12.183333),
    'LIVT' => array('name' => 'Trieste', 'lat' => 45.650000, 'long' => 13.750000),
    'LIPI' => array('name' => 'Udine / Rivolto', 'lat' => 45.983333, 'long' => 13.033333),
    'LIPZ' => array('name' => 'Venezia / Tessera', 'lat' => 45.500000, 'long' => 12.333333),
    'LIPX' => array('name' => 'Verona / Villafranca', 'lat' => 45.383333, 'long' => 10.866667),
    'LIPT' => array('name' => 'Vicenza', 'lat' => 45.566667, 'long' => 11.516667),
    'LIRV' => array('name' => 'Viterbo', 'lat' => 42.433333, 'long' => 12.050000),
  );

  $icao_codes['Jamaica'] = array(
    'MKJP' => array('name' => 'Kingston / Norman Manley', 'lat' => 17.933333, 'long' => -76.783333),
    'MKJS' => array('name' => 'Montego Bay / Sangster', 'lat' => 18.500000, 'long' => -77.916667),
  );

  $icao_codes['Japan'] = array(
    'RJOE' => array('name' => 'Akeno Ab', 'lat' => 34.533333, 'long' => 136.683333),
    'RJSK' => array('name' => 'Akita Airport', 'lat' => 39.616667, 'long' => 140.216667),
    'RJKA' => array('name' => 'Amami Airport', 'lat' => 28.433333, 'long' => 129.716667),
    'RJSA' => array('name' => 'Aomori Airport', 'lat' => 40.733333, 'long' => 140.700000),
    'RJCA' => array('name' => 'Asahikawa Ab', 'lat' => 43.800000, 'long' => 142.366667),
    'RJEC' => array('name' => 'Asahikawa Airport', 'lat' => 43.666667, 'long' => 142.450000),
    'RJFA' => array('name' => 'Ashiya Ab', 'lat' => 33.883333, 'long' => 130.650000),
    'RJTA' => array('name' => 'Atsugi United States Naval Air Station', 'lat' => 35.450000, 'long' => 139.450000),
    'RJCC' => array('name' => 'Chitose Ab', 'lat' => 42.800000, 'long' => 141.666667),
    'RJCJ' => array('name' => 'Chitose Japanese Air Self Defense Force', 'lat' => 42.816667, 'long' => 141.683333),
    'RJTF' => array('name' => 'Chofu Airport', 'lat' => 35.666667, 'long' => 139.533333),
    'RJAT' => array('name' => 'Fuji Ab', 'lat' => 35.316667, 'long' => 138.866667),
    'RJFE' => array('name' => 'Fukue Airport', 'lat' => 32.666667, 'long' => 128.833333),
    'RJNF' => array('name' => 'Fukui Airport', 'lat' => 36.133333, 'long' => 136.233333),
    'RJFF' => array('name' => 'Fukuoka Airport', 'lat' => 33.583333, 'long' => 130.450000),
    'RJSF' => array('name' => 'Fukushima Airport', 'lat' => 37.233333, 'long' => 140.433333),
    'ROTM' => array('name' => 'Futenma Marine Corps Air Facility', 'lat' => 26.266667, 'long' => 127.750000),
    'RJNG' => array('name' => 'Gifu Ab', 'lat' => 35.383333, 'long' => 136.866667),
    'RJTH' => array('name' => 'Hachijojima Airport', 'lat' => 33.116667, 'long' => 139.783333),
    'RJSH' => array('name' => 'Hachinohe Ab', 'lat' => 40.550000, 'long' => 141.466667),
    'RJCH' => array('name' => 'Hakodate Airport', 'lat' => 41.766667, 'long' => 140.816667),
    'RJNH' => array('name' => 'Hamamatsu Ab', 'lat' => 34.750000, 'long' => 137.700000),
    'RJSI' => array('name' => 'Hanamaki Airport', 'lat' => 39.433333, 'long' => 141.133333),
    'RJOA' => array('name' => 'Hiroshima Airport', 'lat' => 34.433333, 'long' => 132.916667),
    'RJBH' => array('name' => 'Hiroshimanishi', 'lat' => 34.366667, 'long' => 132.433333),
    'RJOF' => array('name' => 'Hofu Ab', 'lat' => 34.033333, 'long' => 131.550000),
    'RJAH' => array('name' => 'Hyakuri Ab', 'lat' => 36.183333, 'long' => 140.416667),
    'RJTJ' => array('name' => 'Iruma Ab', 'lat' => 35.833333, 'long' => 139.416667),
    'ROIG' => array('name' => 'Ishigakijima', 'lat' => 24.333333, 'long' => 124.166667),
    'RJOI' => array('name' => 'Iwakuni Marine Corps Air Station', 'lat' => 34.133333, 'long' => 132.233333),
    'RJOW' => array('name' => 'Iwami Airport', 'lat' => 34.666667, 'long' => 131.800000),
    'RJAW' => array('name' => 'Iwojima', 'lat' => 24.783333, 'long' => 141.316667),
    'RJOC' => array('name' => 'Izumo Airport', 'lat' => 35.416667, 'long' => 132.900000),
    'RODN' => array('name' => 'Kadena Ab', 'lat' => 26.350000, 'long' => 127.766667),
    'RJFK' => array('name' => 'Kagoshima Airport', 'lat' => 31.800000, 'long' => 130.716667),
    'RJFY' => array('name' => 'Kanoya Ab', 'lat' => 31.366667, 'long' => 130.833333),
    'RJBB' => array('name' => 'Kansai International Airport', 'lat' => 34.416667, 'long' => 135.250000),
    'RJAK' => array('name' => 'Kasumigaura Ab', 'lat' => 36.033333, 'long' => 140.200000),
    'RJSU' => array('name' => 'Kasuminome Ab', 'lat' => 38.233333, 'long' => 140.916667),
    'RJTK' => array('name' => 'Kisarazu Ab', 'lat' => 35.400000, 'long' => 139.916667),
    'RJFR' => array('name' => 'Kitakyushu Airport', 'lat' => 33.833333, 'long' => 130.950000),
    'RJOK' => array('name' => 'Kochi Airport', 'lat' => 33.533333, 'long' => 133.666667),
    'RJNK' => array('name' => 'Komatsu Ab', 'lat' => 36.383333, 'long' => 136.416667),
    'RJOP' => array('name' => 'Komatsujima Ab', 'lat' => 34.000000, 'long' => 134.633333),
    'RJFT' => array('name' => 'Kumamoto Airport', 'lat' => 32.833333, 'long' => 130.850000),
    'ROKJ' => array('name' => 'Kumejima', 'lat' => 26.333333, 'long' => 126.800000),
    'RJAF' => array('name' => 'Matsumoto Airport', 'lat' => 36.166667, 'long' => 137.933333),
    'RJST' => array('name' => 'Matsushima Ab', 'lat' => 38.400000, 'long' => 141.216667),
    'RJOM' => array('name' => 'Matsuyama Airport', 'lat' => 33.816667, 'long' => 132.700000),
    'RJCM' => array('name' => 'Memambetsu Airport', 'lat' => 43.883333, 'long' => 144.166667),
    'RJDM' => array('name' => 'Metabaru Ab', 'lat' => 33.316667, 'long' => 130.416667),
    'RJOH' => array('name' => 'Miho Ab', 'lat' => 35.483333, 'long' => 133.250000),
    'RJSM' => array('name' => 'Misawa Ab', 'lat' => 40.700000, 'long' => 141.383333),
    'ROMY' => array('name' => 'Miyakojima', 'lat' => 24.783333, 'long' => 125.283333),
    'RJFM' => array('name' => 'Miyazaki Airport', 'lat' => 31.866667, 'long' => 131.450000),
    'RJEB' => array('name' => 'Mombetsu Airport', 'lat' => 44.250000, 'long' => 143.533333),
    'RJFU' => array('name' => 'Nagasaki Airport', 'lat' => 32.916667, 'long' => 129.916667),
    'RJGG' => array('name' => 'Nagoya Airport', 'lat' => 35.250000, 'long' => 136.933333),
    'ROAH' => array('name' => 'Naha Airport', 'lat' => 26.183333, 'long' => 127.650000),
    'RJCN' => array('name' => 'Nakashibetsu Airport', 'lat' => 43.566667, 'long' => 144.966667),
    'RJBD' => array('name' => 'Nankishirahama Airport', 'lat' => 33.666667, 'long' => 135.350000),
    'RJAA' => array('name' => 'New Tokyo Inter-National Airport', 'lat' => 35.766667, 'long' => 140.383333),
    'RJSN' => array('name' => 'Niigata Airport', 'lat' => 37.950000, 'long' => 139.116667),
    'RJFN' => array('name' => 'Nyutabaru Ab', 'lat' => 32.083333, 'long' => 131.450000),
    'RJCB' => array('name' => 'Obihiro Airport', 'lat' => 42.733333, 'long' => 143.216667),
    'RJSR' => array('name' => 'Odate-Noshiro Airport', 'lat' => 40.183333, 'long' => 140.200000),
    'RJFO' => array('name' => 'Oita Airport', 'lat' => 33.483333, 'long' => 131.733333),
    'RJOB' => array('name' => 'Okayama Airport', 'lat' => 34.750000, 'long' => 133.850000),
    'RJKB' => array('name' => 'Okinoerabu', 'lat' => 27.433333, 'long' => 128.700000),
    'RJSO' => array('name' => 'Ominato Ab', 'lat' => 41.233333, 'long' => 141.133333),
    'RJOO' => array('name' => 'Osaka International Airport', 'lat' => 34.783333, 'long' => 135.450000),
    'RJTO' => array('name' => 'Oshima Airport', 'lat' => 34.783333, 'long' => 139.366667),
    'RJOZ' => array('name' => 'Ozuki Ab', 'lat' => 34.050000, 'long' => 131.050000),
    'RJFS' => array('name' => 'Saga Airport', 'lat' => 33.150000, 'long' => 130.300000),
    'RJCO' => array('name' => 'Sapporo Ab', 'lat' => 43.116667, 'long' => 141.383333),
    'RJSS' => array('name' => 'Sendai Airport', 'lat' => 38.133333, 'long' => 140.916667),
    'RJTL' => array('name' => 'Shimofusa Ab', 'lat' => 35.800000, 'long' => 140.016667),
    'RORS' => array('name' => 'Shimoji-Shima Island', 'lat' => 24.833333, 'long' => 125.150000),
    'RJNY' => array('name' => 'Shizuhama Ab', 'lat' => 34.816667, 'long' => 138.300000),
    'RJSY' => array('name' => 'Shonai', 'lat' => 38.816667, 'long' => 139.783333),
    'RJTC' => array('name' => 'Tachikawa Ab', 'lat' => 35.700000, 'long' => 139.400000),
    'RJBT' => array('name' => 'Tajima', 'lat' => 35.516667, 'long' => 134.800000),
    'RJOT' => array('name' => 'Takamatsu Airport', 'lat' => 34.216667, 'long' => 134.016667),
    'RJFG' => array('name' => 'Tanegashima Airport', 'lat' => 30.550000, 'long' => 130.950000),
    'RJTE' => array('name' => 'Tateyama Ab', 'lat' => 34.983333, 'long' => 139.833333),
    'RJOS' => array('name' => 'Tokushima Ab', 'lat' => 34.133333, 'long' => 134.616667),
    'RJTI' => array('name' => 'Tokyo Heliport', 'lat' => 35.633333, 'long' => 139.850000),
    'RJTT' => array('name' => 'Tokyo International Airport', 'lat' => 35.550000, 'long' => 139.783333),
    'RJOR' => array('name' => 'Tottori Airport', 'lat' => 35.533333, 'long' => 134.166667),
    'RJNT' => array('name' => 'Toyama Airport', 'lat' => 36.650000, 'long' => 137.183333),
    'RJFZ' => array('name' => 'Tsuiki Ab', 'lat' => 33.683333, 'long' => 131.050000),
    'RJDT' => array('name' => 'Tsushima Airport', 'lat' => 34.283333, 'long' => 129.333333),
    'RJTU' => array('name' => 'Utsunomiya Ab', 'lat' => 36.516667, 'long' => 139.866667),
    'RJCW' => array('name' => 'Wakkanai Airport', 'lat' => 45.400000, 'long' => 141.800000),
    'RJFC' => array('name' => 'Yakushima', 'lat' => 30.383333, 'long' => 130.666667),
    'RJSC' => array('name' => 'Yamagata Airport', 'lat' => 38.416667, 'long' => 140.366667),
    'RJDC' => array('name' => 'Yamaguchi Ube Airport', 'lat' => 33.933333, 'long' => 131.283333),
    'RJOY' => array('name' => 'Yao Airport', 'lat' => 34.600000, 'long' => 135.600000),
    'RJTY' => array('name' => 'Yokota Ab', 'lat' => 35.750000, 'long' => 139.350000),
    'RJTR' => array('name' => 'Zama Airfield', 'lat' => 35.516667, 'long' => 139.400000),
  );

  $icao_codes['Jordan'] = array(
    'OJAM' => array('name' => 'Amman Airport', 'lat' => 31.983333, 'long' => 35.983333),
    'OJAQ' => array('name' => 'Aqaba Airport', 'lat' => 29.633333, 'long' => 35.016667),
    'OJAI' => array('name' => 'Queen Alia Airport', 'lat' => 31.666667, 'long' => 35.966667),
  );

  $icao_codes['Kazakhstan'] = array(
    'UATE' => array('name' => 'Aktau', 'lat' => 43.870000, 'long' => 51.100000),
    'UATT' => array('name' => 'Aktjubinsk', 'lat' => 50.283333, 'long' => 57.150000),
    'UAAA' => array('name' => 'Almaty', 'lat' => 43.233333, 'long' => 76.933333),
    'UACC' => array('name' => 'Astana', 'lat' => 51.200000, 'long' => 71.450000),
    'UAKK' => array('name' => 'Karaganda', 'lat' => 49.800000, 'long' => 73.150000),
    'UAUU' => array('name' => 'Kostanay', 'lat' => 53.206389, 'long' => 63.550833),
    'UAOO' => array('name' => 'Kzyl-Orda', 'lat' => 44.850000, 'long' => 65.500000),
    'UAII' => array('name' => 'Shymkent', 'lat' => 42.316667, 'long' => 69.700000),
    'UARR' => array('name' => 'Uralsk', 'lat' => 51.250000, 'long' => 51.283333),
  );

  $icao_codes['Kenya'] = array(
    'HKEL' => array('name' => 'Eldoret', 'lat' => 0.533333, 'long' => 35.283333),
    'HKEM' => array('name' => 'Embu', 'lat' => -0.500000, 'long' => 37.450000),
    'HKGA' => array('name' => 'Garissa', 'lat' => -0.466667, 'long' => 39.633333),
    'HKKI' => array('name' => 'Kisumu', 'lat' => -0.100000, 'long' => 34.750000),
    'HKLO' => array('name' => 'Lodwar', 'lat' => 3.116667, 'long' => 35.616667),
    'HKML' => array('name' => 'Malindi', 'lat' => -3.233333, 'long' => 40.100000),
    'HKMO' => array('name' => 'Mombasa', 'lat' => -4.033333, 'long' => 39.616667),
    'HKNC' => array('name' => 'Nairobi / Dagoretti', 'lat' => -1.300000, 'long' => 36.750000),
    'HKNW' => array('name' => 'Nairobi / Wilson', 'lat' => -1.316667, 'long' => 36.816667),
    'HKJK' => array('name' => 'Nairobi/Jomo Kenyatta Airport TWR/APP/NOF/Civil Airlines', 'lat' => -1.316667, 'long' => 36.916667),
    'HKNK' => array('name' => 'Nakuru', 'lat' => -0.266667, 'long' => 36.100000),
    'HKNO' => array('name' => 'Narok', 'lat' => -1.133333, 'long' => 35.833333),
    'HKNI' => array('name' => 'Nyeri', 'lat' => -0.500000, 'long' => 36.966667),
    'HKWJ' => array('name' => 'Wajir', 'lat' => 1.750000, 'long' => 40.066667),
  );

  $icao_codes['Kiribati'] = array(
    'NGTA' => array('name' => 'Tarawa', 'lat' => 1.350000, 'long' => 172.916667),
  );

  $icao_codes['Korea, South'] = array(
    'RKPC' => array('name' => 'Cheju International Airport', 'lat' => 33.500000, 'long' => 126.500000),
    'RKTU' => array('name' => 'Chongju Ab', 'lat' => 36.700000, 'long' => 127.500000),
    'RKSI' => array('name' => 'Incheon International Airport', 'lat' => 37.466667, 'long' => 126.450000),
    'RKJK' => array('name' => 'Kunsan Ab', 'lat' => 35.916667, 'long' => 126.616667),
    'RKSO' => array('name' => 'Osan Ab', 'lat' => 37.100000, 'long' => 127.033333),
    'RKPK' => array('name' => 'Pusan / Kimhae International Airport', 'lat' => 35.183333, 'long' => 128.933333),
    'RKSG' => array('name' => 'Pyongtaek Ab', 'lat' => 36.933333, 'long' => 127.000000),
    'RKSS' => array('name' => 'Seoul / Kimp\'O International Airport', 'lat' => 37.550000, 'long' => 126.800000),
    'RKTN' => array('name' => 'Taegu Ab', 'lat' => 35.900000, 'long' => 128.650000),
    'RKJY' => array('name' => 'Yosu Airport', 'lat' => 34.833333, 'long' => 127.616667),
  );

  $icao_codes['Kuwait'] = array(
    'OKBK' => array('name' => 'Kuwait Internationalairport', 'lat' => 29.216667, 'long' => 47.983333),
  );

  $icao_codes['Kyrgyzstan'] = array(
    'UAFM' => array('name' => 'Bishkek/Manas Airport', 'lat' => 42.850000, 'long' => 74.583333),
  );

  $icao_codes['Laos'] = array(
    'VLVT' => array('name' => 'Vientiane', 'lat' => 17.950000, 'long' => 102.566667),
  );

  $icao_codes['Latvia'] = array(
    'EVLA' => array('name' => 'Liepaja International Airport', 'lat' => 56.516667, 'long' => 21.083333),
    'EVRA' => array('name' => 'Riga International Airport', 'lat' => 56.916667, 'long' => 23.966667),
  );

  $icao_codes['Lebanon'] = array(
    'OLBA' => array('name' => 'Beyrouth Aeroport', 'lat' => 33.816667, 'long' => 35.483333),
  );

  $icao_codes['Liberia'] = array(
    'GLRB' => array('name' => 'Grand Bassa, Roberts Field', 'lat' => 6.250000, 'long' => -10.350000),
  );

  $icao_codes['Libya'] = array(
    'HLLB' => array('name' => 'Benina', 'lat' => 32.100000, 'long' => 20.266667),
    'HLLT' => array('name' => 'Tripoli Inter-National Airport', 'lat' => 32.666667, 'long' => 13.150000),
  );

  $icao_codes['Lithuania'] = array(
    'EYKA' => array('name' => 'Kaunas', 'lat' => 54.900000, 'long' => 23.920000),
    'EYPA' => array('name' => 'Palanga Intl.', 'lat' => 55.920000, 'long' => 21.050000),
    'EYSA' => array('name' => 'Siauliai Intl./Mil.', 'lat' => 55.893889, 'long' => 23.395000),
    'EYVI' => array('name' => 'Vilnius', 'lat' => 54.633333, 'long' => 25.100000),
  );

  $icao_codes['Luxembourg'] = array(
    'ELLX' => array('name' => 'Luxembourg / Luxembourg', 'lat' => 49.616667, 'long' => 6.216667),
  );

  $icao_codes['Macau'] = array(
    'VMMC' => array('name' => 'Taipa', 'lat' => 22.166667, 'long' => 113.566667),
  );

  $icao_codes['Macedonia, The Republic of'] = array(
    'LWOH' => array('name' => 'Ohrid', 'lat' => 41.116667, 'long' => 20.800000),
    'LWSK' => array('name' => 'Skopje-Petrovec', 'lat' => 41.966667, 'long' => 21.650000),
  );

  $icao_codes['Madagascar'] = array(
    'FMMI' => array('name' => 'Antananarivo / Ivato', 'lat' => -18.800000, 'long' => 47.483333),
    'FMNA' => array('name' => 'Diego-Suarez', 'lat' => -12.350000, 'long' => 49.300000),
    'FMNN' => array('name' => 'Fascene Nossi-Be', 'lat' => -13.316667, 'long' => 48.316667),
    'FMSD' => array('name' => 'Fort-Dauphin', 'lat' => -25.033333, 'long' => 46.950000),
    'FMNM' => array('name' => 'Majunga', 'lat' => -15.666667, 'long' => 46.350000),
    'FMMS' => array('name' => 'Sainte-Marie Aerodrome', 'lat' => -17.083333, 'long' => 49.816667),
    'FMMT' => array('name' => 'Tamatave', 'lat' => -18.116667, 'long' => 49.400000),
    'FMST' => array('name' => 'Tulear', 'lat' => -23.383333, 'long' => 43.733333),
  );

  $icao_codes['Malaysia'] = array(
    'WBGB' => array('name' => 'Bintulu', 'lat' => 3.200000, 'long' => 113.033333),
    'WMKJ' => array('name' => 'Johore Bharu / Senai', 'lat' => 1.633333, 'long' => 103.666667),
    'WMKC' => array('name' => 'Kota Bharu', 'lat' => 6.166667, 'long' => 102.283333),
    'WBKK' => array('name' => 'Kota Kinabalu', 'lat' => 5.933333, 'long' => 116.050000),
    'WMKD' => array('name' => 'Kuantan', 'lat' => 3.616667, 'long' => 103.216667),
    'WBGG' => array('name' => 'Kuching', 'lat' => 1.483333, 'long' => 110.333333),
    'WBKT' => array('name' => 'Kudat', 'lat' => 6.916667, 'long' => 116.833333),
    'WBKL' => array('name' => 'Labuan', 'lat' => 5.300000, 'long' => 115.250000),
    'WMKL' => array('name' => 'Langkawi', 'lat' => 6.333333, 'long' => 99.733333),
    'WMKM' => array('name' => 'Malacca', 'lat' => 2.266667, 'long' => 102.250000),
    'WBGR' => array('name' => 'Miri', 'lat' => 4.333333, 'long' => 113.983333),
    'WMKP' => array('name' => 'Penang / Bayan Lepas', 'lat' => 5.300000, 'long' => 100.266667),
    'WBKS' => array('name' => 'Sandakan', 'lat' => 5.900000, 'long' => 118.066667),
    'WMKK' => array('name' => 'Sepang/KL International Airport', 'lat' => 2.733333, 'long' => 101.700000),
    'WBGS' => array('name' => 'Sibu', 'lat' => 2.333333, 'long' => 111.833333),
    'WMBA' => array('name' => 'Sitiawan', 'lat' => 4.216667, 'long' => 100.700000),
    'WMSA' => array('name' => 'Subang/Sultan Abdul Aziz Shah Airport', 'lat' => 3.116667, 'long' => 101.533333),
    'WBKW' => array('name' => 'Tawau', 'lat' => 4.266667, 'long' => 117.883333),
  );

  $icao_codes['Maldives'] = array(
    'VRMM' => array('name' => 'Male', 'lat' => 4.200000, 'long' => 73.533333),
  );

  $icao_codes['Mali'] = array(
    'GABS' => array('name' => 'Bamako / Senou', 'lat' => 12.533333, 'long' => -7.950000),
  );

  $icao_codes['Malta'] = array(
    'LMML' => array('name' => 'Luqa', 'lat' => 35.850000, 'long' => 14.483333),
  );

  $icao_codes['Marshall Islands'] = array(
    'PKWA' => array('name' => 'Kwajalein, Bucholz AAF, Kwajalein KMR ATOL Airport', 'lat' => 8.716667, 'long' => 167.733333),
    'PKMJ' => array('name' => 'Majuro Atoll, Marshall Islands Int. Airp.', 'lat' => 7.066667, 'long' => 171.283333),
    'PKMR' => array('name' => 'Majuro Atoll, NWS Office', 'lat' => 7.083333, 'long' => 171.200000),
  );

  $icao_codes['Martinique'] = array(
    'TFFF' => array('name' => 'Le Lamentin', 'lat' => 14.600000, 'long' => -61.000000),
  );

  $icao_codes['Mauritania'] = array(
    'GQPP' => array('name' => 'Nouadhibou', 'lat' => 20.933333, 'long' => -17.033333),
    'GQNN' => array('name' => 'Nouakchott', 'lat' => 18.100000, 'long' => -15.950000),
  );

  $icao_codes['Mauritius'] = array(
    'FIMP' => array('name' => 'Plaisance Mauritius', 'lat' => -20.433333, 'long' => 57.666667),
    'FIMR' => array('name' => 'Rodrigues', 'lat' => -19.683333, 'long' => 63.416667),
  );

  $icao_codes['Mexico'] = array(
    'MMAA' => array('name' => 'Acapulco / G. Alvarez', 'lat' => 16.766667, 'long' => -99.750000),
    'MMAN' => array('name' => 'Aerop. Internacional Monterrey, N. L.', 'lat' => 25.866667, 'long' => -100.233333),
    'MMAS' => array('name' => 'Aguascalientes, Ags.', 'lat' => 21.883333, 'long' => -102.300000),
    'MMBT' => array('name' => 'Bahias De Huatulco', 'lat' => 15.783333, 'long' => -96.266667),
    'MMCP' => array('name' => 'Campeche, Camp.', 'lat' => 19.850000, 'long' => -90.550000),
    'MMUN' => array('name' => 'Cancun International Airport', 'lat' => 21.033333, 'long' => -86.866667),
    'MMCM' => array('name' => 'Chetumal, Q. Roo', 'lat' => 18.483333, 'long' => -88.300000),
    'MMCT' => array('name' => 'Chichen-Itza', 'lat' => 20.641667, 'long' => -88.449444),
    'MMCU' => array('name' => 'Chihuahua International Airport', 'lat' => 28.700000, 'long' => -105.966667),
    'MMCE' => array('name' => 'Ciudad Del Carmen', 'lat' => 18.650000, 'long' => -91.800000),
    'MMCS' => array('name' => 'Ciudad Juarez International', 'lat' => 31.633333, 'long' => -106.433333),
    'MMCN' => array('name' => 'Ciudad Obregon', 'lat' => 27.392778, 'long' => -109.833056),
    'MMCV' => array('name' => 'Ciudad Victoria Airport', 'lat' => 23.716667, 'long' => -98.966667),
    'MMIA' => array('name' => 'Colima', 'lat' => 19.266667, 'long' => -103.583333),
    'MMCZ' => array('name' => 'Cozumel Civ / Mil', 'lat' => 20.533333, 'long' => -86.933333),
    'MMCB' => array('name' => 'Cuernavaca, Mor.', 'lat' => 18.883333, 'long' => -99.233333),
    'MMCL' => array('name' => 'Culiacan, Sin.', 'lat' => 24.816667, 'long' => -107.400000),
    'MMGL' => array('name' => 'Don Miguel / Guadalaj', 'lat' => 20.516667, 'long' => -103.316667),
    'MMDO' => array('name' => 'Durango Airport', 'lat' => 24.133333, 'long' => -104.533333),
    'MMGM' => array('name' => 'Guaymas International Airport', 'lat' => 27.966667, 'long' => -110.933333),
    'MMHO' => array('name' => 'Hermosillo, Son.', 'lat' => 29.066667, 'long' => -110.950000),
    'MMZH' => array('name' => 'Ixtapa-Zihuatanejo', 'lat' => 17.600000, 'long' => -101.466667),
    'MMIT' => array('name' => 'Ixtepec Ox', 'lat' => 16.450000, 'long' => -95.083333),
    'MMLP' => array('name' => 'La Paz International Airport', 'lat' => 24.066667, 'long' => -110.366667),
    'MMLT' => array('name' => 'Loreto, B. C. S.', 'lat' => 26.016667, 'long' => -111.350000),
    'MMLM' => array('name' => 'Los Mochis Airport', 'lat' => 25.683333, 'long' => -109.083333),
    'MMZO' => array('name' => 'Manzanillo International', 'lat' => 19.150000, 'long' => -104.566667),
    'MMMA' => array('name' => 'Matamoros International', 'lat' => 25.766667, 'long' => -97.533333),
    'MMMZ' => array('name' => 'Mazatlan / G. Buelna', 'lat' => 23.166667, 'long' => -106.266667),
    'MMMD' => array('name' => 'Merida / lic Manuel Crecencio', 'lat' => 20.933333, 'long' => -89.650000),
    'MMML' => array('name' => 'Mexicali International Airport', 'lat' => 32.633333, 'long' => -117.000000),
    'MMMX' => array('name' => 'Mexico City / Licenci', 'lat' => 19.433333, 'long' => -99.100000),
    'MMMT' => array('name' => 'Minatitlan', 'lat' => 18.100000, 'long' => -94.583333),
    'MMMV' => array('name' => 'Monclova, Coah.', 'lat' => 26.883333, 'long' => -101.416667),
    'MMMY' => array('name' => 'Monterrey / Gen Maria', 'lat' => 25.783333, 'long' => -100.100000),
    'MMMM' => array('name' => 'Morelia New', 'lat' => 19.850000, 'long' => -101.033333),
    'MMNL' => array('name' => 'Nuevo Laredo International', 'lat' => 27.433333, 'long' => -99.566667),
    'MMOX' => array('name' => 'Oaxaca / Xoxocotlan', 'lat' => 16.966667, 'long' => -96.733333),
    'MMPG' => array('name' => 'Piedras Negras, Coah.', 'lat' => 28.700000, 'long' => -100.516667),
    'MMPA' => array('name' => 'Poza Rica / Palizada', 'lat' => 20.516667, 'long' => -97.466667),
    'MMPB' => array('name' => 'Puebla, Pue.', 'lat' => 19.050000, 'long' => -98.166667),
    'MMPS' => array('name' => 'Puerto Escondido', 'lat' => 15.866667, 'long' => -97.083333),
    'MMPR' => array('name' => 'Puerto Vallarta / Lic', 'lat' => 20.683333, 'long' => -105.250000),
    'MMQT' => array('name' => 'Queretaro, Qro.', 'lat' => 20.600000, 'long' => -100.383333),
    'MMRX' => array('name' => 'Reynosa International Airport', 'lat' => 26.016667, 'long' => -98.233333),
    'MMIO' => array('name' => 'Saltillo, Coah.', 'lat' => 25.450000, 'long' => -100.983333),
    'MMSD' => array('name' => 'San Jose Del Cabo', 'lat' => 23.150000, 'long' => -109.700000),
    'MMSP' => array('name' => 'San Luis Potosi, S. L. P.', 'lat' => 22.150000, 'long' => -100.983333),
    'MMTM' => array('name' => 'Tampico / Gen Fj Mina', 'lat' => 22.283333, 'long' => -97.866667),
    'MMTP' => array('name' => 'Tapachula', 'lat' => 14.783333, 'long' => -92.383333),
    'MMEP' => array('name' => 'Tepic, Nay.', 'lat' => 21.516667, 'long' => -104.900000),
    'MMTJ' => array('name' => 'Tijuana International Airport', 'lat' => 32.550000, 'long' => -116.966667),
    'MMTO' => array('name' => 'Toluca / Jose Maria', 'lat' => 19.350000, 'long' => -99.566667),
    'MMTC' => array('name' => 'Torreon, Coah.', 'lat' => 25.533333, 'long' => -103.450000),
    'MMTG' => array('name' => 'Tuxtla Gutierrez, Chis.', 'lat' => 16.750000, 'long' => -93.116667),
    'MMPN' => array('name' => 'Uruapan / Gen Rayon', 'lat' => 19.400000, 'long' => -102.033333),
    'MMVR' => array('name' => 'Veracruz / Las Bajadas / General Heriberto Jara', 'lat' => 19.150000, 'long' => -96.183333),
    'MMVA' => array('name' => 'Villahermosa', 'lat' => 18.000000, 'long' => -92.816667),
    'MMZC' => array('name' => 'Zacatecas Airport', 'lat' => 22.900000, 'long' => -102.683333),
  );

  $icao_codes['Micronesia, Federated States of'] = array(
    'PTSA' => array('name' => 'Kosrae Island, Kosrae Airport', 'lat' => 5.350000, 'long' => 162.950000),
    'PTPN' => array('name' => 'Pohnpei Island, Pohnpei Int. Airp.', 'lat' => 6.983333, 'long' => 158.200000),
    'PTTP' => array('name' => 'Pohnpei, NWS Office', 'lat' => 6.966667, 'long' => 158.216667),
    'PTKK' => array('name' => 'Weno Island, Chuuk Int. Airp.', 'lat' => 7.466667, 'long' => 151.850000),
    'PTYA' => array('name' => 'Yap Island, Yap Int. Airp.', 'lat' => 9.483333, 'long' => 138.083333),
  );

  $icao_codes['Moldova'] = array(
    'LUKK' => array('name' => 'Chisinau International Airport', 'lat' => 46.927778, 'long' => 28.930833),
  );

  $icao_codes['Mongolia'] = array(
    'ZMUB' => array('name' => 'Ulan-Bator', 'lat' => 47.850000, 'long' => 106.766667),
  );

  $icao_codes['Morocco'] = array(
    'GMAD' => array('name' => 'Agadir Al Massira', 'lat' => 30.333333, 'long' => -9.400000),
    'GMTA' => array('name' => 'Al Hoceima', 'lat' => 35.183333, 'long' => -3.850000),
    'GMMC' => array('name' => 'Casablanca', 'lat' => 33.566667, 'long' => -7.666667),
    'GMFF' => array('name' => 'Fes-Sais', 'lat' => 33.933333, 'long' => -4.983333),
    'GMML' => array('name' => 'Laayoune/Hassan Isl', 'lat' => 27.166667, 'long' => -13.216389),
    'GMMX' => array('name' => 'Marrakech', 'lat' => 31.616667, 'long' => -8.033333),
    'GMFM' => array('name' => 'Meknes', 'lat' => 33.883333, 'long' => -5.533333),
    'GMMW' => array('name' => 'Nador/Arwi', 'lat' => 34.988889, 'long' => -3.028333),
    'GMMN' => array('name' => 'Nouasseur', 'lat' => 33.366667, 'long' => -7.583333),
    'GMMZ' => array('name' => 'Ouarzazate', 'lat' => 30.933333, 'long' => -6.900000),
    'GMFO' => array('name' => 'Oujda', 'lat' => 34.783333, 'long' => -1.933333),
    'GMME' => array('name' => 'Rabat-Sale', 'lat' => 34.050000, 'long' => -6.766667),
    'GMTT' => array('name' => 'Tanger Aerodrome', 'lat' => 35.733333, 'long' => -5.900000),
    'GMTN' => array('name' => 'Tetuan / Sania Ramel', 'lat' => 35.583333, 'long' => -5.333333),
  );

  $icao_codes['Mozambique'] = array(
    'FQBR' => array('name' => 'Beira', 'lat' => -19.800000, 'long' => 34.900000),
    'FQCH' => array('name' => 'Chimoio', 'lat' => -19.116667, 'long' => 33.466667),
    'FQIN' => array('name' => 'Inhambane', 'lat' => -23.866667, 'long' => 35.383333),
    'FQLC' => array('name' => 'Lichinga', 'lat' => -13.300000, 'long' => 35.233333),
    'FQMA' => array('name' => 'Maputo / Mavalane', 'lat' => -25.916667, 'long' => 32.566667),
    'FQNP' => array('name' => 'Nampula', 'lat' => -15.100000, 'long' => 39.283333),
    'FQPB' => array('name' => 'Pemba', 'lat' => -12.983333, 'long' => 40.533333),
    'FQQL' => array('name' => 'Quelimane', 'lat' => -17.883333, 'long' => 36.883333),
    'FQVL' => array('name' => 'Vilanculos', 'lat' => -22.000000, 'long' => 35.316667),
  );

  $icao_codes['Myanmar'] = array(
    'VYYY' => array('name' => 'Yangon', 'lat' => 16.766667, 'long' => 96.166667),
  );

  $icao_codes['Namibia'] = array(
    'FYOA' => array('name' => 'Ondangwa', 'lat' => -17.878333, 'long' => 15.952500),
    'FYWB' => array('name' => 'Walvis Bay', 'lat' => -22.983056, 'long' => 14.650000),
    'FYWW' => array('name' => 'Windhoek, Town MET', 'lat' => -22.566667, 'long' => 17.100000),
  );

  $icao_codes['Netherlands'] = array(
    'EHAM' => array('name' => 'Amsterdam Airport Schiphol', 'lat' => 52.300000, 'long' => 4.766667),
    'EHKD' => array('name' => 'De Kooy', 'lat' => 52.916667, 'long' => 4.783333),
    'EHDL' => array('name' => 'Deelen', 'lat' => 52.066667, 'long' => 5.883333),
    'EHEH' => array('name' => 'Eindhoven', 'lat' => 51.450000, 'long' => 5.416667),
    'EHGR' => array('name' => 'Gilze-Rijen', 'lat' => 51.566667, 'long' => 4.933333),
    'EHGG' => array('name' => 'Groningen Airport Eelde', 'lat' => 53.133333, 'long' => 6.583333),
    'EHLW' => array('name' => 'Leeuwarden', 'lat' => 53.216667, 'long' => 5.766667),
    'EHBK' => array('name' => 'Maastricht Airport Zuid Limburg', 'lat' => 50.916667, 'long' => 5.783333),
    'EHRD' => array('name' => 'Rotterdam Airport Zestienhoven', 'lat' => 51.950000, 'long' => 4.450000),
    'EHSB' => array('name' => 'Soesterberg', 'lat' => 52.133333, 'long' => 5.283333),
    'EHTW' => array('name' => 'Twenthe', 'lat' => 52.266667, 'long' => 6.900000),
    'EHVB' => array('name' => 'Valkenburg', 'lat' => 52.183333, 'long' => 4.416667),
    'EHVL' => array('name' => 'Vlieland', 'lat' => 53.250000, 'long' => 4.916667),
    'EHVK' => array('name' => 'Volkel', 'lat' => 51.650000, 'long' => 5.700000),
    'EHWO' => array('name' => 'Woensdrecht', 'lat' => 51.450000, 'long' => 4.333333),
  );

  $icao_codes['Netherlands Antilles'] = array(
    'TNCB' => array('name' => 'Flamingo Airport, Bonaire', 'lat' => 12.150000, 'long' => -68.283333),
    'TNCC' => array('name' => 'Hato Airport, Curacao', 'lat' => 12.200000, 'long' => -68.966667),
    'TNCM' => array('name' => 'Juliana Airport, Saint Maarten', 'lat' => 18.050000, 'long' => -63.116667),
    'TNCE' => array('name' => 'Roosevelt Airport Saint Eustatius', 'lat' => 17.483333, 'long' => -62.983333),
  );

  $icao_codes['New Caledonia'] = array(
    'NWWW' => array('name' => 'La Tontouta Nlle-Caledonie', 'lat' => -22.016667, 'long' => 166.216667),
  );

  $icao_codes['New Zealand'] = array(
    'NZAA' => array('name' => 'Auckland Airport', 'lat' => -37.016667, 'long' => 174.800000),
    'NZCH' => array('name' => 'Christchurch', 'lat' => -43.483333, 'long' => 172.550000),
    'PLCH' => array('name' => 'Christmas / Cassidy', 'lat' => 1.983333, 'long' => -157.483333),
    'NZOH' => array('name' => 'Ohakea', 'lat' => -40.200000, 'long' => 175.366667),
    'NZWN' => array('name' => 'Wellington Airport', 'lat' => -41.333333, 'long' => 174.800000),
  );

  $icao_codes['Nicaragua'] = array(
    'MNBL' => array('name' => 'Bluefields', 'lat' => 12.000000, 'long' => -86.766667),
    'MNCH' => array('name' => 'Chinandega', 'lat' => 12.633333, 'long' => -87.133333),
    'MNJG' => array('name' => 'Jinotega', 'lat' => 13.083333, 'long' => -85.983333),
    'MNJU' => array('name' => 'Juigalpa', 'lat' => 12.100000, 'long' => -85.366667),
    'MNMG' => array('name' => 'Managua A. C. Sandino', 'lat' => 12.150000, 'long' => -86.166667),
    'MNPC' => array('name' => 'Puerto Cabezas', 'lat' => 14.050000, 'long' => -83.366667),
    'MNRS' => array('name' => 'Rivas', 'lat' => 11.416667, 'long' => -85.833333),
  );

  $icao_codes['Niger'] = array(
    'DRZA' => array('name' => 'Agadez', 'lat' => 16.966667, 'long' => 7.983333),
    'DRRN' => array('name' => 'Niamey-Aero', 'lat' => 13.483333, 'long' => 2.166667),
    'DRZR' => array('name' => 'Zinder', 'lat' => 13.783333, 'long' => 8.983333),
  );

  $icao_codes['Nigeria'] = array(
    'DNCA' => array('name' => 'Calabar', 'lat' => 4.966667, 'long' => 8.350000),
    'DNEN' => array('name' => 'Enugu', 'lat' => 6.466667, 'long' => 7.550000),
    'DNIL' => array('name' => 'Ilorin', 'lat' => 8.483333, 'long' => 4.583333),
    'DNKA' => array('name' => 'Kaduna', 'lat' => 10.600000, 'long' => 7.450000),
    'DNKN' => array('name' => 'Kano', 'lat' => 12.050000, 'long' => 8.533333),
    'DNMM' => array('name' => 'Lagos / Ikeja', 'lat' => 6.583333, 'long' => 3.333333),
    'DNMA' => array('name' => 'Maiduguri', 'lat' => 11.850000, 'long' => 13.083333),
    'DNPO' => array('name' => 'Port Harcourt', 'lat' => 4.850000, 'long' => 7.016667),
    'DNSO' => array('name' => 'Sokoto', 'lat' => 13.016667, 'long' => 5.250000),
  );

  $icao_codes['Norway'] = array(
    'ENAL' => array('name' => 'Alesund / Vigra', 'lat' => 62.566667, 'long' => 6.116667),
    'ENAT' => array('name' => 'Alta Lufthavn', 'lat' => 69.983333, 'long' => 23.366667),
    'ENAN' => array('name' => 'Andoya', 'lat' => 69.300000, 'long' => 16.150000),
    'ENNA' => array('name' => 'Banak', 'lat' => 70.066667, 'long' => 24.983333),
    'ENDU' => array('name' => 'Bardufoss', 'lat' => 69.066667, 'long' => 18.533333),
    'ENBS' => array('name' => 'Batsfjord', 'lat' => 70.633333, 'long' => 29.733333),
    'ENBR' => array('name' => 'Bergen / Flesland', 'lat' => 60.283333, 'long' => 5.233333),
    'ENBV' => array('name' => 'Berlevag', 'lat' => 70.866667, 'long' => 29.033333),
    'ENBO' => array('name' => 'Bodo Vi', 'lat' => 67.266667, 'long' => 14.366667),
    'ENBN' => array('name' => 'Bronnoysund / Bronnoy', 'lat' => 65.466667, 'long' => 12.216667),
    'ENDR' => array('name' => 'Draugen', 'lat' => 64.355556, 'long' => 7.791667),
    'ENEK' => array('name' => 'Ekofisk Oil Platform', 'lat' => 56.550000, 'long' => 3.250000),
    'ENEV' => array('name' => 'Evenes', 'lat' => 68.516667, 'long' => 16.683333),
    'ENFG' => array('name' => 'Fagernes Leirin', 'lat' => 61.000000, 'long' => 9.300000),
    'ENFL' => array('name' => 'Floro', 'lat' => 61.583333, 'long' => 5.033333),
    'ENBL' => array('name' => 'Forde / Bringeland', 'lat' => 61.450000, 'long' => 5.866667),
    'ENFR' => array('name' => 'Frigg', 'lat' => 59.933333, 'long' => 2.000000),
    'ENGC' => array('name' => 'Gullfax Platform', 'lat' => 61.033333, 'long' => 2.033333),
    'ENHF' => array('name' => 'Hammerfest', 'lat' => 70.666667, 'long' => 23.666667),
    'ENHK' => array('name' => 'Hasvik', 'lat' => 70.483333, 'long' => 22.150000),
    'ENHD' => array('name' => 'Haugesund / Karmoy', 'lat' => 59.350000, 'long' => 5.216667),
    'ENHE' => array('name' => 'Heidrun', 'lat' => 65.325000, 'long' => 2.326667),
    'ENHV' => array('name' => 'Honningsvag / Valan', 'lat' => 71.016667, 'long' => 25.983333),
    'ENKR' => array('name' => 'Kirkenes Lufthavn', 'lat' => 69.733333, 'long' => 29.900000),
    'ENCN' => array('name' => 'Kristiansand / Kjevik', 'lat' => 58.200000, 'long' => 8.083333),
    'ENKB' => array('name' => 'Kristiansund / Kvernberget', 'lat' => 63.116667, 'long' => 7.833333),
    'ENLK' => array('name' => 'Leknes', 'lat' => 68.150000, 'long' => 13.616667),
    'ENLI' => array('name' => 'Lista Flyplass', 'lat' => 58.100000, 'long' => 6.633333),
    'ENMH' => array('name' => 'Mehamn', 'lat' => 71.033333, 'long' => 27.833333),
    'ENRA' => array('name' => 'Mo I Rana / Rossvoll', 'lat' => 66.366667, 'long' => 14.300000),
    'ENML' => array('name' => 'Molde / Aro', 'lat' => 62.750000, 'long' => 7.266667),
    'ENMS' => array('name' => 'Mosjoen Kjaerstad', 'lat' => 65.800000, 'long' => 13.133333),
    'ENNM' => array('name' => 'Namsos Lufthavn', 'lat' => 64.466667, 'long' => 11.583333),
    'ENNK' => array('name' => 'Narvik Iii', 'lat' => 68.466667, 'long' => 17.500000),
    'ENNO' => array('name' => 'Notodden', 'lat' => 59.566667, 'long' => 9.216667),
    'ENOL' => array('name' => 'Orland Iii', 'lat' => 63.700000, 'long' => 9.600000),
    'ENOV' => array('name' => 'Orsta-Volda / Hovden', 'lat' => 62.183333, 'long' => 6.066667),
    'ENOA' => array('name' => 'Oseberg', 'lat' => 59.316667, 'long' => 10.450000),
    'ENGM' => array('name' => 'Oslo / Gardermoen', 'lat' => 60.200000, 'long' => 11.083333),
    'ENRO' => array('name' => 'Roros Lufthavn', 'lat' => 62.583333, 'long' => 11.350000),
    'ENRM' => array('name' => 'Rorvik / Ryum', 'lat' => 64.833333, 'long' => 11.150000),
    'ENRS' => array('name' => 'Rost Flyplass', 'lat' => 67.516667, 'long' => 12.100000),
    'ENRY' => array('name' => 'Rygge', 'lat' => 59.383333, 'long' => 10.783333),
    'ENSD' => array('name' => 'Sandane / Anda', 'lat' => 61.833333, 'long' => 6.116667),
    'ENST' => array('name' => 'Sandnessjoen / Stokka', 'lat' => 65.966667, 'long' => 12.466667),
    'ENSN' => array('name' => 'Skien-Geiteryggen', 'lat' => 59.183333, 'long' => 9.566667),
    'ENSG' => array('name' => 'Sogndal / Haukasen', 'lat' => 61.150000, 'long' => 7.133333),
    'ENSR' => array('name' => 'Sorkjosen', 'lat' => 69.783333, 'long' => 20.966667),
    'ENZV' => array('name' => 'Stavanger / Sola', 'lat' => 58.883333, 'long' => 5.633333),
    'ENSO' => array('name' => 'Stord / Soerstokken', 'lat' => 59.800000, 'long' => 5.350000),
    'ENSK' => array('name' => 'Storkmarknes / Skagen', 'lat' => 68.583333, 'long' => 15.016667),
    'ENSB' => array('name' => 'Svalbard Lufthavn', 'lat' => 78.250000, 'long' => 15.466667),
    'ENSS' => array('name' => 'Svartnes', 'lat' => 70.350000, 'long' => 31.050000),
    'ENSH' => array('name' => 'Svolvaer / Helle', 'lat' => 68.250000, 'long' => 14.666667),
    'ENTO' => array('name' => 'Torp', 'lat' => 59.200000, 'long' => 10.266667),
    'ENTC' => array('name' => 'Tromso / Langnes', 'lat' => 69.683333, 'long' => 18.916667),
    'ENVA' => array('name' => 'Trondheim / Vaernes', 'lat' => 63.466667, 'long' => 10.933333),
    'ENVD' => array('name' => 'Vadso', 'lat' => 70.066667, 'long' => 29.850000),
  );

  $icao_codes['Oman'] = array(
    'OOSA' => array('name' => 'Salalah', 'lat' => 17.033333, 'long' => 54.083333),
    'OOMS' => array('name' => 'Seeb, International Airport', 'lat' => 23.583333, 'long' => 58.283333),
  );

  $icao_codes['Pakistan'] = array(
    'OPRN' => array('name' => 'Islamabad Airport', 'lat' => 33.616667, 'long' => 73.100000),
    'OPKC' => array('name' => 'Karachi Airport', 'lat' => 24.900000, 'long' => 67.133333),
    'OPLA' => array('name' => 'Lahore Airport', 'lat' => 31.516667, 'long' => 74.400000),
    'OPNH' => array('name' => 'Nawabshah', 'lat' => 26.250000, 'long' => 68.366667),
    'OPPS' => array('name' => 'Peshawar', 'lat' => 34.016667, 'long' => 71.583333),
  );

  $icao_codes['Palau'] = array(
    'PTRO' => array('name' => 'Babelthuap Island, Babelthuap/Koror Airport', 'lat' => 7.366667, 'long' => 134.533333),
    'PTKR' => array('name' => 'Koror, Palau, NWS Office', 'lat' => 7.333333, 'long' => 134.483333),
  );

  $icao_codes['Panama'] = array(
    'MPBO' => array('name' => 'Bocas Del Toro International', 'lat' => 9.350000, 'long' => -82.250000),
    'MPCH' => array('name' => 'Changuinola / Captain Manuel Nino', 'lat' => 9.466667, 'long' => -82.516667),
    'MPDA' => array('name' => 'David', 'lat' => 8.400000, 'long' => -82.416667),
    'MPMG' => array('name' => 'Marcos A. Gelabert', 'lat' => 8.983333, 'long' => -79.516667),
    'MPTO' => array('name' => 'Tocumen', 'lat' => 9.050000, 'long' => -79.366667),
  );

  $icao_codes['Papua New Guinea'] = array(
    'AYMO' => array('name' => 'Manus Island/Momote', 'lat' => -2.061944, 'long' => 147.424167),
    'AYPY' => array('name' => 'Moresby', 'lat' => -9.433333, 'long' => 147.216667),
  );

  $icao_codes['Paraguay'] = array(
    'SGES' => array('name' => 'Aeropuerto Guarany', 'lat' => -25.450000, 'long' => -54.850000),
    'SGAS' => array('name' => 'Asuncion / Aeropuerto', 'lat' => -25.266667, 'long' => -57.633333),
  );

  $icao_codes['Peru'] = array(
    'SPHY' => array('name' => 'Andahuayla', 'lat' => -13.716667, 'long' => -73.350000),
    'SPQU' => array('name' => 'Arequipa', 'lat' => -16.316667, 'long' => -71.550000),
    'SPHI' => array('name' => 'Chiclayo', 'lat' => -6.783333, 'long' => -79.833333),
    'SPZO' => array('name' => 'Cuzco', 'lat' => -13.550000, 'long' => -71.983333),
    'SPQT' => array('name' => 'Iquitos', 'lat' => -3.750000, 'long' => -73.250000),
    'SPIM' => array('name' => 'Lima-Callao / Aerop. Internacional Jorgechavez', 'lat' => -12.000000, 'long' => -77.116667),
    'SPSO' => array('name' => 'Pisco', 'lat' => -13.750000, 'long' => -76.283333),
    'SPTN' => array('name' => 'Tacna', 'lat' => -18.066667, 'long' => -70.300000),
    'SPYL' => array('name' => 'Talara', 'lat' => -4.566667, 'long' => -81.250000),
    'SPRU' => array('name' => 'Trujillo', 'lat' => -8.100000, 'long' => -79.033333),
  );

  $icao_codes['Philippines'] = array(
    'RPLC' => array('name' => 'Clarkfield Pampanga International Airport', 'lat' => 15.183333, 'long' => 120.550000),
    'RPMD' => array('name' => 'Davao Airport', 'lat' => 7.116667, 'long' => 125.650000),
    'RPLI' => array('name' => 'Laoag', 'lat' => 18.183333, 'long' => 120.533333),
    'RPVM' => array('name' => 'Masbate', 'lat' => 12.366667, 'long' => 123.616667),
    'RPLL' => array('name' => 'Ninoy Aquino Inter-National Airport', 'lat' => 14.516667, 'long' => 121.000000),
    'RPLB' => array('name' => 'Subic Bay Weather Station', 'lat' => 14.800000, 'long' => 120.266667),
    'RPMZ' => array('name' => 'Zamboanga', 'lat' => 6.900000, 'long' => 122.066667),
  );

  $icao_codes['Poland'] = array(
    'EPGD' => array('name' => 'Gdansk-Rebiechowo', 'lat' => 54.383333, 'long' => 18.466667),
    'EPKT' => array('name' => 'Katowice', 'lat' => 50.233333, 'long' => 19.033333),
    'EPKK' => array('name' => 'Krakow', 'lat' => 50.083333, 'long' => 19.800000),
    'EPPO' => array('name' => 'Poznan', 'lat' => 52.416667, 'long' => 16.833333),
    'EPRZ' => array('name' => 'Rzeszow-Jasionka', 'lat' => 50.100000, 'long' => 22.050000),
    'EPSC' => array('name' => 'Szczecin', 'lat' => 53.400000, 'long' => 14.616667),
    'EPWA' => array('name' => 'Warszawa-Okecie', 'lat' => 52.166667, 'long' => 20.966667),
    'EPWR' => array('name' => 'Wroclaw Ii', 'lat' => 51.100000, 'long' => 16.883333),
  );

  $icao_codes['Portugal'] = array(
    'LPMA' => array('name' => 'Aeroporto Da Madeira', 'lat' => 32.697778, 'long' => -16.774444),
    'LPFR' => array('name' => 'Faro / Aeroporto', 'lat' => 37.016667, 'long' => -7.966667),
    'LPFL' => array('name' => 'Flores Acores', 'lat' => 39.450000, 'long' => -31.133333),
    'LPHR' => array('name' => 'Horta / Castelo Branco Acores', 'lat' => 38.516667, 'long' => -28.716667),
    'LPLA' => array('name' => 'Lajes Acores', 'lat' => 38.766667, 'long' => -27.100000),
    'LPPT' => array('name' => 'Lisboa / Portela', 'lat' => 38.766667, 'long' => -9.133333),
    'LPPD' => array('name' => 'Ponta Delgada / Nordela Acores', 'lat' => 37.733333, 'long' => -25.700000),
    'LPPR' => array('name' => 'Porto / Pedras Rubras', 'lat' => 41.233333, 'long' => -8.683333),
    'LPPS' => array('name' => 'Porto Santo', 'lat' => 33.066667, 'long' => -16.350000),
    'LPAZ' => array('name' => 'Santa Maria Acores', 'lat' => 36.966667, 'long' => -25.166667),
  );

  $icao_codes['Qatar'] = array(
    'KQIR' => array('name' => 'Al Udeid', 'lat' => 25.116667, 'long' => 51.300000),
    'OTBD' => array('name' => 'Doha International Airport', 'lat' => 25.250000, 'long' => 51.566667),
  );

  $icao_codes['Reunion'] = array(
    'FMEE' => array('name' => 'Saint-Denis / Gillot', 'lat' => -20.883333, 'long' => 55.516667),
    'FMEP' => array('name' => 'Saint-Pierre', 'lat' => -21.333333, 'long' => 55.483333),
  );

  $icao_codes['Romania'] = array(
    'LRAR' => array('name' => 'Arad', 'lat' => 46.200000, 'long' => 21.400000),
    'LRBS' => array('name' => 'Bucuresti / Imh', 'lat' => 44.500000, 'long' => 26.133333),
    'LROP' => array('name' => 'Bucuresti Otopeni', 'lat' => 44.550000, 'long' => 26.100000),
    'LRCK' => array('name' => 'Kogalniceanu', 'lat' => 44.333333, 'long' => 28.433333),
    'LRTR' => array('name' => 'Timisoara', 'lat' => 45.766667, 'long' => 21.250000),
    'LRTM' => array('name' => 'Tirgu Mures', 'lat' => 46.533333, 'long' => 24.533333),
    'LRTC' => array('name' => 'Tulcea', 'lat' => 45.183333, 'long' => 28.816667),
  );

  $icao_codes['Russia'] = array(
    'UNAA' => array('name' => 'Abakan', 'lat' => 53.750000, 'long' => 91.400000),
    'URSS' => array('name' => 'Adler', 'lat' => 43.433333, 'long' => 39.900000),
    'UHMA' => array('name' => 'Anadyr', 'lat' => 64.783333, 'long' => 177.566667),
    'URKA' => array('name' => 'Anapa / Vitiazevo', 'lat' => 44.900000, 'long' => 37.316667),
    'ULAA' => array('name' => 'Arhangel\'Sk', 'lat' => 64.500000, 'long' => 40.733333),
    'URWA' => array('name' => 'Astrakhan', 'lat' => 46.283333, 'long' => 48.006389),
    'UNBB' => array('name' => 'Barnaul', 'lat' => 53.433333, 'long' => 83.516667),
    'UIBB' => array('name' => 'Bratsk / Irkutsk', 'lat' => 56.370833, 'long' => 101.698611),
    'UUBP' => array('name' => 'Brjansk', 'lat' => 53.250000, 'long' => 34.316667),
    'UHMD' => array('name' => 'Buhta Providenja', 'lat' => 64.416667, 'long' => -173.233333),
    'USCC' => array('name' => 'Chelyabinsk-Balandino', 'lat' => 55.166667, 'long' => 61.400000),
    'UIAA' => array('name' => 'Chita', 'lat' => 52.083333, 'long' => 113.483333),
    'UELL' => array('name' => 'Cul\'Man', 'lat' => 56.833333, 'long' => 124.866667),
    'USSS' => array('name' => 'Ekaterinburg', 'lat' => 56.833333, 'long' => 60.633333),
    'URWI' => array('name' => 'Elista', 'lat' => 46.366667, 'long' => 44.333333),
    'UHHH' => array('name' => 'Habarovsk', 'lat' => 48.516667, 'long' => 135.166667),
    'UIII' => array('name' => 'Irkutsk', 'lat' => 52.266667, 'long' => 104.316667),
    'UEEE' => array('name' => 'Jakutsk', 'lat' => 62.016667, 'long' => 129.716667),
    'UMKK' => array('name' => 'Kaliningrad/Khrabrovo Airport', 'lat' => 54.720000, 'long' => 20.500000),
    'UWKD' => array('name' => 'Kazan\'', 'lat' => 55.783333, 'long' => 49.200000),
    'UNEE' => array('name' => 'Kemerovo', 'lat' => 55.330000, 'long' => 86.080000),
    'URKK' => array('name' => 'Krasnodar', 'lat' => 45.033333, 'long' => 39.150000),
    'URMM' => array('name' => 'Mineral\'Nye Vody', 'lat' => 44.233333, 'long' => 43.066667),
    'UERR' => array('name' => 'Mirny', 'lat' => 62.530000, 'long' => 114.030000),
    'UUDD' => array('name' => 'Moscow / Domodedovo', 'lat' => 55.400000, 'long' => 37.900000),
    'UUEE' => array('name' => 'Moscow / Sheremet\'Ye', 'lat' => 55.983333, 'long' => 37.500000),
    'UUWW' => array('name' => 'Moscow / Vnukovo', 'lat' => 55.650000, 'long' => 37.266667),
    'ULMM' => array('name' => 'Murmansk', 'lat' => 68.966667, 'long' => 33.050000),
    'URMN' => array('name' => 'Nalchik', 'lat' => 43.512778, 'long' => 43.636667),
    'USNN' => array('name' => 'Nizhnevartovsk', 'lat' => 60.933333, 'long' => 76.483333),
    'UWGG' => array('name' => 'Nizhny Novgorod/Strigino', 'lat' => 56.330000, 'long' => 44.000000),
    'UNWW' => array('name' => 'Novokuznetsk', 'lat' => 53.733333, 'long' => 87.183333),
    'UNOO' => array('name' => 'Omsk', 'lat' => 54.966667, 'long' => 73.300000),
    'UWOO' => array('name' => 'Orenburg / Tsentralny', 'lat' => 51.780000, 'long' => 55.120000),
    'UWPP' => array('name' => 'Penza', 'lat' => 53.116667, 'long' => 45.016667),
    'USPP' => array('name' => 'Perm\'/Bolshoe Savino', 'lat' => 58.000000, 'long' => 56.250000),
    'UHPP' => array('name' => 'Petropavlovsk-Kamchatskij', 'lat' => 53.083333, 'long' => 158.583333),
    'UERP' => array('name' => 'Polyarny', 'lat' => 66.400556, 'long' => 112.030278),
    'URRR' => array('name' => 'Rostov-Na-Donu', 'lat' => 47.266667, 'long' => 39.816667),
    'UWWW' => array('name' => 'Samara', 'lat' => 53.200000, 'long' => 50.150000),
    'UWSS' => array('name' => 'Saratov / Tsentralny', 'lat' => 51.570000, 'long' => 46.070000),
    'ULLI' => array('name' => 'St. Peterburg', 'lat' => 59.966667, 'long' => 30.300000),
    'URMT' => array('name' => 'Stavropol / Shpakovskoye', 'lat' => 45.333333, 'long' => 42.000000),
    'USRR' => array('name' => 'Surgut', 'lat' => 61.250000, 'long' => 73.500000),
    'UUYY' => array('name' => 'Syktyvkar', 'lat' => 61.716667, 'long' => 50.833333),
    'UEST' => array('name' => 'Tiksi', 'lat' => 71.700000, 'long' => 128.900000),
    'UUEM' => array('name' => 'Tver', 'lat' => 56.900000, 'long' => 35.883333),
    'UWUU' => array('name' => 'Ufa', 'lat' => 54.730000, 'long' => 55.930000),
    'UIUU' => array('name' => 'Ulan-Ude', 'lat' => 51.833333, 'long' => 107.600000),
    'UWLW' => array('name' => 'Ulyanovsk', 'lat' => 54.350000, 'long' => 48.383333),
    'ULOL' => array('name' => 'Velikie Luki', 'lat' => 56.350000, 'long' => 30.616667),
    'UHWW' => array('name' => 'Vladivostok', 'lat' => 43.116667, 'long' => 131.933333),
    'URWW' => array('name' => 'Volgograd', 'lat' => 48.783333, 'long' => 44.366667),
    'ULWW' => array('name' => 'Vologda', 'lat' => 59.316667, 'long' => 39.916667),
    'UUOO' => array('name' => 'Voronez', 'lat' => 51.650000, 'long' => 39.250000),
    'UHSS' => array('name' => 'Yuzhno-Sakhalinsk', 'lat' => 46.950000, 'long' => 142.716667),
  );

  $icao_codes['Saint Helena'] = array(
    'FHAW' => array('name' => 'Wide Awake Field Ascension Island', 'lat' => -7.966667, 'long' => -14.400000),
  );

  $icao_codes['Saint Kitts and Nevis'] = array(
    'TKPK' => array('name' => 'Golden Rock', 'lat' => 17.300000, 'long' => -62.683333),
  );

  $icao_codes['Saint Lucia'] = array(
    'TLPL' => array('name' => 'Hewanorra International Airport', 'lat' => 13.750000, 'long' => -60.950000),
    'TLPC' => array('name' => 'Vigie', 'lat' => 14.016667, 'long' => -61.000000),
  );

  $icao_codes['Saint Pierre and Miquelon'] = array(
    'LFVP' => array('name' => 'Saint-Pierre', 'lat' => 46.766667, 'long' => -56.166667),
  );

  $icao_codes['Saint Vincent and the Grenadines'] = array(
    'TVSV' => array('name' => 'Arnos Vale', 'lat' => 13.133333, 'long' => -61.200000),
  );

  $icao_codes['Samoa'] = array(
    'NSFA' => array('name' => 'Faleolo Intl / Apia', 'lat' => -13.816667, 'long' => -172.000000),
  );

  $icao_codes['Saudi Arabia'] = array(
    'OEAB' => array('name' => 'Abha', 'lat' => 18.233333, 'long' => 42.650000),
    'OEAH' => array('name' => 'Al Ahsa', 'lat' => 25.300000, 'long' => 49.483333),
    'OEBA' => array('name' => 'Al Baha', 'lat' => 20.300000, 'long' => 41.633333),
    'OEPA' => array('name' => 'Al Qaysumah', 'lat' => 28.316667, 'long' => 46.116667),
    'OESK' => array('name' => 'Al-Jouf', 'lat' => 29.783333, 'long' => 40.100000),
    'OERR' => array('name' => 'Arar', 'lat' => 30.900000, 'long' => 41.133333),
    'OEBH' => array('name' => 'Bisha', 'lat' => 19.983333, 'long' => 42.616667),
    'OEDF' => array('name' => 'Dammam-King Fahd International Airport', 'lat' => 26.466667, 'long' => 49.783333),
    'OEDR' => array('name' => 'Dhahran', 'lat' => 26.266667, 'long' => 50.150000),
    'OEGS' => array('name' => 'Gassim', 'lat' => 26.300000, 'long' => 43.766667),
    'OEGN' => array('name' => 'Gizan', 'lat' => 16.900000, 'long' => 42.583333),
    'OEGT' => array('name' => 'Guriat', 'lat' => 31.400000, 'long' => 37.266667),
    'OEKK' => array('name' => 'Hafr Al-Batin', 'lat' => 27.900000, 'long' => 45.533333),
    'OEHL' => array('name' => 'Hail', 'lat' => 27.433333, 'long' => 41.683333),
    'OEJN' => array('name' => 'Jeddah King Abdul Aziz International Airport', 'lat' => 21.700000, 'long' => 39.183333),
    'OEKM' => array('name' => 'Khamis Mushait', 'lat' => 18.300000, 'long' => 42.800000),
    'OERK' => array('name' => 'King Khaled International Airport', 'lat' => 24.933333, 'long' => 46.716667),
    'OEMA' => array('name' => 'Madinah', 'lat' => 24.550000, 'long' => 39.700000),
    'OEMK' => array('name' => 'Makkah', 'lat' => 21.433333, 'long' => 39.766667),
    'OENG' => array('name' => 'Najran', 'lat' => 17.616667, 'long' => 44.416667),
    'OERF' => array('name' => 'Rafha', 'lat' => 29.616667, 'long' => 43.483333),
    'OERY' => array('name' => 'Riyadh', 'lat' => 24.716667, 'long' => 46.733333),
    'OESH' => array('name' => 'Sharurah', 'lat' => 17.466667, 'long' => 47.116667),
    'OETB' => array('name' => 'Tabuk', 'lat' => 28.366667, 'long' => 36.600000),
    'OETF' => array('name' => 'Taif', 'lat' => 21.483333, 'long' => 40.550000),
    'OETR' => array('name' => 'Turaif', 'lat' => 31.683333, 'long' => 38.733333),
    'OEWD' => array('name' => 'Wadi Al Dawasser Airport', 'lat' => 20.500000, 'long' => 45.200000),
    'OEWJ' => array('name' => 'Wejh', 'lat' => 26.200000, 'long' => 36.466667),
    'OEYN' => array('name' => 'Yenbo', 'lat' => 24.150000, 'long' => 38.066667),
  );

  $icao_codes['Senegal'] = array(
    'GOGS' => array('name' => 'Cap-Skirring', 'lat' => 12.400000, 'long' => -16.750000),
    'GOOY' => array('name' => 'Dakar / Yoff', 'lat' => 14.733333, 'long' => -17.500000),
    'GOSS' => array('name' => 'Saint-Louis', 'lat' => 16.050000, 'long' => -16.450000),
    'GOTT' => array('name' => 'Tambacounda', 'lat' => 13.766667, 'long' => -13.683333),
    'GOGG' => array('name' => 'Ziguinchor', 'lat' => 12.550000, 'long' => -16.266667),
  );

  $icao_codes['Serbia and Montenegro'] = array(
    'LYBE' => array('name' => 'Beograd / Surcin', 'lat' => 44.816667, 'long' => 20.283333),
    'KQUK' => array('name' => 'Camp Bondsteel', 'lat' => 42.583333, 'long' => 21.383333),
    'LYNI' => array('name' => 'Nis', 'lat' => 43.333333, 'long' => 21.900000),
    'LYPG' => array('name' => 'Podgorica Titograd', 'lat' => 42.433333, 'long' => 19.283333),
    'LYTV' => array('name' => 'Tivat', 'lat' => 42.400000, 'long' => 18.733333),
  );

  $icao_codes['Seychelles'] = array(
    'FSIA' => array('name' => 'Seychelles Inter-National Airport', 'lat' => -4.666667, 'long' => 55.516667),
  );

  $icao_codes['Sierra Leone'] = array(
    'GFLL' => array('name' => 'Lungi', 'lat' => 8.616667, 'long' => -13.200000),
  );

  $icao_codes['Singapore'] = array(
    'WSSS' => array('name' => 'Singapore / Changi Airport', 'lat' => 1.366667, 'long' => 103.983333),
    'WSAP' => array('name' => 'Singapore / Paya Lebar', 'lat' => 1.366667, 'long' => 103.916667),
  );

  $icao_codes['Slovakia'] = array(
    'LZIB' => array('name' => 'Bratislava Ivanka', 'lat' => 48.200000, 'long' => 17.200000),
    'LZZI' => array('name' => 'Dolny Hricov', 'lat' => 49.233333, 'long' => 18.613611),
    'LZKC' => array('name' => 'Kamenica Nad Cirochou', 'lat' => 48.933333, 'long' => 22.000000),
    'LZKZ' => array('name' => 'Kosice, Barca', 'lat' => 48.663056, 'long' => 21.241111),
    'LZLU' => array('name' => 'Lucenec', 'lat' => 48.333333, 'long' => 19.733333),
    'LZNI' => array('name' => 'Nitra', 'lat' => 48.279444, 'long' => 18.132778),
    'LZPP' => array('name' => 'Piestany', 'lat' => 48.625000, 'long' => 17.828611),
    'LZTT' => array('name' => 'Poprad / Tatry', 'lat' => 49.066667, 'long' => 20.250000),
    'LZPE' => array('name' => 'Prievidza', 'lat' => 48.766389, 'long' => 18.588333),
    'LZSL' => array('name' => 'Sliac', 'lat' => 48.638056, 'long' => 19.134167),
  );

  $icao_codes['Slovenia'] = array(
    'LJLJ' => array('name' => 'Ljubljana / Brnik', 'lat' => 46.216667, 'long' => 14.483333),
    'LJMB' => array('name' => 'Maribor / Slivnica', 'lat' => 46.483333, 'long' => 15.683333),
    'LJPZ' => array('name' => 'Portoroz', 'lat' => 45.516667, 'long' => 13.566667),
  );

  $icao_codes['Solomon Islands'] = array(
    'AGGH' => array('name' => 'Honiara / Henderson', 'lat' => -9.416667, 'long' => 160.050000),
  );

  $icao_codes['Somalia'] = array(
    'HCMI' => array('name' => 'Berbera', 'lat' => 10.416667, 'long' => 45.016667),
    'HCMV' => array('name' => 'Burao', 'lat' => 9.500000, 'long' => 45.566667),
    'HCMH' => array('name' => 'Hargeisa', 'lat' => 9.500000, 'long' => 44.083333),
  );

  $icao_codes['South Africa'] = array(
    'FAAB' => array('name' => 'Alexander Bay', 'lat' => -28.566667, 'long' => 16.533333),
    'FABL' => array('name' => 'Bloemfontein, Bloemfontein Airport', 'lat' => -29.100000, 'long' => 26.300000),
    'FACT' => array('name' => 'Cape Town, Cape Town International Airport', 'lat' => -33.983333, 'long' => 18.600000),
    'FADN' => array('name' => 'Durban, Durban International Airport', 'lat' => -29.966667, 'long' => 30.950000),
    'FAEL' => array('name' => 'East London, East London Airport', 'lat' => -33.033333, 'long' => 27.833333),
    'FAGG' => array('name' => 'George, George Airport', 'lat' => -34.000000, 'long' => 22.383333),
    'FAJS' => array('name' => 'Johannesburg International Airport', 'lat' => -26.133333, 'long' => 28.233333),
    'FAKM' => array('name' => 'Kimberley, Kim-Apt', 'lat' => -28.800000, 'long' => 24.766667),
    'FAKD' => array('name' => 'Klerksdorp', 'lat' => -26.866667, 'long' => 26.716667),
    'FALA' => array('name' => 'Lanseria', 'lat' => -25.933333, 'long' => 27.933333),
    'FAMM' => array('name' => 'Mafikeng Intl. Ad', 'lat' => -25.783333, 'long' => 25.533333),
    'FANS' => array('name' => 'Nelspruit', 'lat' => -25.433333, 'long' => 30.983333),
    'FAPE' => array('name' => 'Port Elizabeth, Port E Apt', 'lat' => -33.983333, 'long' => 25.600000),
    'FAPS' => array('name' => 'Potchefstroom', 'lat' => -26.671111, 'long' => 27.081944),
    'FAGM' => array('name' => 'Rand', 'lat' => -26.250000, 'long' => 28.000000),
    'FARG' => array('name' => 'Rustenburg', 'lat' => -25.644167, 'long' => 27.271111),
    'FASR' => array('name' => 'Standerton', 'lat' => -26.933333, 'long' => 29.216667),
    'FAUP' => array('name' => 'Upington, Up-Apt', 'lat' => -28.400000, 'long' => 21.266667),
    'FAVV' => array('name' => 'Vereeniging', 'lat' => -26.574722, 'long' => 27.962500),
    'FAWK' => array('name' => 'Waterkloof (SAAF)', 'lat' => -25.833333, 'long' => 28.216667),
  );

  $icao_codes['South Georgia and the Islands'] = array(
    'EGYP' => array('name' => 'Mount Pleasant Airport', 'lat' => -51.816667, 'long' => -58.450000),
  );

  $icao_codes['Spain'] = array(
    'LEAB' => array('name' => 'Albacete / Los Llanos', 'lat' => 38.950000, 'long' => -1.850000),
    'LEAL' => array('name' => 'Alicante / El Altet', 'lat' => 38.283333, 'long' => -0.550000),
    'LEAM' => array('name' => 'Almeria / Aeropuerto', 'lat' => 36.850000, 'long' => -2.383333),
    'LEAS' => array('name' => 'Asturias / Aviles', 'lat' => 43.550000, 'long' => -6.033333),
    'LEBZ' => array('name' => 'Badajoz / Talavera La Real', 'lat' => 38.883333, 'long' => -6.816667),
    'LEBL' => array('name' => 'Barcelona / Aeropuerto', 'lat' => 41.283333, 'long' => 2.066667),
    'LEBB' => array('name' => 'Bilbao / Sondica', 'lat' => 43.300000, 'long' => -2.933333),
    'LEBA' => array('name' => 'Cordoba / Aeropuerto', 'lat' => 37.850000, 'long' => -4.850000),
    'GCFV' => array('name' => 'Fuerteventura / Aeropuerto', 'lat' => 28.450000, 'long' => -13.866667),
    'LEGE' => array('name' => 'Gerona / Costa Brava', 'lat' => 41.900000, 'long' => 2.766667),
    'GCLP' => array('name' => 'Gran Canaria - Canary Islands', 'lat' => 27.933333, 'long' => -15.383333),
    'LEGR' => array('name' => 'Granada / Aeropuerto', 'lat' => 37.183333, 'long' => -3.783333),
    'LEGA' => array('name' => 'Granada / Armilla', 'lat' => 37.133333, 'long' => -3.635556),
    'GCHI' => array('name' => 'Hierro / Aeropuerto', 'lat' => 27.816667, 'long' => -17.883333),
    'LEIB' => array('name' => 'Ibiza / Es Codola', 'lat' => 38.866667, 'long' => 1.383333),
    'LEJR' => array('name' => 'Jerez De La Fronteraaeropuerto', 'lat' => 36.750000, 'long' => -6.066667),
    'LECO' => array('name' => 'La Coruna / Alvedro', 'lat' => 43.300000, 'long' => -8.383333),
    'GCLA' => array('name' => 'La Palma / Aeropuerto', 'lat' => 28.616667, 'long' => -17.750000),
    'GCRR' => array('name' => 'Lanzarote / Aeropuerto', 'lat' => 28.950000, 'long' => -13.600000),
    'LELN' => array('name' => 'Leon / Virgen Del Camino', 'lat' => 42.583333, 'long' => -5.650000),
    'LEMD' => array('name' => 'Madrid / Barajas', 'lat' => 40.450000, 'long' => -3.550000),
    'LEVS' => array('name' => 'Madrid / Cuatro Vientos', 'lat' => 40.383333, 'long' => -3.783333),
    'LEGT' => array('name' => 'Madrid / Getafe', 'lat' => 40.300000, 'long' => -3.716667),
    'LETO' => array('name' => 'Madrid / Torrejon', 'lat' => 40.483333, 'long' => -3.450000),
    'LEMG' => array('name' => 'Malaga / Aeropuerto', 'lat' => 36.666667, 'long' => -4.483333),
    'GEML' => array('name' => 'Melilla', 'lat' => 35.283333, 'long' => -2.950000),
    'LEMH' => array('name' => 'Menorca / Mahon', 'lat' => 39.866667, 'long' => 4.233333),
    'LEMO' => array('name' => 'Moron De La Frontera', 'lat' => 37.150000, 'long' => -5.616667),
    'LERI' => array('name' => 'Murcia / Alcantarilla', 'lat' => 37.950000, 'long' => -1.233333),
    'LELC' => array('name' => 'Murcia / San Javier', 'lat' => 37.783333, 'long' => -0.800000),
    'LEPA' => array('name' => 'Palma De Mallorca / Son San Juan', 'lat' => 39.550000, 'long' => 2.733333),
    'LEPP' => array('name' => 'Pamplona / Noain', 'lat' => 42.766667, 'long' => -1.633333),
    'LERS' => array('name' => 'Reus / Aeropuerto', 'lat' => 41.150000, 'long' => 1.166667),
    'LERT' => array('name' => 'Rota', 'lat' => 36.650000, 'long' => -6.350000),
    'LESA' => array('name' => 'Salamanca / Matacan', 'lat' => 40.950000, 'long' => -5.500000),
    'LESO' => array('name' => 'San Sebastian / Fuenterrabia', 'lat' => 43.350000, 'long' => -1.800000),
    'LEXJ' => array('name' => 'Santander / Parayas', 'lat' => 43.433333, 'long' => -3.816667),
    'LEST' => array('name' => 'Santiago / Labacolla', 'lat' => 42.900000, 'long' => -8.433333),
    'LEZL' => array('name' => 'Sevilla / San Pablo', 'lat' => 37.416667, 'long' => -5.900000),
    'GCXO' => array('name' => 'Tenerife / Los Rodeos', 'lat' => 28.466667, 'long' => -16.316667),
    'GCTS' => array('name' => 'Tenerife Sur', 'lat' => 28.050000, 'long' => -16.566667),
    'LEVC' => array('name' => 'Valencia / Aeropuerto', 'lat' => 39.500000, 'long' => -0.466667),
    'LEVD' => array('name' => 'Valladolid / Villanubla', 'lat' => 41.716667, 'long' => -4.850000),
    'LEVX' => array('name' => 'Vigo / Peinador', 'lat' => 42.216667, 'long' => -8.633333),
    'LEVT' => array('name' => 'Vitoria', 'lat' => 42.883333, 'long' => -2.716667),
    'LEZG' => array('name' => 'Zaragoza / Aeropuerto', 'lat' => 41.666667, 'long' => -1.016667),
  );

  $icao_codes['Sri Lanka'] = array(
    'VCBI' => array('name' => 'Katunayake', 'lat' => 7.166667, 'long' => 79.883333),
  );

  $icao_codes['Suriname'] = array(
    'SMJP' => array('name' => 'Johan A. Pengel', 'lat' => 5.450000, 'long' => -55.183333),
  );

  $icao_codes['Swaziland'] = array(
    'FDMS' => array('name' => 'Manzini / Matsapa Airport', 'lat' => -26.533333, 'long' => 31.300000),
  );

  $icao_codes['Sweden'] = array(
    'ESSD' => array('name' => 'Borlange', 'lat' => 60.433333, 'long' => 15.516667),
    'ESNG' => array('name' => 'Gallivare', 'lat' => 67.150000, 'long' => 20.650000),
    'ESGG' => array('name' => 'Goteborg / Landvetter', 'lat' => 57.666667, 'long' => 12.300000),
    'ESGP' => array('name' => 'Goteborg / Save', 'lat' => 57.783333, 'long' => 11.883333),
    'ESMT' => array('name' => 'Halmstad Swedish Air Force Base', 'lat' => 56.683333, 'long' => 12.833333),
    'ESSF' => array('name' => 'Hultsfred Swedish Air Force Base', 'lat' => 57.516667, 'long' => 15.833333),
    'ESGJ' => array('name' => 'Jonkoping Flygplats', 'lat' => 57.766667, 'long' => 14.083333),
    'ESMQ' => array('name' => 'Kalmar', 'lat' => 56.733333, 'long' => 16.300000),
    'ESOK' => array('name' => 'Karlstad', 'lat' => 59.444722, 'long' => 13.337500),
    'ESNQ' => array('name' => 'Kiruna Airport', 'lat' => 67.816667, 'long' => 20.333333),
    'ESNK' => array('name' => 'Kramfors Flygplats', 'lat' => 63.050000, 'long' => 17.766667),
    'ESMK' => array('name' => 'Kristianstad / Everod', 'lat' => 55.916667, 'long' => 14.083333),
    'ESSL' => array('name' => 'Linkoping / Saab', 'lat' => 58.400000, 'long' => 15.683333),
    'ESTL' => array('name' => 'Ljungbyhed', 'lat' => 56.066667, 'long' => 13.200000),
    'ESPA' => array('name' => 'Lulea / Kallax', 'lat' => 65.550000, 'long' => 22.133333),
    'ESNL' => array('name' => 'Lycksele', 'lat' => 64.547500, 'long' => 18.717500),
    'ESMS' => array('name' => 'Malmo / Sturup', 'lat' => 55.550000, 'long' => 13.366667),
    'ESSP' => array('name' => 'Norrkoping', 'lat' => 58.583333, 'long' => 16.150000),
    'ESOE' => array('name' => 'Orebro Private', 'lat' => 59.233333, 'long' => 15.050000),
    'ESPC' => array('name' => 'Ostersund / Froson', 'lat' => 63.183333, 'long' => 14.500000),
    'ESDF' => array('name' => 'Ronneby', 'lat' => 56.266667, 'long' => 15.283333),
    'ESNS' => array('name' => 'Skelleftea Airport', 'lat' => 64.633333, 'long' => 21.083333),
    'ESGR' => array('name' => 'Skovde Flygplats', 'lat' => 58.450000, 'long' => 13.966667),
    'ESNY' => array('name' => 'Soderhamn', 'lat' => 61.261389, 'long' => 17.099167),
    'ESSA' => array('name' => 'Stockholm / Arlanda', 'lat' => 59.650000, 'long' => 17.950000),
    'ESSB' => array('name' => 'Stockholm / Bromma', 'lat' => 59.350000, 'long' => 17.950000),
    'ESKN' => array('name' => 'Stockholm/Skavsta', 'lat' => 58.783333, 'long' => 16.916667),
    'ESNN' => array('name' => 'Sundsvall-Harnosand Flygplats', 'lat' => 62.533333, 'long' => 17.450000),
    'ESGT' => array('name' => 'Trollhattan Private', 'lat' => 58.316667, 'long' => 12.350000),
    'ESNU' => array('name' => 'Umea Flygplats', 'lat' => 63.800000, 'long' => 20.283333),
    'ESOW' => array('name' => 'Vasteras / Hasslo', 'lat' => 59.583333, 'long' => 16.633333),
    'ESMX' => array('name' => 'Vaxjo', 'lat' => 56.850000, 'long' => 14.833333),
    'ESSV' => array('name' => 'Visby Flygplats', 'lat' => 57.666667, 'long' => 18.350000),
  );

  $icao_codes['Switzerland'] = array(
    'LSZB' => array('name' => 'Bern / Belp', 'lat' => 46.916667, 'long' => 7.500000),
    'LSGG' => array('name' => 'Geneve-Cointrin', 'lat' => 46.250000, 'long' => 6.133333),
    'LSZA' => array('name' => 'Lugano', 'lat' => 46.000000, 'long' => 8.966667),
    'LSZH' => array('name' => 'Zurich-Kloten', 'lat' => 47.483333, 'long' => 8.533333),
  );

  $icao_codes['Syria'] = array(
    'OSAP' => array('name' => 'Aleppo International Airport', 'lat' => 36.183333, 'long' => 37.200000),
    'OSDI' => array('name' => 'Damascus Int. Airport', 'lat' => 33.416667, 'long' => 36.516667),
    'OSDZ' => array('name' => 'Deir Ezzor', 'lat' => 35.316667, 'long' => 40.150000),
    'OSKL' => array('name' => 'Kamishli', 'lat' => 37.050000, 'long' => 41.216667),
    'OSLK' => array('name' => 'Lattakia', 'lat' => 35.533333, 'long' => 35.766667),
  );

  $icao_codes['Taiwan'] = array(
    'RCTP' => array('name' => 'Chiang Kai Shek', 'lat' => 25.083333, 'long' => 121.216667),
    'RCKH' => array('name' => 'Kaohsiung International Airport', 'lat' => 22.583333, 'long' => 120.350000),
    'RCSS' => array('name' => 'Sungshan / Taipei', 'lat' => 25.066667, 'long' => 121.550000),
  );

  $icao_codes['Tajikistan'] = array(
    'UTDD' => array('name' => 'Dushanbe', 'lat' => 38.550000, 'long' => 68.783333),
  );

  $icao_codes['Thailand'] = array(
    'VTCC' => array('name' => 'Chiang Mai', 'lat' => 18.783333, 'long' => 98.983333),
    'VTBD' => array('name' => 'Don Muang', 'lat' => 13.916667, 'long' => 100.600000),
    'VTSS' => array('name' => 'Hat Yai', 'lat' => 6.916667, 'long' => 100.433333),
    'VTPH' => array('name' => 'Hua Hin', 'lat' => 12.583333, 'long' => 99.950000),
    'VTUK' => array('name' => 'Khon Kaen', 'lat' => 16.433333, 'long' => 102.833333),
    'VTCL' => array('name' => 'Lampang', 'lat' => 18.283333, 'long' => 99.516667),
    'VTUL' => array('name' => 'Loei', 'lat' => 17.450000, 'long' => 101.733333),
    'VTCH' => array('name' => 'Mae Hong Son', 'lat' => 19.300000, 'long' => 97.833333),
    'VTPM' => array('name' => 'Mae Sot', 'lat' => 16.666667, 'long' => 98.550000),
    'VTCN' => array('name' => 'Nan', 'lat' => 18.766667, 'long' => 100.766667),
    'VTCP' => array('name' => 'Phrae', 'lat' => 18.166667, 'long' => 100.166667),
    'VTSP' => array('name' => 'Phuket Airport', 'lat' => 8.116667, 'long' => 98.316667),
    'VTSR' => array('name' => 'Ranong', 'lat' => 9.983333, 'long' => 98.616667),
    'VTBU' => array('name' => 'Rayong', 'lat' => 12.633333, 'long' => 101.350000),
    'VTSB' => array('name' => 'Surat Thani', 'lat' => 9.116667, 'long' => 99.350000),
    'VTST' => array('name' => 'Trang', 'lat' => 7.516667, 'long' => 99.616667),
    'VTUU' => array('name' => 'Ubon Ratchathani', 'lat' => 15.250000, 'long' => 104.866667),
    'VTUD' => array('name' => 'Udon Thani', 'lat' => 17.383333, 'long' => 102.800000),
  );

  $icao_codes['Togo'] = array(
    'DXXX' => array('name' => 'Lome', 'lat' => 6.166667, 'long' => 1.250000),
    'DXNG' => array('name' => 'Niamtougou', 'lat' => 9.766667, 'long' => 1.100000),
  );

  $icao_codes['Tonga'] = array(
    'NFTF' => array('name' => 'Fua\'Amotu', 'lat' => -21.233333, 'long' => -175.150000),
  );

  $icao_codes['Trinidad and Tobago'] = array(
    'TTCP' => array('name' => 'Crown Pt./ Scarborou', 'lat' => 11.150000, 'long' => -60.850000),
    'TTPP' => array('name' => 'Piarco International Airport, Trinidad', 'lat' => 10.616667, 'long' => -61.350000),
  );

  $icao_codes['Tunisia'] = array(
    'DTTB' => array('name' => 'Bizerte', 'lat' => 37.250000, 'long' => 9.800000),
    'DTTJ' => array('name' => 'Djerba Mellita', 'lat' => 33.866667, 'long' => 10.766667),
    'DTTR' => array('name' => 'El Borma', 'lat' => 31.683333, 'long' => 9.166667),
    'DTTG' => array('name' => 'Gabes', 'lat' => 33.883333, 'long' => 10.100000),
    'DTTF' => array('name' => 'Gafsa', 'lat' => 34.416667, 'long' => 8.816667),
    'DTMB' => array('name' => 'Habib Bourguiba', 'lat' => 35.766667, 'long' => 10.750000),
    'DTTN' => array('name' => 'Jendouba', 'lat' => 36.483333, 'long' => 8.800000),
    'DTTK' => array('name' => 'Kairouan', 'lat' => 35.666667, 'long' => 10.100000),
    'DTTL' => array('name' => 'Kelibia', 'lat' => 36.850000, 'long' => 11.083333),
    'DTTD' => array('name' => 'Remada', 'lat' => 32.316667, 'long' => 10.400000),
    'DTTX' => array('name' => 'Sfax El-Maou', 'lat' => 34.716667, 'long' => 10.683333),
    'DTKA' => array('name' => 'Tabarka', 'lat' => 36.950000, 'long' => 8.750000),
    'DTTZ' => array('name' => 'Tozeur', 'lat' => 33.916667, 'long' => 8.100000),
    'DTTA' => array('name' => 'Tunis-Carthage', 'lat' => 36.833333, 'long' => 10.233333),
  );

  $icao_codes['Turkey'] = array(
    'LTAG' => array('name' => 'Adana / Incirlik', 'lat' => 37.000000, 'long' => 35.416667),
    'LTAF' => array('name' => 'Adana / Sakirpasa', 'lat' => 36.983333, 'long' => 35.300000),
    'LTAC' => array('name' => 'Ankara / Esenboga', 'lat' => 40.116667, 'long' => 32.983333),
    'LTAD' => array('name' => 'Ankara / Etimesgut', 'lat' => 39.950000, 'long' => 32.683333),
    'LTAB' => array('name' => 'Ankara / Guvercin Lik', 'lat' => 39.933333, 'long' => 32.750000),
    'LTAI' => array('name' => 'Antalya', 'lat' => 36.700000, 'long' => 30.733333),
    'LTBF' => array('name' => 'Balikesir', 'lat' => 39.616667, 'long' => 27.916667),
    'LTBG' => array('name' => 'Bandirma', 'lat' => 40.316667, 'long' => 27.966667),
    'LTCJ' => array('name' => 'Batman', 'lat' => 37.866667, 'long' => 41.166667),
    'LTFE' => array('name' => 'Bodrum Milas Airport', 'lat' => 37.248056, 'long' => 27.681944),
    'LTBR' => array('name' => 'Bursa / Yenisehir, Mil-Civ', 'lat' => 40.255278, 'long' => 29.562500),
    'LTBU' => array('name' => 'Corlu', 'lat' => 41.133333, 'long' => 27.916667),
    'LTBS' => array('name' => 'Dalaman', 'lat' => 36.700000, 'long' => 28.783333),
    'LTCC' => array('name' => 'Diyarbakir', 'lat' => 37.883333, 'long' => 40.183333),
    'LTCA' => array('name' => 'Elazig', 'lat' => 38.600000, 'long' => 39.283333),
    'LTCD' => array('name' => 'Erzincan', 'lat' => 39.733333, 'long' => 39.500000),
    'LTCE' => array('name' => 'Erzurum', 'lat' => 39.916667, 'long' => 41.266667),
    'LTBI' => array('name' => 'Eskisehir', 'lat' => 39.783333, 'long' => 30.566667),
    'LTAJ' => array('name' => 'Gaziantep', 'lat' => 37.083333, 'long' => 37.366667),
    'LTBA' => array('name' => 'Istanbul / Ataturk', 'lat' => 40.966667, 'long' => 28.816667),
    'LTFJ' => array('name' => 'Istanbul / Sabiha Gokcen', 'lat' => 40.898611, 'long' => 29.309167),
    'LTBJ' => array('name' => 'Izmir / Adnan Menderes', 'lat' => 38.266667, 'long' => 27.150000),
    'LTBL' => array('name' => 'Izmir / Cigli', 'lat' => 38.500000, 'long' => 27.016667),
    'LTCF' => array('name' => 'Kars', 'lat' => 40.600000, 'long' => 43.083333),
    'LTAU' => array('name' => 'Kayseri / Erkilet', 'lat' => 38.783333, 'long' => 35.483333),
    'LTAN' => array('name' => 'Konya', 'lat' => 37.966667, 'long' => 32.550000),
    'LTAT' => array('name' => 'Malatya / Erhac', 'lat' => 38.433333, 'long' => 38.083333),
    'LTAP' => array('name' => 'Merzifon', 'lat' => 40.850000, 'long' => 35.583333),
    'LTAE' => array('name' => 'Murted Tur-Afb', 'lat' => 40.083333, 'long' => 32.566667),
    'LTAZ' => array('name' => 'Nevsehir', 'lat' => 38.770000, 'long' => 34.541667),
    'LTFH' => array('name' => 'Samsun / Carsamba', 'lat' => 41.254167, 'long' => 36.567500),
    'LTFC' => array('name' => 'Suleyman Demirel', 'lat' => 37.850000, 'long' => 30.366667),
    'LTBQ' => array('name' => 'Topel Tur-Afb', 'lat' => 40.733333, 'long' => 30.083333),
    'LTCG' => array('name' => 'Trabzon', 'lat' => 41.000000, 'long' => 39.716667),
    'LTCI' => array('name' => 'Van', 'lat' => 38.450000, 'long' => 43.316667),
  );

  $icao_codes['Turkmenistan'] = array(
    'UTAA' => array('name' => 'Ashgabat', 'lat' => 37.983333, 'long' => 58.366667),
  );

  $icao_codes['Turks and Caicos Islands'] = array(
    'MBPV' => array('name' => 'Providenciales', 'lat' => 21.773611, 'long' => -72.265833),
  );

  $icao_codes['Tuvalu'] = array(
    'NGFU' => array('name' => 'Funafuti', 'lat' => -8.516667, 'long' => 179.216667),
  );

  $icao_codes['Uganda'] = array(
    'HUAR' => array('name' => 'Arua', 'lat' => 3.050000, 'long' => 30.916667),
    'HUEN' => array('name' => 'Entebbe Airport', 'lat' => 0.050000, 'long' => 32.450000),
    'HUGU' => array('name' => 'Gulu', 'lat' => 2.750000, 'long' => 32.333333),
    'HUJI' => array('name' => 'Jinja', 'lat' => 0.450000, 'long' => 33.183333),
    'HUKB' => array('name' => 'Kabale', 'lat' => -1.250000, 'long' => 29.983333),
    'HUKS' => array('name' => 'Kasese', 'lat' => 0.183333, 'long' => 30.100000),
    'HULI' => array('name' => 'Lira', 'lat' => 2.250000, 'long' => 32.900000),
    'HUMI' => array('name' => 'Masindi', 'lat' => 1.683333, 'long' => 31.716667),
    'HUMA' => array('name' => 'Mbarara', 'lat' => -0.616667, 'long' => 30.650000),
    'HUSO' => array('name' => 'Soroti', 'lat' => 1.716667, 'long' => 33.616667),
    'HUTO' => array('name' => 'Tororo', 'lat' => 0.683333, 'long' => 34.166667),
  );

  $icao_codes['Ukraine'] = array(
    'UKBB' => array('name' => 'Boryspil', 'lat' => 50.333333, 'long' => 30.966667),
    'UKLN' => array('name' => 'Chernovsty', 'lat' => 48.260000, 'long' => 25.981667),
    'UKDD' => array('name' => 'Dnipropetrovs\'k', 'lat' => 48.533333, 'long' => 34.666667),
    'UKCC' => array('name' => 'Donetsk', 'lat' => 48.083333, 'long' => 37.750000),
    'UKKM' => array('name' => 'Hostomel', 'lat' => 50.600278, 'long' => 30.193611),
    'UKLI' => array('name' => 'Ivano-Frankivsk', 'lat' => 48.884167, 'long' => 24.686111),
    'UKHH' => array('name' => 'Kharkiv', 'lat' => 49.966667, 'long' => 36.133333),
    'UKDR' => array('name' => 'Krivyy Rih / Dnipropetrovs\'k', 'lat' => 48.050000, 'long' => 33.220000),
    'UKKK' => array('name' => 'Kyiv', 'lat' => 50.400000, 'long' => 30.566667),
    'UKLL' => array('name' => 'L\'Viv', 'lat' => 49.816667, 'long' => 23.950000),
    'UKON' => array('name' => 'Mykolaiv', 'lat' => 47.058056, 'long' => 31.920833),
    'UKOO' => array('name' => 'Odesa', 'lat' => 46.433333, 'long' => 30.766667),
    'UKLR' => array('name' => 'Rivne', 'lat' => 50.583333, 'long' => 26.133333),
    'UKFF' => array('name' => 'Simferopol', 'lat' => 44.683333, 'long' => 34.133333),
    'UKLU' => array('name' => 'Uzhhorod', 'lat' => 48.634722, 'long' => 22.264722),
    'UKDE' => array('name' => 'Zaporizhzhia / Mokraya', 'lat' => 47.867222, 'long' => 35.316389),
  );

  $icao_codes['United Arab Emirates'] = array(
    'OMAA' => array('name' => 'Abu Dhabi International Airport', 'lat' => 24.433333, 'long' => 54.650000),
    'OMAL' => array('name' => 'Al Ain International Airport', 'lat' => 24.266667, 'long' => 55.600000),
    'OMDB' => array('name' => 'Dubai International Airport', 'lat' => 25.250000, 'long' => 55.333333),
    'OMFJ' => array('name' => 'Fujairah', 'lat' => 25.100000, 'long' => 56.333333),
    'OMRK' => array('name' => 'Ras Al Khaimah International Airport', 'lat' => 25.616667, 'long' => 55.933333),
    'OMSJ' => array('name' => 'Sharjah International Airport', 'lat' => 25.333333, 'long' => 55.516667),
  );

  $icao_codes['United Kingdom'] = array(
    'EGPD' => array('name' => 'Aberdeen / Dyce', 'lat' => 57.200000, 'long' => -2.216667),
    'EGJA' => array('name' => 'Alderney / Channel Island', 'lat' => 49.716667, 'long' => -2.200000),
    'EGYE' => array('name' => 'Barkston Heath Royal Air Force Base', 'lat' => 52.966667, 'long' => -0.566667),
    'EGAA' => array('name' => 'Belfast / Aldergrove Airport', 'lat' => 54.650000, 'long' => -6.216667),
    'EGAC' => array('name' => 'Belfast / Harbour', 'lat' => 54.600000, 'long' => -5.883333),
    'EGPL' => array('name' => 'Benbecula', 'lat' => 57.466667, 'long' => -7.366667),
    'EGUB' => array('name' => 'Benson', 'lat' => 51.616667, 'long' => -1.083333),
    'EGKB' => array('name' => 'Biggin Hill', 'lat' => 51.316667, 'long' => 0.033333),
    'EGBB' => array('name' => 'Birmingham / Airport', 'lat' => 52.450000, 'long' => -1.733333),
    'EGNH' => array('name' => 'Blackpool Airport', 'lat' => 53.766667, 'long' => -3.033333),
    'EGDM' => array('name' => 'Boscombe Down', 'lat' => 51.166667, 'long' => -1.750000),
    'EGHH' => array('name' => 'Bournemouth Airport', 'lat' => 50.783333, 'long' => -1.833333),
    'EGGD' => array('name' => 'Bristol / Lulsgate', 'lat' => 51.383333, 'long' => -2.716667),
    'EGVN' => array('name' => 'Brize Norton', 'lat' => 51.750000, 'long' => -1.583333),
    'EGSC' => array('name' => 'Cambridge', 'lat' => 52.200000, 'long' => 0.183333),
    'EGEC' => array('name' => 'Campbeltown', 'lat' => 55.437222, 'long' => -5.686389),
    'EGFF' => array('name' => 'Cardiff-Wales Airport', 'lat' => 51.400000, 'long' => -3.350000),
    'EGNC' => array('name' => 'Carlisle', 'lat' => 54.933333, 'long' => -2.950000),
    'EGXG' => array('name' => 'Church Fenton', 'lat' => 53.833333, 'long' => -1.200000),
    'EGXC' => array('name' => 'Coningsby Royal Air Force Base', 'lat' => 53.083333, 'long' => -0.166667),
    'EGWC' => array('name' => 'Cosford Royal Air Force Base', 'lat' => 52.633333, 'long' => -2.300000),
    'EGXJ' => array('name' => 'Cottesmore', 'lat' => 52.733333, 'long' => -0.650000),
    'EGBE' => array('name' => 'Coventry Airport', 'lat' => 52.366667, 'long' => -1.483333),
    'EGTC' => array('name' => 'Cranfield', 'lat' => 52.066667, 'long' => -0.616667),
    'EGYD' => array('name' => 'Cranwell', 'lat' => 53.033333, 'long' => -0.500000),
    'EGDR' => array('name' => 'Culdrose', 'lat' => 50.083333, 'long' => -5.250000),
    'EGXD' => array('name' => 'Disforth', 'lat' => 54.133333, 'long' => -1.416667),
    'EGPN' => array('name' => 'Dundee / Riverside', 'lat' => 56.450000, 'long' => -3.016667),
    'EGNX' => array('name' => 'East Midlands', 'lat' => 52.833333, 'long' => -1.333333),
    'EGPH' => array('name' => 'Edinburgh Airport', 'lat' => 55.950000, 'long' => -3.350000),
    'EGAE' => array('name' => 'Eglinton / Londonderr', 'lat' => 55.050000, 'long' => -7.150000),
    'EGTE' => array('name' => 'Exeter Airport', 'lat' => 50.733333, 'long' => -3.416667),
    'EGLF' => array('name' => 'Farnborough', 'lat' => 51.283333, 'long' => -0.766667),
    'EGTG' => array('name' => 'Filton Private', 'lat' => 51.516667, 'long' => -2.583333),
    'EGPF' => array('name' => 'Glasgow Airport', 'lat' => 55.866667, 'long' => -4.433333),
    'EGJB' => array('name' => 'Guernsey Airport', 'lat' => 49.433333, 'long' => -2.600000),
    'EGNR' => array('name' => 'Hawarden', 'lat' => 53.166667, 'long' => -2.983333),
    'EGYH' => array('name' => 'Holbeach', 'lat' => 52.866667, 'long' => 0.150000),
    'EGNJ' => array('name' => 'Humberside', 'lat' => 53.583333, 'long' => -0.350000),
    'EGPE' => array('name' => 'Inverness / Dalcross', 'lat' => 57.533333, 'long' => -4.050000),
    'EGPI' => array('name' => 'Islay', 'lat' => 55.681944, 'long' => -6.256667),
    'EGNS' => array('name' => 'Isle Of Man / Ronaldsway Airport', 'lat' => 54.083333, 'long' => -4.633333),
    'EGJJ' => array('name' => 'Jersey Airport', 'lat' => 49.216667, 'long' => -2.200000),
    'EGQK' => array('name' => 'Kinloss', 'lat' => 57.650000, 'long' => -3.566667),
    'EGPA' => array('name' => 'Kirkwall Airport', 'lat' => 58.950000, 'long' => -2.900000),
    'EGUL' => array('name' => 'Lakenheath Royal Air Force Base', 'lat' => 52.416667, 'long' => 0.566667),
    'EGNM' => array('name' => 'Leeds And Bradford', 'lat' => 53.866667, 'long' => -1.650000),
    'EGXE' => array('name' => 'Leeming', 'lat' => 54.300000, 'long' => -1.533333),
    'EGQL' => array('name' => 'Leuchars', 'lat' => 56.383333, 'long' => -2.866667),
    'EGXU' => array('name' => 'Linton-On-Ouse', 'lat' => 54.050000, 'long' => -1.250000),
    'EGGP' => array('name' => 'Liverpool Airport', 'lat' => 53.333333, 'long' => -2.850000),
    'EGKK' => array('name' => 'London / Gatwick Airport', 'lat' => 51.150000, 'long' => -0.183333),
    'EGLL' => array('name' => 'London / Heathrow Airport', 'lat' => 51.483333, 'long' => -0.450000),
    'EGLC' => array('name' => 'London City Airport', 'lat' => 51.500000, 'long' => -0.500000),
    'EGQS' => array('name' => 'Lossiemouth', 'lat' => 57.716667, 'long' => -3.316667),
    'EGGW' => array('name' => 'Luton Airport', 'lat' => 51.866667, 'long' => -0.366667),
    'EGMD' => array('name' => 'Lydd Airport', 'lat' => 50.950000, 'long' => 0.933333),
    'EGDL' => array('name' => 'Lyneham', 'lat' => 51.500000, 'long' => -1.983333),
    'EGCC' => array('name' => 'Manchester Airport', 'lat' => 53.350000, 'long' => -2.283333),
    'EGMH' => array('name' => 'Manston, South East', 'lat' => 51.341944, 'long' => 1.346111),
    'EGYM' => array('name' => 'Marham', 'lat' => 52.650000, 'long' => 0.566667),
    'EGVP' => array('name' => 'Middle Wallop', 'lat' => 51.150000, 'long' => -1.566667),
    'EGUN' => array('name' => 'Mildenhall Royal Air Force Base', 'lat' => 52.366667, 'long' => 0.483333),
    'EGNT' => array('name' => 'Newcastle', 'lat' => 55.033333, 'long' => -1.700000),
    'EGWU' => array('name' => 'Northolt', 'lat' => 51.550000, 'long' => -0.416667),
    'EGSH' => array('name' => 'Norwich Weather Centre', 'lat' => 52.633333, 'long' => 1.300000),
    'EGVO' => array('name' => 'Odiham', 'lat' => 51.233333, 'long' => -0.950000),
    'EGOP' => array('name' => 'Pembrey Sands', 'lat' => 51.716667, 'long' => -4.366667),
    'EGHD' => array('name' => 'Plymouth / Roborough', 'lat' => 50.416667, 'long' => -4.116667),
    'EGPK' => array('name' => 'Prestwick Airport', 'lat' => 55.500000, 'long' => -4.583333),
    'EGDG' => array('name' => 'Saint Mawgan', 'lat' => 50.433333, 'long' => -5.000000),
    'EGPM' => array('name' => 'Scatsa / Shetland Island', 'lat' => 60.433333, 'long' => -1.300000),
    'EGHE' => array('name' => 'Scilly, Saint Mary\'S', 'lat' => 49.916667, 'long' => -6.300000),
    'EGOS' => array('name' => 'Shawbury', 'lat' => 52.800000, 'long' => -2.666667),
    'EGKA' => array('name' => 'Shoreham Airport', 'lat' => 50.833333, 'long' => -0.283333),
    'EGHI' => array('name' => 'Southampton / Weather Centre', 'lat' => 50.900000, 'long' => -1.400000),
    'EGMC' => array('name' => 'Southend-On-Sea', 'lat' => 51.566667, 'long' => 0.700000),
    'EGOM' => array('name' => 'Spadeadam', 'lat' => 55.050000, 'long' => -2.550000),
    'EGDX' => array('name' => 'St Athan Royal Air Force Base', 'lat' => 51.400000, 'long' => -3.433333),
    'EGSS' => array('name' => 'Stansted Airport', 'lat' => 51.883333, 'long' => 0.233333),
    'EGBJ' => array('name' => 'Staverton Private', 'lat' => 51.900000, 'long' => -2.166667),
    'EGPO' => array('name' => 'Stornoway', 'lat' => 58.216667, 'long' => -6.316667),
    'EGPB' => array('name' => 'Sumburgh Cape', 'lat' => 59.883333, 'long' => -1.300000),
    'EGQA' => array('name' => 'Tain Range', 'lat' => 57.816667, 'long' => -3.966667),
    'EGNV' => array('name' => 'Tees-Side', 'lat' => 54.516667, 'long' => -1.416667),
    'EGXZ' => array('name' => 'Topcliffe Royal Air Force Base', 'lat' => 54.200000, 'long' => -1.383333),
    'EGOV' => array('name' => 'Valley', 'lat' => 53.250000, 'long' => -4.533333),
    'EGXW' => array('name' => 'Waddington', 'lat' => 53.166667, 'long' => -0.516667),
    'EGYW' => array('name' => 'Wainfleet', 'lat' => 53.083333, 'long' => 0.266667),
    'EGUW' => array('name' => 'Wattisham', 'lat' => 52.116667, 'long' => 0.966667),
    'EGPC' => array('name' => 'Wick', 'lat' => 58.450000, 'long' => -3.083333),
    'EGXT' => array('name' => 'Wittering', 'lat' => 52.616667, 'long' => -0.466667),
    'EGUY' => array('name' => 'Wyton Royal Air Force Base', 'lat' => 52.350000, 'long' => -0.116667),
    'EGDY' => array('name' => 'Yeovilton', 'lat' => 51.000000, 'long' => -2.633333),
  );

  $icao_codes['United States of America'] = array(
    'PADK' => array('name' => 'AK - Adak Island, Adak Airport', 'lat' => 51.877778, 'long' => -176.645833),
    'PAFM' => array('name' => 'AK - Ambler, Ambler Airport', 'lat' => 67.100000, 'long' => -157.850000),
    'PAKP' => array('name' => 'AK - Anaktuvuk Pass, Anaktuvuk Pass Airport', 'lat' => 68.133611, 'long' => -151.743333),
    'PAED' => array('name' => 'AK - Anchorage, Elmendorf Air Force Base', 'lat' => 61.253056, 'long' => -149.793889),
    'PALH' => array('name' => 'AK - Anchorage, Lake Hood Seaplane Base', 'lat' => 61.183333, 'long' => -149.966667),
    'PAMR' => array('name' => 'AK - Anchorage, Merrill Field Airport', 'lat' => 61.216667, 'long' => -149.850000),
    'PANC' => array('name' => 'AK - Anchorage, Ted Stevens Anchorage International Airport', 'lat' => 61.174444, 'long' => -149.996111),
    'PAGN' => array('name' => 'AK - Angoon', 'lat' => 57.500000, 'long' => -134.583333),
    'PANI' => array('name' => 'AK - Aniak, Aniak Airport', 'lat' => 61.581389, 'long' => -159.542778),
    'PANT' => array('name' => 'AK - Annette, Annette Island Airport', 'lat' => 55.042222, 'long' => -131.572222),
    'PANV' => array('name' => 'AK - Anvik, Anvik Airport', 'lat' => 62.648333, 'long' => -160.189722),
    'PARC' => array('name' => 'AK - Arctic Village, Arctic Village Airport', 'lat' => 68.114444, 'long' => -145.579167),
    'PAAK' => array('name' => 'AK - Atka, Atka Airport', 'lat' => 52.220278, 'long' => -174.206389),
    'PABR' => array('name' => 'AK - Barrow, Wiley Post-Will Rogers Memorial Airport', 'lat' => 71.285278, 'long' => -156.765833),
    'PABA' => array('name' => 'AK - Barter Island, Barter Island LRRS Airport', 'lat' => 70.133889, 'long' => -143.576944),
    'PABE' => array('name' => 'AK - Bethel, Bethel Airport', 'lat' => 60.779722, 'long' => -161.837778),
    'PABT' => array('name' => 'AK - Bettles, Bettles Airport', 'lat' => 66.916667, 'long' => -151.516667),
    'PALV' => array('name' => 'AK - Big River Lake', 'lat' => 60.816667, 'long' => -152.300000),
    'PABV' => array('name' => 'AK - Birchwood, Birchwood Airport', 'lat' => 61.416667, 'long' => -149.516667),
    'PABL' => array('name' => 'AK - Buckland, Buckland Airport', 'lat' => 65.982222, 'long' => -161.151944),
    'PATW' => array('name' => 'AK - Cantwell, Cantwell Airport', 'lat' => 63.400000, 'long' => -148.950000),
    'PALU' => array('name' => 'AK - Cape Lisburne, Cape Lisburne LRRS Airport', 'lat' => 68.883333, 'long' => -166.100000),
    'PAEH' => array('name' => 'AK - Cape Newenham, Cape Newenham LRRS Airport', 'lat' => 58.650000, 'long' => -162.066667),
    'PACZ' => array('name' => 'AK - Cape Romanzof, Cape Romanzof LRRS Airport', 'lat' => 61.783333, 'long' => -166.033333),
    'PARL' => array('name' => 'AK - Central, Central Airport', 'lat' => 65.573889, 'long' => -144.783056),
    'PALR' => array('name' => 'AK - Chandalar Lake, Chandalar Lake Airport', 'lat' => 67.500000, 'long' => -148.483333),
    'PAJC' => array('name' => 'AK - Chignik, Chignik Airport', 'lat' => 56.311389, 'long' => -158.373333),
    'PAEC' => array('name' => 'AK - Chulitna, Chulitna Airport', 'lat' => 62.883333, 'long' => -149.833333),
    'PACD' => array('name' => 'AK - Cold Bay, Cold Bay Airport', 'lat' => 55.220833, 'long' => -162.727778),
    'PACV' => array('name' => 'AK - Cordova, Merle K (Mudhole) Smith Airport', 'lat' => 60.491667, 'long' => -145.477778),
    'PALP' => array('name' => 'AK - Deadhorse, Alpine Airstrip', 'lat' => 70.333333, 'long' => -150.933333),
    'PASC' => array('name' => 'AK - Deadhorse, Deadhorse Airport', 'lat' => 70.200000, 'long' => -148.466667),
    'PADE' => array('name' => 'AK - Deering, Deering/New Airport', 'lat' => 66.083333, 'long' => -162.750000),
    'PABI' => array('name' => 'AK - Delta Junction/Ft Greely, Allen Army Airfield', 'lat' => 64.000000, 'long' => -145.733333),
    'PADL' => array('name' => 'AK - Dillingham, Dillingham Airport', 'lat' => 59.050000, 'long' => -158.516667),
    'PAEG' => array('name' => 'AK - Eagle, Eagle Airport', 'lat' => 64.776389, 'long' => -141.150833),
    'PAII' => array('name' => 'AK - Egegik, Egegik Airport', 'lat' => 58.185278, 'long' => -157.385556),
    'PAEL' => array('name' => 'AK - Elfin Cove, Elfin Cove Seaplane Base', 'lat' => 58.200000, 'long' => -136.350000),
    'PAEM' => array('name' => 'AK - Emmonak, Emmonak Airport', 'lat' => 62.783333, 'long' => -164.500000),
    'PAZK' => array('name' => 'AK - Eureka, Skelton Airport', 'lat' => 61.933333, 'long' => -147.166667),
    'PAEI' => array('name' => 'AK - Fairbanks, Eielson Air Force Base', 'lat' => 64.650000, 'long' => -147.100000),
    'PAFA' => array('name' => 'AK - Fairbanks, Fairbanks International Airport', 'lat' => 64.803889, 'long' => -147.876111),
    'PAFK' => array('name' => 'AK - Farewell Lake, Farewell Lake Seaplane Base', 'lat' => 62.542500, 'long' => -153.622500),
    'PAFB' => array('name' => 'AK - Fort Wainwright AAF', 'lat' => 64.836667, 'long' => -147.595556),
    'PFYU' => array('name' => 'AK - Fort Yukon, Fort Yukon Airport', 'lat' => 66.566667, 'long' => -145.266667),
    'PAGB' => array('name' => 'AK - Galbraith Lake, Galbraith Lake Airport', 'lat' => 68.483333, 'long' => -149.483333),
    'PAGA' => array('name' => 'AK - Galena, Edward G. Pitka Sr. Airport', 'lat' => 64.733333, 'long' => -156.933333),
    'PAGM' => array('name' => 'AK - Gambell, Gambell Airport', 'lat' => 63.766667, 'long' => -171.733333),
    'PAGL' => array('name' => 'AK - Golovin, Golovin Airport', 'lat' => 64.543333, 'long' => -163.039444),
    'PAGK' => array('name' => 'AK - Gulkana, Gulkana Airport', 'lat' => 62.150000, 'long' => -145.450000),
    'PAGS' => array('name' => 'AK - Gustavus, Gustavus Airport', 'lat' => 58.416667, 'long' => -135.700000),
    'PAHN' => array('name' => 'AK - Haines, Haines Airport', 'lat' => 59.250000, 'long' => -135.516667),
    'PAHZ' => array('name' => 'AK - Hayes River, Hayes River Airport', 'lat' => 61.983333, 'long' => -152.083333),
    'PAHV' => array('name' => 'AK - Healy, Healy River Airport', 'lat' => 63.866667, 'long' => -148.966667),
    'PAHO' => array('name' => 'AK - Homer, Homer Airport', 'lat' => 59.650000, 'long' => -151.483333),
    'PAOH' => array('name' => 'AK - Hoonah, Hoonah Seaplane Base', 'lat' => 58.116667, 'long' => -135.450000),
    'PAHP' => array('name' => 'AK - Hooper Bay, Hooper Bay Airport', 'lat' => 61.516667, 'long' => -166.133333),
    'PAHY' => array('name' => 'AK - Hydaburg, Hydaburg Seaplane Base', 'lat' => 55.200000, 'long' => -132.833333),
    'PAIL' => array('name' => 'AK - Iliamna, Iliamna Airport', 'lat' => 59.750000, 'long' => -154.900000),
    'PAJN' => array('name' => 'AK - Juneau, Juneau International Airport', 'lat' => 58.354722, 'long' => -134.576111),
    'PAFE' => array('name' => 'AK - Kake, Kake Airport', 'lat' => 56.950000, 'long' => -133.900000),
    'PAKV' => array('name' => 'AK - Kaltag, Kaltag Airport', 'lat' => 64.316667, 'long' => -158.733333),
    'PAEN' => array('name' => 'AK - Kenai, Kenai Municipal Airport', 'lat' => 60.573056, 'long' => -151.245000),
    'PAKT' => array('name' => 'AK - Ketchikan, Ketchikan International Airport', 'lat' => 55.355556, 'long' => -131.713611),
    'PAKN' => array('name' => 'AK - King Salmon, King Salmon Airport', 'lat' => 58.676667, 'long' => -156.649167),
    'PAKI' => array('name' => 'AK - Kipnuk, Kipnuk Airport', 'lat' => 59.932778, 'long' => -164.030278),
    'PAVL' => array('name' => 'AK - Kivalina, Kivalina Airport', 'lat' => 67.733333, 'long' => -164.550000),
    'PAKW' => array('name' => 'AK - Klawock, Klawock Airport', 'lat' => 55.583333, 'long' => -133.083333),
    'PADQ' => array('name' => 'AK - Kodiak, Kodiak Airport', 'lat' => 57.750000, 'long' => -152.500000),
    'PAOT' => array('name' => 'AK - Kotzebue, Ralph Wien Memorial Airport', 'lat' => 66.884444, 'long' => -162.598333),
    'PAKK' => array('name' => 'AK - Koyuk, Koyuk Airport', 'lat' => 64.933889, 'long' => -161.158056),
    'PAKU' => array('name' => 'AK - Kuparuk, Ugnu-Kuparuk Airport', 'lat' => 70.316667, 'long' => -149.583333),
    'PAML' => array('name' => 'AK - Manley Hot Springs, Manly Hot Springs Airport', 'lat' => 64.983333, 'long' => -150.633333),
    'PAMX' => array('name' => 'AK - McCarthy', 'lat' => 61.433333, 'long' => -142.933333),
    'PAMC' => array('name' => 'AK - McGrath, McGrath Airport', 'lat' => 62.966667, 'long' => -155.616667),
    'PAIN' => array('name' => 'AK - McKinley Park, McKinley National Park Airport', 'lat' => 63.733333, 'long' => -148.916667),
    'PAMY' => array('name' => 'AK - Mekoryuk, Mekoryuk Airport', 'lat' => 60.366667, 'long' => -166.266667),
    'PAER' => array('name' => 'AK - Merrill Pass West', 'lat' => 61.250000, 'long' => -153.816667),
    'PAMM' => array('name' => 'AK - Metlakatla, Metlakatla Seaplane Base', 'lat' => 55.131111, 'long' => -131.578056),
    'PAMD' => array('name' => 'AK - Middleton Island, Middleton Island Airport', 'lat' => 59.433333, 'long' => -146.300000),
    'PAMH' => array('name' => 'AK - Minchumina, Minchumina Airport', 'lat' => 63.880556, 'long' => -152.300556),
    'PABN' => array('name' => 'AK - Nabesna, Devil Mountain Lodge Airport', 'lat' => 62.400000, 'long' => -143.000000),
    'PANN' => array('name' => 'AK - Nenana, Nenana Municipal Airport', 'lat' => 64.550000, 'long' => -149.083333),
    'PAWN' => array('name' => 'AK - Noatak, Noatak Airport', 'lat' => 67.566667, 'long' => -162.983333),
    'PAOM' => array('name' => 'AK - Nome, Nome Airport', 'lat' => 64.511944, 'long' => -165.445000),
    'PAOR' => array('name' => 'AK - Northway, Northway Airport', 'lat' => 62.961111, 'long' => -141.928889),
    'PAQT' => array('name' => 'AK - Nuiqsut, Nuiqsut Airport', 'lat' => 70.210000, 'long' => -151.005556),
    'PAAQ' => array('name' => 'AK - Palmer, Palmer Municipal Airport', 'lat' => 61.600000, 'long' => -149.083333),
    'PAXK' => array('name' => 'AK - Paxson', 'lat' => 63.033333, 'long' => -145.500000),
    'PAPG' => array('name' => 'AK - Petersburg', 'lat' => 56.816667, 'long' => -132.966667),
    'PAPM' => array('name' => 'AK - Platinum', 'lat' => 59.016667, 'long' => -161.816667),
    'PAPO' => array('name' => 'AK - Point Hope, Point Hope Airport', 'lat' => 68.350000, 'long' => -166.800000),
    'PPIZ' => array('name' => 'AK - Point Lay, Point Lay LRRS Airport', 'lat' => 69.716667, 'long' => -163.000000),
    'PAAP' => array('name' => 'AK - Port Alexander, Port Alexander Seaplane Base', 'lat' => 56.250000, 'long' => -134.650000),
    'PALJ' => array('name' => 'AK - Port Alsworth, Port Alsworth Airport', 'lat' => 60.200000, 'long' => -154.316667),
    'PAPC' => array('name' => 'AK - Port Clarence, Port Clarence Coast Guard Station', 'lat' => 65.250000, 'long' => -166.850000),
    'PAPH' => array('name' => 'AK - Port Heiden, Port Heiden Airport', 'lat' => 56.950000, 'long' => -158.633333),
    'PATO' => array('name' => 'AK - Portage, Portage Glacier', 'lat' => 60.783333, 'long' => -148.833333),
    'PAPR' => array('name' => 'AK - Prospect Creek, Prospect Creek Airport', 'lat' => 66.812778, 'long' => -150.643889),
    'PAPT' => array('name' => 'AK - Puntilla', 'lat' => 62.100000, 'long' => -152.750000),
    'PARD' => array('name' => 'AK - Red Dog, Red Dog Airport', 'lat' => 68.031389, 'long' => -162.903056),
    'PASD' => array('name' => 'AK - Sand Point', 'lat' => 55.316667, 'long' => -160.516667),
    'PASA' => array('name' => 'AK - Savoonga Airport', 'lat' => 63.683333, 'long' => -170.500000),
    'PASK' => array('name' => 'AK - Selawik', 'lat' => 66.616667, 'long' => -160.000000),
    'PASO' => array('name' => 'AK - Seldovia, Seldovia Airport', 'lat' => 59.450000, 'long' => -151.700000),
    'PAWD' => array('name' => 'AK - Seward', 'lat' => 60.116667, 'long' => -149.450000),
    'PASP' => array('name' => 'AK - Sheep Mountain, Sheep Mountain Airport', 'lat' => 61.811944, 'long' => -147.506944),
    'PASY' => array('name' => 'AK - Shemya, Eareckson AFB', 'lat' => 52.716667, 'long' => 174.116667),
    'PASH' => array('name' => 'AK - Shishmaref, Shishmaref Airport', 'lat' => 66.266667, 'long' => -166.083333),
    'PASI' => array('name' => 'AK - Sitka, Sitka Airport', 'lat' => 57.048056, 'long' => -135.364722),
    'PAGY' => array('name' => 'AK - Skagway', 'lat' => 59.466667, 'long' => -135.300000),
    'PASW' => array('name' => 'AK - Skwentna', 'lat' => 61.966667, 'long' => -151.183333),
    'PADT' => array('name' => 'AK - Slana Airport', 'lat' => 62.700000, 'long' => -143.983333),
    'PASL' => array('name' => 'AK - Sleetmute', 'lat' => 61.716667, 'long' => -157.150000),
    'PALK' => array('name' => 'AK - Snowshoe Lake', 'lat' => 62.033333, 'long' => -142.666667),
    'PASX' => array('name' => 'AK - Soldotna', 'lat' => 60.483333, 'long' => -151.033333),
    'PASV' => array('name' => 'AK - Sparrevohn Airways Facilities Sector', 'lat' => 61.100000, 'long' => -155.566667),
    'PAPB' => array('name' => 'AK - St. George, St. George Airport', 'lat' => 56.578611, 'long' => -169.661389),
    'PASM' => array('name' => 'AK - St. Mary\'s, St. Mary\'s Airport', 'lat' => 62.050000, 'long' => -163.300000),
    'PASN' => array('name' => 'AK - St. Paul Island, St. Paul Island Airport', 'lat' => 57.166667, 'long' => -170.216667),
    'PAJV' => array('name' => 'AK - Sutton', 'lat' => 61.716667, 'long' => -148.883333),
    'PATL' => array('name' => 'AK - Takotna, Tatalina LRRS Airport', 'lat' => 62.900000, 'long' => -155.983333),
    'PATK' => array('name' => 'AK - Talkeetna, Talkeetna Airport', 'lat' => 62.320556, 'long' => -150.093611),
    'PATA' => array('name' => 'AK - Tanana, Calhoun Memorial Airport', 'lat' => 65.166667, 'long' => -152.100000),
    'PATC' => array('name' => 'AK - Tin City Airways Facilities Sector', 'lat' => 65.566667, 'long' => -167.916667),
    'PATG' => array('name' => 'AK - Togiac Village, Togiak Airport', 'lat' => 59.050000, 'long' => -160.400000),
    'PAUN' => array('name' => 'AK - Unalakleet', 'lat' => 63.883333, 'long' => -160.800000),
    'PADU' => array('name' => 'AK - Unalaska, Unalaska Airport', 'lat' => 53.900000, 'long' => -166.533333),
    'PAIM' => array('name' => 'AK - Utopia Creek, Indian Mountain LRRS Airport', 'lat' => 66.983333, 'long' => -153.700000),
    'PAVD' => array('name' => 'AK - Valdez 2', 'lat' => 61.133333, 'long' => -146.266667),
    'PAWI' => array('name' => 'AK - Wainwright, Wainwright Airport', 'lat' => 70.633333, 'long' => -159.850000),
    'PAWS' => array('name' => 'AK - Wasilla, Wasilla Airport', 'lat' => 61.571944, 'long' => -149.540556),
    'PAWR' => array('name' => 'AK - Whittier', 'lat' => 60.766667, 'long' => -148.683333),
    'PAUO' => array('name' => 'AK - Willow Airport', 'lat' => 61.750000, 'long' => -150.050000),
    'PAWG' => array('name' => 'AK - Wrangell', 'lat' => 56.483333, 'long' => -132.366667),
    'PAYA' => array('name' => 'AK - Yakutat', 'lat' => 59.516667, 'long' => -139.666667),
    'KEET' => array('name' => 'AL - Alabaster, Shelby County Airport', 'lat' => 33.178333, 'long' => -86.781667),
    'K8A0' => array('name' => 'AL - Albertville, Albertville Municipal Airport', 'lat' => 34.228889, 'long' => -86.255556),
    'KALX' => array('name' => 'AL - Alexander City, Thomas C Russell Field Airport', 'lat' => 32.914722, 'long' => -85.962778),
    'K79J' => array('name' => 'AL - Andalusia, Andalusia-Opp Municipal Airport', 'lat' => 31.300000, 'long' => -86.383333),
    'KANB' => array('name' => 'AL - Anniston, Anniston Metropolitan Airport', 'lat' => 33.590556, 'long' => -85.847500),
    'KAUO' => array('name' => 'AL - Auburn-Opelika Airport', 'lat' => 32.616667, 'long' => -85.433333),
    'KBHM' => array('name' => 'AL - Birmingham, Birmingham International Airport', 'lat' => 33.565556, 'long' => -86.745000),
    'KOZR' => array('name' => 'AL - Cairns Army Air Field / Ozark', 'lat' => 31.283333, 'long' => -85.716667),
    'K3A1' => array('name' => 'AL - Cullman, Folsom Field Airport', 'lat' => 34.268611, 'long' => -86.858333),
    'KDCU' => array('name' => 'AL - Decatur, Pryor Field', 'lat' => 34.658056, 'long' => -86.943333),
    'KDHN' => array('name' => 'AL - Dothan, Dothan Regional Airport', 'lat' => 31.321389, 'long' => -85.449722),
    'KGZH' => array('name' => 'AL - Evergreen, Middleton Field', 'lat' => 31.418889, 'long' => -87.048056),
    'K0J4' => array('name' => 'AL - Florala, Florala Municipal Airport', 'lat' => 31.042500, 'long' => -86.311667),
    'K4A9' => array('name' => 'AL - Fort Payne, Isbell Field Airport', 'lat' => 34.473611, 'long' => -85.721389),
    'KGAD' => array('name' => 'AL - Gadsden, Gadsden Municipal Airport', 'lat' => 33.966667, 'long' => -86.083333),
    'KHSV' => array('name' => 'AL - Huntsville, Huntsville International / Jones Field', 'lat' => 34.643611, 'long' => -86.785556),
    'KMDQ' => array('name' => 'AL - Huntsville, Madison County Executive Airport', 'lat' => 34.861389, 'long' => -86.557222),
    'KMXF' => array('name' => 'AL - Maxwell Air Force Base / Montgomery', 'lat' => 32.383333, 'long' => -86.366667),
    'KBFM' => array('name' => 'AL - Mobile, Mobile Downtown Airport', 'lat' => 30.613889, 'long' => -88.063333),
    'KMOB' => array('name' => 'AL - Mobile, Mobile Regional Airport', 'lat' => 30.688333, 'long' => -88.245556),
    'KMGM' => array('name' => 'AL - Montgomery, Dannelly Field', 'lat' => 32.300278, 'long' => -86.406111),
    'KMSL' => array('name' => 'AL - Muscle Shoals, North West Alabama Regional Airport', 'lat' => 34.743889, 'long' => -87.599444),
    'KTOI' => array('name' => 'AL - Troy, Troy Municipal Airport', 'lat' => 31.860556, 'long' => -86.012222),
    'KTCL' => array('name' => 'AL - Tuscaloosa, Tuscaloosa Regional Airport', 'lat' => 33.220556, 'long' => -87.611389),
    'KBVX' => array('name' => 'AR - Batesville, Batesville Regional Airport', 'lat' => 35.733333, 'long' => -91.650000),
    'KVBT' => array('name' => 'AR - Bentonville, Bentonville Municipal Airport/Louise M Thaden Field', 'lat' => 36.350000, 'long' => -94.216667),
    'KHKA' => array('name' => 'AR - Blytheville, Blytheville Municipal Airport', 'lat' => 35.938889, 'long' => -89.832500),
    'KDEQ' => array('name' => 'AR - De Queen, J Lynn Helms Sevier County Airport', 'lat' => 34.046944, 'long' => -94.399444),
    'KBYH' => array('name' => 'AR - Eaker Air Force Base', 'lat' => 35.966667, 'long' => -89.950000),
    'KELD' => array('name' => 'AR - El Dorado, South Arkansas Regional at Goodwin Field Airport', 'lat' => 33.220833, 'long' => -92.813333),
    'KFYV' => array('name' => 'AR - Fayetteville, Drake Field', 'lat' => 36.010278, 'long' => -94.167778),
    'KXNA' => array('name' => 'AR - Fayetteville/Springdale, Northwest Arkansas Regional Airport', 'lat' => 36.281944, 'long' => -94.306944),
    'KFLP' => array('name' => 'AR - Flippin, Marion County Regional Airport', 'lat' => 36.300000, 'long' => -92.583333),
    'KFSM' => array('name' => 'AR - Fort Smith, Fort Smith Regional Airport', 'lat' => 35.333611, 'long' => -94.365000),
    'KHRO' => array('name' => 'AR - Harrison, Boone County Airport', 'lat' => 36.261667, 'long' => -93.154722),
    'KHOT' => array('name' => 'AR - Hot Springs, Memorial Field Airport', 'lat' => 34.478056, 'long' => -93.096111),
    'KJBR' => array('name' => 'AR - Jonesboro, Jonesboro Municipal Airport', 'lat' => 35.837222, 'long' => -90.643056),
    'KLRF' => array('name' => 'AR - Little Rock Air Force Base', 'lat' => 34.916667, 'long' => -92.150000),
    'KLIT' => array('name' => 'AR - Little Rock, Adams Field', 'lat' => 34.726667, 'long' => -92.236111),
    'KMEZ' => array('name' => 'AR - Mena, Mena Intermountain Municipal Airport', 'lat' => 34.545278, 'long' => -94.202500),
    'KLLQ' => array('name' => 'AR - Monticello, Monticello Municipal Airport/Ellis Field', 'lat' => 33.638333, 'long' => -91.751111),
    'KMWT' => array('name' => 'AR - Mount Ida', 'lat' => 34.550000, 'long' => -93.583333),
    'KBPK' => array('name' => 'AR - Mountain Home, Ozark Regional Airport', 'lat' => 36.370556, 'long' => -92.471944),
    'KM19' => array('name' => 'AR - Newport, Newport Municipal Airport', 'lat' => 35.637500, 'long' => -91.176111),
    'KPBF' => array('name' => 'AR - Pine Bluff, Grider Field Airport', 'lat' => 34.175000, 'long' => -91.934722),
    'KROG' => array('name' => 'AR - Rogers, Rogers Municipal Airport-Carter Field', 'lat' => 36.366667, 'long' => -94.100000),
    'KRUE' => array('name' => 'AR - Russellville, Russellville Regional Airport', 'lat' => 35.258889, 'long' => -93.093333),
    'KSRC' => array('name' => 'AR - Searcy, Searcy Municipal Airport', 'lat' => 35.211944, 'long' => -91.737222),
    'KSLG' => array('name' => 'AR - Siloam Springs, Smith Field Airport', 'lat' => 36.200000, 'long' => -94.483333),
    'KASG' => array('name' => 'AR - Springdale Municipal', 'lat' => 36.183333, 'long' => -94.116667),
    'KSGT' => array('name' => 'AR - Stuttgart, Stuttgart Municipal Airport', 'lat' => 34.600000, 'long' => -91.566667),
    'KTXK' => array('name' => 'AR - Texarkana, Texarkana Regional-Webb Field', 'lat' => 33.456111, 'long' => -93.987500),
    'KARG' => array('name' => 'AR - Walnut Ridge, Walnut Ridge Regional Airport', 'lat' => 36.133333, 'long' => -90.916667),
    'KAWM' => array('name' => 'AR - West Memphis, West Memphis Municipal Airport', 'lat' => 35.133333, 'long' => -90.233333),
    'KIFP' => array('name' => 'AZ - Bullhead City, Laughlin/Bullhead International Airport', 'lat' => 35.157500, 'long' => -114.559444),
    'KCGZ' => array('name' => 'AZ - Casa Grande, Casa Grande Municipal Airport', 'lat' => 32.950000, 'long' => -111.766667),
    'KCHD' => array('name' => 'AZ - Chandler, Chandler Municipal Airport', 'lat' => 33.269167, 'long' => -111.811111),
    'KDMA' => array('name' => 'AZ - Davis-Monthan Air Force Base', 'lat' => 32.166667, 'long' => -110.883333),
    'KDUG' => array('name' => 'AZ - Douglas Bisbee, Bisbee Douglas International Airport', 'lat' => 31.469167, 'long' => -109.603611),
    'KFLG' => array('name' => 'AZ - Flagstaff, Flagstaff Pulliam Airport', 'lat' => 35.140278, 'long' => -111.672222),
    'KFHU' => array('name' => 'AZ - Fort Huachuca, Libby AAF Ft Huachuca', 'lat' => 47.633333, 'long' => -110.333333),
    'KGBN' => array('name' => 'AZ - Gila Bend U. S. Army Airfield', 'lat' => 32.433333, 'long' => -112.683333),
    'KGEU' => array('name' => 'AZ - Glendale, Glendale Municipal Airport', 'lat' => 33.527222, 'long' => -112.295278),
    'KGYR' => array('name' => 'AZ - Goodyear Municipal', 'lat' => 33.416667, 'long' => -112.383333),
    'KGCN' => array('name' => 'AZ - Grand Canyon, Grand Canyon National Park Airport', 'lat' => 35.946111, 'long' => -112.154722),
    'KIGM' => array('name' => 'AZ - Kingman, Kingman Airport', 'lat' => 35.257778, 'long' => -113.933056),
    'KLUF' => array('name' => 'AZ - Luke Air Force Base / Phoenix', 'lat' => 33.533333, 'long' => -112.383333),
    'KFFZ' => array('name' => 'AZ - Mesa / Falcon Field', 'lat' => 33.466667, 'long' => -111.733333),
    'KIWA' => array('name' => 'AZ - Mesa, Williams Gateway Airport', 'lat' => 33.316667, 'long' => -111.650000),
    'KOLS' => array('name' => 'AZ - Nogales, Nogales International Airport', 'lat' => 31.420833, 'long' => -110.845833),
    'KPGA' => array('name' => 'AZ - Page, Page Municipal Airport', 'lat' => 36.920556, 'long' => -111.448056),
    'KPHX' => array('name' => 'AZ - Phoenix, Phoenix Sky Harbor International Airport', 'lat' => 33.434167, 'long' => -112.051111),
    'KDVT' => array('name' => 'AZ - Phoenix, Phoenix-Deer Valley Municipal Airport', 'lat' => 33.690278, 'long' => -112.065556),
    'KPRC' => array('name' => 'AZ - Prescott, Love Field', 'lat' => 34.649167, 'long' => -112.422222),
    'KSAD' => array('name' => 'AZ - Safford, Safford Municipal Airport', 'lat' => 32.857222, 'long' => -109.635556),
    'KSDL' => array('name' => 'AZ - Scottsdale, Scottsdale Airport', 'lat' => 33.622778, 'long' => -111.910556),
    'KSOW' => array('name' => 'AZ - Show Low, Show Low Regional Airport', 'lat' => 34.265278, 'long' => -110.005556),
    'KSJN' => array('name' => 'AZ - St. Johns, St. Johns Industrial Airpark', 'lat' => 34.518333, 'long' => -109.379167),
    'KTUS' => array('name' => 'AZ - Tucson, Tucson International Airport', 'lat' => 32.131389, 'long' => -110.955278),
    'KRQE' => array('name' => 'AZ - Window Rock, Window Rock Airport', 'lat' => 35.650000, 'long' => -109.066667),
    'KINW' => array('name' => 'AZ - Winslow, Winslow Municipal Airport', 'lat' => 35.028056, 'long' => -110.720833),
    'KYUM' => array('name' => 'AZ - Yuma / Yuma International', 'lat' => 32.650000, 'long' => -114.600000),
    'KNYL' => array('name' => 'AZ - Yuma, Marine Corps Air Station', 'lat' => 32.623611, 'long' => -113.763889),
    'KAAT' => array('name' => 'CA - Alturas', 'lat' => 41.491389, 'long' => -120.564444),
    'KACV' => array('name' => 'CA - Arcata / Eureka, Arcata Airport', 'lat' => 40.978056, 'long' => -124.108611),
    'KAUN' => array('name' => 'CA - Auburn, Auburn Municipal Airport', 'lat' => 38.950000, 'long' => -121.066667),
    'KAVX' => array('name' => 'CA - Avalon, Catalina Airport', 'lat' => 33.405000, 'long' => -118.415833),
    'KBFL' => array('name' => 'CA - Bakersfield, Meadows Field Airport', 'lat' => 35.433611, 'long' => -119.056667),
    'KBIH' => array('name' => 'CA - Bishop, Bishop Airport', 'lat' => 37.371111, 'long' => -118.358056),
    'KBLH' => array('name' => 'CA - Blythe, Blythe Airport', 'lat' => 33.619167, 'long' => -114.716944),
    'KBUR' => array('name' => 'CA - Burbank, Burbank-Glendale-Pasadena Airport', 'lat' => 34.199722, 'long' => -118.364722),
    'KCMA' => array('name' => 'CA - Camarillo, Camarillo Airport', 'lat' => 34.216667, 'long' => -119.083333),
    'KCZZ' => array('name' => 'CA - Campo', 'lat' => 32.626111, 'long' => -116.468333),
    'KCRQ' => array('name' => 'CA - Carlsbad, McClellan-Palomar Airport', 'lat' => 33.130000, 'long' => -117.275833),
    'KCIC' => array('name' => 'CA - Chico Municipal', 'lat' => 39.800000, 'long' => -121.850000),
    'KNID' => array('name' => 'CA - China Lake, Naval Air Facility', 'lat' => 35.686389, 'long' => -117.690000),
    'KCNO' => array('name' => 'CA - Chino, Chino Airport', 'lat' => 33.975556, 'long' => -117.623611),
    'KCCR' => array('name' => 'CA - Concord, Buchanan Field', 'lat' => 37.991667, 'long' => -122.051944),
    'KCEC' => array('name' => 'CA - Crescent City, Jack McNamara Field Airport', 'lat' => 41.780278, 'long' => -124.236667),
    'KDAG' => array('name' => 'CA - Daggett, Barstow-Daggett Airport', 'lat' => 34.853611, 'long' => -116.786667),
    'KEDW' => array('name' => 'CA - Edwards Air Force Base', 'lat' => 34.916667, 'long' => -117.900000),
    'K9L2' => array('name' => 'CA - Edwards, Edwards Air Force Auxiliary North Base', 'lat' => 34.983333, 'long' => -117.850000),
    'KNJK' => array('name' => 'CA - El Centro, Naval Air Facility', 'lat' => 32.825000, 'long' => -115.660556),
    'KEMT' => array('name' => 'CA - El Monte', 'lat' => 34.083333, 'long' => -118.033333),
    'KBLU' => array('name' => 'CA - Emigrant Gap, Blue Canyon Nyack Airport', 'lat' => 39.276111, 'long' => -120.708056),
    'KEKA' => array('name' => 'CA - Eureka', 'lat' => 40.800000, 'long' => -124.166667),
    'KSUU' => array('name' => 'CA - Fairfield / Travis Air Force Base', 'lat' => 38.266667, 'long' => -121.950000),
    'KFAT' => array('name' => 'CA - Fresno, Fresno Air Terminal', 'lat' => 36.780000, 'long' => -119.719444),
    'KFUL' => array('name' => 'CA - Fullerton, Fullerton Municipal Airport', 'lat' => 33.871944, 'long' => -117.984722),
    'KHHR' => array('name' => 'CA - Hawthorne, Hawthorne Municipal Airport', 'lat' => 33.923611, 'long' => -118.331944),
    'KHWD' => array('name' => 'CA - Hayward, Hayward Air Terminal', 'lat' => 37.660833, 'long' => -122.118333),
    'KNRS' => array('name' => 'CA - Imperial Beach, Naval Auxiliary Landing Field', 'lat' => 32.563056, 'long' => -117.110000),
    'KIPL' => array('name' => 'CA - Imperial, Imperial County Airport', 'lat' => 32.834167, 'long' => -115.578611),
    'KIYK' => array('name' => 'CA - Inyokern', 'lat' => 35.666667, 'long' => -117.833333),
    'KPOC' => array('name' => 'CA - La Verne / Brackett', 'lat' => 34.100000, 'long' => -117.783333),
    'KWJF' => array('name' => 'CA - Lancaster, General William J. Fox Airfield Airport', 'lat' => 34.740833, 'long' => -118.218889),
    'KNLC' => array('name' => 'CA - Lemoore, Naval Air Station', 'lat' => 36.303611, 'long' => -119.938056),
    'KLVK' => array('name' => 'CA - Livermore, Livermore Municipal Airport', 'lat' => 37.692778, 'long' => -121.814444),
    'KLPC' => array('name' => 'CA - Lompoc, Lompoc Airport', 'lat' => 34.666667, 'long' => -120.466667),
    'KVBG' => array('name' => 'CA - Lompoc, Vandenberg Air Force Base', 'lat' => 34.729444, 'long' => -120.576667),
    'KLGB' => array('name' => 'CA - Long Beach, Long Beach Airport', 'lat' => 33.811667, 'long' => -118.146389),
    'KSLI' => array('name' => 'CA - Los Alamitos U. S. Army Airfield', 'lat' => 33.783333, 'long' => -118.050000),
    'KCQT' => array('name' => 'CA - Los Angeles / USC Campus Downtown', 'lat' => 34.016667, 'long' => -118.283333),
    'KLAX' => array('name' => 'CA - Los Angeles, Los Angeles International Airport', 'lat' => 33.938056, 'long' => -118.388889),
    'KWHP' => array('name' => 'CA - Los Angeles, Whiteman Airport', 'lat' => 34.250000, 'long' => -118.400000),
    'KMAE' => array('name' => 'CA - Madera, Madera Municipal Airport', 'lat' => 36.986667, 'long' => -120.110833),
    'KMMH' => array('name' => 'CA - Mammoth / June Lakes', 'lat' => 37.616667, 'long' => -118.833333),
    'KBAB' => array('name' => 'CA - Marysville, Beale Air Force Base', 'lat' => 39.133333, 'long' => -121.433333),
    'KMYV' => array('name' => 'CA - Marysville, Yuba County Airport', 'lat' => 39.097778, 'long' => -121.569722),
    'KMCE' => array('name' => 'CA - Merced, Merced Municipal Airport', 'lat' => 37.283056, 'long' => -120.507778),
    'KMOD' => array('name' => 'CA - Modesto, Modesto City-County-Sham Field', 'lat' => 37.624167, 'long' => -120.950556),
    'KMHV' => array('name' => 'CA - Mojave', 'lat' => 35.066667, 'long' => -118.150000),
    'KSIY' => array('name' => 'CA - Montague, Siskiyou County Airport', 'lat' => 41.781389, 'long' => -122.468056),
    'KMRY' => array('name' => 'CA - Monterey, Monterey Peninsula Airport', 'lat' => 36.590556, 'long' => -121.847500),
    'KMHS' => array('name' => 'CA - Mount Shasta', 'lat' => 41.315833, 'long' => -122.316111),
    'KMWS' => array('name' => 'CA - Mount Wilson', 'lat' => 34.233333, 'long' => -118.066667),
    'KNUQ' => array('name' => 'CA - Mountain View, Moffett Field', 'lat' => 37.405833, 'long' => -122.048056),
    'KAPC' => array('name' => 'CA - Napa, Napa County Airport', 'lat' => 38.207500, 'long' => -122.279444),
    'KEED' => array('name' => 'CA - Needles, Needles Airport', 'lat' => 34.766111, 'long' => -114.623333),
    'K3A6' => array('name' => 'CA - Newhall', 'lat' => 34.366667, 'long' => -118.566667),
    'KOAK' => array('name' => 'CA - Oakland, Metro Oakland International Airport', 'lat' => 37.719444, 'long' => -122.235278),
    'KNFG' => array('name' => 'CA - Oceanside, Camp Pendleton, Marine Corps Air Station', 'lat' => 33.304722, 'long' => -117.353889),
    'KONT' => array('name' => 'CA - Ontario, Ontario International Airport', 'lat' => 34.053333, 'long' => -117.575833),
    'KOVE' => array('name' => 'CA - Oroville, Oroville Municipal Airport', 'lat' => 39.494722, 'long' => -121.620278),
    'KOXR' => array('name' => 'CA - Oxnard, Oxnard Airport', 'lat' => 34.200556, 'long' => -119.203056),
    'KTRM' => array('name' => 'CA - Palm Springs, Jacqueline Cochran Regional Airport', 'lat' => 33.626667, 'long' => -116.159444),
    'KPSP' => array('name' => 'CA - Palm Springs, Palm Springs Regional Airport', 'lat' => 33.822222, 'long' => -116.503611),
    'KPMD' => array('name' => 'CA - Palmdale, Palmdale Production Flight Plant', 'lat' => 34.629722, 'long' => -118.081389),
    'KPAO' => array('name' => 'CA - Palo Alto Airport', 'lat' => 37.466667, 'long' => -122.116667),
    'KPRB' => array('name' => 'CA - Paso Robles, Paso Robles Municipal Airport', 'lat' => 35.672778, 'long' => -120.626944),
    'KNTD' => array('name' => 'CA - Point Mugu, Naval Air Warfare Center', 'lat' => 34.123889, 'long' => -119.121667),
    'KPTV' => array('name' => 'CA - Porterville, Porterville Municipal Airport', 'lat' => 36.033333, 'long' => -119.066667),
    'KRNM' => array('name' => 'CA - Ramona, Ramona Airport', 'lat' => 33.037500, 'long' => -116.915833),
    'KRBL' => array('name' => 'CA - Red Bluff, Red Bluff Municipal Airport', 'lat' => 40.150556, 'long' => -122.252222),
    'KRDD' => array('name' => 'CA - Redding, Redding Municipal Airport', 'lat' => 40.515000, 'long' => -122.296667),
    'KRIV' => array('name' => 'CA - Riverside / March Air Force Base', 'lat' => 33.900000, 'long' => -117.250000),
    'KRAL' => array('name' => 'CA - Riverside, Riverside Municipal Airport', 'lat' => 33.951389, 'long' => -117.450556),
    'KSAC' => array('name' => 'CA - Sacramento, Sacramento Executive Airport', 'lat' => 38.506944, 'long' => -121.495000),
    'KSMF' => array('name' => 'CA - Sacramento, Sacramento International Airport', 'lat' => 38.701389, 'long' => -121.593889),
    'KMHR' => array('name' => 'CA - Sacramento, Sacramento Mather Airport', 'lat' => 38.550000, 'long' => -121.300000),
    'KSNS' => array('name' => 'CA - Salinas, Salinas Municipal Airport', 'lat' => 36.663611, 'long' => -121.608056),
    'KSQL' => array('name' => 'CA - San Carlos Airport', 'lat' => 37.516667, 'long' => -122.250000),
    'KNUC' => array('name' => 'CA - San Clemente Island, San Clemente Island NALF', 'lat' => 33.023333, 'long' => -118.586944),
    'KSDM' => array('name' => 'CA - San Diego, Brown Field Municipal Airport', 'lat' => 32.575278, 'long' => -116.993056),
    'KNKX' => array('name' => 'CA - San Diego, Miramar MCAS/Mitscher Field Airport', 'lat' => 32.868333, 'long' => -117.142500),
    'KMYF' => array('name' => 'CA - San Diego, Montgomery Field', 'lat' => 32.814444, 'long' => -117.136389),
    'KNZY' => array('name' => 'CA - San Diego, North Island, Naval Air Station', 'lat' => 32.690833, 'long' => -117.208889),
    'KSAN' => array('name' => 'CA - San Diego, San Diego International-Lindbergh Field', 'lat' => 32.733611, 'long' => -117.183056),
    'KSEE' => array('name' => 'CA - San Diego/El Cajon, Gillespie Field Airport', 'lat' => 32.826111, 'long' => -116.972222),
    'KSFO' => array('name' => 'CA - San Francisco, San Francisco International Airport', 'lat' => 37.619722, 'long' => -122.364722),
    'KRHV' => array('name' => 'CA - San Jose / Reid / Hillv', 'lat' => 37.333333, 'long' => -121.816667),
    'KSJC' => array('name' => 'CA - San Jose, San Jose International Airport', 'lat' => 37.359167, 'long' => -121.924167),
    'KSBP' => array('name' => 'CA - San Luis Obispo, San Luis Obispo County-Mc Chesney Field', 'lat' => 35.236111, 'long' => -120.636111),
    'KNSI' => array('name' => 'CA - San Nicholas Island', 'lat' => 33.234722, 'long' => -119.452778),
    'KSDB' => array('name' => 'CA - Sandberg', 'lat' => 34.743611, 'long' => -118.724444),
    'KSNA' => array('name' => 'CA - Santa Ana, John Wayne Airport-Orange County Airport', 'lat' => 33.680000, 'long' => -117.866389),
    'KSBA' => array('name' => 'CA - Santa Barbara, Santa Barbara Municipal Airport', 'lat' => 34.426111, 'long' => -119.843611),
    'KSMX' => array('name' => 'CA - Santa Maria, Santa Maria Public Airport', 'lat' => 34.899444, 'long' => -120.448611),
    'KSMO' => array('name' => 'CA - Santa Monica, Santa Monica Municipal Airport', 'lat' => 34.015833, 'long' => -118.451389),
    'KSTS' => array('name' => 'CA - Santa Rosa, Santa Rosa Sonoma County Airport', 'lat' => 38.500000, 'long' => -122.816667),
    'KIZA' => array('name' => 'CA - Santa Ynez, Santa Ynez Airport', 'lat' => 34.606944, 'long' => -120.075556),
    'KO87' => array('name' => 'CA - Shelter Cove', 'lat' => 40.016667, 'long' => -124.066667),
    'KTVL' => array('name' => 'CA - South Lake Tahoe, Lake Tahoe Airport', 'lat' => 38.893889, 'long' => -119.995278),
    'KSCK' => array('name' => 'CA - Stockton, Stockton Metropolitan Airport', 'lat' => 37.889722, 'long' => -121.223611),
    'KTOA' => array('name' => 'CA - Torrance, Zamperini Field Airport', 'lat' => 33.800000, 'long' => -118.333333),
    'KTRK' => array('name' => 'CA - Truckee-Tahoe', 'lat' => 39.316667, 'long' => -120.133333),
    'KNXP' => array('name' => 'CA - Twenty-Nine Palms, Marine Corps Air-Ground Combat Center', 'lat' => 34.294444, 'long' => -116.145000),
    'KUKI' => array('name' => 'CA - Ukiah, Ukiah Municipal Airport', 'lat' => 39.125833, 'long' => -123.200833),
    'KVCB' => array('name' => 'CA - Vacaville, Nut Tree Airport', 'lat' => 38.377778, 'long' => -121.957500),
    'KVNY' => array('name' => 'CA - Van Nuys, Van Nuys Airport', 'lat' => 34.212500, 'long' => -118.490833),
    'KVCV' => array('name' => 'CA - Victorville, Southern California Logistics Airport', 'lat' => 34.597222, 'long' => -117.382778),
    'KVIS' => array('name' => 'CA - Visalia, Visalia Municipal Airport', 'lat' => 36.316667, 'long' => -119.400000),
    'KWVI' => array('name' => 'CA - Watsonville, Watsonville Municipal Airport', 'lat' => 36.939444, 'long' => -121.788889),
    'KAFF' => array('name' => 'CO - Air Force Academy', 'lat' => 38.966667, 'long' => -104.816667),
    'KAKO' => array('name' => 'CO - Akron, Akron-Washington County Airport', 'lat' => 40.174444, 'long' => -103.214444),
    'KALS' => array('name' => 'CO - Alamosa, San Luis Valley Regional Airport', 'lat' => 37.438889, 'long' => -105.861389),
    'KASE' => array('name' => 'CO - Aspen, Aspen-Pitkin County Airport', 'lat' => 39.228889, 'long' => -106.869444),
    'KBKF' => array('name' => 'CO - Aurora, Buckley Air Force Base Airport', 'lat' => 39.710000, 'long' => -104.758056),
    'KBJC' => array('name' => 'CO - Broomfield / Jeffco', 'lat' => 39.916667, 'long' => -105.116667),
    'KITR' => array('name' => 'CO - Burlington, Carson County Airport', 'lat' => 39.242222, 'long' => -102.282778),
    'KCOS' => array('name' => 'CO - Colorado Springs, City Of Colorado Springs Municipal Airport', 'lat' => 38.815833, 'long' => -104.710833),
    'KCCU' => array('name' => 'CO - Copper Mountain, Red Cliff Pass', 'lat' => 39.467222, 'long' => -106.150278),
    'KCEZ' => array('name' => 'CO - Cortez, Cortez-Montezuma County Airport', 'lat' => 37.306389, 'long' => -108.625556),
    'K7BM' => array('name' => 'CO - Cottonwood Pass', 'lat' => 38.782500, 'long' => -106.218056),
    'KCAG' => array('name' => 'CO - Craig, Craig-Moffat Airport', 'lat' => 40.493333, 'long' => -107.523611),
    'KFTG' => array('name' => 'CO - Denver Nexrad', 'lat' => 39.783333, 'long' => -104.550000),
    'KAPA' => array('name' => 'CO - Denver, Centennial Airport', 'lat' => 39.563889, 'long' => -104.848333),
    'KDEN' => array('name' => 'CO - Denver, Denver International Airport', 'lat' => 39.832778, 'long' => -104.657500),
    'KDRO' => array('name' => 'CO - Durango, Durango-La Plata County Airport', 'lat' => 37.143056, 'long' => -107.759722),
    'KEGE' => array('name' => 'CO - Eagle County Regional', 'lat' => 39.650000, 'long' => -106.916667),
    'KMNH' => array('name' => 'CO - Elbert Mountain, Monument Pass', 'lat' => 39.216667, 'long' => -104.633889),
    'KFCS' => array('name' => 'CO - Fort Carson', 'lat' => 38.700000, 'long' => -104.766667),
    'KFNL' => array('name' => 'CO - Fort Collins/Loveland, Fort Collins-Loveland Municipal Airport', 'lat' => 40.450000, 'long' => -105.016667),
    'KGJT' => array('name' => 'CO - Grand Junction, Walker Field', 'lat' => 39.133889, 'long' => -108.538611),
    'KGXY' => array('name' => 'CO - Greeley, Greeley-Weld County Airport', 'lat' => 40.433333, 'long' => -104.633333),
    'KGUC' => array('name' => 'CO - Gunnison, Gunnison-Crested Butte Regional Airport', 'lat' => 38.533333, 'long' => -106.933333),
    'KHDN' => array('name' => 'CO - Hayden, Yampa Valley Airport', 'lat' => 40.483333, 'long' => -107.216667),
    'K20V' => array('name' => 'CO - Kremmling, Mc Elroy Airfield', 'lat' => 40.053611, 'long' => -106.368889),
    'KLHX' => array('name' => 'CO - La Junta, La Junta Municipal Airport', 'lat' => 38.049444, 'long' => -103.512222),
    'KVTP' => array('name' => 'CO - La Veta Mountain, La Veta Pass', 'lat' => 37.501111, 'long' => -105.166944),
    'KLAA' => array('name' => 'CO - Lamar, Lamar Municipal Airport', 'lat' => 38.072500, 'long' => -102.686667),
    'KLXV' => array('name' => 'CO - Leadville, Lake County Airport', 'lat' => 39.228056, 'long' => -106.316111),
    'KLIC' => array('name' => 'CO - Limon, Limon Municipal Airport', 'lat' => 39.273333, 'long' => -103.666667),
    'KEEO' => array('name' => 'CO - Meeker, Meeker Airport', 'lat' => 40.042222, 'long' => -107.889722),
    'KMTJ' => array('name' => 'CO - Montrose, Montrose Regional Airport', 'lat' => 38.505000, 'long' => -107.897500),
    'K3MW' => array('name' => 'CO - Mount Werner', 'lat' => 40.459444, 'long' => -106.759722),
    'KCPW' => array('name' => 'CO - Pagosa Springs, Wolf Creek Pass', 'lat' => 37.451389, 'long' => -106.800278),
    'KPUB' => array('name' => 'CO - Pueblo, Pueblo Memorial Airport', 'lat' => 38.290000, 'long' => -104.498333),
    'KRIL' => array('name' => 'CO - Rifle, Garfield County Regional Airport', 'lat' => 39.525000, 'long' => -107.727222),
    'K04V' => array('name' => 'CO - Saguache, Saguache Municipal Airport', 'lat' => 38.097222, 'long' => -106.168611),
    'KMYP' => array('name' => 'CO - Salida Mountain, Monarch Pass', 'lat' => 38.484444, 'long' => -106.316944),
    'KSPD' => array('name' => 'CO - Springfield, Comanche National Grassland', 'lat' => 37.283333, 'long' => -102.616667),
    'K5SM' => array('name' => 'CO - Sunlight', 'lat' => 39.425556, 'long' => -107.379167),
    'KTEX' => array('name' => 'CO - Telluride, Telluride Regional Airport', 'lat' => 37.953889, 'long' => -107.908611),
    'KTAD' => array('name' => 'CO - Trinidad, Perry Stokes Airport', 'lat' => 37.266667, 'long' => -104.433333),
    'K4BM' => array('name' => 'CO - Wilkerson Pass', 'lat' => 39.050278, 'long' => -105.514444),
    'KBDR' => array('name' => 'CT - Bridgeport, Sikorsky Memorial Airport', 'lat' => 41.158333, 'long' => -73.128889),
    'KSNC' => array('name' => 'CT - Chester, Chester Airport', 'lat' => 41.383889, 'long' => -72.505833),
    'KDXR' => array('name' => 'CT - Danbury, Danbury Municipal Airport', 'lat' => 41.371667, 'long' => -73.484444),
    'KGON' => array('name' => 'CT - Groton / New London, Groton / New London Airport', 'lat' => 41.327500, 'long' => -72.049444),
    'KHFD' => array('name' => 'CT - Hartford, Hartford-Brainard Airport', 'lat' => 41.735000, 'long' => -72.651667),
    'KMMK' => array('name' => 'CT - Meriden, Meriden Markham Municipal Airport', 'lat' => 41.509722, 'long' => -72.827778),
    'KHVN' => array('name' => 'CT - New Haven, Tweed-New Haven Airport', 'lat' => 41.263889, 'long' => -72.887222),
    'KOXC' => array('name' => 'CT - Oxford, Waterbury-Oxford Airport', 'lat' => 41.483333, 'long' => -73.133333),
    'KIJD' => array('name' => 'CT - Willimantic, Windham Airport', 'lat' => 41.741944, 'long' => -72.183611),
    'KBDL' => array('name' => 'CT - Windsor Locks, Bradley International Airport', 'lat' => 41.938056, 'long' => -72.682500),
    'KDOV' => array('name' => 'DE - Dover Air Force Base', 'lat' => 39.133333, 'long' => -75.466667),
    'KGED' => array('name' => 'DE - Georgetown, Sussex County Airport', 'lat' => 38.690000, 'long' => -75.362500),
    'KILG' => array('name' => 'DE - Wilmington, New Castle County Airport', 'lat' => 39.672778, 'long' => -75.600833),
    'KAQR' => array('name' => 'FL - Atoka, Atoka Municipal Airport', 'lat' => 34.398333, 'long' => -96.148056),
    'KBOW' => array('name' => 'FL - Bartow Municipal', 'lat' => 27.950000, 'long' => -81.783333),
    'KBCT' => array('name' => 'FL - Boca Raton, Boca Raton Airport', 'lat' => 26.378611, 'long' => -80.107778),
    'KBKV' => array('name' => 'FL - Brooksville, Hernando County Airport', 'lat' => 28.473611, 'long' => -82.454444),
    'KCOF' => array('name' => 'FL - Cocoa / Patrick Air Force Base', 'lat' => 28.233333, 'long' => -80.600000),
    'KCEW' => array('name' => 'FL - Crestview, Sikes Airport', 'lat' => 30.772222, 'long' => -86.520000),
    'KCTY' => array('name' => 'FL - Cross City, Cross City Airport', 'lat' => 29.550000, 'long' => -83.105278),
    'KDAB' => array('name' => 'FL - Daytona Beach, Daytona Beach Regional Airport', 'lat' => 29.177222, 'long' => -81.060000),
    'KDTS' => array('name' => 'FL - Destin, Destin-Ft. Walton Beach Airport', 'lat' => 30.393333, 'long' => -86.467500),
    'KEGI' => array('name' => 'FL - Duke Field / Eglin Auxiliary', 'lat' => 30.650000, 'long' => -86.516667),
    'KFLL' => array('name' => 'FL - Fort Lauderdale, Fort Lauderdale / Hollywood International Airport', 'lat' => 26.068056, 'long' => -80.152500),
    'KFXE' => array('name' => 'FL - Fort Lauderdale, Fort Lauderdale Executive Airport', 'lat' => 26.200000, 'long' => -80.183333),
    'KFMY' => array('name' => 'FL - Fort Myers, Page Field', 'lat' => 26.584167, 'long' => -81.862500),
    'KRSW' => array('name' => 'FL - Fort Myers, Southwest Florida International Airport', 'lat' => 26.526944, 'long' => -81.766389),
    'KFPR' => array('name' => 'FL - Fort Pierce, St. Lucie County International Airport', 'lat' => 27.498056, 'long' => -80.376667),
    'KGNV' => array('name' => 'FL - Gainesville, Gainesville Regional Airport', 'lat' => 29.691944, 'long' => -82.275556),
    'KHWO' => array('name' => 'FL - Hollywood, North Perry Airport', 'lat' => 25.998889, 'long' => -80.241111),
    'KHST' => array('name' => 'FL - Homestead Air Force Base', 'lat' => 25.483333, 'long' => -80.383333),
    'KHRT' => array('name' => 'FL - Hurlburt Field', 'lat' => 30.416667, 'long' => -86.683333),
    'KVQQ' => array('name' => 'FL - Jacksonville, Cecil Field Airport', 'lat' => 30.218611, 'long' => -81.876667),
    'KCRG' => array('name' => 'FL - Jacksonville, Craig Municipal Airport', 'lat' => 30.336111, 'long' => -81.514722),
    'KJAX' => array('name' => 'FL - Jacksonville, Jacksonville International Airport', 'lat' => 30.494444, 'long' => -81.693333),
    'KNIP' => array('name' => 'FL - Jacksonville, Naval Air Station', 'lat' => 30.234167, 'long' => -81.674722),
    'KEYW' => array('name' => 'FL - Key West, Key West International Airport', 'lat' => 24.553611, 'long' => -81.753611),
    'KNQX' => array('name' => 'FL - Key West, Naval Air Station', 'lat' => 24.579444, 'long' => -81.683889),
    'KLAL' => array('name' => 'FL - Lakeland Regional', 'lat' => 27.983333, 'long' => -82.016667),
    'KLEE' => array('name' => 'FL - Leesburg, Leesburg Regional Airport', 'lat' => 28.822500, 'long' => -81.808889),
    'KMCF' => array('name' => 'FL - Macdill Air Force Base, Fl.', 'lat' => 27.850000, 'long' => -82.500000),
    'KMTH' => array('name' => 'FL - Marathon, Marathon Airport', 'lat' => 24.725833, 'long' => -81.047778),
    'KMAI' => array('name' => 'FL - Marianna, Marianna Municipal Airport', 'lat' => 30.836667, 'long' => -85.183611),
    'KNRB' => array('name' => 'FL - Mayport, Mayport Naval Station, Adm David L. McDonald Field', 'lat' => 30.395833, 'long' => -81.422500),
    'KMLB' => array('name' => 'FL - Melbourne, Melbourne International Airport', 'lat' => 28.102778, 'long' => -80.645833),
    'KTMB' => array('name' => 'FL - Miami, Kendall-Tamiami Executive Airport', 'lat' => 25.641944, 'long' => -80.434722),
    'KMIA' => array('name' => 'FL - Miami, Miami International Airport', 'lat' => 25.790556, 'long' => -80.316389),
    'KOPF' => array('name' => 'FL - Miami, Opa Locka Airport', 'lat' => 25.910000, 'long' => -80.283056),
    'KNSE' => array('name' => 'FL - Milton, Whiting Field Naval Air Station North', 'lat' => 30.724167, 'long' => -87.021944),
    'KAPF' => array('name' => 'FL - Naples, Naples Municipal Airport', 'lat' => 26.150000, 'long' => -81.766667),
    'KEVB' => array('name' => 'FL - New Smyrna Beach, New Smyrna Beach Municipal Airport', 'lat' => 29.055556, 'long' => -80.948333),
    'KOCF' => array('name' => 'FL - Ocala, Ocala International Airport-Jim Taylor Field', 'lat' => 29.166667, 'long' => -82.216667),
    'KSFB' => array('name' => 'FL - Orlando / Sanford Airport', 'lat' => 28.783333, 'long' => -81.250000),
    'KISM' => array('name' => 'FL - Orlando, Kissimmee Municipal Airport', 'lat' => 28.289722, 'long' => -81.437222),
    'KORL' => array('name' => 'FL - Orlando, Orlando Executive Airport', 'lat' => 28.546389, 'long' => -81.335833),
    'KMCO' => array('name' => 'FL - Orlando, Orlando International Airport', 'lat' => 28.417222, 'long' => -81.325000),
    'KOMN' => array('name' => 'FL - Ormond Beach, Ormond Beach Municipal Airport', 'lat' => 29.301111, 'long' => -81.113611),
    'KPFN' => array('name' => 'FL - Panama City, Panama City-Bay County International Airport', 'lat' => 30.207500, 'long' => -85.685000),
    'KNPA' => array('name' => 'FL - Pensacola, Naval Air Station', 'lat' => 30.356111, 'long' => -87.323333),
    'KPNS' => array('name' => 'FL - Pensacola, Pensacola Regional Airport', 'lat' => 30.478056, 'long' => -87.186944),
    'K40J' => array('name' => 'FL - Perry-Foley, Perry-Foley Airport', 'lat' => 30.071944, 'long' => -83.573611),
    'KPCM' => array('name' => 'FL - Plant City, Plant City Municipal Airport', 'lat' => 28.000000, 'long' => -82.150000),
    'KPMP' => array('name' => 'FL - Pompano Beach, Pompano Beach Airpark', 'lat' => 26.245556, 'long' => -80.111389),
    'KPGD' => array('name' => 'FL - Punta Gorda, Charlotte County Airport', 'lat' => 26.917778, 'long' => -81.993611),
    'KSRQ' => array('name' => 'FL - Sarasota / Bradenton, Sarasota-Bradenton International Airport', 'lat' => 27.401389, 'long' => -82.558611),
    'KSGJ' => array('name' => 'FL - St. Augustine, St. Augustine Airport', 'lat' => 29.959167, 'long' => -81.339722),
    'KPIE' => array('name' => 'FL - St. Petersburg / Clearwater, St. Petersburg / Clearwater International Airport', 'lat' => 27.912222, 'long' => -82.685556),
    'KSPG' => array('name' => 'FL - St. Petersburg, Whitted Airport', 'lat' => 27.767778, 'long' => -82.626111),
    'KSUA' => array('name' => 'FL - Stuart, Witham Field Airport', 'lat' => 27.181667, 'long' => -80.221111),
    'KTLH' => array('name' => 'FL - Tallahassee, Tallahassee Regional Airport', 'lat' => 30.393056, 'long' => -84.353333),
    'KTPF' => array('name' => 'FL - Tampa, Peter O Knight Airport', 'lat' => 27.915556, 'long' => -82.449167),
    'KTPA' => array('name' => 'FL - Tampa, Tampa International Airport', 'lat' => 27.961389, 'long' => -82.540278),
    'KVDF' => array('name' => 'FL - Tampa, Vandenberg Airport', 'lat' => 28.013889, 'long' => -82.345278),
    'KVVG' => array('name' => 'FL - The Villages', 'lat' => 28.966667, 'long' => -81.966667),
    'KTIX' => array('name' => 'FL - Titusville', 'lat' => 28.516667, 'long' => -80.800000),
    'KPAM' => array('name' => 'FL - Tyndall Air Force Base', 'lat' => 30.066667, 'long' => -85.583333),
    'KVPS' => array('name' => 'FL - Valparaiso / Eglin Air Force Base', 'lat' => 30.483333, 'long' => -86.516667),
    'KVRB' => array('name' => 'FL - Vero Beach, Vero Beach Municipal Airport', 'lat' => 27.655556, 'long' => -80.418056),
    'KPBI' => array('name' => 'FL - West Palm Beach, Palm Beach International Airport', 'lat' => 26.684722, 'long' => -80.099444),
    'KGIF' => array('name' => 'FL - Winter Haven, Winter Haven\'s Gilbert Airport', 'lat' => 28.060556, 'long' => -81.757500),
    'KABY' => array('name' => 'GA - Albany, Southwest Georgia Regional Airport', 'lat' => 31.535556, 'long' => -84.194444),
    'KAMG' => array('name' => 'GA - Alma, Bacon County Airport', 'lat' => 31.536111, 'long' => -82.506667),
    'KAHN' => array('name' => 'GA - Athens, Athens Airport', 'lat' => 33.950833, 'long' => -83.328056),
    'KPDK' => array('name' => 'GA - Atlanta, De Kalb-Peachtree Airport', 'lat' => 33.878333, 'long' => -84.298056),
    'KFTY' => array('name' => 'GA - Atlanta, Fulton County Airport-Brown Field', 'lat' => 33.777500, 'long' => -84.524444),
    'KATL' => array('name' => 'GA - Atlanta, Hartsfield - Jackson Atlanta International Airport', 'lat' => 33.640278, 'long' => -84.426944),
    'KFFC' => array('name' => 'GA - Atlanta, Peachtree City-Falcon Field', 'lat' => 33.355278, 'long' => -84.566944),
    'KAGS' => array('name' => 'GA - Augusta, Bush Field', 'lat' => 33.364444, 'long' => -81.963333),
    'KDNL' => array('name' => 'GA - Augusta, Daniel Field', 'lat' => 33.466944, 'long' => -82.038611),
    'KBGE' => array('name' => 'GA - Bainbridge, Decatur County Industrial Air Park Airport', 'lat' => 30.966667, 'long' => -84.633333),
    'KBIJ' => array('name' => 'GA - Blakely, Early County Airport', 'lat' => 31.396944, 'long' => -84.895000),
    'KBQK' => array('name' => 'GA - Brunswick / Glynco', 'lat' => 31.250000, 'long' => -81.466667),
    'KSSI' => array('name' => 'GA - Brunswick, Malcolm McKinnon Airport', 'lat' => 31.151667, 'long' => -81.391389),
    'K47A' => array('name' => 'GA - Canton, Cherokee County Airport', 'lat' => 34.310556, 'long' => -84.423889),
    'KVPC' => array('name' => 'GA - Cartersville, Cartersville Airport', 'lat' => 34.128333, 'long' => -84.847222),
    'KCSG' => array('name' => 'GA - Columbus, Columbus Metropolitan Airport', 'lat' => 32.516111, 'long' => -84.942222),
    'KDNN' => array('name' => 'GA - Dalton, Dalton Municipal Airport', 'lat' => 34.721667, 'long' => -84.869167),
    'KDQH' => array('name' => 'GA - Douglas, Douglas Municipal Airport', 'lat' => 31.476667, 'long' => -82.860278),
    'KDBN' => array('name' => 'GA - Dublin, W H \'Bud\' Barron Airport', 'lat' => 32.564444, 'long' => -82.985000),
    'KLSF' => array('name' => 'GA - Fort Benning', 'lat' => 32.333333, 'long' => -84.833333),
    'KLHW' => array('name' => 'GA - Ft. Stewart', 'lat' => 31.883333, 'long' => -81.566667),
    'KGVL' => array('name' => 'GA - Gainesville, Gilmer Memorial Airport', 'lat' => 34.271944, 'long' => -83.830278),
    'K3J7' => array('name' => 'GA - Greensboro, Greene County Regional Airport', 'lat' => 33.597500, 'long' => -83.138889),
    'KSVN' => array('name' => 'GA - Hunter U. S. Army Airfield', 'lat' => 32.016667, 'long' => -81.150000),
    'KLGC' => array('name' => 'GA - La Grange, Callaway Airport', 'lat' => 33.008889, 'long' => -85.072500),
    'KLZU' => array('name' => 'GA - Lawrenceville, Gwinnett County-Briscoe Field Airport', 'lat' => 33.978056, 'long' => -83.962500),
    'KMCN' => array('name' => 'GA - Macon, Middle Georgia Regional Airport', 'lat' => 32.687778, 'long' => -83.654444),
    'KMGE' => array('name' => 'GA - Marietta / Dobbins Air Force Base', 'lat' => 33.916667, 'long' => -84.516667),
    'KRYY' => array('name' => 'GA - Marietta, Cobb County-McCollum Field Airport', 'lat' => 34.013056, 'long' => -84.598611),
    'KMLJ' => array('name' => 'GA - Milledgeville, Baldwin County Airport', 'lat' => 33.154167, 'long' => -83.240556),
    'KVAD' => array('name' => 'GA - Moody Air Force Base', 'lat' => 30.966667, 'long' => -83.200000),
    'KMGR' => array('name' => 'GA - Moultrie, Moultrie Municipal Airport', 'lat' => 31.084722, 'long' => -83.803056),
    'KCCO' => array('name' => 'GA - Newnan, Newnan Coweta County Airport', 'lat' => 33.312222, 'long' => -84.770278),
    'KRMG' => array('name' => 'GA - Rome, R. B. Russell Airport', 'lat' => 34.347778, 'long' => -85.161111),
    'KSAV' => array('name' => 'GA - Savannah, Savannah International Airport', 'lat' => 32.118889, 'long' => -81.202222),
    'KTBR' => array('name' => 'GA - Statesboro, Statesboro-Bulloch County Airport', 'lat' => 32.483056, 'long' => -81.737222),
    'KJYL' => array('name' => 'GA - Sylvania, Plantation Airpark', 'lat' => 32.645278, 'long' => -81.596389),
    'KOPN' => array('name' => 'GA - Thomaston, Thomaston-Upson County Airport', 'lat' => 32.955000, 'long' => -84.264444),
    'KHQU' => array('name' => 'GA - Thomson, Thomson-McDuffie County Airport', 'lat' => 33.529444, 'long' => -82.516389),
    'KVLD' => array('name' => 'GA - Valdosta, Valdosta Regional Airport', 'lat' => 30.783333, 'long' => -83.283333),
    'KVDI' => array('name' => 'GA - Vidalia, Vidalia Municipal Airport', 'lat' => 32.192500, 'long' => -82.371944),
    'KWRB' => array('name' => 'GA - Warner Robins Air Force Base', 'lat' => 32.633333, 'long' => -83.600000),
    'KIIY' => array('name' => 'GA - Washington, Washington-Wilkes County Airport', 'lat' => 33.779722, 'long' => -82.816389),
    'KAYS' => array('name' => 'GA - Waycross / Ware County, Ga', 'lat' => 31.250000, 'long' => -82.400000),
    'KWDR' => array('name' => 'GA - Winder, Winder-Barrow Airport', 'lat' => 33.982222, 'long' => -83.668056),
    'PHSF' => array('name' => 'HI - Bradshaw Army Air Field / Hawaii', 'lat' => 19.783333, 'long' => -155.550000),
    'PHHN' => array('name' => 'HI - Hana, Hana Airport', 'lat' => 20.795556, 'long' => -156.014444),
    'PHIK' => array('name' => 'HI - Hickam Air Force Base / Oahu', 'lat' => 21.316667, 'long' => -157.916667),
    'PHTO' => array('name' => 'HI - Hilo, Hilo International Airport', 'lat' => 19.722222, 'long' => -155.055833),
    'PHNL' => array('name' => 'HI - Honolulu, Honolulu International Airport', 'lat' => 21.327500, 'long' => -157.943056),
    'PHOG' => array('name' => 'HI - Kahului, Kahului Airport', 'lat' => 20.892500, 'long' => -156.436944),
    'PHKO' => array('name' => 'HI - Kailua / Kona, Keahole Airport', 'lat' => 19.740833, 'long' => -156.050556),
    'PHNG' => array('name' => 'HI - Kaneohe, Marine Corps Air Station', 'lat' => 21.453889, 'long' => -157.765556),
    'PHMK' => array('name' => 'HI - Kaunakakai, Molokai Airport', 'lat' => 21.150000, 'long' => -157.100000),
    'PHBK' => array('name' => 'HI - Kekaha, Pacific Missile Test Facility Barking Sands', 'lat' => 22.036389, 'long' => -159.786389),
    'PHJH' => array('name' => 'HI - Lahaina / West Maui', 'lat' => 21.016667, 'long' => -156.633333),
    'PHNY' => array('name' => 'HI - Lanai City, Lanai Airport', 'lat' => 20.785556, 'long' => -156.951389),
    'PHLI' => array('name' => 'HI - Lihue, Lihue Airport', 'lat' => 21.983889, 'long' => -159.341111),
    'PHJR' => array('name' => 'HI - Oahu, Kalaeloa Airport', 'lat' => 21.308333, 'long' => -158.068056),
    'PMDY' => array('name' => 'HI - Sand Island, Henderson Field Airport', 'lat' => 28.216667, 'long' => -177.366667),
    'PHHI' => array('name' => 'HI - Wheeler Air Force Base / Oahu', 'lat' => 21.483333, 'long' => -158.033333),
    'KAXA' => array('name' => 'IA - Algona', 'lat' => 43.083333, 'long' => -94.266667),
    'KAMW' => array('name' => 'IA - Ames, Ames Municipal Airport', 'lat' => 41.990556, 'long' => -93.618889),
    'KIKV' => array('name' => 'IA - Ankeny, Ankeny Regional Airport', 'lat' => 41.690000, 'long' => -93.565833),
    'KAIO' => array('name' => 'IA - Atlantic', 'lat' => 41.400000, 'long' => -95.050000),
    'KADU' => array('name' => 'IA - Audubon, Audubon County Airport', 'lat' => 41.701111, 'long' => -94.920278),
    'KBNW' => array('name' => 'IA - Boone Municipal', 'lat' => 42.050000, 'long' => -93.850000),
    'KBRL' => array('name' => 'IA - Burlington, Burlington Regional Airport', 'lat' => 40.772778, 'long' => -91.125278),
    'KCIN' => array('name' => 'IA - Carroll', 'lat' => 42.050000, 'long' => -94.783333),
    'KCID' => array('name' => 'IA - Cedar Rapids, The Eastern Iowa Airport', 'lat' => 41.884444, 'long' => -91.710556),
    'KCNC' => array('name' => 'IA - Chariton', 'lat' => 41.033333, 'long' => -93.366667),
    'KCCY' => array('name' => 'IA - Charles City', 'lat' => 43.066667, 'long' => -92.616667),
    'KCKP' => array('name' => 'IA - Cherokee, Cherokee Municipal Airport', 'lat' => 42.731667, 'long' => -95.555833),
    'KICL' => array('name' => 'IA - Clarinda', 'lat' => 40.716667, 'long' => -95.033333),
    'KCAV' => array('name' => 'IA - Clarion', 'lat' => 42.750000, 'long' => -93.766667),
    'KCWI' => array('name' => 'IA - Clinton, Clinton Municipal Airport', 'lat' => 41.833333, 'long' => -90.333333),
    'KCBF' => array('name' => 'IA - Council Bluffs', 'lat' => 41.266667, 'long' => -95.766667),
    'KCSQ' => array('name' => 'IA - Creston', 'lat' => 41.016667, 'long' => -94.366667),
    'KDVN' => array('name' => 'IA - Davenport, Davenport Municipal Airport', 'lat' => 41.613889, 'long' => -90.591389),
    'KDEH' => array('name' => 'IA - Decorah', 'lat' => 43.283333, 'long' => -91.733333),
    'KDNS' => array('name' => 'IA - Denison', 'lat' => 41.983333, 'long' => -95.383333),
    'KDSM' => array('name' => 'IA - Des Moines, Des Moines International Airport', 'lat' => 41.537778, 'long' => -93.666111),
    'KDBQ' => array('name' => 'IA - Dubuque, Dubuque Regional Airport', 'lat' => 42.397778, 'long' => -90.703611),
    'KEST' => array('name' => 'IA - Estherville, Estherville Municipal Airport', 'lat' => 43.401111, 'long' => -94.747222),
    'KFFL' => array('name' => 'IA - Fair Field', 'lat' => 41.050000, 'long' => -91.983333),
    'KFOD' => array('name' => 'IA - Fort Dodge', 'lat' => 42.550000, 'long' => -94.183333),
    'KFSW' => array('name' => 'IA - Fort Madison', 'lat' => 40.666667, 'long' => -91.333333),
    'KHNR' => array('name' => 'IA - Harlan, Harlan Municipal Airport', 'lat' => 41.584444, 'long' => -95.339722),
    'KIIB' => array('name' => 'IA - Independence, Independence Municipal Airport', 'lat' => 42.450000, 'long' => -91.933333),
    'KIOW' => array('name' => 'IA - Iowa City, Iowa City Municipal Airport', 'lat' => 41.632778, 'long' => -91.543056),
    'KEOK' => array('name' => 'IA - Keokuk Municipal', 'lat' => 40.466667, 'long' => -91.433333),
    'KOXV' => array('name' => 'IA - Knoxville', 'lat' => 41.300000, 'long' => -93.116667),
    'KLWD' => array('name' => 'IA - Lamoni, Lamoni Municipal Airport', 'lat' => 40.630556, 'long' => -93.900833),
    'KLRJ' => array('name' => 'IA - Le Mars, Le Mars Municipal Airport', 'lat' => 42.778056, 'long' => -96.193611),
    'KMIW' => array('name' => 'IA - Marshalltown, Marshalltown Municipal Airport', 'lat' => 42.110556, 'long' => -92.916111),
    'KMCW' => array('name' => 'IA - Mason City, Mason City Municipal Airport', 'lat' => 43.157778, 'long' => -93.331389),
    'KMXO' => array('name' => 'IA - Monticello Municipal', 'lat' => 42.233333, 'long' => -91.166667),
    'KMPZ' => array('name' => 'IA - Mount Pleasant, Mount Pleasant Municipal Airport', 'lat' => 40.946667, 'long' => -91.511111),
    'KMUT' => array('name' => 'IA - Muscatine', 'lat' => 41.366667, 'long' => -91.150000),
    'KTNU' => array('name' => 'IA - Newton Municipal', 'lat' => 41.683333, 'long' => -93.016667),
    'KOLZ' => array('name' => 'IA - Oelwein, Oelwein Municipal Airport', 'lat' => 42.680833, 'long' => -91.974444),
    'KORC' => array('name' => 'IA - Orange City', 'lat' => 42.983333, 'long' => -96.066667),
    'KOOA' => array('name' => 'IA - Oskaloosa, Oskaloosa Municipal Airport', 'lat' => 41.226111, 'long' => -92.493611),
    'KOTM' => array('name' => 'IA - Ottumwa, Ottumwa Industrial Airport', 'lat' => 41.106667, 'long' => -92.448056),
    'KPEA' => array('name' => 'IA - Pella, Pella Municipal Airport', 'lat' => 41.400000, 'long' => -92.933333),
    'KRDK' => array('name' => 'IA - Red Oak', 'lat' => 41.016667, 'long' => -95.266667),
    'KSHL' => array('name' => 'IA - Sheldon', 'lat' => 43.216667, 'long' => -95.833333),
    'KSDA' => array('name' => 'IA - Shenandoah Municipal', 'lat' => 40.750000, 'long' => -95.416667),
    'KSUX' => array('name' => 'IA - Sioux City, Sioux Gateway Airport', 'lat' => 42.402500, 'long' => -96.384444),
    'KSPW' => array('name' => 'IA - Spencer, Spencer Municipal Airport', 'lat' => 43.165556, 'long' => -95.202778),
    'KSLB' => array('name' => 'IA - Storm Lake', 'lat' => 42.600000, 'long' => -95.233333),
    'KVTI' => array('name' => 'IA - Vinton, Vinton Veterans Memorial Airpark Airport', 'lat' => 42.218611, 'long' => -92.025833),
    'KAWG' => array('name' => 'IA - Washington', 'lat' => 41.283333, 'long' => -91.666667),
    'KALO' => array('name' => 'IA - Waterloo, Waterloo Municipal Airport', 'lat' => 42.554444, 'long' => -92.401111),
    'KEBS' => array('name' => 'IA - Webster City', 'lat' => 42.433333, 'long' => -93.866667),
    'KBOI' => array('name' => 'ID - Boise, Boise Air Terminal', 'lat' => 43.566667, 'long' => -116.240556),
    'KBYI' => array('name' => 'ID - Burley, Burley Municipal Airport', 'lat' => 42.542500, 'long' => -113.771389),
    'KEUL' => array('name' => 'ID - Caldwell, Caldwell Industrial Airport', 'lat' => 43.633333, 'long' => -116.633333),
    'KCOE' => array('name' => 'ID - Coeur d\'Alene, Coeur d\'Alene Air Terminal', 'lat' => 47.766667, 'long' => -116.816667),
    'KU59' => array('name' => 'ID - Driggs, Driggs-Reed Memorial Airport', 'lat' => 43.741667, 'long' => -111.097778),
    'KSUN' => array('name' => 'ID - Hailey, Friedman Memorial Airport', 'lat' => 43.500000, 'long' => -114.300000),
    'KIDA' => array('name' => 'ID - Idaho Falls, Fanning Field', 'lat' => 43.520833, 'long' => -112.066111),
    'KLWS' => array('name' => 'ID - Lewiston, Lewiston-Nez Perce County Airport', 'lat' => 46.374722, 'long' => -117.014444),
    'KP69' => array('name' => 'ID - Lowell', 'lat' => 46.144167, 'long' => -115.596389),
    'K77M' => array('name' => 'ID - Malta', 'lat' => 42.316667, 'long' => -113.333333),
    'KMYL' => array('name' => 'ID - McCall, McCall Airport', 'lat' => 44.883333, 'long' => -116.099444),
    'KMUO' => array('name' => 'ID - Mountain Home Air Force Base', 'lat' => 43.050000, 'long' => -115.866667),
    'KMLP' => array('name' => 'ID - Mullan Pass, Mullan Pass Vor', 'lat' => 47.454167, 'long' => -115.669722),
    'KPIH' => array('name' => 'ID - Pocatello, Pocatello Regional Airport', 'lat' => 42.920278, 'long' => -112.571111),
    'KRXE' => array('name' => 'ID - Rexburg, Rexburg-Madison County Airport', 'lat' => 43.831667, 'long' => -111.806111),
    'KSMN' => array('name' => 'ID - Salmon, Lemhi County Airport', 'lat' => 45.116667, 'long' => -113.883333),
    'KSZT' => array('name' => 'ID - Sandpoint, Sandpoint Airport', 'lat' => 48.299444, 'long' => -116.560000),
    'KU78' => array('name' => 'ID - Soda Springs / Tigert', 'lat' => 42.650000, 'long' => -111.583333),
    'KSNT' => array('name' => 'ID - Stanley, Stanley Ranger Station', 'lat' => 44.208611, 'long' => -114.934444),
    'KTWF' => array('name' => 'ID - Twin Falls, Joslin Field-Magic Valley Regional Airport', 'lat' => 42.478611, 'long' => -114.476111),
    'KALN' => array('name' => 'IL - Alton/St. Louis, St. Louis Regional Airport', 'lat' => 38.900000, 'long' => -90.050000),
    'KARR' => array('name' => 'IL - Aurora, Aurora Municipal Airport', 'lat' => 41.770000, 'long' => -88.481389),
    'KBLV' => array('name' => 'IL - Belleville, Scott AFB/MidAmerica Airport', 'lat' => 38.550000, 'long' => -89.850000),
    'KBMI' => array('name' => 'IL - Bloomington/Normal, Central Illinois Regional Airport at Bloomington-Normal', 'lat' => 40.476944, 'long' => -88.915833),
    'KCPS' => array('name' => 'IL - Cahokia / St. Louis, St. Louis Downtown Airport', 'lat' => 38.570833, 'long' => -90.156111),
    'KCIR' => array('name' => 'IL - Cairo, Cairo Regional Airport', 'lat' => 37.064444, 'long' => -89.219444),
    'KMDH' => array('name' => 'IL - Carbondale / Murphysboro, Southern Illinois Airport', 'lat' => 37.783056, 'long' => -89.245000),
    'KCUL' => array('name' => 'IL - Carmi, Carmi Municipal Airport', 'lat' => 38.089444, 'long' => -88.123056),
    'KENL' => array('name' => 'IL - Centralia, Centralia Municipal Airport', 'lat' => 38.514722, 'long' => -89.092222),
    'KCMI' => array('name' => 'IL - Champaign / Urbana, University Of Illinois-Willard Airport', 'lat' => 40.032222, 'long' => -88.273333),
    'KUGN' => array('name' => 'IL - Chicago / Waukegan, Waukegan Regional Airport', 'lat' => 42.416667, 'long' => -87.866667),
    'KDPA' => array('name' => 'IL - Chicago / West Chicago, Dupage Airport', 'lat' => 41.896389, 'long' => -88.251111),
    'KPWK' => array('name' => 'IL - Chicago / Wheeling, Pal-Waukee Airport', 'lat' => 42.120833, 'long' => -87.904722),
    'KMDW' => array('name' => 'IL - Chicago, Chicago Midway Airport', 'lat' => 41.784167, 'long' => -87.755278),
    'KORD' => array('name' => 'IL - Chicago, Chicago-O\'Hare International Airport', 'lat' => 41.979722, 'long' => -87.904444),
    'KIGQ' => array('name' => 'IL - Chicago, Lansing Municipal Airport', 'lat' => 41.540000, 'long' => -87.532222),
    'KLOT' => array('name' => 'IL - Chicago/Romeoville, Lewis University Airport', 'lat' => 41.608333, 'long' => -88.094167),
    'KDNV' => array('name' => 'IL - Danville, Vermilion County Airport', 'lat' => 40.199444, 'long' => -87.595556),
    'KDKB' => array('name' => 'IL - De Kalb, De Kalb Taylor Municipal Airport', 'lat' => 41.931944, 'long' => -88.708333),
    'KDEC' => array('name' => 'IL - Decatur, Decatur Airport', 'lat' => 39.834444, 'long' => -88.865556),
    'K1H2' => array('name' => 'IL - Effingham, Effingham County Memorial Airport', 'lat' => 39.070556, 'long' => -88.533333),
    'KFWC' => array('name' => 'IL - Fairfield, Fairfield Municipal Airport', 'lat' => 38.378611, 'long' => -88.412778),
    'KFOA' => array('name' => 'IL - Flora, Flora Municipal Airport', 'lat' => 38.665000, 'long' => -88.453056),
    'KFEP' => array('name' => 'IL - Freeport, Albertus Airport', 'lat' => 42.246389, 'long' => -89.582222),
    'KGBG' => array('name' => 'IL - Galesburg, Galesburg Municipal Airport', 'lat' => 40.938056, 'long' => -90.431111),
    'KHSB' => array('name' => 'IL - Harrisburg, Harrisburg-Raleigh Airport', 'lat' => 37.811389, 'long' => -88.549167),
    'KIJX' => array('name' => 'IL - Jacksonville, Jacksonville Municipal Airport', 'lat' => 39.774167, 'long' => -90.238611),
    'KJOT' => array('name' => 'IL - Joliet, Joliet Regional Airport', 'lat' => 41.518056, 'long' => -88.175278),
    'KIKK' => array('name' => 'IL - Kankakee, Greater Kankakee Airport', 'lat' => 41.071389, 'long' => -87.846389),
    'KC75' => array('name' => 'IL - Lacon, Marshall County Airport', 'lat' => 41.019167, 'long' => -89.386389),
    'KLWV' => array('name' => 'IL - Lawrenceville, Lawrenceville-Vincennes International Airport', 'lat' => 38.760556, 'long' => -87.598889),
    'KAAA' => array('name' => 'IL - Lincoln, Logan County Airport', 'lat' => 40.158611, 'long' => -89.335000),
    'K3LF' => array('name' => 'IL - Litchfield, Litchfield Municipal Airport', 'lat' => 39.162222, 'long' => -89.674444),
    'KMQB' => array('name' => 'IL - Macomb, Macomb Municipal Airport', 'lat' => 40.520278, 'long' => -90.652500),
    'KMWA' => array('name' => 'IL - Marion, Williamson County Regional Airport', 'lat' => 37.750278, 'long' => -89.001111),
    'KMTO' => array('name' => 'IL - Mattoon / Charleston, Coles County Memorial Airport', 'lat' => 39.478056, 'long' => -88.279167),
    'KM30' => array('name' => 'IL - Metropolis, Metropolis Municipal Airport', 'lat' => 37.185833, 'long' => -88.750556),
    'KMLI' => array('name' => 'IL - Moline, Quad-City Airport', 'lat' => 41.451389, 'long' => -90.514722),
    'KC09' => array('name' => 'IL - Morris, Morris Municipal-James R Washburn Field Airport', 'lat' => 41.425278, 'long' => -88.418611),
    'KAJG' => array('name' => 'IL - Mount Carmel, Mount Carmel Municipal Airport', 'lat' => 38.606389, 'long' => -87.726667),
    'KMVN' => array('name' => 'IL - Mount Vernon, Mount Vernon Airport', 'lat' => 38.316667, 'long' => -88.866667),
    'KOLY' => array('name' => 'IL - Olney-Noble, Olney-Noble Airport', 'lat' => 38.721944, 'long' => -88.176389),
    'KPRG' => array('name' => 'IL - Paris, Edgar County Airport', 'lat' => 39.700278, 'long' => -87.669722),
    'KPIA' => array('name' => 'IL - Peoria, Greater Peoria Regional Airport', 'lat' => 40.667500, 'long' => -89.683889),
    'KVYS' => array('name' => 'IL - Peru, Illinois Valley Regional-Walter A Duncan Field Airport', 'lat' => 41.351944, 'long' => -89.153056),
    'KPPQ' => array('name' => 'IL - Pittsfield, Pittsfield Penstone Municipal Airport', 'lat' => 39.638889, 'long' => -90.778333),
    'KPNT' => array('name' => 'IL - Pontiac, Pontiac Municipal Airport', 'lat' => 40.923611, 'long' => -88.625278),
    'KUIN' => array('name' => 'IL - Quincy, Quincy Regional-Baldwin Field Airport', 'lat' => 39.942500, 'long' => -91.194444),
    'KTIP' => array('name' => 'IL - Rantoul, Rantoul National Aviation Center Airport-Frank Elliott Field', 'lat' => 40.293611, 'long' => -88.142500),
    'KRSV' => array('name' => 'IL - Robinson, Robinson Municipal Airport', 'lat' => 39.015833, 'long' => -87.649722),
    'KRPJ' => array('name' => 'IL - Rochelle, Rochelle Municipal-Koritz Field Airport', 'lat' => 41.893056, 'long' => -89.078333),
    'KRFD' => array('name' => 'IL - Rockford, Greater Rockford Airport', 'lat' => 42.192778, 'long' => -89.093333),
    'KSLO' => array('name' => 'IL - Salem, Salem-Leckrone Airport', 'lat' => 38.642778, 'long' => -88.964167),
    'KSFY' => array('name' => 'IL - Savanna, Tri-Township Airport', 'lat' => 42.045833, 'long' => -90.107778),
    'KSAR' => array('name' => 'IL - Sparta, Sparta Community-Hunter Field Airport', 'lat' => 38.148889, 'long' => -89.698611),
    'KSPI' => array('name' => 'IL - Springfield, Abraham Lincoln Capital Airport', 'lat' => 39.845278, 'long' => -89.683889),
    'KSQI' => array('name' => 'IL - Sterling Rockfalls', 'lat' => 41.750000, 'long' => -89.666667),
    'KTAZ' => array('name' => 'IL - Taylorville, Taylorville Municipal Airport', 'lat' => 39.534167, 'long' => -89.327778),
    'KAID' => array('name' => 'IN - Anderson Municipal', 'lat' => 40.116667, 'long' => -85.616667),
    'KBMG' => array('name' => 'IN - Bloomington, Monroe County Airport', 'lat' => 39.143056, 'long' => -86.616667),
    'KBAK' => array('name' => 'IN - Columbus / Bakalar', 'lat' => 39.266667, 'long' => -85.900000),
    'KEKM' => array('name' => 'IN - Elkhart Municipal', 'lat' => 41.716667, 'long' => -86.000000),
    'KEVV' => array('name' => 'IN - Evansville, Evansville Regional Airport', 'lat' => 38.043056, 'long' => -87.520278),
    'KFWA' => array('name' => 'IN - Fort Wayne, Fort Wayne International Airport', 'lat' => 40.978333, 'long' => -85.195278),
    'KGYY' => array('name' => 'IN - Gary Regional', 'lat' => 41.616667, 'long' => -87.416667),
    'KGSH' => array('name' => 'IN - Goshen, Goshen Municipal Airport', 'lat' => 41.526111, 'long' => -85.786667),
    'KGUS' => array('name' => 'IN - Grissom Air Force Base / Peru', 'lat' => 40.650000, 'long' => -86.150000),
    'KHNB' => array('name' => 'IN - Huntingburg', 'lat' => 38.250000, 'long' => -86.950000),
    'KEYE' => array('name' => 'IN - Indianapolis, Eagle Creek Airpark', 'lat' => 39.825000, 'long' => -86.295833),
    'KIND' => array('name' => 'IN - Indianapolis, Indianapolis International Airport', 'lat' => 39.725000, 'long' => -86.281944),
    'KOKK' => array('name' => 'IN - Kokomo, Kokomo Municipal Airport', 'lat' => 40.533333, 'long' => -86.066667),
    'KLAF' => array('name' => 'IN - Lafayette, Purdue University Airport', 'lat' => 40.412500, 'long' => -86.947500),
    'KMIE' => array('name' => 'IN - Muncie, Delaware County-Johnson Field', 'lat' => 40.234167, 'long' => -85.393611),
    'KGEZ' => array('name' => 'IN - Shelbyville, Shelbyville Municipal Airport', 'lat' => 39.585556, 'long' => -85.800000),
    'KSBN' => array('name' => 'IN - South Bend, South Bend Regional Airport', 'lat' => 41.708889, 'long' => -86.318611),
    'KHUF' => array('name' => 'IN - Terre Haute, Terre Haute International Airport - Hulman Field', 'lat' => 39.441667, 'long' => -87.325278),
    'KVPZ' => array('name' => 'IN - Valparaiso, Porter County Municipal Airport', 'lat' => 41.453056, 'long' => -86.998056),
    'KASW' => array('name' => 'IN - Warsaw, Warsaw Municipal Airport', 'lat' => 41.274444, 'long' => -85.840000),
    'KCNU' => array('name' => 'KS - Chanute, Chanute Martin Johnson Airport', 'lat' => 37.670278, 'long' => -95.484167),
    'KCFV' => array('name' => 'KS - Coffeyville, Coffeyville Municipal Airport', 'lat' => 37.091111, 'long' => -95.566389),
    'KCNK' => array('name' => 'KS - Concordia, Blosser Municipal Airport', 'lat' => 39.551389, 'long' => -97.650556),
    'KDDC' => array('name' => 'KS - Dodge City, Dodge City Regional Airport', 'lat' => 37.772778, 'long' => -99.969722),
    'KEHA' => array('name' => 'KS - Elkhart, Elkhart-Morton County Airport', 'lat' => 37.000000, 'long' => -101.883333),
    'KEMP' => array('name' => 'KS - Emporia, Emporia Municipal Airport', 'lat' => 38.328889, 'long' => -96.193889),
    'KGCK' => array('name' => 'KS - Garden City, Garden City Regional Airport', 'lat' => 37.927500, 'long' => -100.724444),
    'KGLD' => array('name' => 'KS - Goodland, Renner Field', 'lat' => 39.367500, 'long' => -101.693056),
    'KGBD' => array('name' => 'KS - Great Bend, Great Bend Municipal Airport', 'lat' => 38.350000, 'long' => -98.866667),
    'KHYS' => array('name' => 'KS - Hays, Hays Regional Airport', 'lat' => 38.850000, 'long' => -99.266667),
    'KHLC' => array('name' => 'KS - Hill City, Hill City Municipal Airport', 'lat' => 39.374722, 'long' => -99.829722),
    'KHUT' => array('name' => 'KS - Hutchinson, Hutchinson Municipal Airport', 'lat' => 38.068056, 'long' => -97.860556),
    'KLWC' => array('name' => 'KS - Lawrence, Lawrence Municipal Airport', 'lat' => 39.008333, 'long' => -95.211667),
    'KLBL' => array('name' => 'KS - Liberal, Liberal Municipal Airport', 'lat' => 37.050000, 'long' => -100.966667),
    'KMHK' => array('name' => 'KS - Manhattan, Manhattan Municipal Airport', 'lat' => 39.135278, 'long' => -96.677778),
    'KIAB' => array('name' => 'KS - McConnell Air Force Base', 'lat' => 37.616667, 'long' => -97.266667),
    'KP28' => array('name' => 'KS - Medicine Lodge, Medicine Lodge', 'lat' => 37.283889, 'long' => -98.552778),
    'KEWK' => array('name' => 'KS - Newton, Newton City/County Airport', 'lat' => 38.050000, 'long' => -97.283333),
    'KOJC' => array('name' => 'KS - Olathe, Johnson County Executive Airport', 'lat' => 38.850000, 'long' => -94.739167),
    'KIXD' => array('name' => 'KS - Olathe, New Century Aircenter', 'lat' => 38.824444, 'long' => -94.886944),
    'KPPF' => array('name' => 'KS - Parsons, Tri-City Airport', 'lat' => 37.327778, 'long' => -95.504167),
    'KPTT' => array('name' => 'KS - Pratt Municipal', 'lat' => 37.700000, 'long' => -98.750000),
    'KRSL' => array('name' => 'KS - Russell, Russell Municipal Airport', 'lat' => 38.872778, 'long' => -98.813056),
    'KSLN' => array('name' => 'KS - Salina, Salina Municipal Airport', 'lat' => 38.780000, 'long' => -97.644167),
    'KFOE' => array('name' => 'KS - Topeka, Forbes Field', 'lat' => 38.941389, 'long' => -95.650556),
    'KTOP' => array('name' => 'KS - Topeka, Philip Billard Municipal Airport', 'lat' => 39.072500, 'long' => -95.625833),
    'KAAO' => array('name' => 'KS - Wichita, Colonel James Jabara Airport', 'lat' => 37.749722, 'long' => -97.218889),
    'KICT' => array('name' => 'KS - Wichita, Wichita Mid-Continent Airport', 'lat' => 37.647222, 'long' => -97.429444),
    'KWLD' => array('name' => 'KS - Winfield / Arkansas City, Strother Field', 'lat' => 37.168056, 'long' => -97.036944),
    'KBWG' => array('name' => 'KY - Bowling Green, Bowling Green-Warren County Regional Airport', 'lat' => 36.964444, 'long' => -86.419444),
    'KCVG' => array('name' => 'KY - Covington / Cincinnati, Cincinnati / Northern Kentucky International Airport', 'lat' => 39.043056, 'long' => -84.671667),
    'KHOP' => array('name' => 'KY - Fort Campbell U. S. Army Airfield', 'lat' => 36.666667, 'long' => -87.500000),
    'KFTK' => array('name' => 'KY - Fort Knox', 'lat' => 37.900000, 'long' => -85.966667),
    'KFFT' => array('name' => 'KY - Frankfort, Capital City Airport', 'lat' => 38.184722, 'long' => -84.903333),
    'KGLW' => array('name' => 'KY - Glasgow, Glasgow Municipal Airport', 'lat' => 37.031667, 'long' => -85.953611),
    'KEHR' => array('name' => 'KY - Henderson City', 'lat' => 37.816667, 'long' => -87.683333),
    'KJKL' => array('name' => 'KY - Jackson, Carroll Airport', 'lat' => 37.591389, 'long' => -83.314444),
    'KLEX' => array('name' => 'KY - Lexington, Blue Grass Airport', 'lat' => 38.040833, 'long' => -84.605833),
    'KLOZ' => array('name' => 'KY - London, London-Corbin Airport-Magee Field', 'lat' => 37.089444, 'long' => -84.068611),
    'KLOU' => array('name' => 'KY - Louisville, Bowman Field Airport', 'lat' => 38.227778, 'long' => -85.663611),
    'KSDF' => array('name' => 'KY - Louisville, Standiford Field', 'lat' => 38.177222, 'long' => -85.729722),
    'K1A6' => array('name' => 'KY - Middlesboro, Middlesboro-Bell County Airport', 'lat' => 36.610556, 'long' => -83.737222),
    'KEKQ' => array('name' => 'KY - Monticello, Wayne County Airport', 'lat' => 36.855278, 'long' => -84.856111),
    'KOWB' => array('name' => 'KY - Owensboro, Owensboro-Daviess County Airport', 'lat' => 37.740000, 'long' => -87.166667),
    'KPAH' => array('name' => 'KY - Paducah, Barkley Regional Airport', 'lat' => 37.056389, 'long' => -88.773889),
    'KSME' => array('name' => 'KY - Somerset, Somerset-Pulaski County - J.T. Wilson Field Airport', 'lat' => 37.054167, 'long' => -84.615000),
    'KESF' => array('name' => 'LA - Alexandria, Alexandria Esler Regional Airport', 'lat' => 31.395000, 'long' => -92.290278),
    'KAEX' => array('name' => 'LA - Alexandria, Alexandria International Airport', 'lat' => 31.334722, 'long' => -92.558611),
    'K7R3' => array('name' => 'LA - Amelia / Lake Palourd', 'lat' => 29.700000, 'long' => -91.100000),
    'KAUD' => array('name' => 'LA - Audubon Park', 'lat' => 29.933333, 'long' => -90.133333),
    'KBAD' => array('name' => 'LA - Barksdale Air Force Base', 'lat' => 32.500000, 'long' => -93.666667),
    'K2F8' => array('name' => 'LA - Bastrop, Morehouse Memorial Airport', 'lat' => 32.755833, 'long' => -91.880556),
    'KBTR' => array('name' => 'LA - Baton Rouge, Baton Rouge Metropolitan, Ryan Field', 'lat' => 30.537222, 'long' => -91.146944),
    'KBVE' => array('name' => 'LA - Boothville', 'lat' => 29.333333, 'long' => -89.400000),
    'K1B7' => array('name' => 'LA - Boothville Heliport', 'lat' => 29.350000, 'long' => -89.433333),
    'KCWF' => array('name' => 'LA - Chenault Airpark', 'lat' => 30.216667, 'long' => -93.150000),
    'KDRI' => array('name' => 'LA - De Ridder, Beauregard Parish Airport', 'lat' => 30.831667, 'long' => -93.339722),
    'K3B6' => array('name' => 'LA - Eugene Island 330', 'lat' => 28.083333, 'long' => -92.700000),
    'KPOE' => array('name' => 'LA - Fort Polk, Polk AAF Ft Polk', 'lat' => 31.050000, 'long' => -93.193889),
    'K9F2' => array('name' => 'LA - Fourchon Supplementary Aviation Weather Reporting Station', 'lat' => 29.100000, 'long' => -90.200000),
    'KBKB' => array('name' => 'LA - Ft. Polk, Fullerton Landing Strip', 'lat' => 31.000000, 'long' => -93.616667),
    'KAQV' => array('name' => 'LA - Ft. Polk, Peason Ridge', 'lat' => 31.666667, 'long' => -93.450000),
    'KDNK' => array('name' => 'LA - Ft. Polk, Self Strip', 'lat' => 31.166667, 'long' => -93.000000),
    'K2GL' => array('name' => 'LA - Galliano, Galliano Heliport', 'lat' => 29.413333, 'long' => -90.298889),
    'KAXO' => array('name' => 'LA - Grand Isle Supplementary Aviation Weather Reporting Station', 'lat' => 29.250000, 'long' => -89.966667),
    'KXCN' => array('name' => 'LA - Green Canyon 184', 'lat' => 27.766667, 'long' => -91.516667),
    'KHDC' => array('name' => 'LA - Hammond, Hammond Municipal Airport', 'lat' => 30.520833, 'long' => -90.417500),
    'KH08' => array('name' => 'LA - High Island 264C', 'lat' => 28.466667, 'long' => -93.733333),
    'KHUM' => array('name' => 'LA - Houma-Terrebonne', 'lat' => 29.566667, 'long' => -90.666667),
    'K7R4' => array('name' => 'LA - Intracoastal City', 'lat' => 29.783333, 'long' => -92.133333),
    'KLFT' => array('name' => 'LA - Lafayette, Lafayette Regional Airport', 'lat' => 30.202222, 'long' => -91.993056),
    'KLCH' => array('name' => 'LA - Lake Charles, Lake Charles Regional Airport', 'lat' => 30.126111, 'long' => -93.223333),
    'KMLU' => array('name' => 'LA - Monroe, Monroe Regional Airport', 'lat' => 32.511667, 'long' => -92.031389),
    'KIER' => array('name' => 'LA - Natchitoches, Natchitoches Regional Airport', 'lat' => 31.735833, 'long' => -93.099167),
    'KARA' => array('name' => 'LA - New Iberia, Acadiana Regional Airport', 'lat' => 30.028889, 'long' => -91.884444),
    'KNBG' => array('name' => 'LA - New Orleans, Naval Air Station - Alvin Callender Field', 'lat' => 29.825278, 'long' => -90.035000),
    'KMSY' => array('name' => 'LA - New Orleans, New Orleans International Airport', 'lat' => 29.992778, 'long' => -90.250833),
    'KNEW' => array('name' => 'LA - New Orleans, New Orleans Lakefront Airport', 'lat' => 30.049444, 'long' => -90.028889),
    'KPTN' => array('name' => 'LA - Patterson Memorial', 'lat' => 29.716667, 'long' => -91.333333),
    'KRSN' => array('name' => 'LA - Ruston, Ruston Regional Airport', 'lat' => 32.514444, 'long' => -92.588333),
    'KP92' => array('name' => 'LA - Salt Point', 'lat' => 29.562222, 'long' => -91.525556),
    'KGSM' => array('name' => 'LA - Ship Shoal 207A', 'lat' => 28.533333, 'long' => -90.983333),
    'KDTN' => array('name' => 'LA - Shreveport, Shreveport Downtown Airport', 'lat' => 32.542500, 'long' => -93.744722),
    'KSHV' => array('name' => 'LA - Shreveport, Shreveport Regional Airport', 'lat' => 32.446944, 'long' => -93.824167),
    'KASD' => array('name' => 'LA - Slidell, Slidell Airport', 'lat' => 30.343056, 'long' => -89.821944),
    'KSRN' => array('name' => 'LA - South Marsh 268A', 'lat' => 29.116667, 'long' => -91.866667),
    'KS58' => array('name' => 'LA - South Timbalier', 'lat' => 28.533333, 'long' => -90.583333),
    'KTVR' => array('name' => 'LA - Vicksburg, Vicksburg / Tallulah Regional Airport', 'lat' => 32.348056, 'long' => -91.030000),
    'KBED' => array('name' => 'MA - Bedford, Hanscom Field', 'lat' => 42.468333, 'long' => -71.294444),
    'KBVY' => array('name' => 'MA - Beverly, Beverly Municipal Airport', 'lat' => 42.583611, 'long' => -70.916389),
    'KBOS' => array('name' => 'MA - Boston, Logan International Airport', 'lat' => 42.360556, 'long' => -71.010556),
    'KCQX' => array('name' => 'MA - Chatham, Chatham Municipal Airport', 'lat' => 41.687500, 'long' => -69.993333),
    'KCEF' => array('name' => 'MA - Chicopee Falls / Westover Air Force Base', 'lat' => 42.200000, 'long' => -72.533333),
    'KMQE' => array('name' => 'MA - East Milton', 'lat' => 42.212222, 'long' => -71.114722),
    'KFIT' => array('name' => 'MA - Fitchburg, Fitchburg Municipal Airport', 'lat' => 42.551944, 'long' => -71.755833),
    'KHYA' => array('name' => 'MA - Hyannis, Barnstable Municipal-Boardman Airport', 'lat' => 41.671944, 'long' => -70.269722),
    'KLWM' => array('name' => 'MA - Lawrence, Lawrence Municipal Airport', 'lat' => 42.713056, 'long' => -71.125833),
    'K3B2' => array('name' => 'MA - Marshfield Airport', 'lat' => 42.100000, 'long' => -70.683333),
    'KACK' => array('name' => 'MA - Nantucket, Nantucket Memorial Airport', 'lat' => 41.253889, 'long' => -70.059722),
    'KEWB' => array('name' => 'MA - New Bedford, New Bedford Regional Airport', 'lat' => 41.675278, 'long' => -70.956944),
    'KAQW' => array('name' => 'MA - North Adams, Harriman-And-West Airport', 'lat' => 42.697222, 'long' => -73.170278),
    'KOWD' => array('name' => 'MA - Norwood, Norwood Memorial Airport', 'lat' => 42.190833, 'long' => -71.173889),
    'KORE' => array('name' => 'MA - Orange, Orange Municipal Airport', 'lat' => 42.571667, 'long' => -72.277500),
    'KFMH' => array('name' => 'MA - Otis Air National Guard Base', 'lat' => 41.650000, 'long' => -70.516667),
    'KPSF' => array('name' => 'MA - Pittsfield, Pittsfield Municipal Airport', 'lat' => 42.427222, 'long' => -73.289167),
    'KPYM' => array('name' => 'MA - Plymouth, Plymouth Municipal Airport', 'lat' => 41.908611, 'long' => -70.728056),
    'KPVC' => array('name' => 'MA - Provincetown, Provincetown Municipal Airport', 'lat' => 42.066667, 'long' => -70.216667),
    'KTAN' => array('name' => 'MA - Taunton, Taunton Municipal Airport', 'lat' => 41.875556, 'long' => -71.021111),
    'KMVY' => array('name' => 'MA - Vineyard Haven, Marthas Vineyard Airport', 'lat' => 41.392222, 'long' => -70.616667),
    'KBAF' => array('name' => 'MA - Westfield, Barnes Municipal Airport', 'lat' => 42.159722, 'long' => -72.712778),
    'KORH' => array('name' => 'MA - Worcester, Worcester Regional Airport', 'lat' => 42.270556, 'long' => -71.873056),
    'KNAK' => array('name' => 'MD - Annapolis, United States Naval Academy', 'lat' => 38.991389, 'long' => -76.483333),
    'KMTN' => array('name' => 'MD - Baltimore / Martin', 'lat' => 39.333333, 'long' => -76.416667),
    'KBWI' => array('name' => 'MD - Baltimore, Baltimore-Washington International Airport', 'lat' => 39.166667, 'long' => -76.683333),
    'KDMH' => array('name' => 'MD - Baltimore, Inner Harbor', 'lat' => 39.283333, 'long' => -76.616667),
    'KADW' => array('name' => 'MD - Camp Springs / Andrews Air Force Base', 'lat' => 38.816667, 'long' => -76.850000),
    'KCBE' => array('name' => 'MD - Cumberland, Greater Cumberland Regional Airport', 'lat' => 39.615278, 'long' => -78.760833),
    'KESN' => array('name' => 'MD - Easton / Newman Field', 'lat' => 38.800000, 'long' => -76.066667),
    'KFME' => array('name' => 'MD - Fort Meade / Tipton', 'lat' => 39.083333, 'long' => -76.766667),
    'KFDK' => array('name' => 'MD - Frederick, Frederick Municipal Airport', 'lat' => 39.417500, 'long' => -77.374444),
    'KHGR' => array('name' => 'MD - Hagerstown, Washington County Regional Airport', 'lat' => 39.705833, 'long' => -77.730000),
    'KOXB' => array('name' => 'MD - Ocean City, Ocean City Municipal Airport', 'lat' => 38.310556, 'long' => -75.123889),
    'KNHK' => array('name' => 'MD - Patuxent River, Naval Air Station', 'lat' => 38.278611, 'long' => -76.413889),
    'KAPG' => array('name' => 'MD - Phillips Army Air Field / Aberdeen', 'lat' => 39.466667, 'long' => -76.166667),
    'KSBY' => array('name' => 'MD - Salisbury, Salisbury-Ocean City Wicomico County Regional Airport', 'lat' => 38.340556, 'long' => -75.510278),
    'KNUI' => array('name' => 'MD - St. Inigoes, Webster Field, Naval Electronic Systems Engineering Activity', 'lat' => 38.148889, 'long' => -76.420000),
    'KLEW' => array('name' => 'ME - Auburn-Lewiston', 'lat' => 44.050000, 'long' => -70.283333),
    'KAUG' => array('name' => 'ME - Augusta, Augusta State Airport', 'lat' => 44.320556, 'long' => -69.797222),
    'KBGR' => array('name' => 'ME - Bangor, Bangor International Airport', 'lat' => 44.797222, 'long' => -68.818611),
    'KBHB' => array('name' => 'ME - Bar Harbor, Hancock County-Bar Harbor Airport', 'lat' => 44.450000, 'long' => -68.366667),
    'KNHZ' => array('name' => 'ME - Brunswick, Naval Air Station', 'lat' => 43.900278, 'long' => -69.935000),
    'KCAR' => array('name' => 'ME - Caribou, Caribou Municipal Airport', 'lat' => 46.867222, 'long' => -68.013333),
    'K40B' => array('name' => 'ME - Clayton Lake', 'lat' => 46.616667, 'long' => -69.533333),
    'KFVE' => array('name' => 'ME - Frenchville, Northern Aroostook Regional Airport', 'lat' => 47.285000, 'long' => -68.307222),
    'KIZG' => array('name' => 'ME - Fryeburg, Eastern Slopes Regional Airport', 'lat' => 43.989167, 'long' => -70.950278),
    'KGNR' => array('name' => 'ME - Greenville', 'lat' => 45.466667, 'long' => -69.583333),
    'KHUL' => array('name' => 'ME - Houlton, Houlton International Airport', 'lat' => 46.123056, 'long' => -67.791944),
    'KMLT' => array('name' => 'ME - Millinocket, Millinocket Municipal Airport', 'lat' => 45.647778, 'long' => -68.691944),
    'KPWM' => array('name' => 'ME - Portland, Portland International Jetport', 'lat' => 43.642222, 'long' => -70.304444),
    'KPQI' => array('name' => 'ME - Presque Isle', 'lat' => 46.683333, 'long' => -68.050000),
    'KRKD' => array('name' => 'ME - Rockland, Knox County Regional Airport', 'lat' => 44.066667, 'long' => -69.100000),
    'KSFM' => array('name' => 'ME - Sanford, Sanford Regional Airport', 'lat' => 43.400000, 'long' => -70.716667),
    'KWVL' => array('name' => 'ME - Waterville, Waterville Robert LaFleur Airport', 'lat' => 44.533333, 'long' => -69.683333),
    'KIWI' => array('name' => 'ME - Wiscasset, Wiscasset Airport', 'lat' => 43.963611, 'long' => -69.711667),
    'KADG' => array('name' => 'MI - Adrian, Lenawee County Airport', 'lat' => 41.867778, 'long' => -84.079444),
    'KAMN' => array('name' => 'MI - Alma, Gratiot Community Airport', 'lat' => 43.321944, 'long' => -84.687778),
    'KAPN' => array('name' => 'MI - Alpena, Alpena County Regional Airport', 'lat' => 45.071667, 'long' => -83.564444),
    'KARB' => array('name' => 'MI - Ann Arbor, Ann Arbor Municipal Airport', 'lat' => 42.223889, 'long' => -83.740000),
    'KBAX' => array('name' => 'MI - Bad Axe, Huron County Memorial Airport', 'lat' => 43.780833, 'long' => -82.985556),
    'KBTL' => array('name' => 'MI - Battle Creek, Kellogg Airport', 'lat' => 42.312500, 'long' => -85.240833),
    'KSJX' => array('name' => 'MI - Beaver Island, Beaver Island Airport', 'lat' => 45.692222, 'long' => -85.566389),
    'KACB' => array('name' => 'MI - Bellaire, Antrim County Airport', 'lat' => 44.988333, 'long' => -85.198333),
    'KBEH' => array('name' => 'MI - Benton Harbor, Southwest Michigan Regional Airport', 'lat' => 42.128611, 'long' => -86.428333),
    'KRQB' => array('name' => 'MI - Big Rapids, Roben-Hood Airport', 'lat' => 43.722500, 'long' => -85.504167),
    'KCAD' => array('name' => 'MI - Cadillac / Wexford County', 'lat' => 44.283333, 'long' => -85.416667),
    'KCFS' => array('name' => 'MI - Caro, Tuscola Area Airport', 'lat' => 43.458611, 'long' => -83.445278),
    'KCVX' => array('name' => 'MI - Charlevoix, Charlevoix Municipal Airport', 'lat' => 45.304722, 'long' => -85.274722),
    'KFPK' => array('name' => 'MI - Charlotte, Fitch H Beach Airport', 'lat' => 42.574444, 'long' => -84.811389),
    'KOEB' => array('name' => 'MI - Coldwater, Branch County Memorial Airport', 'lat' => 41.933333, 'long' => -85.052500),
    'KP59' => array('name' => 'MI - Copper Harbor', 'lat' => 47.466944, 'long' => -87.875000),
    'KDET' => array('name' => 'MI - Detroit, Detroit City Airport', 'lat' => 42.409167, 'long' => -83.010000),
    'KDTW' => array('name' => 'MI - Detroit, Detroit Metropolitan Wayne County Airport', 'lat' => 42.231389, 'long' => -83.330833),
    'KYIP' => array('name' => 'MI - Detroit, Willow Run Airport', 'lat' => 42.236667, 'long' => -83.526111),
    'KONZ' => array('name' => 'MI - Detroit/Grosse Ile, Grosse Ile Airport', 'lat' => 42.098611, 'long' => -83.161111),
    'KESC' => array('name' => 'MI - Escanaba', 'lat' => 45.750000, 'long' => -87.033333),
    'KFNT' => array('name' => 'MI - Flint, Bishop International Airport', 'lat' => 42.966667, 'long' => -83.749444),
    'KFKS' => array('name' => 'MI - Frankfort, Frankfort Dow Memorial Field Airport', 'lat' => 44.625000, 'long' => -86.200556),
    'KGLR' => array('name' => 'MI - Gaylord, Otsego County Airport', 'lat' => 45.016389, 'long' => -84.688889),
    'KGRR' => array('name' => 'MI - Grand Rapids, Gerald R. Ford International Airport', 'lat' => 42.880833, 'long' => -85.522778),
    'KGOV' => array('name' => 'MI - Grayling, Grayling Army Airfield', 'lat' => 44.680278, 'long' => -84.728889),
    'KCMX' => array('name' => 'MI - Hancock, Houghton County Memorial Airport', 'lat' => 47.168333, 'long' => -88.488889),
    'KMGN' => array('name' => 'MI - Harbor Springs, Harbor Springs Airport', 'lat' => 45.425556, 'long' => -84.913333),
    'KJYM' => array('name' => 'MI - Hillsdale, Hillsdale Municipal Airport', 'lat' => 41.921389, 'long' => -84.585833),
    'KBIV' => array('name' => 'MI - Holland, Tulip City Airport', 'lat' => 42.746111, 'long' => -86.096667),
    'KHTL' => array('name' => 'MI - Houghton Lake, Roscommon County Airport', 'lat' => 44.351111, 'long' => -84.674167),
    'KOZW' => array('name' => 'MI - Howell, Livingston County Airport', 'lat' => 42.629444, 'long' => -83.984167),
    'KIMT' => array('name' => 'MI - Iron Mountain / Kingsford, Ford Airport', 'lat' => 45.814167, 'long' => -88.108889),
    'KIWD' => array('name' => 'MI - Ironwood, Gogebic-Iron County Airport', 'lat' => 46.533333, 'long' => -90.133333),
    'KJXN' => array('name' => 'MI - Jackson, Jackson County-Reynolds Field Airport', 'lat' => 42.259722, 'long' => -84.459444),
    'KAZO' => array('name' => 'MI - Kalamazoo, Kalamazoo / Battle Creek International Airport', 'lat' => 42.229167, 'long' => -85.546389),
    'KDUH' => array('name' => 'MI - Lambertville, Toledo Suburban Airport', 'lat' => 41.735833, 'long' => -83.655278),
    'KLAN' => array('name' => 'MI - Lansing, Capital City Airport', 'lat' => 42.780278, 'long' => -84.578889),
    'KLDM' => array('name' => 'MI - Ludington, Mason County Airport', 'lat' => 43.966667, 'long' => -86.400000),
    'KMCD' => array('name' => 'MI - Macinac Island, Mackinac Island Airport', 'lat' => 45.865000, 'long' => -84.637222),
    'KMBL' => array('name' => 'MI - Manistee, Manistee County-Blacker Airport', 'lat' => 44.266667, 'long' => -86.250000),
    'KISQ' => array('name' => 'MI - Manistique, Schoolcraft County Airport', 'lat' => 45.974722, 'long' => -86.171944),
    'KSAW' => array('name' => 'MI - Marquette, Sawyer International Airport', 'lat' => 46.353611, 'long' => -87.395278),
    'KRMY' => array('name' => 'MI - Marshall, Brooks Field Airport', 'lat' => 42.251111, 'long' => -84.955556),
    'KTEW' => array('name' => 'MI - Mason, Mason Jewett Field Airport', 'lat' => 42.565833, 'long' => -84.423333),
    'KMNM' => array('name' => 'MI - Menominee, Menominee-Marinette Twin County Airport', 'lat' => 45.133333, 'long' => -87.633333),
    'KTTF' => array('name' => 'MI - Monroe, Custer Airport', 'lat' => 41.940000, 'long' => -83.434722),
    'KMOP' => array('name' => 'MI - Mount Pleasant, Mount Pleasant Municipal Airport', 'lat' => 43.616667, 'long' => -84.733333),
    'KP53' => array('name' => 'MI - Munising, Munising Lakeshore Observation', 'lat' => 46.411667, 'long' => -86.650833),
    'KMKG' => array('name' => 'MI - Muskegon, Muskegon County Airport', 'lat' => 43.171111, 'long' => -86.236667),
    'KERY' => array('name' => 'MI - Newberry, Luce County Airport', 'lat' => 46.311111, 'long' => -85.457222),
    'KOSC' => array('name' => 'MI - Oscoda, Oscoda-Wurtsmith Airport', 'lat' => 44.450000, 'long' => -83.366667),
    'KRNP' => array('name' => 'MI - Owosso, Owosso Community Airport', 'lat' => 42.992778, 'long' => -84.138889),
    'KPLN' => array('name' => 'MI - Pellston, Pellston Regional Airport of Emmet County Airport', 'lat' => 45.570833, 'long' => -84.796667),
    'KPTK' => array('name' => 'MI - Pontiac, Oakland County International Airport', 'lat' => 42.663056, 'long' => -83.410000),
    'KP58' => array('name' => 'MI - Port Hope', 'lat' => 44.021944, 'long' => -82.793056),
    'KPZQ' => array('name' => 'MI - Rogers City, Presque Isle County Airport', 'lat' => 45.406944, 'long' => -83.812778),
    'KMBS' => array('name' => 'MI - Saginaw, MBS International Airport', 'lat' => 43.532778, 'long' => -84.079444),
    'KHYX' => array('name' => 'MI - Saginaw, Saginaw County H.W. Browne Airport', 'lat' => 43.433333, 'long' => -83.862500),
    'KCIU' => array('name' => 'MI - Sault Ste Marie, Chippewa County International Airport', 'lat' => 46.250000, 'long' => -84.466667),
    'KANJ' => array('name' => 'MI - Sault Ste. Marie', 'lat' => 46.479444, 'long' => -84.357222),
    'KMTC' => array('name' => 'MI - Selfridge Air National Guard Base', 'lat' => 42.616667, 'long' => -82.833333),
    'KLWA' => array('name' => 'MI - South Haven, South Haven Area Regional Airport', 'lat' => 42.350833, 'long' => -86.256111),
    'KPHN' => array('name' => 'MI - St. Clair County International', 'lat' => 42.916667, 'long' => -82.533333),
    'KIRS' => array('name' => 'MI - Sturgis, Kirsch Municipal Airport', 'lat' => 41.812778, 'long' => -85.439167),
    'KTVC' => array('name' => 'MI - Traverse City, Cherry Capital Airport', 'lat' => 44.736667, 'long' => -85.570000),
    'KVLL' => array('name' => 'MI - Troy, Oakland/Troy Airport', 'lat' => 42.542778, 'long' => -83.177778),
    'KAIT' => array('name' => 'MN - Aitkin, Aitkin Municipal Airport-Steve Kurtz Field', 'lat' => 46.550000, 'long' => -93.683333),
    'KAEL' => array('name' => 'MN - Albert Lea, Albert Lea Municipal Airport', 'lat' => 43.683333, 'long' => -93.366667),
    'KAXN' => array('name' => 'MN - Alexandria, Chandler Field', 'lat' => 45.868611, 'long' => -95.394167),
    'KAQP' => array('name' => 'MN - Appleton, Appleton Municipal Airport', 'lat' => 45.227500, 'long' => -96.004167),
    'KAUM' => array('name' => 'MN - Austin Municipal', 'lat' => 43.666667, 'long' => -92.933333),
    'KBDE' => array('name' => 'MN - Baudette, Baudette International Airport', 'lat' => 48.726667, 'long' => -94.612222),
    'KBJI' => array('name' => 'MN - Bemidji', 'lat' => 47.500000, 'long' => -94.933333),
    'KBBB' => array('name' => 'MN - Benson Municipal', 'lat' => 45.316667, 'long' => -95.650000),
    'KFOZ' => array('name' => 'MN - Bigfork, Bigfork Municipal Airport', 'lat' => 47.782778, 'long' => -93.650278),
    'KBRD' => array('name' => 'MN - Brainerd, Brainerd-Crow Wing County Regional Airport', 'lat' => 46.404722, 'long' => -94.130833),
    'KCFE' => array('name' => 'MN - Buffalo, Buffalo Municipal Airport', 'lat' => 45.158889, 'long' => -93.843056),
    'KCBG' => array('name' => 'MN - Cambridge Municipal', 'lat' => 45.566667, 'long' => -93.266667),
    'KCOQ' => array('name' => 'MN - Cloquet, Cloquet Carlton County Airport', 'lat' => 46.700000, 'long' => -92.500000),
    'KCQM' => array('name' => 'MN - Cook, Cook Municipal Airport', 'lat' => 47.821944, 'long' => -92.689444),
    'KCDD' => array('name' => 'MN - Crane Lake, Scotts Seaplane Base', 'lat' => 48.266389, 'long' => -92.483611),
    'KCKN' => array('name' => 'MN - Crookston Municipal Field', 'lat' => 47.850000, 'long' => -96.616667),
    'KDTL' => array('name' => 'MN - Detroit Lakes, Detroit Lakes Airport-Wething Field', 'lat' => 46.833333, 'long' => -95.883333),
    'KTOB' => array('name' => 'MN - Dodge Center, Dodge Center Airport', 'lat' => 44.018056, 'long' => -92.831389),
    'KDLH' => array('name' => 'MN - Duluth, Duluth International Airport', 'lat' => 46.842778, 'long' => -92.226111),
    'KDYT' => array('name' => 'MN - Duluth, Sky Harbor Airport', 'lat' => 46.721944, 'long' => -92.043333),
    'KELO' => array('name' => 'MN - Ely, Ely Municipal Airport', 'lat' => 47.816667, 'long' => -91.833333),
    'KEVM' => array('name' => 'MN - Eveleth, Eveleth-Virginia Municipal Airport', 'lat' => 47.416667, 'long' => -92.500000),
    'KFRM' => array('name' => 'MN - Fairmont, Fairmont Municipal Airport', 'lat' => 43.650000, 'long' => -94.416667),
    'KFBL' => array('name' => 'MN - Faribault, Faribault Municipal Airport', 'lat' => 44.333333, 'long' => -93.316667),
    'KFFM' => array('name' => 'MN - Fergus Falls, Fergus Falls Municipal Airport-Einar Mickelson Field', 'lat' => 46.283333, 'long' => -96.150000),
    'KFGN' => array('name' => 'MN - Flag Island', 'lat' => 49.316667, 'long' => -94.900000),
    'KFSE' => array('name' => 'MN - Fosston, Fosston Municipal Airport', 'lat' => 47.592778, 'long' => -95.773333),
    'KGYL' => array('name' => 'MN - Glencoe, Glencoe Municipal Airport', 'lat' => 44.756111, 'long' => -94.081111),
    'KGHW' => array('name' => 'MN - Glenwood, Glenwood Municipal Airport', 'lat' => 45.650000, 'long' => -95.316667),
    'KCKC' => array('name' => 'MN - Grand Marais, Grand Marais/Cook County Airport', 'lat' => 47.838333, 'long' => -90.383056),
    'KGNA' => array('name' => 'MN - Grand Marais, The Bay of Grand Marais', 'lat' => 47.833333, 'long' => -90.383333),
    'KGPZ' => array('name' => 'MN - Grand Rapids, Grand Rapids/Itasca County Airport-Gordon Newstrom Field', 'lat' => 47.216667, 'long' => -93.516667),
    'KGDB' => array('name' => 'MN - Granite Falls, Granite Falls Municipal Airport/Lenzen-Roe Memorial Field', 'lat' => 44.753056, 'long' => -95.555833),
    'KHCO' => array('name' => 'MN - Hallock, Hallock Municipal Airport', 'lat' => 48.752778, 'long' => -96.943056),
    'KHIB' => array('name' => 'MN - Hibbing, Chisholm-Hibbing Airport', 'lat' => 47.386667, 'long' => -92.838889),
    'KHCD' => array('name' => 'MN - Hutchinson, Hutchinson Municipal Airport-Butler Field', 'lat' => 44.866667, 'long' => -94.383333),
    'KINL' => array('name' => 'MN - International Falls, Falls International Airport', 'lat' => 48.561944, 'long' => -93.397778),
    'KMJQ' => array('name' => 'MN - Jackson, Jackson Municipal Airport', 'lat' => 43.650000, 'long' => -94.983333),
    'KLJF' => array('name' => 'MN - Litchfield, Litchfield Municipal Airport', 'lat' => 45.097222, 'long' => -94.507222),
    'KLXL' => array('name' => 'MN - Little Falls, Little Falls/Morrison County Airport-Lindbergh Field', 'lat' => 45.950000, 'long' => -94.350000),
    'KXVG' => array('name' => 'MN - Longville, Longville Municipal Airport', 'lat' => 46.990278, 'long' => -94.203889),
    'KLYV' => array('name' => 'MN - Luverne, Quentin Aanenson Field Airport', 'lat' => 43.621111, 'long' => -96.215556),
    'KDXX' => array('name' => 'MN - Madison, Madison-Lac Qui Parle County Airport', 'lat' => 44.986111, 'long' => -96.177778),
    'KMKT' => array('name' => 'MN - Mankato, Mankato Regional Airport', 'lat' => 44.216667, 'long' => -93.916667),
    'KMGG' => array('name' => 'MN - Maple Lake, Maple Lake Municipal Airport', 'lat' => 45.236111, 'long' => -93.985556),
    'KMML' => array('name' => 'MN - Marshall, Southwest Minnesota Regional Airport - Marshall/Ryan Field', 'lat' => 44.450000, 'long' => -95.816667),
    'KHZX' => array('name' => 'MN - Mc Gregor, Isedor Iverson Airport', 'lat' => 46.618611, 'long' => -93.309722),
    'KANE' => array('name' => 'MN - Minneapolis / Blaine', 'lat' => 45.150000, 'long' => -93.216667),
    'KLVN' => array('name' => 'MN - Minneapolis, Airlake Airport', 'lat' => 44.627778, 'long' => -93.228056),
    'KMIC' => array('name' => 'MN - Minneapolis, Crystal Airport', 'lat' => 45.062500, 'long' => -93.350833),
    'KFCM' => array('name' => 'MN - Minneapolis, Flying Cloud Airport', 'lat' => 44.832222, 'long' => -93.470278),
    'KMSP' => array('name' => 'MN - Minneapolis, Minneapolis-St. Paul International Airport', 'lat' => 44.883056, 'long' => -93.228889),
    'KMVE' => array('name' => 'MN - Montevideo, Montevideo-Chippewa County Airport', 'lat' => 44.966667, 'long' => -95.716667),
    'KJKJ' => array('name' => 'MN - Moorhead, Moorhead Municipal Airport', 'lat' => 46.839167, 'long' => -96.663056),
    'KMZH' => array('name' => 'MN - Moose Lake, Moose Lake Carlton County Airport', 'lat' => 46.416667, 'long' => -92.800000),
    'KJMR' => array('name' => 'MN - Mora, Mora Municipal Airport', 'lat' => 45.886111, 'long' => -93.271667),
    'KMOX' => array('name' => 'MN - Morris, Morris Municipal Airport', 'lat' => 45.566667, 'long' => -95.966667),
    'KULM' => array('name' => 'MN - New Ulm, New Ulm Municipal Airport', 'lat' => 44.316667, 'long' => -94.500000),
    'KORB' => array('name' => 'MN - Orr', 'lat' => 48.016667, 'long' => -92.866667),
    'KVVV' => array('name' => 'MN - Ortonville, Ortonville Muncipal-Martinson Field Airport', 'lat' => 45.305556, 'long' => -96.424444),
    'KOWA' => array('name' => 'MN - Owatonna, Owatonna Degner Regional Airport', 'lat' => 44.116667, 'long' => -93.250000),
    'KPKD' => array('name' => 'MN - Park Rapids, Park Rapids Municipal Airport', 'lat' => 46.900556, 'long' => -95.067778),
    'KPEX' => array('name' => 'MN - Paynesville, Paynesville Municipal Airport', 'lat' => 45.372222, 'long' => -94.746389),
    'KPWC' => array('name' => 'MN - Pine River, Pine River Regional Airport', 'lat' => 46.725000, 'long' => -94.383611),
    'KPQN' => array('name' => 'MN - Pipestone, Pipestone Municipal Airport', 'lat' => 43.983333, 'long' => -96.316667),
    'KFKA' => array('name' => 'MN - Preston, Fillmore County Airport', 'lat' => 43.676667, 'long' => -92.179722),
    'KPNM' => array('name' => 'MN - Princeton', 'lat' => 45.550000, 'long' => -93.600000),
    'KRGK' => array('name' => 'MN - Red Wing, Red Wing Municipal Airport', 'lat' => 44.590278, 'long' => -92.486111),
    'KRWF' => array('name' => 'MN - Redwood Falls, Redwood Falls Municipal Airport', 'lat' => 44.547222, 'long' => -95.082222),
    'KRST' => array('name' => 'MN - Rochester, Rochester International Airport', 'lat' => 43.904167, 'long' => -92.491667),
    'KROX' => array('name' => 'MN - Roseau, Roseau Municipal Airport/Rudy Billberg Field', 'lat' => 48.850000, 'long' => -95.700000),
    'KROS' => array('name' => 'MN - Rush City, Rush City Regional Airport', 'lat' => 45.698056, 'long' => -92.953056),
    'KBFW' => array('name' => 'MN - Silver Bay', 'lat' => 47.200000, 'long' => -91.400000),
    'KDVP' => array('name' => 'MN - Slayton, Slayton Municipal Airport', 'lat' => 43.986667, 'long' => -95.782500),
    'KSGS' => array('name' => 'MN - South St. Paul, South St. Paul Municipal-Richard E. Fleming Field Airport', 'lat' => 44.857222, 'long' => -93.032778),
    'KSTC' => array('name' => 'MN - St Cloud, St Cloud Regional Airport', 'lat' => 45.546389, 'long' => -94.059722),
    'KJYG' => array('name' => 'MN - St. James, St. James Municipal Airport', 'lat' => 43.986389, 'long' => -94.558056),
    'KSTP' => array('name' => 'MN - St. Paul, St. Paul Downtown Holman Field', 'lat' => 44.930278, 'long' => -93.048056),
    'KSYN' => array('name' => 'MN - Stanton, Stanton Airfield', 'lat' => 44.475278, 'long' => -93.016111),
    'KSAZ' => array('name' => 'MN - Staples, Staples Municipal Airport', 'lat' => 46.380833, 'long' => -94.806667),
    'KTVF' => array('name' => 'MN - Thief River Falls, Thief River Falls Regional Airport', 'lat' => 48.066667, 'long' => -96.183333),
    'KTWM' => array('name' => 'MN - Two Harbors', 'lat' => 47.050000, 'long' => -91.750000),
    'KADC' => array('name' => 'MN - Wadena, Wadena Municipal Airport', 'lat' => 46.450278, 'long' => -95.210833),
    'KRRT' => array('name' => 'MN - Warroad, Warroad International Airport-Swede Carlson Field', 'lat' => 48.941389, 'long' => -95.348333),
    'KACQ' => array('name' => 'MN - Waseca, Waseca Municipal Airport', 'lat' => 44.073333, 'long' => -93.553056),
    'KVWU' => array('name' => 'MN - Waskish, Waskish Municipal Airport', 'lat' => 48.154167, 'long' => -94.516944),
    'KETH' => array('name' => 'MN - Wheaton, Wheaton Municipal Airport', 'lat' => 45.766667, 'long' => -96.533333),
    'KILL' => array('name' => 'MN - Willmar, Willmar Municipal Airport-John L Rice Field', 'lat' => 45.116667, 'long' => -95.083333),
    'KMWM' => array('name' => 'MN - Windom, Windom Municipal Airport', 'lat' => 43.913333, 'long' => -95.109444),
    'KONA' => array('name' => 'MN - Winona, Winona Municipal Airport-Max Conrad Field', 'lat' => 44.083333, 'long' => -91.700000),
    'KOTG' => array('name' => 'MN - Worthington, Worthington Municipal Airport', 'lat' => 43.650000, 'long' => -95.583333),
    'KCGI' => array('name' => 'MO - Cape Girardeau, Cape Girardeau Regional Airport', 'lat' => 37.225556, 'long' => -89.578333),
    'KCDJ' => array('name' => 'MO - Chillicothe, Chillicothe Agri-Science Center', 'lat' => 39.816667, 'long' => -93.583333),
    'KCOU' => array('name' => 'MO - Columbia, Columbia Regional Airport', 'lat' => 38.816944, 'long' => -92.218333),
    'KFAM' => array('name' => 'MO - Farmington Airport', 'lat' => 37.766667, 'long' => -90.433333),
    'KTBN' => array('name' => 'MO - Fort Leonard Wood', 'lat' => 37.733333, 'long' => -92.133333),
    'KJEF' => array('name' => 'MO - Jefferson City, Jefferson City Memorial Airport', 'lat' => 38.594444, 'long' => -92.155833),
    'KJLN' => array('name' => 'MO - Joplin, Joplin Regional Airport', 'lat' => 37.156111, 'long' => -94.500556),
    'KAIZ' => array('name' => 'MO - Kaiser Lake Ozark, Lee C Fine Memorial Airport', 'lat' => 38.100000, 'long' => -92.550000),
    'KMKC' => array('name' => 'MO - Kansas City, Kansas City Downtown Airport', 'lat' => 39.120833, 'long' => -94.596944),
    'KMCI' => array('name' => 'MO - Kansas City, Kansas City International Airport', 'lat' => 39.297222, 'long' => -94.730556),
    'KIRK' => array('name' => 'MO - Kirksville, Kirksville Regional Airport', 'lat' => 40.097222, 'long' => -92.543333),
    'KLXT' => array('name' => 'MO - Lee\'s Summit, Lee\'s Summit Municipal Airport', 'lat' => 38.959722, 'long' => -94.371667),
    'KPOF' => array('name' => 'MO - Poplar Bluff, Poplar Bluff Municipal Airport', 'lat' => 36.770556, 'long' => -90.322222),
    'KVIH' => array('name' => 'MO - Rolla / Vichy, Rolla National Airport', 'lat' => 38.131944, 'long' => -91.765278),
    'KDMO' => array('name' => 'MO - Sedalia, Sedalia Memorial Airport', 'lat' => 38.712222, 'long' => -93.174444),
    'KSGF' => array('name' => 'MO - Springfield, Springfield Regional Airport', 'lat' => 37.239722, 'long' => -93.389722),
    'KSET' => array('name' => 'MO - St. Charles, St. Charles County Smartt Airport', 'lat' => 38.930556, 'long' => -90.432500),
    'KSTJ' => array('name' => 'MO - St. Joseph, Rosecrans Memorial Airport', 'lat' => 39.768056, 'long' => -94.909167),
    'KSTL' => array('name' => 'MO - St. Louis, Lambert-St. Louis International Airport', 'lat' => 38.752500, 'long' => -90.373611),
    'KSUS' => array('name' => 'MO - St. Louis, Spirit Of St. Louis Airport', 'lat' => 38.657222, 'long' => -90.655833),
    'KUNO' => array('name' => 'MO - West Plains, West Plains Municipal Airport', 'lat' => 36.879167, 'long' => -91.905000),
    'KSZL' => array('name' => 'MO - Whiteman Air Force Base', 'lat' => 38.733333, 'long' => -93.550000),
    'KCBM' => array('name' => 'MS - Columbus Air Force Base', 'lat' => 33.650000, 'long' => -88.450000),
    'KGTR' => array('name' => 'MS - Columbus/West Point/Starkville, Golden Triangle Regional Airport', 'lat' => 33.450000, 'long' => -88.583333),
    'KGLH' => array('name' => 'MS - Greenville, Mid Delta Regional Airport', 'lat' => 33.482778, 'long' => -90.985556),
    'KGWO' => array('name' => 'MS - Greenwood, Greenwood-LeFlore Airport', 'lat' => 33.492500, 'long' => -90.083611),
    'KGPT' => array('name' => 'MS - Gulfport, Gulfport-Biloxi Regional Airport', 'lat' => 30.411944, 'long' => -89.080833),
    'KHBG' => array('name' => 'MS - Hattiesburg, Bobby L Chain Municipal Airport', 'lat' => 31.265000, 'long' => -89.253056),
    'KPIB' => array('name' => 'MS - Hattiesburg/Laurel, Hattiesburg-Laurel Regional Airport', 'lat' => 31.466667, 'long' => -89.333333),
    'KHKS' => array('name' => 'MS - Jackson, Hawkins Field Airport', 'lat' => 32.334722, 'long' => -90.222500),
    'KJAN' => array('name' => 'MS - Jackson, Jackson International Airport', 'lat' => 32.319722, 'long' => -90.077500),
    'KBIX' => array('name' => 'MS - Keesler Air Force Base / Biloxi', 'lat' => 30.416667, 'long' => -88.916667),
    'KMCB' => array('name' => 'MS - McComb, McComb / Pike County / John E Lewis Field Airport', 'lat' => 31.178333, 'long' => -90.471944),
    'KMEI' => array('name' => 'MS - Meridian, Key Field', 'lat' => 32.338056, 'long' => -88.747778),
    'KNMM' => array('name' => 'MS - Meridian, Meridian Naval Air Station - McCain Field', 'lat' => 32.551944, 'long' => -88.555278),
    'KHEZ' => array('name' => 'MS - Natchez, Hardy-Anders Field Natchez-Adams County Airport', 'lat' => 31.616667, 'long' => -91.300000),
    'KOLV' => array('name' => 'MS - Olive Branch, Olive Branch Airport', 'lat' => 34.978889, 'long' => -89.786944),
    'KPQL' => array('name' => 'MS - Pascagoula, Lott International Airport', 'lat' => 30.463611, 'long' => -88.531944),
    'KUTA' => array('name' => 'MS - Tunica, Tunica Municipal Airport', 'lat' => 34.680833, 'long' => -90.346389),
    'KTUP' => array('name' => 'MS - Tupelo, Tupelo Regional Airport', 'lat' => 34.268056, 'long' => -88.770000),
    'KBHK' => array('name' => 'MT - Baker, Baker Municipal Airport', 'lat' => 46.347778, 'long' => -104.257500),
    'KBIL' => array('name' => 'MT - Billings, Billings Logan International Airport', 'lat' => 45.806944, 'long' => -108.542222),
    'KBZN' => array('name' => 'MT - Bozeman, Gallatin Field', 'lat' => 45.788056, 'long' => -111.160833),
    'K8S0' => array('name' => 'MT - Browning, Starr-Browning Airstrip', 'lat' => 48.601111, 'long' => -113.114722),
    'KBTM' => array('name' => 'MT - Butte, Bert Mooney Airport', 'lat' => 45.954722, 'long' => -112.497500),
    'KCTB' => array('name' => 'MT - Cut Bank, Cut Bank Municipal Airport', 'lat' => 48.608333, 'long' => -112.376111),
    'KDLN' => array('name' => 'MT - Dillon, Dillon Airport', 'lat' => 45.257500, 'long' => -112.554444),
    'K3DU' => array('name' => 'MT - Drummond', 'lat' => 46.666667, 'long' => -113.150000),
    'KGGW' => array('name' => 'MT - Glasgow, Glasgow International Airport', 'lat' => 48.213889, 'long' => -106.621389),
    'KGDV' => array('name' => 'MT - Glendive, Dawson Community Airport', 'lat' => 47.133333, 'long' => -104.800000),
    'KGTF' => array('name' => 'MT - Great Falls, Great Falls International Airport', 'lat' => 47.473333, 'long' => -111.382222),
    'KHVR' => array('name' => 'MT - Havre, Havre City-County Airport', 'lat' => 48.542778, 'long' => -109.763333),
    'KHLN' => array('name' => 'MT - Helena, Helena Regional Airport', 'lat' => 46.605556, 'long' => -111.963611),
    'KJDN' => array('name' => 'MT - Jordan, Jordan Airport', 'lat' => 47.325833, 'long' => -106.947500),
    'KGPI' => array('name' => 'MT - Kalispell, Glacier Park International Airport', 'lat' => 48.304167, 'long' => -114.263611),
    'KLWT' => array('name' => 'MT - Lewistown, Lewistown Municipal Airport', 'lat' => 47.049167, 'long' => -109.466389),
    'KLVM' => array('name' => 'MT - Livingston, Mission Field Airport', 'lat' => 45.699444, 'long' => -110.448333),
    'KGFA' => array('name' => 'MT - Malmstrom Air Force Base', 'lat' => 47.500000, 'long' => -111.183333),
    'KMLS' => array('name' => 'MT - Miles City, Frank Wiley Field Airport', 'lat' => 46.428056, 'long' => -105.886389),
    'KMSO' => array('name' => 'MT - Missoula, Missoula International Airport', 'lat' => 46.920833, 'long' => -114.092500),
    'KSDY' => array('name' => 'MT - Sidney-Richland', 'lat' => 47.700000, 'long' => -104.200000),
    'KWYS' => array('name' => 'MT - West Yellowstone', 'lat' => 44.683333, 'long' => -111.116667),
    'KOLF' => array('name' => 'MT - Wolf Point, Clayton Airport', 'lat' => 48.094444, 'long' => -105.577222),
    'KASJ' => array('name' => 'NC - Ahoskie, Tri-County Airport', 'lat' => 36.297500, 'long' => -77.170833),
    'KVUJ' => array('name' => 'NC - Albemarle, Stanly County Airport', 'lat' => 35.416667, 'long' => -80.150833),
    'KRHP' => array('name' => 'NC - Andrews, Andrews-Murphy Airport', 'lat' => 35.195000, 'long' => -83.863611),
    'KAVL' => array('name' => 'NC - Asheville, Asheville Regional Airport', 'lat' => 35.431944, 'long' => -82.537500),
    'KMRH' => array('name' => 'NC - Beaufort, Michael J Smith Field Airport', 'lat' => 34.733611, 'long' => -76.660556),
    'KTNB' => array('name' => 'NC - Boone, Watauga County Hospital Heliport', 'lat' => 36.200000, 'long' => -81.650000),
    'KBUY' => array('name' => 'NC - Burlington, Burlington Alamance Regional Airport', 'lat' => 36.047778, 'long' => -79.473889),
    'KIGX' => array('name' => 'NC - Chapel Hill, Williams Airport', 'lat' => 35.766667, 'long' => -79.064167),
    'KCLT' => array('name' => 'NC - Charlotte, Charlotte / Douglas International Airport', 'lat' => 35.213333, 'long' => -80.948611),
    'KNKT' => array('name' => 'NC - Cherry Point, Marine Corps Air Station', 'lat' => 34.897778, 'long' => -76.880833),
    'KCTZ' => array('name' => 'NC - Clinton, Sampson County Airport', 'lat' => 34.975556, 'long' => -78.364722),
    'KJQF' => array('name' => 'NC - Concord, Concord Regional Airport', 'lat' => 35.385278, 'long' => -80.709722),
    'KONX' => array('name' => 'NC - Currituck, Currituck County Airport', 'lat' => 36.398889, 'long' => -76.016111),
    'KEDE' => array('name' => 'NC - Edenton, Northeastern Regional Airport', 'lat' => 36.027778, 'long' => -76.567222),
    'KECG' => array('name' => 'NC - Elizabeth City, Elizabeth City Coast Guard Air Station', 'lat' => 36.263056, 'long' => -76.182778),
    'KEYF' => array('name' => 'NC - Elizabethtown, Curtis L Brown Jr. Field Airport', 'lat' => 34.600000, 'long' => -78.583333),
    'KHRJ' => array('name' => 'NC - Erwin, Harnett County Airport', 'lat' => 35.378611, 'long' => -78.733611),
    'KFAY' => array('name' => 'NC - Fayetteville, Fayetteville Regional Airport', 'lat' => 34.989444, 'long' => -78.880000),
    'KFBG' => array('name' => 'NC - Fort Bragg / Simmons Army Airfield', 'lat' => 35.133333, 'long' => -78.933333),
    'K1A5' => array('name' => 'NC - Franklin, Macon County Airport', 'lat' => 35.216667, 'long' => -83.416667),
    'KAKH' => array('name' => 'NC - Gastonia, Gastonia Municipal Airport', 'lat' => 35.196667, 'long' => -81.155833),
    'KGWW' => array('name' => 'NC - Goldsboro, Goldsboro-Wayne Municipal Airport', 'lat' => 35.460556, 'long' => -77.965000),
    'KGSO' => array('name' => 'NC - Greensboro, Piedmont Triad International Airport', 'lat' => 36.097500, 'long' => -79.943611),
    'KHSE' => array('name' => 'NC - Hatteras, Mitchell Field', 'lat' => 35.232222, 'long' => -75.622500),
    'KHKY' => array('name' => 'NC - Hickory, Hickory Regional Airport', 'lat' => 35.742222, 'long' => -81.382222),
    'KOAJ' => array('name' => 'NC - Jacksonville, Albert J Ellis Airport', 'lat' => 34.833333, 'long' => -77.616667),
    'KNCA' => array('name' => 'NC - Jacksonville, New River, Marine Corps Air Station', 'lat' => 34.705833, 'long' => -77.440833),
    'KGEV' => array('name' => 'NC - Jefferson, Ashe County Airport', 'lat' => 36.433333, 'long' => -81.416667),
    'KDPL' => array('name' => 'NC - Kenansville, Duplin County Airport', 'lat' => 35.000000, 'long' => -77.981667),
    'KFFA' => array('name' => 'NC - Kill Devil Hills, First Flight Airport', 'lat' => 36.016667, 'long' => -75.666667),
    'KISO' => array('name' => 'NC - Kinston, Kinston Regional Jetport at Stallings Field', 'lat' => 35.333333, 'long' => -77.616667),
    'KEXX' => array('name' => 'NC - Lexington, Davidson County Airport', 'lat' => 35.781111, 'long' => -80.303889),
    'KIPJ' => array('name' => 'NC - Lincolnton, Lincolnton-Lincoln County Regional Airport', 'lat' => 35.483056, 'long' => -81.161389),
    'KLHZ' => array('name' => 'NC - Louisburg, Franklin County Airport', 'lat' => 36.023333, 'long' => -78.330278),
    'KLBT' => array('name' => 'NC - Lumberton, Lumberton Municipal Airport', 'lat' => 34.607222, 'long' => -79.060000),
    'KHFF' => array('name' => 'NC - Mackall U. S. Army Airfield', 'lat' => 35.033333, 'long' => -79.500000),
    'KMQI' => array('name' => 'NC - Manteo / Dare County Regional', 'lat' => 35.916667, 'long' => -75.700000),
    'KMEB' => array('name' => 'NC - Maxton, Laurinburg-Maxton Airport', 'lat' => 34.791389, 'long' => -79.368056),
    'KEQY' => array('name' => 'NC - Monroe, Monroe Airport', 'lat' => 35.016944, 'long' => -80.620556),
    'KMRN' => array('name' => 'NC - Morganton, Morganton-Lenoir Airport', 'lat' => 35.821389, 'long' => -81.610833),
    'KMWK' => array('name' => 'NC - Mount Airy, Mount Airy/Surry County Airport', 'lat' => 36.459722, 'long' => -80.553056),
    'KEWN' => array('name' => 'NC - New Bern, Craven County Regional Airport', 'lat' => 35.067500, 'long' => -77.047222),
    'KUKF' => array('name' => 'NC - North Wilkesboro, Wilkes County Airport', 'lat' => 36.216667, 'long' => -81.083333),
    'KSUT' => array('name' => 'NC - Oak Island, Brunswick County Airport', 'lat' => 33.929167, 'long' => -78.074722),
    'KHNZ' => array('name' => 'NC - Oxford, Henderson-Oxford Airport', 'lat' => 36.361667, 'long' => -78.529167),
    'KSOP' => array('name' => 'NC - Pinehurst/Southern Pines, Moore County Airport', 'lat' => 35.233333, 'long' => -79.400000),
    'KPGV' => array('name' => 'NC - Pitt-Greenville Airport', 'lat' => 35.633333, 'long' => -77.400000),
    'KPOB' => array('name' => 'NC - Pope Air Force Base', 'lat' => 35.166667, 'long' => -79.033333),
    'KRDU' => array('name' => 'NC - Raleigh / Durham, Raleigh-Durham International Airport', 'lat' => 35.870556, 'long' => -78.786389),
    'K78N' => array('name' => 'NC - Reidsville, Rockingham County NC Shiloh Airport', 'lat' => 36.437222, 'long' => -79.850833),
    'KRZZ' => array('name' => 'NC - Roanoke Rapids, Halifax County Airport', 'lat' => 36.439444, 'long' => -77.709722),
    'K45J' => array('name' => 'NC - Rockingham, Rockingham-Hamlet Airport', 'lat' => 34.890833, 'long' => -79.758889),
    'KRWI' => array('name' => 'NC - Rocky Mount, Rocky Mount-Wilson Regional Airport', 'lat' => 35.855000, 'long' => -77.893056),
    'KTDF' => array('name' => 'NC - Roxboro, Person County Airport', 'lat' => 36.285000, 'long' => -78.984167),
    'KFQD' => array('name' => 'NC - Rutherfordton, Rutherford County-Marchman Field Airport', 'lat' => 35.428333, 'long' => -81.935000),
    'KRUQ' => array('name' => 'NC - Salisbury, Rowan County Airport', 'lat' => 35.650000, 'long' => -80.516667),
    'KTTA' => array('name' => 'NC - Sanford, Sanford-Lee County Regional Airport', 'lat' => 35.582500, 'long' => -79.101389),
    'KGSB' => array('name' => 'NC - Seymour-Johnson Air Force Base', 'lat' => 35.333333, 'long' => -77.966667),
    'KEHO' => array('name' => 'NC - Shelby, Shelby Municipal Airport', 'lat' => 35.250000, 'long' => -81.600000),
    'KJNX' => array('name' => 'NC - Smithfield, Johnston County Airport', 'lat' => 35.540833, 'long' => -78.390278),
    'KSVH' => array('name' => 'NC - Statesville, Statesville Municipal Airport', 'lat' => 35.765278, 'long' => -80.956667),
    'KOCW' => array('name' => 'NC - Washington, Warren Field Airport', 'lat' => 35.570556, 'long' => -77.049722),
    'KCPC' => array('name' => 'NC - Whiteville, Columbus County Municipal Airport', 'lat' => 34.272778, 'long' => -78.715000),
    'KILM' => array('name' => 'NC - Wilmington, Wilmington International Airport', 'lat' => 34.270556, 'long' => -77.902500),
    'KINT' => array('name' => 'NC - Winston Salem, Smith Reynolds Airport', 'lat' => 36.133333, 'long' => -80.224722),
    'KBIS' => array('name' => 'ND - Bismarck, Bismarck Municipal Airport', 'lat' => 46.782500, 'long' => -100.757222),
    'KDVL' => array('name' => 'ND - Devils Lake, Devils Lake Municipal Airport', 'lat' => 48.116667, 'long' => -98.916667),
    'KDIK' => array('name' => 'ND - Dickinson, Dickinson Municipal Airport', 'lat' => 46.797222, 'long' => -102.801944),
    'KFAR' => array('name' => 'ND - Fargo, Hector International Airport', 'lat' => 46.925278, 'long' => -96.811111),
    'KN60' => array('name' => 'ND - Garrison', 'lat' => 47.645833, 'long' => -101.439444),
    'KRDR' => array('name' => 'ND - Grand Forks Air Force Base', 'lat' => 47.966667, 'long' => -97.400000),
    'KGFK' => array('name' => 'ND - Grand Forks, Grand Forks International Airport', 'lat' => 47.948056, 'long' => -97.182500),
    'KHEI' => array('name' => 'ND - Hettinger, Hettinger Municipal Airport', 'lat' => 46.010556, 'long' => -102.649722),
    'KJMS' => array('name' => 'ND - Jamestown, Jamestown Municipal Airport', 'lat' => 46.929722, 'long' => -98.678333),
    'KMIB' => array('name' => 'ND - Minot Air Force Base', 'lat' => 48.416667, 'long' => -101.350000),
    'KMOT' => array('name' => 'ND - Minot, Minot International Airport', 'lat' => 48.259444, 'long' => -101.280278),
    'KBWP' => array('name' => 'ND - Wahpeton, Harry Stern Airport', 'lat' => 46.243889, 'long' => -96.607222),
    'KISN' => array('name' => 'ND - Williston, Sloulin Field International Airport', 'lat' => 48.173889, 'long' => -103.636667),
    'KANW' => array('name' => 'NE - Ainsworth Municipal', 'lat' => 42.583333, 'long' => -100.000000),
    'KBVN' => array('name' => 'NE - Albion, Albion Municipal Airport', 'lat' => 41.728333, 'long' => -98.055556),
    'KAIA' => array('name' => 'NE - Alliance, Alliance Municipal Airport', 'lat' => 42.057222, 'long' => -102.800000),
    'KAUH' => array('name' => 'NE - Aurora, Aurora Municipal Airport', 'lat' => 40.893889, 'long' => -97.994444),
    'KBIE' => array('name' => 'NE - Beatrice Municipal', 'lat' => 40.300000, 'long' => -96.750000),
    'KHDE' => array('name' => 'NE - Brewster Field Airport', 'lat' => 40.450000, 'long' => -99.333333),
    'KBBW' => array('name' => 'NE - Broken Bow, Broken Bow Municipal Airport', 'lat' => 41.433333, 'long' => -99.650000),
    'KCDR' => array('name' => 'NE - Chadron, Chadron Municipal Airport', 'lat' => 42.837500, 'long' => -103.095278),
    'KOLU' => array('name' => 'NE - Columbus, Columbus Municipal Airport', 'lat' => 41.450000, 'long' => -97.333333),
    'KFNB' => array('name' => 'NE - Falls City, Brenner Field Airport', 'lat' => 40.078889, 'long' => -95.591944),
    'KFET' => array('name' => 'NE - Fremont Municipal Airport', 'lat' => 41.450000, 'long' => -96.516667),
    'KGRI' => array('name' => 'NE - Grand Island, Central Nebraska Regional Airport', 'lat' => 40.958333, 'long' => -98.312500),
    'KHSI' => array('name' => 'NE - Hastings, Hastings Municipal Airport', 'lat' => 40.600556, 'long' => -98.425833),
    'KHJH' => array('name' => 'NE - Hebron, Hebron Municipal Airport', 'lat' => 40.152222, 'long' => -97.586944),
    'KIML' => array('name' => 'NE - Imperial, Imperial Municipal Airport', 'lat' => 40.516667, 'long' => -101.616667),
    'KEAR' => array('name' => 'NE - Kearney, Kearney Municipal Airport', 'lat' => 40.733333, 'long' => -99.000000),
    'KIBM' => array('name' => 'NE - Kimball, Kimball Municipal Airport/Robert E Arraj Field', 'lat' => 41.183333, 'long' => -103.666667),
    'KLXN' => array('name' => 'NE - Lexington, Jim Kelly Field Airport', 'lat' => 40.791111, 'long' => -99.777222),
    'KLNK' => array('name' => 'NE - Lincoln, Lincoln Municipal Airport', 'lat' => 40.831111, 'long' => -96.764444),
    'KMCK' => array('name' => 'NE - McCook, McCook Municipal Airport', 'lat' => 40.203056, 'long' => -100.588333),
    'KAFK' => array('name' => 'NE - Nebraska City, Nebraska City Municipal Airport', 'lat' => 40.600000, 'long' => -95.850000),
    'KOFK' => array('name' => 'NE - Norfolk, Stefan Memorial Airport', 'lat' => 41.980556, 'long' => -97.436944),
    'KLBF' => array('name' => 'NE - North Platte, North Platte Regional Airport', 'lat' => 41.121944, 'long' => -100.668333),
    'KONL' => array('name' => 'NE - O\'Neill / Baker Field', 'lat' => 42.466667, 'long' => -98.683333),
    'KOGA' => array('name' => 'NE - Ogallala, Searle Field Airport', 'lat' => 41.119722, 'long' => -101.768889),
    'KOFF' => array('name' => 'NE - Omaha / Offutt Air Force Base', 'lat' => 41.116667, 'long' => -95.900000),
    'KOMA' => array('name' => 'NE - Omaha, Eppley Airfield', 'lat' => 41.310278, 'long' => -95.899167),
    'KMLE' => array('name' => 'NE - Omaha, Millard Airport', 'lat' => 41.195833, 'long' => -96.112222),
    'KODX' => array('name' => 'NE - Ord, Evelyn Sharp Field Airport', 'lat' => 41.624167, 'long' => -98.952500),
    'KPMV' => array('name' => 'NE - Plattsmouth, Plattsmouth Municipal Airport', 'lat' => 40.950000, 'long' => -95.917778),
    'KBFF' => array('name' => 'NE - Scottsbluff, Heilig Field', 'lat' => 41.866944, 'long' => -103.585833),
    'KSNY' => array('name' => 'NE - Sidney, Sidney Municipal Airport', 'lat' => 41.099444, 'long' => -102.985556),
    'KTQE' => array('name' => 'NE - Tekamah, Tekamah Municipal Airport', 'lat' => 41.766944, 'long' => -96.177778),
    'KTIF' => array('name' => 'NE - Thedford, Thomas County Airport', 'lat' => 41.961944, 'long' => -100.568889),
    'KVTN' => array('name' => 'NE - Valentine, Miller Field', 'lat' => 42.858611, 'long' => -100.551389),
    'KLCG' => array('name' => 'NE - Wayne, Wayne Municipal Airport', 'lat' => 42.241667, 'long' => -96.981389),
    'KJYR' => array('name' => 'NE - York, York Municipal Airport', 'lat' => 40.896667, 'long' => -97.622778),
    'KBML' => array('name' => 'NH - Berlin, Berlin Municipal Airport', 'lat' => 44.576111, 'long' => -71.178611),
    'KCON' => array('name' => 'NH - Concord, Concord Municipal Airport', 'lat' => 43.195278, 'long' => -71.501111),
    'KAFN' => array('name' => 'NH - Jaffrey, Jaffrey Municipal-Silver Ranch Airport', 'lat' => 42.805833, 'long' => -72.000556),
    'KEEN' => array('name' => 'NH - Keene, Dillant-Hopkins Airport', 'lat' => 42.900000, 'long' => -72.266667),
    'KLCI' => array('name' => 'NH - Laconia, Laconia Municipal Airport', 'lat' => 43.566667, 'long' => -71.416667),
    'KLEB' => array('name' => 'NH - Lebanon, Lebanon Municipal Airport', 'lat' => 43.627222, 'long' => -72.305833),
    'KMHT' => array('name' => 'NH - Manchester, Manchester Airport', 'lat' => 42.929167, 'long' => -71.435833),
    'KMWN' => array('name' => 'NH - Mount Washington', 'lat' => 44.266667, 'long' => -71.300000),
    'KASH' => array('name' => 'NH - Nashua, Boire Field Airport', 'lat' => 42.781667, 'long' => -71.514722),
    'KPSM' => array('name' => 'NH - Pease Air Force Base / Portsmouth', 'lat' => 43.083333, 'long' => -70.816667),
    'K1P1' => array('name' => 'NH - Plymouth, Plymouth Municipal Airport', 'lat' => 43.779167, 'long' => -71.753611),
    'KDAW' => array('name' => 'NH - Rochester, Skyhaven Airport', 'lat' => 43.278056, 'long' => -70.922222),
    'KHIE' => array('name' => 'NH - Whitefield, Mount Washington Regional Airport', 'lat' => 44.366111, 'long' => -71.552500),
    'K12N' => array('name' => 'NJ - Andover, Aeroflex-Andover Airport', 'lat' => 41.008889, 'long' => -74.736667),
    'KACY' => array('name' => 'NJ - Atlantic City, Atlantic City International Airport', 'lat' => 39.464722, 'long' => -74.586667),
    'KBLM' => array('name' => 'NJ - Belmar-Farmingdale', 'lat' => 40.183333, 'long' => -74.133333),
    'KCDW' => array('name' => 'NJ - Caldwell, Essex County Airport', 'lat' => 40.876389, 'long' => -74.283056),
    'KNEL' => array('name' => 'NJ - Lakehurst Naval Air Station', 'lat' => 40.033333, 'long' => -74.316667),
    'KWRI' => array('name' => 'NJ - Mcguire Air Force Base', 'lat' => 40.016667, 'long' => -74.600000),
    'KMIV' => array('name' => 'NJ - Millville, Millville Municipal Airport', 'lat' => 39.366111, 'long' => -75.078333),
    'KMMU' => array('name' => 'NJ - Morristown Municipal', 'lat' => 40.800000, 'long' => -74.416667),
    'KVAY' => array('name' => 'NJ - Mount Holly, South Jersey Regional Airport', 'lat' => 39.940556, 'long' => -74.841111),
    'KEWR' => array('name' => 'NJ - Newark, Newark International Airport', 'lat' => 40.682500, 'long' => -74.169444),
    'KSMQ' => array('name' => 'NJ - Somerville, Somerset Airport', 'lat' => 40.623889, 'long' => -74.669444),
    'KFWN' => array('name' => 'NJ - Sussex, Sussex Airport', 'lat' => 41.200278, 'long' => -74.623056),
    'KTEB' => array('name' => 'NJ - Teterboro, Teterboro Airport', 'lat' => 40.858889, 'long' => -74.056667),
    'KTTN' => array('name' => 'NJ - Trenton, Mercer County Airport', 'lat' => 40.276389, 'long' => -74.816389),
    'KWWD' => array('name' => 'NJ - Wildwood, Cape May County Airport', 'lat' => 39.016667, 'long' => -74.916667),
    'KALM' => array('name' => 'NM - Alamogordo-White', 'lat' => 32.833333, 'long' => -105.983333),
    'KABQ' => array('name' => 'NM - Albuquerque, Albuquerque International Airport', 'lat' => 35.041667, 'long' => -106.614722),
    'KAEG' => array('name' => 'NM - Albuquerque, Double Eagle II Airport', 'lat' => 35.145000, 'long' => -106.795000),
    'KATS' => array('name' => 'NM - Artesia, Artesia Municipal Airport', 'lat' => 32.852500, 'long' => -104.467500),
    'KCVS' => array('name' => 'NM - Cannon Air Force Base / Clovis', 'lat' => 34.383333, 'long' => -103.316667),
    'KCNM' => array('name' => 'NM - Carlsbad, Cavern City Air Terminal Airport', 'lat' => 32.337500, 'long' => -104.263333),
    'KE33' => array('name' => 'NM - Chama', 'lat' => 36.900000, 'long' => -106.583333),
    'KCAO' => array('name' => 'NM - Clayton, Clayton Municipal Airpark', 'lat' => 36.448333, 'long' => -103.153056),
    'KCQC' => array('name' => 'NM - Clines Corners', 'lat' => 35.000000, 'long' => -105.666667),
    'KCVN' => array('name' => 'NM - Clovis, Clovis Municipal Airport', 'lat' => 34.433333, 'long' => -103.083333),
    'K4CR' => array('name' => 'NM - Corona / Lincoln', 'lat' => 34.100000, 'long' => -105.683333),
    'KDMN' => array('name' => 'NM - Deming, Deming Municipal Airport', 'lat' => 32.262222, 'long' => -107.720556),
    'KFMN' => array('name' => 'NM - Farmington, Four Corners Regional Airport', 'lat' => 36.743611, 'long' => -108.229167),
    'KGUP' => array('name' => 'NM - Gallup, Gallup Municipal Airport', 'lat' => 35.511111, 'long' => -108.789444),
    'KGNT' => array('name' => 'NM - Grants, Grants-Milan Municipal Airport', 'lat' => 35.165278, 'long' => -107.902222),
    'KHOB' => array('name' => 'NM - Hobbs / Lea County', 'lat' => 32.683333, 'long' => -103.216667),
    'KHMN' => array('name' => 'NM - Holloman Air Force Base', 'lat' => 32.850000, 'long' => -106.100000),
    'KLRU' => array('name' => 'NM - Las Cruces, Las Cruces International Airport', 'lat' => 32.289444, 'long' => -106.921944),
    'KLVS' => array('name' => 'NM - Las Vegas, Las Vegas Municipal Airport', 'lat' => 35.654167, 'long' => -105.142500),
    'KLAM' => array('name' => 'NM - Los Alamos, Los Alamos Airport', 'lat' => 35.879722, 'long' => -106.269167),
    'K4MY' => array('name' => 'NM - Moriarty', 'lat' => 34.983333, 'long' => -106.050000),
    'KRTN' => array('name' => 'NM - Raton, Raton Municipal \ Crews Field Airport', 'lat' => 36.741944, 'long' => -104.657778),
    'KROW' => array('name' => 'NM - Roswell, Roswell Industrial Air Center Airport', 'lat' => 33.308056, 'long' => -104.507778),
    'KSRR' => array('name' => 'NM - Ruidoso Regional', 'lat' => 33.466667, 'long' => -105.533333),
    'KSAF' => array('name' => 'NM - Santa Fe, Santa Fe County Municipal Airport', 'lat' => 35.610556, 'long' => -106.095000),
    'K5T6' => array('name' => 'NM - Santa Teresa, Dona Ana County Airport at Santa Teresa', 'lat' => 31.880833, 'long' => -106.704722),
    'KSVC' => array('name' => 'NM - Silver City / Grant', 'lat' => 32.633333, 'long' => -108.150000),
    'KSKX' => array('name' => 'NM - Taos, Taos Regional Airport', 'lat' => 36.450000, 'long' => -105.666667),
    'K4SL' => array('name' => 'NM - Torreon', 'lat' => 35.800000, 'long' => -107.183333),
    'KTCS' => array('name' => 'NM - Truth Or Consequences, Truth Or Consequences Municipal Airport', 'lat' => 33.236667, 'long' => -107.268056),
    'KTCC' => array('name' => 'NM - Tucumcari, Tucumcari Municipal Airport', 'lat' => 35.182778, 'long' => -103.603056),
    'KB23' => array('name' => 'NV - Battle Mountain', 'lat' => 40.600000, 'long' => -116.866667),
    'KEKO' => array('name' => 'NV - Elko, Elko Regional Airport', 'lat' => 40.825000, 'long' => -115.791667),
    'KELY' => array('name' => 'NV - Ely, Ely Airport', 'lat' => 39.295000, 'long' => -114.845278),
    'KP68' => array('name' => 'NV - Eureka', 'lat' => 39.601389, 'long' => -116.005556),
    'KNFL' => array('name' => 'NV - Fallon, Naval Air Station', 'lat' => 39.432222, 'long' => -118.685556),
    'KINS' => array('name' => 'NV - Indian Springs, Indian Springs Auxiliary AFLD Nellis AFB', 'lat' => 36.583333, 'long' => -115.666667),
    'KHND' => array('name' => 'NV - Las Vegas, Henderson Executive Airport', 'lat' => 35.972778, 'long' => -115.134444),
    'KLAS' => array('name' => 'NV - Las Vegas, McCarran International Airport', 'lat' => 36.078889, 'long' => -115.155278),
    'KVGT' => array('name' => 'NV - Las Vegas, North Las Vegas Airport', 'lat' => 36.211667, 'long' => -115.195833),
    'KBJN' => array('name' => 'NV - Las Vegas, Tonopah Range #74 Nellis AFB', 'lat' => 37.617222, 'long' => -116.264167),
    'KLOL' => array('name' => 'NV - Lovelock, Derby Field Airport', 'lat' => 40.066389, 'long' => -118.565278),
    'KDRA' => array('name' => 'NV - Mercury, Desert Rock Airport', 'lat' => 36.620556, 'long' => -116.027778),
    'KLSV' => array('name' => 'NV - Nellis Air Force Base', 'lat' => 36.233333, 'long' => -115.033333),
    'KRNO' => array('name' => 'NV - Reno, Reno Tahoe International Airport', 'lat' => 39.483889, 'long' => -119.771111),
    'KTPH' => array('name' => 'NV - Tonopah, Tonopah Airport', 'lat' => 38.060278, 'long' => -117.087222),
    'K9BB' => array('name' => 'NV - Wells', 'lat' => 41.116667, 'long' => -114.966667),
    'KAWH' => array('name' => 'NV - Wildhorse Reservation / Elko', 'lat' => 41.666667, 'long' => -115.783333),
    'KWMC' => array('name' => 'NV - Winnemucca, Winnemucca Municipal Airport', 'lat' => 40.901944, 'long' => -117.807222),
    'KALB' => array('name' => 'NY - Albany, Albany International Airport', 'lat' => 42.748056, 'long' => -73.801667),
    'KBGM' => array('name' => 'NY - Binghamton, Binghamton Regional Airport', 'lat' => 42.207778, 'long' => -75.981389),
    'KBUF' => array('name' => 'NY - Buffalo, Greater Buffalo International Airport', 'lat' => 42.940833, 'long' => -78.735833),
    'KDSV' => array('name' => 'NY - Dansville, Dansville Municipal Airport', 'lat' => 42.569444, 'long' => -77.714444),
    'KDKK' => array('name' => 'NY - Dunkirk, Chautauqua County / Dunkirk Airport', 'lat' => 42.493056, 'long' => -79.275833),
    'KHTO' => array('name' => 'NY - East Hampton, East Hampton Airport', 'lat' => 40.959444, 'long' => -72.251944),
    'KELM' => array('name' => 'NY - Elmira, Elmira / Corning Regional Airport', 'lat' => 42.156389, 'long' => -76.902778),
    'KFRG' => array('name' => 'NY - Farmingdale, Republic Airport', 'lat' => 40.734167, 'long' => -73.416944),
    'KGTB' => array('name' => 'NY - Fort Drum / Wheeler-Sack U. S. Army Airfield', 'lat' => 44.050000, 'long' => -75.733333),
    'KGFL' => array('name' => 'NY - Glens Falls, Floyd Bennett Memorial Airport', 'lat' => 43.341111, 'long' => -73.610556),
    'KISP' => array('name' => 'NY - Islip, Long Island Mac Arthur Airport', 'lat' => 40.793889, 'long' => -73.101667),
    'KITH' => array('name' => 'NY - Ithaca, Ithaca Tompkins Regional Airport', 'lat' => 42.490833, 'long' => -76.458333),
    'KJHW' => array('name' => 'NY - Jamestown, Chautauqua County/Jamestown Airport', 'lat' => 42.150000, 'long' => -79.266667),
    'KMSS' => array('name' => 'NY - Massena, Massena International-Richards Field', 'lat' => 44.935833, 'long' => -74.845556),
    'KMTP' => array('name' => 'NY - Montauk, Montauk Airport', 'lat' => 41.073056, 'long' => -71.923333),
    'KMGJ' => array('name' => 'NY - Montgomery, Orange County Airport', 'lat' => 41.509167, 'long' => -74.265000),
    'KMSV' => array('name' => 'NY - Monticello, Sullivan County International Airport', 'lat' => 41.700000, 'long' => -74.800000),
    'KNYC' => array('name' => 'NY - New York City, Central Park', 'lat' => 40.783333, 'long' => -73.966667),
    'KJFK' => array('name' => 'NY - New York, Kennedy International Airport', 'lat' => 40.638611, 'long' => -73.762222),
    'KLGA' => array('name' => 'NY - New York, La Guardia Airport', 'lat' => 40.779167, 'long' => -73.880000),
    'KSWF' => array('name' => 'NY - Newburgh / Stewart', 'lat' => 41.500000, 'long' => -74.100000),
    'KIAG' => array('name' => 'NY - Niagara Falls, Niagara Falls International Airport', 'lat' => 43.107222, 'long' => -78.945278),
    'KOGS' => array('name' => 'NY - Ogdensburg International', 'lat' => 44.683333, 'long' => -75.466667),
    'KPEO' => array('name' => 'NY - Penn Yan, Penn Yan Airport', 'lat' => 42.643056, 'long' => -77.049444),
    'KPLB' => array('name' => 'NY - Plattsburgh, Clinton County Airport', 'lat' => 44.682222, 'long' => -73.527778),
    'KPOU' => array('name' => 'NY - Poughkeepsie, Dutchess County Airport', 'lat' => 41.626667, 'long' => -73.884167),
    'KROC' => array('name' => 'NY - Rochester, Greater Rochester International Airport', 'lat' => 43.116667, 'long' => -77.676667),
    'KSLK' => array('name' => 'NY - Saranac Lake, Adirondack Regional Airport', 'lat' => 44.393056, 'long' => -74.202778),
    'KSCH' => array('name' => 'NY - Schenectady Airport', 'lat' => 42.850000, 'long' => -73.933333),
    'KHWV' => array('name' => 'NY - Shirley, Brookhaven Airport', 'lat' => 40.821667, 'long' => -72.868889),
    'KSYR' => array('name' => 'NY - Syracuse, Syracuse Hancock International Airport', 'lat' => 43.109167, 'long' => -76.103333),
    'KUCA' => array('name' => 'NY - Utica, Oneida County Airport', 'lat' => 43.145000, 'long' => -75.384444),
    'KART' => array('name' => 'NY - Watertown, Watertown International Airport', 'lat' => 43.991944, 'long' => -76.021667),
    'KELZ' => array('name' => 'NY - Wellsville, Wellsville Municipal Airport', 'lat' => 42.107500, 'long' => -77.984444),
    'KFOK' => array('name' => 'NY - Westhampton Beach, The Gabreski Airport', 'lat' => 40.850833, 'long' => -72.620556),
    'KHPN' => array('name' => 'NY - White Plains, Westchester County Airport', 'lat' => 41.066944, 'long' => -73.707500),
    'KAKR' => array('name' => 'OH - Akron, Akron Fulton International Airport', 'lat' => 41.037500, 'long' => -81.464167),
    'KCAK' => array('name' => 'OH - Akron, Akron-Canton Regional Airport', 'lat' => 40.918056, 'long' => -81.442500),
    'KLUK' => array('name' => 'OH - Cincinnati, Cincinnati Municipal Airport Lunken Field', 'lat' => 39.105833, 'long' => -84.415833),
    'KCGF' => array('name' => 'OH - Cleveland / Cuyahoga', 'lat' => 41.566667, 'long' => -81.483333),
    'KBKL' => array('name' => 'OH - Cleveland, Burke Lakefront Airport', 'lat' => 41.525556, 'long' => -81.668889),
    'KCLE' => array('name' => 'OH - Cleveland, Cleveland-Hopkins International Airport', 'lat' => 41.405000, 'long' => -81.852778),
    'KTZR' => array('name' => 'OH - Columbus, Bolton Field Airport', 'lat' => 39.900833, 'long' => -83.137222),
    'KOSU' => array('name' => 'OH - Columbus, Ohio State University Airport', 'lat' => 40.078056, 'long' => -83.078056),
    'KCMH' => array('name' => 'OH - Columbus, Port Columbus International Airport', 'lat' => 39.995000, 'long' => -82.876389),
    'KFFO' => array('name' => 'OH - Dayton / Wright-Patterson Air Force Base', 'lat' => 39.833333, 'long' => -84.050000),
    'KDAY' => array('name' => 'OH - Dayton, Cox Dayton International Airport', 'lat' => 39.906111, 'long' => -84.218611),
    'KMGY' => array('name' => 'OH - Dayton, Dayton-Wright Brothers Airport', 'lat' => 39.588889, 'long' => -84.224722),
    'KDFI' => array('name' => 'OH - Defiance, Defiance Memorial Airport', 'lat' => 41.336389, 'long' => -84.429444),
    'KFDY' => array('name' => 'OH - Findlay, Findlay Airport', 'lat' => 41.013611, 'long' => -83.668611),
    'KHAO' => array('name' => 'OH - Hamilton, Butler County Regional Airport', 'lat' => 39.361389, 'long' => -84.520833),
    'KLHQ' => array('name' => 'OH - Lancaster, Fairfield County Airport', 'lat' => 39.757222, 'long' => -82.663333),
    'KAOH' => array('name' => 'OH - Lima, Lima Allen County Airport', 'lat' => 40.708056, 'long' => -84.021389),
    'KLPR' => array('name' => 'OH - Lorain / Elyria, Lorain County Regional Airport', 'lat' => 41.346111, 'long' => -82.179444),
    'KMFD' => array('name' => 'OH - Mansfield, Mansfield Lahm Municipal Airport', 'lat' => 40.820278, 'long' => -82.517778),
    'KMNN' => array('name' => 'OH - Marion, Marion Municipal Airport', 'lat' => 40.616667, 'long' => -83.068333),
    'KPHD' => array('name' => 'OH - New Philadelphia, Harry Clever Field', 'lat' => 40.471944, 'long' => -81.423611),
    'KVTA' => array('name' => 'OH - Newark, Newark Heath Airport', 'lat' => 40.022778, 'long' => -82.462500),
    'KLCK' => array('name' => 'OH - Rickenbacker Air National Guard Base', 'lat' => 39.816667, 'long' => -82.933333),
    'KSGH' => array('name' => 'OH - Springfield, Springfield-Beckley Municipal Airport', 'lat' => 39.840278, 'long' => -83.840000),
    'KTDZ' => array('name' => 'OH - Toledo, Metcalf Field', 'lat' => 41.563056, 'long' => -83.476389),
    'KTOL' => array('name' => 'OH - Toledo, Toledo Express Airport', 'lat' => 41.588611, 'long' => -83.801389),
    'KILN' => array('name' => 'OH - Wilmington, Airborne Airpark Airport', 'lat' => 39.428333, 'long' => -83.779167),
    'KBJJ' => array('name' => 'OH - Wooster, Wayne County Airport', 'lat' => 40.873056, 'long' => -81.886667),
    'KYNG' => array('name' => 'OH - Youngstown, Youngstown-Warren Regional Airport', 'lat' => 41.254444, 'long' => -80.673889),
    'KZZV' => array('name' => 'OH - Zanesville, Zanesville Municipal Airport', 'lat' => 39.944444, 'long' => -81.892222),
    'KADH' => array('name' => 'OK - Ada, Ada Municipal Airport', 'lat' => 34.804444, 'long' => -96.671389),
    'KLTS' => array('name' => 'OK - Altus Air Force Base', 'lat' => 34.650000, 'long' => -99.266667),
    'KAXS' => array('name' => 'OK - Altus, Altus/Quartz Mountain Regional Airport', 'lat' => 34.698611, 'long' => -99.338056),
    'KAVK' => array('name' => 'OK - Alva, Alva Regional Airport', 'lat' => 36.773056, 'long' => -98.670000),
    'K1F0' => array('name' => 'OK - Ardmore, Ardmore Downtown Executive Airport', 'lat' => 34.146944, 'long' => -97.122500),
    'KADM' => array('name' => 'OK - Ardmore, Ardmore Municipal Airport', 'lat' => 34.303056, 'long' => -97.019444),
    'KBVO' => array('name' => 'OK - Bartlesville, Bartlesville Municipal Airport', 'lat' => 36.768333, 'long' => -96.026111),
    'KCQB' => array('name' => 'OK - Chandler, Chandler Municipal Airport', 'lat' => 35.723889, 'long' => -96.820278),
    'KCHK' => array('name' => 'OK - Chickasha, Chickasha Municipal Airport', 'lat' => 35.096111, 'long' => -97.966111),
    'KGCM' => array('name' => 'OK - Claremore, Claremore Regional Airport', 'lat' => 36.294444, 'long' => -95.479722),
    'KCLK' => array('name' => 'OK - Clinton, Clinton Regional Airport', 'lat' => 35.538056, 'long' => -98.921389),
    'KCSM' => array('name' => 'OK - Clinton, Clinton-Sherman Airport', 'lat' => 35.356667, 'long' => -99.203611),
    'KCUH' => array('name' => 'OK - Cushing, Cushing Municipal Airport', 'lat' => 35.949722, 'long' => -96.772778),
    'KDUC' => array('name' => 'OK - Duncan, Halliburton Field Airport', 'lat' => 34.470833, 'long' => -97.960000),
    'KDUA' => array('name' => 'OK - Durant, Eaker Field Airport', 'lat' => 33.942222, 'long' => -96.394444),
    'KRQO' => array('name' => 'OK - El Reno, El Reno Regional Airport', 'lat' => 35.472500, 'long' => -98.005556),
    'KWDG' => array('name' => 'OK - Enid, Enid Woodring Regional Airport', 'lat' => 36.379167, 'long' => -97.791111),
    'KFSI' => array('name' => 'OK - Fort Sill', 'lat' => 34.600000, 'long' => -98.400000),
    'KFDR' => array('name' => 'OK - Frederick, Frederick Municipal Airport', 'lat' => 34.344444, 'long' => -98.983056),
    'KGAG' => array('name' => 'OK - Gage, Gage Airport', 'lat' => 36.296667, 'long' => -99.768889),
    'KGMJ' => array('name' => 'OK - Grove, Grove Municipal Airport', 'lat' => 36.605278, 'long' => -94.738611),
    'KGOK' => array('name' => 'OK - Guthrie, Guthrie Municipal Airport', 'lat' => 35.851944, 'long' => -97.407500),
    'KGUY' => array('name' => 'OK - Guymon / Guymon Municipal Airport', 'lat' => 36.681667, 'long' => -101.505278),
    'KHBR' => array('name' => 'OK - Hobart, Hobart Municipal Airport', 'lat' => 34.989444, 'long' => -99.052500),
    'K4O4' => array('name' => 'OK - Idabel, Mc Curtain County Regional Airport', 'lat' => 33.909167, 'long' => -94.859167),
    'KLAW' => array('name' => 'OK - Lawton, Lawton Municipal Airport', 'lat' => 34.557500, 'long' => -98.416667),
    'KMLC' => array('name' => 'OK - McAlester, McAlester Regional Airport', 'lat' => 34.882222, 'long' => -95.783056),
    'KMKO' => array('name' => 'OK - Muskogee, Davis Field', 'lat' => 35.656944, 'long' => -95.359722),
    'KOUN' => array('name' => 'OK - Norman / Max Westheimer', 'lat' => 35.216667, 'long' => -97.450000),
    'KPWA' => array('name' => 'OK - Oklahoma City, Wiley Post Airport', 'lat' => 35.541111, 'long' => -97.646667),
    'KOKC' => array('name' => 'OK - Oklahoma City, Will Rogers World Airport', 'lat' => 35.388611, 'long' => -97.600278),
    'KOKM' => array('name' => 'OK - Okmulgee, Okmulgee Municipal Airport', 'lat' => 35.668056, 'long' => -95.948611),
    'KPVJ' => array('name' => 'OK - Pauls Valley, Pauls Valley Municipal Airport', 'lat' => 34.711111, 'long' => -97.223333),
    'KPNC' => array('name' => 'OK - Ponca City, Ponca City Municipal Airport', 'lat' => 36.730556, 'long' => -97.099722),
    'KRKR' => array('name' => 'OK - Poteau, Robert S Kerr Airport', 'lat' => 35.021667, 'long' => -94.621389),
    'KJSV' => array('name' => 'OK - Sallisaw, Sallisaw Municipal Airport', 'lat' => 35.438056, 'long' => -94.802778),
    'KSRE' => array('name' => 'OK - Seminole, Seminole Municipal Airport', 'lat' => 35.274444, 'long' => -96.675000),
    'KSNL' => array('name' => 'OK - Shawnee, Shawnee Municipal Airport', 'lat' => 35.357222, 'long' => -96.942778),
    'KSWO' => array('name' => 'OK - Stillwater, Stillwater Regional Airport', 'lat' => 36.162222, 'long' => -97.089167),
    'KTQH' => array('name' => 'OK - Tahlequah, Tahlequah Municipal Airport', 'lat' => 35.928889, 'long' => -95.004444),
    'KTIK' => array('name' => 'OK - Tinker Air Force Base', 'lat' => 35.416667, 'long' => -97.383333),
    'KRVS' => array('name' => 'OK - Tulsa, Jones Jr. Airport', 'lat' => 36.042500, 'long' => -95.989444),
    'KTUL' => array('name' => 'OK - Tulsa, Tulsa International Airport', 'lat' => 36.197500, 'long' => -95.886389),
    'KEND' => array('name' => 'OK - Vance Air Force Base / Enid', 'lat' => 36.333333, 'long' => -97.916667),
    'KJWG' => array('name' => 'OK - Watonga, Watonga Airport', 'lat' => 35.864722, 'long' => -98.420833),
    'KWWR' => array('name' => 'OK - Woodward, West Woodward Airport', 'lat' => 36.436667, 'long' => -99.521111),
    'KAST' => array('name' => 'OR - Astoria, Astoria Regional Airport', 'lat' => 46.156944, 'long' => -123.882500),
    'KUAO' => array('name' => 'OR - Aurora, Aurora State Airport', 'lat' => 45.248889, 'long' => -122.765556),
    'KBKE' => array('name' => 'OR - Baker City, Baker City Municipal Airport', 'lat' => 44.837222, 'long' => -117.809167),
    'KBOK' => array('name' => 'OR - Brookings, Brookings Airport', 'lat' => 42.074444, 'long' => -124.290000),
    'KBNO' => array('name' => 'OR - Burns, Burns Municipal Airport', 'lat' => 43.595000, 'long' => -118.956389),
    'KCZK' => array('name' => 'OR - Cascade Locks State', 'lat' => 45.666667, 'long' => -121.883333),
    'KCVO' => array('name' => 'OR - Corvallis, Corvallis Municipal Airport', 'lat' => 44.500000, 'long' => -123.283333),
    'KEUG' => array('name' => 'OR - Eugene, Mahlon Sweet Field', 'lat' => 44.133333, 'long' => -123.214444),
    'KHRI' => array('name' => 'OR - Hermiston, Hermiston Municipal Airport', 'lat' => 45.825833, 'long' => -119.261111),
    'K5J0' => array('name' => 'OR - John Day, John Day State Airport', 'lat' => 44.404167, 'long' => -118.962500),
    'KLMT' => array('name' => 'OR - Klamath Falls, Klamath Falls International Airport', 'lat' => 42.146944, 'long' => -121.724167),
    'KLGD' => array('name' => 'OR - La Grande, La Grande/Union County Airport', 'lat' => 45.283333, 'long' => -118.000000),
    'KLKV' => array('name' => 'OR - Lakeview, Lake County Airport', 'lat' => 42.166667, 'long' => -120.400000),
    'KMMV' => array('name' => 'OR - McMinnville, McMinnville Municipal Airport', 'lat' => 45.196111, 'long' => -123.132222),
    'KMEH' => array('name' => 'OR - Meacham, Meacham', 'lat' => 45.511389, 'long' => -118.424722),
    'KMFR' => array('name' => 'OR - Medford, Rogue Valley International Airport', 'lat' => 42.381111, 'long' => -122.872222),
    'KONP' => array('name' => 'OR - Newport, Newport Municipal Airport', 'lat' => 44.580278, 'long' => -124.058056),
    'KOTH' => array('name' => 'OR - North Bend, North Bend Municipal Airport', 'lat' => 43.416667, 'long' => -124.250000),
    'KONO' => array('name' => 'OR - Ontario, Ontario Municipal Airport', 'lat' => 44.019444, 'long' => -117.009722),
    'KPDT' => array('name' => 'OR - Pendleton, Eastern Oregon Regional At Pendleton Airport', 'lat' => 45.698333, 'long' => -118.834167),
    'KPDX' => array('name' => 'OR - Portland, Portland International Airport', 'lat' => 45.590833, 'long' => -122.600278),
    'KHIO' => array('name' => 'OR - Portland, Portland-Hillsboro Airport', 'lat' => 45.548056, 'long' => -122.954444),
    'KTTD' => array('name' => 'OR - Portland, Portland-Troutdale Airport', 'lat' => 45.551111, 'long' => -122.408889),
    'KRDM' => array('name' => 'OR - Redmond, Roberts Field Airport', 'lat' => 44.254167, 'long' => -121.149722),
    'KREO' => array('name' => 'OR - Rome, Rome', 'lat' => 42.590556, 'long' => -117.864444),
    'KRBG' => array('name' => 'OR - Roseburg, Roseburg Regional Airport', 'lat' => 43.233889, 'long' => -123.356111),
    'KSLE' => array('name' => 'OR - Salem, McNary Field', 'lat' => 44.907778, 'long' => -122.995000),
    'KSPB' => array('name' => 'OR - Scappoose, Scappoose Industrial Airpark', 'lat' => 45.769167, 'long' => -122.862222),
    'KSXT' => array('name' => 'OR - Sexton Summit,', 'lat' => 42.600278, 'long' => -123.364167),
    'KDLS' => array('name' => 'OR - The Dalles, Columbia Gorge Regional / The Dalles Municipal Airport', 'lat' => 45.618611, 'long' => -121.167222),
    'KS47' => array('name' => 'OR - Tillamook, Tillamook Airport', 'lat' => 45.418056, 'long' => -123.814444),
    'KABE' => array('name' => 'PA - Allentown, Lehigh Valley International Airport', 'lat' => 40.650833, 'long' => -75.449167),
    'KAOO' => array('name' => 'PA - Altoona, Altoona-Blair County Airport', 'lat' => 40.300000, 'long' => -78.316944),
    'KBVI' => array('name' => 'PA - Beaver Falls Airport', 'lat' => 40.766667, 'long' => -80.400000),
    'KBFD' => array('name' => 'PA - Bradford, Bradford Regional Airport', 'lat' => 41.798611, 'long' => -78.635833),
    'KBTP' => array('name' => 'PA - Butler, Butler County Airport/K W Scholter Field', 'lat' => 40.783333, 'long' => -79.950000),
    'KFIG' => array('name' => 'PA - Clearfield, Clearfield-Lawrence Airport', 'lat' => 41.046667, 'long' => -78.411667),
    'KDYL' => array('name' => 'PA - Doylestown, Doylestown Airport', 'lat' => 40.330000, 'long' => -75.122500),
    'KDUJ' => array('name' => 'PA - Du Bois, Du Bois-Jefferson County Airport', 'lat' => 41.183333, 'long' => -78.900000),
    'KERI' => array('name' => 'PA - Erie, Erie International Airport', 'lat' => 42.080000, 'long' => -80.182500),
    'KFKL' => array('name' => 'PA - Franklin, Venango Regional Airport', 'lat' => 41.383333, 'long' => -79.866667),
    'KCXY' => array('name' => 'PA - Harrisburg, Capital City Airport', 'lat' => 40.217222, 'long' => -76.851389),
    'KMDT' => array('name' => 'PA - Harrisburg, Harrisburg International Airport', 'lat' => 40.193611, 'long' => -76.763333),
    'KIDI' => array('name' => 'PA - Indiana / Stewart Field', 'lat' => 40.633333, 'long' => -79.100000),
    'KJST' => array('name' => 'PA - Johnstown, Johnstown-Cambria County Airport', 'lat' => 40.316111, 'long' => -78.833889),
    'KLNS' => array('name' => 'PA - Lancaster, Lancaster Airport', 'lat' => 40.120278, 'long' => -76.294444),
    'KLBE' => array('name' => 'PA - Latrobe / Westmorland', 'lat' => 40.283333, 'long' => -79.400000),
    'KGKJ' => array('name' => 'PA - Meadville, Port Meadville Airport', 'lat' => 41.626389, 'long' => -80.214722),
    'KMPO' => array('name' => 'PA - Mount Pocono, Pocono Mountains Municipal Airport', 'lat' => 41.138889, 'long' => -75.396111),
    'KMUI' => array('name' => 'PA - Muir Army Air Field / Indiantown', 'lat' => 40.433333, 'long' => -76.566667),
    'KUCP' => array('name' => 'PA - New Castle, New Castle Municipal Airport', 'lat' => 41.025278, 'long' => -80.413333),
    'KPNE' => array('name' => 'PA - Philadelphia, Northeast Philadelphia Airport', 'lat' => 40.078889, 'long' => -75.013611),
    'KPHL' => array('name' => 'PA - Philadelphia, Philadelphia International Airport', 'lat' => 39.868333, 'long' => -75.231111),
    'KAGC' => array('name' => 'PA - Pittsburgh, Allegheny County Airport', 'lat' => 40.354722, 'long' => -79.921667),
    'KPIT' => array('name' => 'PA - Pittsburgh, Pittsburgh International Airport', 'lat' => 40.503889, 'long' => -80.266389),
    'KPTW' => array('name' => 'PA - Pottstown, Pottstown Limerick Airport', 'lat' => 40.238333, 'long' => -75.557222),
    'KUKT' => array('name' => 'PA - Quakertown, Quakertown Airport', 'lat' => 40.435000, 'long' => -75.381667),
    'KRDG' => array('name' => 'PA - Reading, Reading Regional Airport', 'lat' => 40.373333, 'long' => -75.959444),
    'KSEG' => array('name' => 'PA - Selinsgrove, Penn Valley Airport', 'lat' => 40.819167, 'long' => -76.866111),
    'KUNV' => array('name' => 'PA - State College, University Park Airport', 'lat' => 40.850000, 'long' => -77.850000),
    'KAFJ' => array('name' => 'PA - Washington, Washington County Airport', 'lat' => 40.133333, 'long' => -80.283333),
    'KAVP' => array('name' => 'PA - Wilkes-Barre - Scranton, Wilkes-Barre / Scranton International Airport', 'lat' => 41.338889, 'long' => -75.726667),
    'KIPT' => array('name' => 'PA - Williamsport, Williamsport Regional Airport', 'lat' => 41.241667, 'long' => -76.920833),
    'KNXX' => array('name' => 'PA - Willow Grove, Naval Air Station', 'lat' => 40.193056, 'long' => -75.144444),
    'KTHV' => array('name' => 'PA - York, York Airport', 'lat' => 39.919444, 'long' => -76.876944),
    'TJBQ' => array('name' => 'PR - Aquadilla, Rafael Hernandez Airport', 'lat' => 18.500000, 'long' => -67.133333),
    'TJMZ' => array('name' => 'PR - Mayaguez, Eugenio Maria de Hostos Airport', 'lat' => 18.266667, 'long' => -67.150000),
    'TJPS' => array('name' => 'PR - Ponce, Mercedita Airport', 'lat' => 18.016667, 'long' => -66.566667),
    'TJNR' => array('name' => 'PR - Roosevelt Roads, Roosevelt Roads Naval Station, Ofstie Field', 'lat' => 18.255278, 'long' => -65.643333),
    'TJSJ' => array('name' => 'PR - San Juan, Luis Munoz Marin International Airport', 'lat' => 18.450000, 'long' => -66.000000),
    'KBID' => array('name' => 'RI - Block Island, Block Island State Airport', 'lat' => 41.166667, 'long' => -71.566667),
    'KOQU' => array('name' => 'RI - N. Kingston / Quonset', 'lat' => 41.600000, 'long' => -71.416667),
    'KUUU' => array('name' => 'RI - Newport, Newport State Airport', 'lat' => 41.530000, 'long' => -71.283611),
    'KSFZ' => array('name' => 'RI - Pawtucket, North Central State Airport', 'lat' => 41.916667, 'long' => -71.500000),
    'KPVD' => array('name' => 'RI - Providence, Theodore Francis Green State Airport', 'lat' => 41.723889, 'long' => -71.428056),
    'KWST' => array('name' => 'RI - Westerly, Westerly State Airport', 'lat' => 41.349722, 'long' => -71.798889),
    'KAND' => array('name' => 'SC - Anderson, Anderson County Airport', 'lat' => 34.497778, 'long' => -82.709722),
    'KNBC' => array('name' => 'SC - Beaufort, Marine Corps Air Station', 'lat' => 32.493611, 'long' => -80.703056),
    'KCHS' => array('name' => 'SC - Charleston, Charleston Air Force Base', 'lat' => 32.898889, 'long' => -80.040556),
    'KCEU' => array('name' => 'SC - Clemson, Clemson-Oconee County Airport', 'lat' => 34.672222, 'long' => -82.881389),
    'KCAE' => array('name' => 'SC - Columbia, Columbia Metropolitan Airport', 'lat' => 33.941944, 'long' => -81.118056),
    'KCUB' => array('name' => 'SC - Columbia, Columbia Owens Downtown Airport', 'lat' => 33.970833, 'long' => -80.994444),
    'KUDG' => array('name' => 'SC - Darlington, Darlington County Jetport Airport', 'lat' => 34.449167, 'long' => -79.890278),
    'KFLO' => array('name' => 'SC - Florence, Florence Regional Airport', 'lat' => 34.187778, 'long' => -79.730833),
    'KGMU' => array('name' => 'SC - Greenville, Greenville Downtown Airport', 'lat' => 34.846111, 'long' => -82.346111),
    'KGRD' => array('name' => 'SC - Greenwood, Greenwood County Airport', 'lat' => 34.247222, 'long' => -82.154722),
    'KGSP' => array('name' => 'SC - Greer, Greenville-Spartanburg Airport', 'lat' => 34.883889, 'long' => -82.220833),
    'KHXD' => array('name' => 'SC - Hilton Head Island, Hilton Head Airport', 'lat' => 32.216667, 'long' => -80.700000),
    'KMMT' => array('name' => 'SC - McEntire Air National Guard Weather Facility Base', 'lat' => 33.916667, 'long' => -80.800000),
    'KMYR' => array('name' => 'SC - Myrtle Beach Air Force Base', 'lat' => 33.683333, 'long' => -78.933333),
    'KCRE' => array('name' => 'SC - North Myrtle Beach, Grand Strand Airport', 'lat' => 33.811667, 'long' => -78.723889),
    'KOGB' => array('name' => 'SC - Orangeburg, Orangeburg Municipal Airport', 'lat' => 33.463889, 'long' => -80.853611),
    'KUZA' => array('name' => 'SC - Rock Hill, Rock Hill - York County Airport', 'lat' => 34.983889, 'long' => -81.055833),
    'KSSC' => array('name' => 'SC - Shaw Air Force Base', 'lat' => 33.966667, 'long' => -80.483333),
    'KABR' => array('name' => 'SD - Aberdeen, Aberdeen Regional Airport', 'lat' => 45.443333, 'long' => -98.413056),
    'KBKX' => array('name' => 'SD - Brookings, Brookings Municipal Airport', 'lat' => 44.300000, 'long' => -96.816667),
    'K2WX' => array('name' => 'SD - Buffalo', 'lat' => 45.604444, 'long' => -103.546389),
    'K9V9' => array('name' => 'SD - Chamberlain, Chamberlain Municipal Airport', 'lat' => 43.766667, 'long' => -99.318333),
    'KCUT' => array('name' => 'SD - Custer, Custer County Airport', 'lat' => 43.733056, 'long' => -103.617500),
    'KRCA' => array('name' => 'SD - Ellsworth Air Force Base', 'lat' => 44.150000, 'long' => -103.100000),
    'KD07' => array('name' => 'SD - Faith', 'lat' => 45.031944, 'long' => -102.019167),
    'KHON' => array('name' => 'SD - Huron, Huron Regional Airport', 'lat' => 44.388056, 'long' => -98.228333),
    'KMHE' => array('name' => 'SD - Mitchell, Mitchell Municipal Airport', 'lat' => 43.766667, 'long' => -98.033333),
    'KMBG' => array('name' => 'SD - Mobridge, Mobridge Municipal Airport', 'lat' => 45.550000, 'long' => -100.408611),
    'KPHP' => array('name' => 'SD - Philip, Philip Airport', 'lat' => 44.051111, 'long' => -101.601111),
    'KPIR' => array('name' => 'SD - Pierre, Pierre Regional Airport', 'lat' => 44.382778, 'long' => -100.285833),
    'KIEN' => array('name' => 'SD - Pine Ridge, Pine Ridge Airport', 'lat' => 43.025556, 'long' => -102.523056),
    'KRAP' => array('name' => 'SD - Rapid City, Rapid City Regional Airport', 'lat' => 44.045556, 'long' => -103.053889),
    'KFSD' => array('name' => 'SD - Sioux Falls, Foss Field', 'lat' => 43.576944, 'long' => -96.753611),
    'K8D3' => array('name' => 'SD - Sisseton, Sisseton Municipal Airport', 'lat' => 45.668889, 'long' => -96.991389),
    'KATY' => array('name' => 'SD - Watertown, Watertown Municipal Airport', 'lat' => 44.904722, 'long' => -97.149444),
    'KSFD' => array('name' => 'SD - Winner, Bob Wiley Field Airport', 'lat' => 43.390556, 'long' => -99.842500),
    'KYKN' => array('name' => 'SD - Yankton, Chan Gurney Municipal Airport', 'lat' => 42.916667, 'long' => -97.383333),
    'KTRI' => array('name' => 'TN - Bristol / Johnson / Kingsport, Tri-City Regional Airport', 'lat' => 36.479722, 'long' => -82.398889),
    'KCHA' => array('name' => 'TN - Chattanooga, Lovell Field', 'lat' => 35.033333, 'long' => -85.200000),
    'KCKV' => array('name' => 'TN - Clarksville, Outlaw Field Airport', 'lat' => 36.621944, 'long' => -87.415000),
    'KCSV' => array('name' => 'TN - Crossville, Crossville Memorial-Whitson Field Airport', 'lat' => 35.951389, 'long' => -85.085000),
    'KDYR' => array('name' => 'TN - Dyersburg, Dyersburg Municipal Airport', 'lat' => 36.000000, 'long' => -89.400000),
    'KMKL' => array('name' => 'TN - Jackson, McKellar-Sipes Regional Airport', 'lat' => 35.593056, 'long' => -88.916667),
    'KTYS' => array('name' => 'TN - Knoxville, McGhee Tyson Airport', 'lat' => 35.818056, 'long' => -83.985833),
    'KMEM' => array('name' => 'TN - Memphis, Memphis International Airport', 'lat' => 35.061111, 'long' => -89.985000),
    'KNQA' => array('name' => 'TN - Millington, Millington Municipal Airport', 'lat' => 35.356667, 'long' => -89.870278),
    'KBNA' => array('name' => 'TN - Nashville, Nashville International Airport', 'lat' => 36.118889, 'long' => -86.689167),
    'KOQT' => array('name' => 'TN - Oak Ridge', 'lat' => 36.022778, 'long' => -84.233333),
    'KMQY' => array('name' => 'TN - Smyrna, Smyrna Airport', 'lat' => 36.008889, 'long' => -86.520000),
    'KABI' => array('name' => 'TX - Abilene, Abilene Regional Airport', 'lat' => 32.410278, 'long' => -99.681667),
    'KDYS' => array('name' => 'TX - Abilene, Dyess Air Force Base', 'lat' => 32.420000, 'long' => -99.856944),
    'KALI' => array('name' => 'TX - Alice, Alice International Airport', 'lat' => 27.741111, 'long' => -98.026944),
    'KE38' => array('name' => 'TX - Alpine, Alpine-Casparis Municipal Airport', 'lat' => 30.384167, 'long' => -103.683333),
    'KAMA' => array('name' => 'TX - Amarillo, Amarillo International Airport', 'lat' => 35.220000, 'long' => -101.717222),
    'KLBX' => array('name' => 'TX - Angleton / Lake Jackson, Brazoria County Airport', 'lat' => 29.115278, 'long' => -95.463056),
    'KGKY' => array('name' => 'TX - Arlington, Arlington Municipal Airport', 'lat' => 32.663889, 'long' => -97.095833),
    'KATT' => array('name' => 'TX - Austin City, Austin Camp Mabry', 'lat' => 30.316667, 'long' => -97.766667),
    'KAUS' => array('name' => 'TX - Austin, Austin-Bergstrom International Airport', 'lat' => 30.194444, 'long' => -97.670000),
    'KBYY' => array('name' => 'TX - Bay City, Bay City Municipal Airport', 'lat' => 28.973056, 'long' => -95.863333),
    'KBPT' => array('name' => 'TX - Beaumont / Port Arthur, Southeast Texas Regional Airport', 'lat' => 29.950833, 'long' => -94.020833),
    'KBGD' => array('name' => 'TX - Borger, Hutchinson County Airport', 'lat' => 35.695000, 'long' => -101.395000),
    'KBBD' => array('name' => 'TX - Brady, Curtis Field Airport', 'lat' => 31.179167, 'long' => -99.323889),
    'K11R' => array('name' => 'TX - Brenham, Brenham Municipal Airport', 'lat' => 30.218889, 'long' => -96.374167),
    'KXBP' => array('name' => 'TX - Bridgeport, Bridgeport Municipal Airport', 'lat' => 33.175278, 'long' => -97.828333),
    'KBRO' => array('name' => 'TX - Brownsville, Brownsville / South Padre Island International Airport', 'lat' => 25.914167, 'long' => -97.423056),
    'KBWD' => array('name' => 'TX - Brownwood, Brownwood Regional Airport', 'lat' => 31.800000, 'long' => -98.950000),
    'KBMQ' => array('name' => 'TX - Burnet, Burnet Municipal Craddock Field', 'lat' => 30.740556, 'long' => -98.235278),
    'KRWV' => array('name' => 'TX - Caldwell, Caldwell Municipal Airport', 'lat' => 30.515278, 'long' => -96.703889),
    'KHHF' => array('name' => 'TX - Canadian, Hemphill County Airport', 'lat' => 35.900000, 'long' => -100.400000),
    'KCDS' => array('name' => 'TX - Childress, Childress Municipal Airport', 'lat' => 34.427500, 'long' => -100.283333),
    'KLBR' => array('name' => 'TX - Clarksville, Clarksville/Red River County-J D Trissell Field Airport', 'lat' => 33.593056, 'long' => -95.063333),
    'KCLL' => array('name' => 'TX - College Station, Easterwood Field', 'lat' => 30.582222, 'long' => -96.361667),
    'KMKN' => array('name' => 'TX - Comanche, Comanche County-City Airport', 'lat' => 31.916667, 'long' => -98.600278),
    'KCXO' => array('name' => 'TX - Conroe, Montgomery County Airport', 'lat' => 30.356667, 'long' => -95.413889),
    'KCRP' => array('name' => 'TX - Corpus Christi, Corpus Christi International Airport', 'lat' => 27.773056, 'long' => -97.512778),
    'KNGP' => array('name' => 'TX - Corpus Christi, Corpus Christi Naval Air Station/Truax Field', 'lat' => 27.692500, 'long' => -97.291111),
    'KCRS' => array('name' => 'TX - Corsicana, Campbell Field-Corsicana Municipal Airport', 'lat' => 32.031111, 'long' => -96.398889),
    'KCOT' => array('name' => 'TX - Cotulla, Cotulla-La Salle County Airport', 'lat' => 28.458333, 'long' => -99.220278),
    'KDHT' => array('name' => 'TX - Dalhart, Dalhart Municipal Airport', 'lat' => 36.023333, 'long' => -102.547222),
    'KADS' => array('name' => 'TX - Dallas / Addison Airport', 'lat' => 32.966667, 'long' => -96.833333),
    'KDFW' => array('name' => 'TX - Dallas / Fort Worth, Dallas / Fort Worth International Airport', 'lat' => 32.896944, 'long' => -97.021944),
    'KDAL' => array('name' => 'TX - Dallas, Dallas Love Field', 'lat' => 32.852500, 'long' => -96.855556),
    'KRBD' => array('name' => 'TX - Dallas, Redbird Airport', 'lat' => 32.675833, 'long' => -96.863889),
    'KLUD' => array('name' => 'TX - Decatur, Decatur Municipal Airport', 'lat' => 33.254444, 'long' => -97.580556),
    'KDRT' => array('name' => 'TX - Del Rio, Del Rio International Airport', 'lat' => 29.374722, 'long' => -100.923611),
    'KDTO' => array('name' => 'TX - Denton, Denton Municipal Airport', 'lat' => 33.206111, 'long' => -97.198889),
    'K6R6' => array('name' => 'TX - Dryden, Terrel County Airport', 'lat' => 30.048056, 'long' => -102.213056),
    'KDUX' => array('name' => 'TX - Dumas, Moore County Airport', 'lat' => 35.857778, 'long' => -102.013056),
    'KEBG' => array('name' => 'TX - Edinburg, Edinburg International Airport', 'lat' => 26.441944, 'long' => -98.129444),
    'KELP' => array('name' => 'TX - El Paso, El Paso International Airport', 'lat' => 31.811111, 'long' => -106.375833),
    'KHLR' => array('name' => 'TX - Fort Hood, Hood AAF Ft Hood', 'lat' => 31.133333, 'long' => -97.700000),
    'KGRK' => array('name' => 'TX - Fort Hood, Robert Gray AAF Ft Hood', 'lat' => 31.066667, 'long' => -97.816667),
    'KFST' => array('name' => 'TX - Fort Stockton, Fort Stockton-Pecos County Airport', 'lat' => 30.911944, 'long' => -102.916667),
    'KAFW' => array('name' => 'TX - Fort Worth, Fort Worth Alliance Airport', 'lat' => 32.973333, 'long' => -97.318056),
    'KFWS' => array('name' => 'TX - Fort Worth, Fort Worth Spinks Airport', 'lat' => 32.566667, 'long' => -97.300000),
    'KFTW' => array('name' => 'TX - Fort Worth, Meacham International Airport', 'lat' => 32.825278, 'long' => -97.364167),
    'KNFW' => array('name' => 'TX - Fort Worth, Naval Air Station', 'lat' => 32.765833, 'long' => -97.433333),
    'KT82' => array('name' => 'TX - Fredericksburg, Gillespie County Airport', 'lat' => 30.243611, 'long' => -98.909444),
    'KGLE' => array('name' => 'TX - Gainesville, Gainesville Municipal Airport', 'lat' => 33.651389, 'long' => -97.196944),
    'KGLS' => array('name' => 'TX - Galveston, Scholes Field', 'lat' => 29.270278, 'long' => -94.864167),
    'KGOP' => array('name' => 'TX - Gatesville, City-County Airport', 'lat' => 31.421111, 'long' => -97.796944),
    'KGTU' => array('name' => 'TX - Georgetown, Georgetown Municipal Airport', 'lat' => 30.683333, 'long' => -97.683333),
    'KGYB' => array('name' => 'TX - Giddings, Giddings-Lee County Airport', 'lat' => 30.169167, 'long' => -96.980000),
    'KJXI' => array('name' => 'TX - Gilmer, Fox Stephens Field - Gilmer Municipal Airport', 'lat' => 32.698889, 'long' => -94.948611),
    'KRPH' => array('name' => 'TX - Graham, Graham Municipal Airport', 'lat' => 33.110000, 'long' => -98.555278),
    'KGDJ' => array('name' => 'TX - Granbury, Granbury Municipal Airport', 'lat' => 32.444167, 'long' => -97.816667),
    'KGPM' => array('name' => 'TX - Grand Prairie, Grand Prairie Municipal Airport', 'lat' => 32.698611, 'long' => -97.046667),
    'KGVT' => array('name' => 'TX - Greenville / Majors', 'lat' => 33.066667, 'long' => -96.066667),
    'KHRL' => array('name' => 'TX - Harlingen, Rio Grande Valley International Airport', 'lat' => 26.229722, 'long' => -97.655278),
    'KHBV' => array('name' => 'TX - Hebbronville, Jim Hogg County Airport', 'lat' => 27.333333, 'long' => -98.733333),
    'KINJ' => array('name' => 'TX - Hillsboro, Hillsboro Municipal Airport', 'lat' => 32.083333, 'long' => -97.097222),
    'KHDO' => array('name' => 'TX - Hondo, Hondo Municipal Airport', 'lat' => 29.359444, 'long' => -99.174167),
    'KEFD' => array('name' => 'TX - Houston / Ellington', 'lat' => 29.600000, 'long' => -95.166667),
    'KDWH' => array('name' => 'TX - Houston, Hooks Memorial Airport', 'lat' => 30.067500, 'long' => -95.556111),
    'KHOU' => array('name' => 'TX - Houston, Houston Hobby Airport', 'lat' => 29.637500, 'long' => -95.282500),
    'KIAH' => array('name' => 'TX - Houston, Houston Intercontinental Airport', 'lat' => 29.992500, 'long' => -95.363889),
    'KLVJ' => array('name' => 'TX - Houston, Pearland Regional Airport', 'lat' => 29.521111, 'long' => -95.241944),
    'KSGR' => array('name' => 'TX - Houston, Sugar Land Municipal / Hull Field Airport', 'lat' => 29.622222, 'long' => -95.656667),
    'KUTS' => array('name' => 'TX - Huntsville, Huntsville Municipal Airport', 'lat' => 30.743889, 'long' => -95.586111),
    'KJSO' => array('name' => 'TX - Jacksonville, Cherokee County Airport', 'lat' => 31.869167, 'long' => -95.217222),
    'KJAS' => array('name' => 'TX - Jasper, Jasper County-Bell Field Airport', 'lat' => 30.885556, 'long' => -94.034722),
    'KJCT' => array('name' => 'TX - Junction, Kimble County Airport', 'lat' => 30.510833, 'long' => -99.766389),
    'KSKF' => array('name' => 'TX - Kelly Air Force Base', 'lat' => 29.383333, 'long' => -98.583333),
    'KERV' => array('name' => 'TX - Kerrville, Kerrville Municipal Airport/Louis Schreiner Field', 'lat' => 29.966667, 'long' => -99.083333),
    'KILE' => array('name' => 'TX - Killeen, Skylark Field Airport', 'lat' => 31.083333, 'long' => -97.683333),
    'KNQI' => array('name' => 'TX - Kingsville, Naval Air Station', 'lat' => 27.503056, 'long' => -97.811667),
    'K3T5' => array('name' => 'TX - La Grange, Fayette Regional Air Center Airport', 'lat' => 29.908056, 'long' => -96.950000),
    'KLNC' => array('name' => 'TX - Lancaster, Lancaster Airport', 'lat' => 32.579167, 'long' => -96.718889),
    'KLRD' => array('name' => 'TX - Laredo, Laredo International Airport', 'lat' => 27.543611, 'long' => -99.461389),
    'KDLF' => array('name' => 'TX - Laughlin, Laughlin Air Force Base Auxiliary Airfield', 'lat' => 29.116667, 'long' => -100.466667),
    'KAQO' => array('name' => 'TX - Llano, Llano Municipal Airport', 'lat' => 30.783611, 'long' => -98.661944),
    'KGGG' => array('name' => 'TX - Longview, Gregg County Airport', 'lat' => 32.390556, 'long' => -94.713889),
    'KLBB' => array('name' => 'TX - Lubbock, Lubbock International Airport', 'lat' => 33.667500, 'long' => -101.821389),
    'KLFK' => array('name' => 'TX - Lufkin, Angelina County Airport', 'lat' => 31.233889, 'long' => -94.750000),
    'KMRF' => array('name' => 'TX - Marfa', 'lat' => 30.366667, 'long' => -104.016667),
    'KTKI' => array('name' => 'TX - Mc Kinney, Collin County Regional Airport at Mc Kinney', 'lat' => 33.177778, 'long' => -96.590278),
    'KMFE' => array('name' => 'TX - McAllen, Miller International Airport', 'lat' => 26.179722, 'long' => -98.244444),
    'KHQZ' => array('name' => 'TX - Mesquite, Mesquite Metro Airport', 'lat' => 32.746944, 'long' => -96.530278),
    'KMDD' => array('name' => 'TX - Midland, Midland Airpark', 'lat' => 32.036389, 'long' => -102.100833),
    'KMAF' => array('name' => 'TX - Midland, Midland International Airport', 'lat' => 31.947778, 'long' => -102.208611),
    'KJWY' => array('name' => 'TX - Midlothian/Waxahachie, Mid-Way Regional Airport', 'lat' => 32.455833, 'long' => -96.912222),
    'KJDD' => array('name' => 'TX - Mineola/Quitman, Wood County Airport', 'lat' => 32.741944, 'long' => -95.496389),
    'KMWL' => array('name' => 'TX - Mineral Wells, Mineral Wells Airport', 'lat' => 32.781667, 'long' => -98.060278),
    'KOSA' => array('name' => 'TX - Mount Pleasant, Mount Pleasant Regional Airport', 'lat' => 33.095278, 'long' => -94.961389),
    'KOCH' => array('name' => 'TX - Nacogdoches, A L Mangham Jr. Regional Airport', 'lat' => 31.583333, 'long' => -94.716667),
    'KBAZ' => array('name' => 'TX - New Braunfels, New Braunfels Municipal Airport', 'lat' => 29.708611, 'long' => -98.045278),
    'KODO' => array('name' => 'TX - Odessa, Odessa-Schlemeyer Field', 'lat' => 31.921389, 'long' => -102.391667),
    'KORG' => array('name' => 'TX - Orange, Orange County Airport', 'lat' => 30.069167, 'long' => -93.803611),
    'KPSX' => array('name' => 'TX - Palacios, Palacios Municipal Airport', 'lat' => 28.727500, 'long' => -96.250833),
    'KPSN' => array('name' => 'TX - Palestine, Palestine Municipal Airport', 'lat' => 31.779444, 'long' => -95.706111),
    'KPPA' => array('name' => 'TX - Pampa, Perry Lefors Field Airport', 'lat' => 35.612778, 'long' => -100.996111),
    'KPRX' => array('name' => 'TX - Paris / Cox Field', 'lat' => 33.633333, 'long' => -95.450000),
    'KPEQ' => array('name' => 'TX - Pecos, Pecos Municipal Airport', 'lat' => 31.382222, 'long' => -103.510556),
    'KPYX' => array('name' => 'TX - Perryton, Perryton Ochiltree County Airport', 'lat' => 36.400000, 'long' => -100.733333),
    'KGDP' => array('name' => 'TX - Pine Springs, Guadalupe Mountains National Park', 'lat' => 31.831111, 'long' => -104.808889),
    'KPVW' => array('name' => 'TX - Plainview, Hale County Airport', 'lat' => 34.168056, 'long' => -101.717222),
    'KRAS' => array('name' => 'TX - Port Aransas, Mustang Beach Airport', 'lat' => 27.811667, 'long' => -97.088611),
    'KPIL' => array('name' => 'TX - Port Isabel, Port Isabel-Cameron County Airport', 'lat' => 26.159167, 'long' => -97.337500),
    'KRND' => array('name' => 'TX - Randolph Air Force Base', 'lat' => 29.533333, 'long' => -98.283333),
    'KRKP' => array('name' => 'TX - Rockport, Aransas County Airport', 'lat' => 28.083611, 'long' => -97.046389),
    'KECU' => array('name' => 'TX - Rocksprings, Edwards County Airport', 'lat' => 29.946667, 'long' => -100.173611),
    'KRPE' => array('name' => 'TX - Sabine Pass', 'lat' => 29.700000, 'long' => -93.950000),
    'KSJT' => array('name' => 'TX - San Angelo, Mathis Field', 'lat' => 31.351389, 'long' => -100.493889),
    'KSAT' => array('name' => 'TX - San Antonio, San Antonio International Airport', 'lat' => 29.532778, 'long' => -98.463611),
    'KSSF' => array('name' => 'TX - San Antonio, Stinson Municipal Airport', 'lat' => 29.338889, 'long' => -98.471667),
    'KHYI' => array('name' => 'TX - San Marcos, San Marcos Municipal Airport', 'lat' => 29.893611, 'long' => -97.864722),
    'KGNC' => array('name' => 'TX - Seminole, Gaines County Airport', 'lat' => 32.675278, 'long' => -102.652500),
    'KGYI' => array('name' => 'TX - Sherman/Denison, Grayson County Airport', 'lat' => 33.716667, 'long' => -96.666667),
    'KSNK' => array('name' => 'TX - Snyder, Winston Field Airport', 'lat' => 32.693333, 'long' => -100.950278),
    'KSOA' => array('name' => 'TX - Sonora, Sonora Municipal Airport', 'lat' => 30.585556, 'long' => -100.648333),
    'KSEP' => array('name' => 'TX - Stephenville, Clark Field Municipal Airport', 'lat' => 32.216667, 'long' => -98.183333),
    'KSLR' => array('name' => 'TX - Sulphur Springs, Sulphur Springs Municipal Airport', 'lat' => 33.161111, 'long' => -95.621111),
    'KSWW' => array('name' => 'TX - Sweetwater, Avenger Field Airport', 'lat' => 32.467222, 'long' => -100.466389),
    'KTPL' => array('name' => 'TX - Temple, Draughon-Miller Central Texas Regional Airport', 'lat' => 31.150000, 'long' => -97.400000),
    'KTRL' => array('name' => 'TX - Terrell, Terrell Municipal Airport', 'lat' => 32.713611, 'long' => -96.268333),
    'KTYR' => array('name' => 'TX - Tyler, Tyler Pounds Field', 'lat' => 32.358611, 'long' => -95.403889),
    'KUVA' => array('name' => 'TX - Uvalde, Garner Field Airport', 'lat' => 29.211111, 'long' => -99.743333),
    'KF05' => array('name' => 'TX - Vernon, Wilbarger County Airport', 'lat' => 34.225556, 'long' => -99.283611),
    'KVCT' => array('name' => 'TX - Victoria, Victoria Regional Airport', 'lat' => 28.862500, 'long' => -96.929722),
    'KPWG' => array('name' => 'TX - Waco, Mc Gregor Executive Airport', 'lat' => 31.483333, 'long' => -97.316667),
    'KACT' => array('name' => 'TX - Waco, Waco Regional Airport', 'lat' => 31.617222, 'long' => -97.227778),
    'KT65' => array('name' => 'TX - Weslaco, Mid Valley Airport', 'lat' => 26.177500, 'long' => -97.973056),
    'KARM' => array('name' => 'TX - Wharton, Wharton Regional Airport', 'lat' => 29.254167, 'long' => -96.154167),
    'KSPS' => array('name' => 'TX - Wichita Falls, Sheppard Air Force Base', 'lat' => 33.978611, 'long' => -98.492778),
    'KINK' => array('name' => 'TX - Wink, Winkler County Airport', 'lat' => 31.779722, 'long' => -103.201389),
    'K4BL' => array('name' => 'UT - Blanding', 'lat' => 37.616667, 'long' => -109.466667),
    'KBCE' => array('name' => 'UT - Bryce Canyon, Bryce Canyon Airport', 'lat' => 37.706389, 'long' => -112.145556),
    'KCDC' => array('name' => 'UT - Cedar City, Cedar City Municipal Airport', 'lat' => 37.706667, 'long' => -113.096667),
    'KU24' => array('name' => 'UT - Delta', 'lat' => 39.333333, 'long' => -112.583333),
    'KDPG' => array('name' => 'UT - Dugway Proving Grounds', 'lat' => 40.166667, 'long' => -112.933333),
    'KU28' => array('name' => 'UT - Green River Range', 'lat' => 39.000000, 'long' => -110.166667),
    'K4HV' => array('name' => 'UT - Hanksville', 'lat' => 38.366667, 'long' => -110.716667),
    'KHIF' => array('name' => 'UT - Hill Air Force Base / Ogden', 'lat' => 41.116667, 'long' => -111.966667),
    'KLGU' => array('name' => 'UT - Logan, Logan-Cache Airport', 'lat' => 41.782778, 'long' => -111.853889),
    'KMLF' => array('name' => 'UT - Milford, Milford Municipal Airport', 'lat' => 38.422500, 'long' => -113.009722),
    'KCNY' => array('name' => 'UT - Moab, Canyonlands Field', 'lat' => 38.760000, 'long' => -109.744722),
    'KOGD' => array('name' => 'UT - Ogden, Ogden-Hinckley Airport', 'lat' => 41.193611, 'long' => -112.016389),
    'KPUC' => array('name' => 'UT - Price, Carbon County Airport', 'lat' => 39.609167, 'long' => -110.754722),
    'KPVU' => array('name' => 'UT - Provo, Provo Municipal Airport', 'lat' => 40.216667, 'long' => -111.716667),
    'KSLC' => array('name' => 'UT - Salt Lake City, Salt Lake City International Airport', 'lat' => 40.778056, 'long' => -111.969444),
    'KSGU' => array('name' => 'UT - St George, St George Municipal Airport', 'lat' => 37.083333, 'long' => -113.600000),
    'KVEL' => array('name' => 'UT - Vernal, Vernal Airport', 'lat' => 40.444167, 'long' => -109.511667),
    'KENV' => array('name' => 'UT - Wendover / Air Force Auxillary Field', 'lat' => 40.733333, 'long' => -114.033333),
    'KVJI' => array('name' => 'VA - Abingdon', 'lat' => 36.683333, 'long' => -82.033333),
    'KOFP' => array('name' => 'VA - Ashland, Hanover County Municipal Airport', 'lat' => 37.708056, 'long' => -77.434444),
    'KCHO' => array('name' => 'VA - Charlottesville, Charlottesville-Albemarle Airport', 'lat' => 38.138333, 'long' => -78.455833),
    'KCPK' => array('name' => 'VA - Chesapeake, Chesapeake Municipal Airport', 'lat' => 36.665556, 'long' => -76.320556),
    'KCJR' => array('name' => 'VA - Culpeper, Culpeper County Airport', 'lat' => 38.526667, 'long' => -77.858889),
    'KDAN' => array('name' => 'VA - Danville, Danville Regional Airport', 'lat' => 36.572778, 'long' => -79.336111),
    'KPSK' => array('name' => 'VA - Dublin / New River Valley', 'lat' => 37.133333, 'long' => -80.683333),
    'KEMV' => array('name' => 'VA - Emporia, Emporia-Greensville Regional Airport', 'lat' => 36.686944, 'long' => -77.482778),
    'KFVX' => array('name' => 'VA - Farmville', 'lat' => 37.350000, 'long' => -78.433333),
    'KDAA' => array('name' => 'VA - Fort Belvoir', 'lat' => 38.716667, 'long' => -77.183333),
    'KFAF' => array('name' => 'VA - Fort Eustis / Felker', 'lat' => 37.133333, 'long' => -76.616667),
    'KFKN' => array('name' => 'VA - Franklin / J B Rose', 'lat' => 36.700000, 'long' => -76.900000),
    'KEZF' => array('name' => 'VA - Fredericksburg, Shannon Airport', 'lat' => 38.266667, 'long' => -77.450000),
    'KHLX' => array('name' => 'VA - Hillsville', 'lat' => 36.766667, 'long' => -80.816667),
    'KHSP' => array('name' => 'VA - Hot Springs / Ingalls', 'lat' => 37.950000, 'long' => -79.833333),
    'KLFI' => array('name' => 'VA - Langley Air Force Base', 'lat' => 37.083333, 'long' => -76.350000),
    'KJYO' => array('name' => 'VA - Leesburg / Godfrey', 'lat' => 39.083333, 'long' => -77.566667),
    'KLKU' => array('name' => 'VA - Louisa, Louisa County Airport/Freeman Field', 'lat' => 38.009722, 'long' => -77.970278),
    'KLYH' => array('name' => 'VA - Lynchburg, Lynchburg Regional Airport', 'lat' => 37.320833, 'long' => -79.206667),
    'KHEF' => array('name' => 'VA - Manassas, Manassas Regional Airport/Harry P. Davis Field', 'lat' => 38.716667, 'long' => -77.516667),
    'KMKJ' => array('name' => 'VA - Marion / Wytheville', 'lat' => 36.900000, 'long' => -81.350000),
    'KMTV' => array('name' => 'VA - Martinsville', 'lat' => 36.633333, 'long' => -80.016667),
    'KMFV' => array('name' => 'VA - Melfa / Accomack Airport', 'lat' => 37.650000, 'long' => -75.766667),
    'KPHF' => array('name' => 'VA - Newport News, Newport News / Williamsburg International Airport', 'lat' => 37.131944, 'long' => -76.493056),
    'KNGU' => array('name' => 'VA - Norfolk, Naval Air Station', 'lat' => 36.933611, 'long' => -76.295833),
    'KORF' => array('name' => 'VA - Norfolk, Norfolk International Airport', 'lat' => 36.903611, 'long' => -76.191944),
    'KOMH' => array('name' => 'VA - Orange, Orange County Airport', 'lat' => 38.247222, 'long' => -78.045556),
    'KPTB' => array('name' => 'VA - Petersburg, Dinwiddie County Airport', 'lat' => 37.183333, 'long' => -77.516667),
    'KNYG' => array('name' => 'VA - Quantico, Marine Corps Air Facility', 'lat' => 38.512500, 'long' => -77.291667),
    'K6V3' => array('name' => 'VA - Richlands, Tazewell County Airport', 'lat' => 37.063611, 'long' => -81.798056),
    'KRIC' => array('name' => 'VA - Richmond, Richmond International Airport', 'lat' => 37.511111, 'long' => -77.323333),
    'KROA' => array('name' => 'VA - Roanoke, Roanoke Regional Airport', 'lat' => 37.316944, 'long' => -79.974167),
    'KAVC' => array('name' => 'VA - South Hill, Mecklenburg-Brunswick Regional Airport', 'lat' => 36.688611, 'long' => -78.054167),
    'KRMN' => array('name' => 'VA - Stafford, Stafford Regional Airport', 'lat' => 38.398056, 'long' => -77.455278),
    'KSHD' => array('name' => 'VA - Staunton / Shenandoah', 'lat' => 38.266667, 'long' => -78.900000),
    'KSFQ' => array('name' => 'VA - Suffolk, Suffolk Municipal Airport', 'lat' => 36.682222, 'long' => -76.601944),
    'KNTU' => array('name' => 'VA - Virginia Beach, Oceana, Naval Air Station', 'lat' => 36.821111, 'long' => -76.028333),
    'KBCB' => array('name' => 'VA - Virginia Tech Airport', 'lat' => 37.216667, 'long' => -80.416667),
    'KAKQ' => array('name' => 'VA - Wakefield, Wakefield Municipal Airport', 'lat' => 36.981389, 'long' => -77.001111),
    'KWAL' => array('name' => 'VA - Wallops Island, Wallops Flight Facility Airport', 'lat' => 37.940556, 'long' => -75.463056),
    'KDCA' => array('name' => 'VA - Washington DC, Reagan National Airport', 'lat' => 38.848333, 'long' => -77.034167),
    'KIAD' => array('name' => 'VA - Washington DC, Washington-Dulles International Airport', 'lat' => 38.934722, 'long' => -77.447500),
    'KFYJ' => array('name' => 'VA - West Point, Middle Peninsula Regional Airport', 'lat' => 37.521111, 'long' => -76.764444),
    'KJGG' => array('name' => 'VA - Williamsburg, Williamsburg-Jamestown Airport', 'lat' => 37.239167, 'long' => -76.715833),
    'KOKV' => array('name' => 'VA - Winchester Regional', 'lat' => 39.150000, 'long' => -78.150000),
    'KLNP' => array('name' => 'VA - Wise / Lonesome Pine', 'lat' => 36.983333, 'long' => -82.533333),
    'KMPV' => array('name' => 'VT - Barre / Montpelier, Knapp State Airport', 'lat' => 44.204722, 'long' => -72.566111),
    'KDDH' => array('name' => 'VT - Bennington, Bennington Morse State Airport', 'lat' => 42.890000, 'long' => -73.246389),
    'KBTV' => array('name' => 'VT - Burlington, Burlington International Airport', 'lat' => 44.468056, 'long' => -73.150278),
    'KMVL' => array('name' => 'VT - Morrisville, Morrisville-Stowe State Airport', 'lat' => 44.536111, 'long' => -72.616111),
    'KRUT' => array('name' => 'VT - Rutland, Rutland State Airport', 'lat' => 43.533333, 'long' => -72.950000),
    'K1V4' => array('name' => 'VT - Saint Johnsbury', 'lat' => 44.419444, 'long' => -72.019444),
    'KVSF' => array('name' => 'VT - Springfield, Hartness State Springfield Airport', 'lat' => 43.342500, 'long' => -72.521667),
    'KAWO' => array('name' => 'WA - Arlington Municipal', 'lat' => 48.166667, 'long' => -122.166667),
    'KBLI' => array('name' => 'WA - Bellingham, Bellingham International Airport', 'lat' => 48.799444, 'long' => -122.539167),
    'KPWT' => array('name' => 'WA - Bremerton, Bremerton National Airport', 'lat' => 47.500000, 'long' => -122.750000),
    'KBVS' => array('name' => 'WA - Burlington/Mount Vernon, Skagit Regional Airport', 'lat' => 48.470833, 'long' => -122.420833),
    'KDEW' => array('name' => 'WA - Deer Park, Deer Park Airport', 'lat' => 47.974167, 'long' => -117.428333),
    'KORS' => array('name' => 'WA - Eastsound, Orcas Island Airport', 'lat' => 48.708056, 'long' => -122.910278),
    'KELN' => array('name' => 'WA - Ellensburg, Ellensburg Bowers Field', 'lat' => 47.033611, 'long' => -120.529167),
    'KEPH' => array('name' => 'WA - Ephrata, Ephrata Municipal Airport', 'lat' => 47.307500, 'long' => -119.515833),
    'KPAE' => array('name' => 'WA - Everett, Snohomish County Airport', 'lat' => 47.923056, 'long' => -122.282500),
    'KSKA' => array('name' => 'WA - Fairchild Air Force Base', 'lat' => 47.616667, 'long' => -117.650000),
    'KGRF' => array('name' => 'WA - Fort Lewis / Gray U. S. Army Airfield', 'lat' => 47.116667, 'long' => -122.550000),
    'KFHR' => array('name' => 'WA - Friday Harbor, Friday Harbor Airport', 'lat' => 48.520278, 'long' => -123.025278),
    'KHMS' => array('name' => 'WA - Hanford', 'lat' => 46.566667, 'long' => -119.600000),
    'KHQM' => array('name' => 'WA - Hoquiam, Bowerman Airport', 'lat' => 46.971111, 'long' => -123.920000),
    'KKLS' => array('name' => 'WA - Kelso, Kelso-Longview Airport', 'lat' => 46.116667, 'long' => -122.900000),
    'KMWH' => array('name' => 'WA - Moses Lake, Grant County Airport', 'lat' => 47.193056, 'long' => -119.313333),
    'K76S' => array('name' => 'WA - Oak Harbor Airpark', 'lat' => 48.250000, 'long' => -122.666667),
    'KOLM' => array('name' => 'WA - Olympia, Olympia Airport', 'lat' => 46.973333, 'long' => -122.903333),
    'KOMK' => array('name' => 'WA - Omak, Omak Airport', 'lat' => 48.464167, 'long' => -119.518056),
    'KPSC' => array('name' => 'WA - Pasco, Tri-Cities Airport', 'lat' => 46.269722, 'long' => -119.116667),
    'KCLM' => array('name' => 'WA - Port Angeles, William R. Fairchild International Airport', 'lat' => 48.122222, 'long' => -123.505278),
    'KPUW' => array('name' => 'WA - Pullman / Moscow, Pullman / Moscow Regional Airport', 'lat' => 46.743889, 'long' => -117.109722),
    'KUIL' => array('name' => 'WA - Quillayute, Quillayute State Airport', 'lat' => 47.937500, 'long' => -124.555000),
    'KRNT' => array('name' => 'WA - Renton, Renton Municipal Airport', 'lat' => 47.494444, 'long' => -122.212778),
    'KBFI' => array('name' => 'WA - Seattle, Seattle Boeing Field', 'lat' => 47.545833, 'long' => -122.313611),
    'KSEA' => array('name' => 'WA - Seattle, Seattle-Tacoma International Airport', 'lat' => 47.444722, 'long' => -122.313611),
    'KSHN' => array('name' => 'WA - Shelton, Shelton Sanderson Field', 'lat' => 47.238056, 'long' => -123.140833),
    'KSFF' => array('name' => 'WA - Spokane, Felts Field', 'lat' => 47.685556, 'long' => -117.320278),
    'KGEG' => array('name' => 'WA - Spokane, Spokane International Airport', 'lat' => 47.621389, 'long' => -117.527778),
    'KSMP' => array('name' => 'WA - Stampede Pass', 'lat' => 47.276667, 'long' => -121.337222),
    'KTCM' => array('name' => 'WA - Tacoma / McChord Air Force Base', 'lat' => 47.150000, 'long' => -122.483333),
    'KTIW' => array('name' => 'WA - Tacoma, Tacoma Narrows Airport', 'lat' => 47.267500, 'long' => -122.576111),
    'KTDO' => array('name' => 'WA - Toledo-Winlock Memorial', 'lat' => 46.483333, 'long' => -122.800000),
    'KVUO' => array('name' => 'WA - Vancouver, Pearson Field Airport', 'lat' => 45.620278, 'long' => -122.656389),
    'KALW' => array('name' => 'WA - Walla Walla, Walla Walla Regional Airport', 'lat' => 46.095000, 'long' => -118.284167),
    'KEAT' => array('name' => 'WA - Wenatchee, Pangborn Memorial Airport', 'lat' => 47.398889, 'long' => -120.206944),
    'KNUW' => array('name' => 'WA - Whidbey Island, Naval Air Station', 'lat' => 48.349167, 'long' => -122.650556),
    'KYKM' => array('name' => 'WA - Yakima, Yakima Air Terminal', 'lat' => 46.564167, 'long' => -120.533611),
    'KAIG' => array('name' => 'WI - Antigo, Langlade County Airport', 'lat' => 45.150000, 'long' => -89.100000),
    'KATW' => array('name' => 'WI - Appleton / Outagamie', 'lat' => 44.250000, 'long' => -88.516667),
    'KASX' => array('name' => 'WI - Ashland, Kennedy Memorial Airport', 'lat' => 46.549722, 'long' => -90.918333),
    'KDLL' => array('name' => 'WI - Baraboo, Baraboo Wisconsin Dells Airport', 'lat' => 43.521944, 'long' => -89.770833),
    'KOVS' => array('name' => 'WI - Boscobel, Boscobel Airport', 'lat' => 43.156111, 'long' => -90.677500),
    'KCLI' => array('name' => 'WI - Clintonville, Clintonville Municipal Airport', 'lat' => 44.613889, 'long' => -88.731389),
    'KEGV' => array('name' => 'WI - Eagle River, Eagle River Union Airport', 'lat' => 45.931667, 'long' => -89.269167),
    'KEAU' => array('name' => 'WI - Eau Claire, Chippewa Valley Regional Airport', 'lat' => 44.865278, 'long' => -91.485000),
    'KFLD' => array('name' => 'WI - Fond Du Lac, Fond Du Lac County Airport', 'lat' => 43.770000, 'long' => -88.486389),
    'KGRB' => array('name' => 'WI - Green Bay, Austin Straubel International Airport', 'lat' => 44.479444, 'long' => -88.136667),
    'KHYR' => array('name' => 'WI - Hayward, Hayward Municipal Airport', 'lat' => 46.020556, 'long' => -91.450278),
    'KJVL' => array('name' => 'WI - Janesville / Rock County', 'lat' => 42.616667, 'long' => -89.033333),
    'KUNU' => array('name' => 'WI - Juneau, Dodge County Airport', 'lat' => 43.426667, 'long' => -88.703333),
    'KENW' => array('name' => 'WI - Kenosha, Kenosha Regional Airport', 'lat' => 42.595000, 'long' => -87.938056),
    'KLSE' => array('name' => 'WI - La Crosse, La Crosse Municipal Airport', 'lat' => 43.879444, 'long' => -91.256667),
    'KRCX' => array('name' => 'WI - Ladysmith, Ruck County Airport', 'lat' => 45.496667, 'long' => -91.000278),
    'KLNL' => array('name' => 'WI - Land O\' Lakes, Kings Land O\' Lakes Airport', 'lat' => 46.153889, 'long' => -89.211944),
    'KLNR' => array('name' => 'WI - Lone Rock, Tri-County Regional Airport', 'lat' => 43.211944, 'long' => -90.181389),
    'KMSN' => array('name' => 'WI - Madison, Dane County Regional-Truax Field', 'lat' => 43.140556, 'long' => -89.345278),
    'KMTW' => array('name' => 'WI - Manitowoc, Manitowoc County Airport', 'lat' => 44.133333, 'long' => -87.683333),
    'KMFI' => array('name' => 'WI - Marshfield, Marshfield Municipal Airport', 'lat' => 44.638056, 'long' => -90.187500),
    'KMDZ' => array('name' => 'WI - Medford, Taylor County Airport', 'lat' => 45.101111, 'long' => -90.303333),
    'KRRL' => array('name' => 'WI - Merrill, Merrill Municipal Airport', 'lat' => 45.183333, 'long' => -89.700000),
    'KMWC' => array('name' => 'WI - Milwaukee / Timmerman', 'lat' => 43.116667, 'long' => -88.033333),
    'KMKE' => array('name' => 'WI - Milwaukee, General Mitchell International Airport', 'lat' => 42.955000, 'long' => -87.904444),
    'KMRJ' => array('name' => 'WI - Mineral Point, Iowa County Airport', 'lat' => 42.885278, 'long' => -90.231944),
    'KARV' => array('name' => 'WI - Minocqua/Woodruff, Lakeland Airport/Noble F. Lee Memorial Field', 'lat' => 45.933333, 'long' => -89.733333),
    'KEFT' => array('name' => 'WI - Monroe, Monroe Municipal Airport', 'lat' => 42.615000, 'long' => -89.590833),
    'KCWA' => array('name' => 'WI - Mosinee / Central Wisconsin', 'lat' => 44.783333, 'long' => -89.666667),
    'KRNH' => array('name' => 'WI - New Richmond, New Richmond Municipal Airport', 'lat' => 45.148333, 'long' => -92.538056),
    'KOEO' => array('name' => 'WI - Osceola, L O Simenstad Municipal Airport', 'lat' => 45.308611, 'long' => -92.690000),
    'KOSH' => array('name' => 'WI - Oshkosh, Wittman Regional Airport', 'lat' => 43.966667, 'long' => -88.558056),
    'KPBH' => array('name' => 'WI - Phillips / Price County', 'lat' => 45.700000, 'long' => -90.400000),
    'KPDC' => array('name' => 'WI - Prairie Du Chien, Prairie Du Chien Municipal Airport', 'lat' => 43.021944, 'long' => -91.124722),
    'KRAC' => array('name' => 'WI - Racine, Batten International Airport', 'lat' => 42.758611, 'long' => -87.817778),
    'KRHI' => array('name' => 'WI - Rhinelander, Rhinelander-Oneida County Airport', 'lat' => 45.631667, 'long' => -89.482222),
    'KRPD' => array('name' => 'WI - Rice Lake, Rice Lake Regional-Carl\'s Field Airport', 'lat' => 45.418056, 'long' => -91.773611),
    'KSBM' => array('name' => 'WI - Sheboygan, Sheboygan County Memorial Airport', 'lat' => 43.776389, 'long' => -87.849722),
    'KRZN' => array('name' => 'WI - Siren, Burnett County Airport', 'lat' => 45.822778, 'long' => -92.372500),
    'KCMY' => array('name' => 'WI - Sparta, Sparta / Fort McCoy Airport', 'lat' => 43.958333, 'long' => -90.737778),
    'KSTE' => array('name' => 'WI - Stevens Point, Stevens Point Municipal Airport', 'lat' => 44.545000, 'long' => -89.530278),
    'KSUE' => array('name' => 'WI - Sturgeon Bay', 'lat' => 44.850000, 'long' => -87.416667),
    'KSUW' => array('name' => 'WI - Superior, Richard I. Bong Airport', 'lat' => 46.689722, 'long' => -92.094722),
    'KTKV' => array('name' => 'WI - Tomahawk, Tomahawk Regional Airport', 'lat' => 45.468889, 'long' => -89.805556),
    'KVOK' => array('name' => 'WI - Volk / Camp Douglas', 'lat' => 43.933333, 'long' => -90.266667),
    'KRYV' => array('name' => 'WI - Watertown', 'lat' => 43.166667, 'long' => -88.716667),
    'KUES' => array('name' => 'WI - Waukesha, Waukesha County Airport', 'lat' => 43.041111, 'long' => -88.236944),
    'KPCZ' => array('name' => 'WI - Waupaca, Waupaca Municipal Airport', 'lat' => 44.333611, 'long' => -89.015278),
    'KAUW' => array('name' => 'WI - Wausau, Wausau Downtown Airport', 'lat' => 44.928611, 'long' => -89.626667),
    'KETB' => array('name' => 'WI - West Bend, West Bend Municipal Airport', 'lat' => 43.422222, 'long' => -88.128056),
    'KISW' => array('name' => 'WI - Wisconsin Rapids, Alexander Field South Wood County Airport', 'lat' => 44.359167, 'long' => -89.836944),
    'KBKW' => array('name' => 'WV - Beckley, Raleigh County Memorial Airport', 'lat' => 37.795000, 'long' => -81.124722),
    'KBLF' => array('name' => 'WV - Bluefield, Mercer County Airport', 'lat' => 37.295833, 'long' => -81.207778),
    'KW22' => array('name' => 'WV - Buckhannon, Upshur County Regional Airport', 'lat' => 39.000000, 'long' => -80.266667),
    'KCRW' => array('name' => 'WV - Charleston, Yeager Airport', 'lat' => 38.379444, 'long' => -81.591389),
    'KCKB' => array('name' => 'WV - Clarksburg, Clarksburg Benedum Airport', 'lat' => 39.300000, 'long' => -80.224722),
    'KEKN' => array('name' => 'WV - Elkins, Elkins-Randolph County-Jennings Randolph Field', 'lat' => 38.885278, 'long' => -79.852778),
    'KHTS' => array('name' => 'WV - Huntington, Tri-State Airport', 'lat' => 38.365000, 'long' => -82.555000),
    'KLWB' => array('name' => 'WV - Lewisburg / Greenbrier', 'lat' => 37.866667, 'long' => -80.400000),
    'KMRB' => array('name' => 'WV - Martinsburg, Eastern West Virginia Regional/Shepherd Airport', 'lat' => 39.401944, 'long' => -77.984444),
    'KMGW' => array('name' => 'WV - Morgantown, Morgantown Municipal-Hart Field', 'lat' => 39.649444, 'long' => -79.921111),
    'KPKB' => array('name' => 'WV - Parkersburg, Mid-Ohio Valley Regional Airport', 'lat' => 39.345000, 'long' => -81.439167),
    'KW99' => array('name' => 'WV - Petersburg, Grant County Airport', 'lat' => 38.983333, 'long' => -79.133333),
    'KI16' => array('name' => 'WV - Pineville, Kee Field Airport', 'lat' => 37.600278, 'long' => -81.559167),
    'K3I2' => array('name' => 'WV - Point Pleasant, Mason County Airport', 'lat' => 38.914444, 'long' => -82.098333),
    'K48I' => array('name' => 'WV - Sutton, Braxton County Airport', 'lat' => 38.686944, 'long' => -80.651667),
    'KHLG' => array('name' => 'WV - Wheeling, Wheeling Ohio County Airport', 'lat' => 40.170278, 'long' => -80.644444),
    'KARL' => array('name' => 'WY - Arlington', 'lat' => 41.700000, 'long' => -106.216667),
    'KBPI' => array('name' => 'WY - Big Piney, Big Piney-Marbleton Airport', 'lat' => 42.578889, 'long' => -110.103056),
    'KBRX' => array('name' => 'WY - Bordeaux', 'lat' => 41.933333, 'long' => -104.950000),
    'KBYG' => array('name' => 'WY - Buffalo, Buffalo Johnson County Airport', 'lat' => 44.381389, 'long' => -106.718889),
    'KCPR' => array('name' => 'WY - Casper, Natrona County International Airport', 'lat' => 42.897500, 'long' => -106.473056),
    'KCMS' => array('name' => 'WY - Cemetery Separa', 'lat' => 41.533333, 'long' => -109.466667),
    'KCYS' => array('name' => 'WY - Cheyenne, Cheyenne Airport', 'lat' => 41.157778, 'long' => -104.806944),
    'KCOD' => array('name' => 'WY - Cody', 'lat' => 44.516667, 'long' => -109.016667),
    'KDGW' => array('name' => 'WY - Douglas, Converse County Airport', 'lat' => 42.794167, 'long' => -105.381944),
    'KEVW' => array('name' => 'WY - Evanston, Evanston-Uninta County Burns Field', 'lat' => 41.273056, 'long' => -111.030556),
    'KGCC' => array('name' => 'WY - Gillette, Gillette-Campbell County Airport', 'lat' => 44.339444, 'long' => -105.541944),
    'KGEY' => array('name' => 'WY - Greybull, South Big Horn County Airport', 'lat' => 44.515833, 'long' => -108.075833),
    'KJAC' => array('name' => 'WY - Jackson, Jackson Hole Airport', 'lat' => 43.600000, 'long' => -110.733333),
    'KLND' => array('name' => 'WY - Lander', 'lat' => 42.814722, 'long' => -108.728056),
    'KLAR' => array('name' => 'WY - Laramie, Laramie Regional Airport', 'lat' => 41.311944, 'long' => -105.675000),
    'KPNA' => array('name' => 'WY - Pinedale, Ralph Wenz Field Airport', 'lat' => 42.795278, 'long' => -109.806944),
    'KPUM' => array('name' => 'WY - Pumpkin Vine', 'lat' => 41.050000, 'long' => -105.466667),
    'KRWL' => array('name' => 'WY - Rawlins, Rawlins Municipal Airport', 'lat' => 41.805556, 'long' => -107.199722),
    'KRIW' => array('name' => 'WY - Riverton, Riverton Regional Airport', 'lat' => 43.061944, 'long' => -108.446389),
    'KRKS' => array('name' => 'WY - Rock Springs, Rock Springs-Sweetwater County Airport', 'lat' => 41.594167, 'long' => -109.065278),
    'KSHR' => array('name' => 'WY - Sheridan, Sheridan County Airport', 'lat' => 44.769444, 'long' => -106.968889),
    'KSIB' => array('name' => 'WY - Sibley Peak', 'lat' => 42.450000, 'long' => -105.033333),
    'KTOR' => array('name' => 'WY - Torrington, Torrington Municipal Airport', 'lat' => 42.064722, 'long' => -104.152778),
    'KVDW' => array('name' => 'WY - Vedauwoo', 'lat' => 41.150000, 'long' => -105.400000),
    'KWRL' => array('name' => 'WY - Worland, Worland Municipal Airport', 'lat' => 43.965833, 'long' => -107.950833),
    'KP60' => array('name' => 'WY - Yellowstone Lake', 'lat' => 44.544444, 'long' => -110.421111),
  );

  $icao_codes['Uruguay'] = array(
    'SUAG' => array('name' => 'Artigas', 'lat' => -30.383333, 'long' => -56.500000),
    'SULS' => array('name' => 'Capitan Corbeta', 'lat' => -34.866667, 'long' => -55.100000),
    'SUMU' => array('name' => 'Carrasco', 'lat' => -34.833333, 'long' => -56.000000),
    'SUCA' => array('name' => 'Colonia', 'lat' => -34.450000, 'long' => -57.833333),
    'SUDU' => array('name' => 'Durazno', 'lat' => -33.350000, 'long' => -56.500000),
    'SUAA' => array('name' => 'Melilla', 'lat' => -34.783333, 'long' => -56.250000),
    'SUME' => array('name' => 'Mercedes', 'lat' => -33.250000, 'long' => -58.066667),
    'SUSO' => array('name' => 'Salto', 'lat' => -31.383333, 'long' => -57.950000),
  );

  $icao_codes['Uzbekistan'] = array(
    'UTNN' => array('name' => 'Nukus / Karakalpakstan', 'lat' => 42.480000, 'long' => 59.630000),
    'UTSS' => array('name' => 'Samarkand', 'lat' => 39.566667, 'long' => 66.950000),
    'UTTT' => array('name' => 'Tashkent', 'lat' => 41.266667, 'long' => 69.266667),
    'UTST' => array('name' => 'Termez', 'lat' => 37.233333, 'long' => 67.266667),
    'UTNU' => array('name' => 'Urgench', 'lat' => 41.583333, 'long' => 60.645000),
  );

  $icao_codes['Vanuatu'] = array(
    'NVVV' => array('name' => 'Bauerfield Efate', 'lat' => -17.700000, 'long' => 168.300000),
    'NVSL' => array('name' => 'Lamap Malekula', 'lat' => -16.416667, 'long' => 167.800000),
    'NVSS' => array('name' => 'Pekoa Airport Santo', 'lat' => -15.516667, 'long' => 167.216667),
    'NVSC' => array('name' => 'Sola Vanua Lava', 'lat' => -13.850000, 'long' => 167.550000),
  );

  $icao_codes['Venezuela'] = array(
    'SVAC' => array('name' => 'Acarigua', 'lat' => 9.550000, 'long' => -69.233333),
    'SVBC' => array('name' => 'Barcelona', 'lat' => 10.116667, 'long' => -64.683333),
    'SVBI' => array('name' => 'Barinas', 'lat' => 8.616667, 'long' => -70.216667),
    'SVBM' => array('name' => 'Barquisimeto', 'lat' => 10.066667, 'long' => -69.316667),
    'SVCL' => array('name' => 'Calabozo', 'lat' => 8.933333, 'long' => -67.416667),
    'SVMI' => array('name' => 'Caracas / Maiquetia Aerop. Intl. Simon Bolivar', 'lat' => 10.600000, 'long' => -66.983333),
    'SVCB' => array('name' => 'Ciudad Bolivar', 'lat' => 8.150000, 'long' => -63.550000),
    'SVCR' => array('name' => 'Coro', 'lat' => 11.416667, 'long' => -69.683333),
    'SVCU' => array('name' => 'Cumana', 'lat' => 10.450000, 'long' => -64.183333),
    'SVVG' => array('name' => 'El Vigia / Perez Alph', 'lat' => 8.633333, 'long' => -71.666667),
    'SVGU' => array('name' => 'Guanare', 'lat' => 9.016667, 'long' => -69.733333),
    'SVGD' => array('name' => 'Guasdualito', 'lat' => 7.233333, 'long' => -70.800000),
    'SVMC' => array('name' => 'Maracaibo-La Chinita', 'lat' => 10.566667, 'long' => -71.733333),
    'SVBS' => array('name' => 'Maracay-B. A. Sucre', 'lat' => 10.250000, 'long' => -67.650000),
    'SVMG' => array('name' => 'Margarita / Del Carib', 'lat' => 10.916667, 'long' => -63.983333),
    'SVMT' => array('name' => 'Maturin', 'lat' => 9.750000, 'long' => -63.183333),
    'SVMN' => array('name' => 'Mene Grande', 'lat' => 9.816667, 'long' => -70.933333),
    'SVMD' => array('name' => 'Merida', 'lat' => 8.600000, 'long' => -71.183333),
    'SVJC' => array('name' => 'Paraguana / Josefa', 'lat' => 11.783333, 'long' => -70.150000),
    'SVPM' => array('name' => 'Paramillo Private', 'lat' => 7.800000, 'long' => -72.200000),
    'SVPC' => array('name' => 'Pto. Cabello', 'lat' => 10.500000, 'long' => -68.000000),
    'SVPA' => array('name' => 'Puerto Ayacucho', 'lat' => 5.600000, 'long' => -67.500000),
    'SVSA' => array('name' => 'San Antonio Del Tachira', 'lat' => 7.850000, 'long' => -72.450000),
    'SVSR' => array('name' => 'San Fernando De Apure', 'lat' => 7.900000, 'long' => -67.416667),
    'SVJM' => array('name' => 'San Juan De Los Morros', 'lat' => 9.916667, 'long' => -67.333333),
    'SVSZ' => array('name' => 'Santa Barbara Zulia', 'lat' => 8.983333, 'long' => -71.950000),
    'SVSO' => array('name' => 'Sto. Domingo', 'lat' => 7.583333, 'long' => -72.066667),
    'SVVA' => array('name' => 'Valencia', 'lat' => 10.166667, 'long' => -67.933333),
    'SVVL' => array('name' => 'Valera', 'lat' => 9.350000, 'long' => -70.616667),
  );

  $icao_codes['Vietnam'] = array(
    'VVDN' => array('name' => 'Da Nang', 'lat' => 16.033333, 'long' => 108.183333),
    'VVNB' => array('name' => 'Ha Noi', 'lat' => 21.016667, 'long' => 105.800000),
    'VVTS' => array('name' => 'Ho Chi Minh', 'lat' => 10.816667, 'long' => 106.666667),
  );

  $icao_codes['Yemen'] = array(
    'OYAA' => array('name' => 'Aden', 'lat' => 12.666667, 'long' => 45.033333),
    'OYAT' => array('name' => 'Ataq', 'lat' => 14.516667, 'long' => 46.850000),
    'OYHD' => array('name' => 'Hodeidah', 'lat' => 14.750000, 'long' => 42.983333),
    'OYMB' => array('name' => 'Marib', 'lat' => 15.433333, 'long' => 45.333333),
    'OYSH' => array('name' => 'Sa\'Ada / Sadah', 'lat' => 16.966667, 'long' => 43.733333),
    'OYSN' => array('name' => 'Sana\'A', 'lat' => 15.516667, 'long' => 44.183333),
    'OYSY' => array('name' => 'Sayun', 'lat' => 15.966667, 'long' => 48.800000),
    'OYSQ' => array('name' => 'Socotra', 'lat' => 12.633333, 'long' => 53.900000),
    'OYTZ' => array('name' => 'Taiz', 'lat' => 13.683333, 'long' => 44.133333),
  );

  $icao_codes['Zambia'] = array(
    'FLLI' => array('name' => 'Livingstone', 'lat' => -17.816667, 'long' => 25.816667),
    'FLLS' => array('name' => 'Lusaka International Airport', 'lat' => -15.316667, 'long' => 28.450000),
    'FLMF' => array('name' => 'Mfuwe', 'lat' => -13.258889, 'long' => 31.936667),
    'FLND' => array('name' => 'Ndola', 'lat' => -13.000000, 'long' => 28.650000),
  );

  $icao_codes['Zimbabwe'] = array(
    'FVCZ' => array('name' => 'Buffalo Range', 'lat' => -21.016667, 'long' => 31.583333),
    'FVBU' => array('name' => 'Bulawayo Airport', 'lat' => -20.016667, 'long' => 28.616667),
    'FVTL' => array('name' => 'Gweru', 'lat' => -19.450000, 'long' => 29.850000),
    'FVHA' => array('name' => 'Harare Kutsaga', 'lat' => -17.916667, 'long' => 31.133333),
    'FVMV' => array('name' => 'Masvingo', 'lat' => -20.066667, 'long' => 30.866667),
  );

  return $icao_codes;
}
